#
# spec file for package systemd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
# The git repository used to track all Suse specific changes can be
# found at: https://github.com/openSUSE/systemd.
#

%define bootstrap 0
%define mini %nil
%define min_kernel_version 4.5
%define suse_version +suse.669.g080062ed5f

%bcond_with     gnuefi
%if 0%{?bootstrap}
%bcond_with     importd
%bcond_with     journal_remote
%bcond_with     machined
%bcond_with     networkd
%bcond_with     resolved
%bcond_with     sysvcompat
%else
%ifarch %{ix86} x86_64
%bcond_without  gnuefi
%endif
%bcond_without  importd
%bcond_without  journal_remote
%bcond_without  machined
%bcond_without  networkd
%bcond_with     resolved
%bcond_without  sysvcompat
%endif

Name:           systemd
URL:            http://www.freedesktop.org/wiki/Software/systemd
Version:        234
Release:        lp152.31.16.1
Summary:        A System and Session Manager
License:        LGPL-2.1-or-later
Group:          System/Base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if ! 0%{?bootstrap}
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  kbd
BuildRequires:  libapparmor-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libxslt-tools
%if %{with networkd}
BuildRequires:  polkit
%endif
# python is only required for generating systemd.directives.xml
BuildRequires:  python3
BuildRequires:  python3-lxml
BuildRequires:  pkgconfig(libcryptsetup) >= 1.6.0
BuildRequires:  pkgconfig(libdw) >= 0.158
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libselinux) >= 2.1.9
%ifarch aarch64 %ix86 x86_64 x32 %arm ppc64le s390x
BuildRequires:  pkgconfig(libseccomp) >= 2.3.1
%endif
%endif
BuildRequires:  fdupes
BuildRequires:  gperf
BuildRequires:  intltool
BuildRequires:  libacl-devel
BuildRequires:  libcap-devel
BuildRequires:  libmount-devel >= 2.27.1
BuildRequires:  libtool
BuildRequires:  pam-devel
# regenerate_initrd_post macro is expanded during build, hence this
# BR. Also this macro was introduced since version 12.4.
BuildRequires:  suse-module-tools >= 12.4
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(blkid) >= 2.26
BuildRequires:  pkgconfig(libkmod) >= 15
BuildRequires:  pkgconfig(libpci) >= 3
BuildRequires:  pkgconfig(libpcre)
%if %{with importd}
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
%endif
%if %{with journal_remote}
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmicrohttpd) >= 0.9.33
%endif
%if %{with gnuefi}
BuildRequires:  gnu-efi
%endif

%if 0%{?bootstrap}
#!BuildIgnore:  dbus-1
Requires:       this-is-only-for-build-envs
Provides:       systemd = %{version}-%{release}
%else
# the buildignore is important for bootstrapping
#!BuildIgnore:  udev
Requires:       dbus-1 >= 1.4.0
Requires:       kbd
Requires:       kmod >= 15
Requires:       netcfg >= 11.5
Requires:       systemd-presets-branding
Requires:       sysvinit-tools
Requires:       udev = %{version}-%{release}
Requires:       util-linux >= 2.27.1
Requires:       group(lock)
Recommends:     %{name}-bash-completion
Requires(post): coreutils
Requires(post): findutils
Requires(post): systemd-presets-branding
Requires(post): pam-config >= 0.79-5
%endif

%if 0%{?bootstrap}
Conflicts:      systemd
Conflicts:      kiwi
%endif
Conflicts:      sysvinit
Conflicts:      filesystem < 11.5
Conflicts:      mkinitrd < 2.7.0
Conflicts:      suse-module-tools < 15.0.1
Obsoletes:      systemd-analyze < 201
Provides:       systemd-analyze = %{version}
Obsoletes:      pm-utils <= 1.4.1
Obsoletes:      suspend <= 1.0
Source0:        systemd-v%{version}%{suse_version}.tar.xz
Source1:        %{name}-rpmlintrc
Source2:        systemd-user
Source3:        systemd-sysv-convert
Source6:        baselibs.conf
Source11:       after-local.service
Source12:       systemd-sysv-install
Source14:       kbd-model-map.legacy

Source100:      scripts-systemd-fix-machines-btrfs-subvol.sh
Source101:      scripts-systemd-upgrade-from-pre-210.sh
Source102:      scripts-systemd-migrate-sysconfig-i18n.sh
Source200:      scripts-udev-convert-lib-udev-path.sh

# Homeless rules sent (and maintained) by the kernel folks (see bsc#1040800)
Source2000:     80-acpi-container-hotplug.rules
Source2001:     99-wakeup-from-idle.rules
Source2002:     80-hotplug-cpu-mem.rules
Source2003:     60-io-scheduler.rules

# Patches listed in here are put in quarantine. Normally all
# changes must go to upstream first and then are cherry-picked in the
# SUSE git repository. But in very few cases, some stuff might be
# broken in upstream and need an urgent fix. Even in this case, the
# patches are temporary and should be removed as soon as a fix is
# merged by upstream.
Patch1:         0001-udev-don-t-create-by-partlabel-primary-and-.-logical.patch
Patch2:         0002-udev-optionally-disable-the-generation-of-the-partla.patch
Patch3:         0001-mount-swap-cryptsetup-introduce-an-option-to-prevent.patch

Patch200:       0010-core-accept-MemorySwapMax-properties-that-are-scaled.patch
Patch201:       0011-bus-unit-util-add-proper-MemorySwapMax-serialization.patch
Patch202:       0012-core-cgroup-accepts-MemorySwapMax-0-8366.patch
Patch203:       0013-cgroup-Support-0-value-for-memory-protection-directi.patch
Patch204:       0014-cgroup-Make-empty-assignments-reset-to-default.patch
Patch205:       0015-cgroup-Parse-infinity-properly-for-memory-protection.patch

%description
Systemd is a system and service manager, compatible with SysV and LSB
init scripts for Linux. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system state,
maintains mount and automount points and implements an elaborate
transactional dependency-based service control logic. It can work as a
drop-in replacement for sysvinit.

%package devel
Summary:        Development headers for systemd
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libsystemd0%{?mini} = %{version}-%{release}
Requires:       systemd-rpm-macros
%if 0%{?bootstrap}
Conflicts:      systemd-devel
%endif

%description devel
Development headers and auxiliary files for developing applications for systemd.

%package sysvinit
Summary:        System V init tools
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Provides:       sbin_init
Conflicts:      otherproviders(sbin_init)
Provides:       sysvinit:/sbin/init

%description sysvinit
Drop-in replacement of System V init tools.

%package -n libsystemd0%{?mini}
Summary:        Component library for systemd
License:        LGPL-2.1-or-later
Group:          System/Libraries
%if 0%{?bootstrap}
Conflicts:      libsystemd0
Requires:       this-is-only-for-build-envs
%endif

%description -n libsystemd0%{?mini}
This library provides several of the systemd C APIs:

* sd-bus implements an alternative D-Bus client library that is
  relatively easy to use, very efficient and supports both classic
  D-Bus as well as kdbus as transport backend.

* sd-daemon(3): for system services (daemons) to report their status
  to systemd and to make easy use of socket-based activation logic

* sd-event is a generic event loop abstraction that is built around
  Linux epoll, but adds features such as event prioritization or
  efficient timer handling.

* sd-id128(3): generation and processing of 128-bit IDs

* sd-journal(3): API to submit and query journal log entries

* sd-login(3): APIs to introspect and monitor seat, login session and
  user status information on the local system.

%package -n udev%{?mini}
Summary:        A rule-based device node and kernel event manager
License:        GPL-2.0-only
Group:          System/Kernel
URL:            http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev.html
Requires:       system-group-hardware
Requires(pre):  /usr/bin/stat
Requires(post): sed
Requires(post): /usr/bin/systemctl

Requires(post): coreutils
Requires(postun): coreutils

Conflicts:      systemd < 39
Conflicts:      aaa_base < 11.5
Conflicts:      filesystem < 11.5
Conflicts:      mkinitrd < 2.7.0
Conflicts:      dracut < 044.1
Conflicts:      util-linux < 2.16
Conflicts:      ConsoleKit < 0.4.1
Requires:       filesystem
%if 0%{?bootstrap}
Provides:       udev = %{version}
Conflicts:      libudev1
Conflicts:      udev
# avoid kiwi picking it for bootstrap
Requires:       this-is-only-for-build-envs
%endif

%description -n udev%{?mini}
Udev creates and removes device nodes in /dev for devices discovered or
removed from the system. It receives events via kernel netlink messages
and dispatches them according to rules in /lib/udev/rules.d/. Matching
rules may name a device node, create additional symlinks to the node,
call tools to initialize a device, or load needed kernel modules.

%package -n libudev%{?mini}1
Summary:        Dynamic library to access udev device information
License:        LGPL-2.1-or-later
Group:          System/Libraries
%if 0%{?bootstrap}
Conflicts:      libudev1
Conflicts:      kiwi
# avoid kiwi picking it for bootstrap
Requires:       this-is-only-for-build-envs
%endif

%description -n libudev%{?mini}1
This package contains the dynamic library libudev, which provides
access to udev device information

%package -n libudev%{?mini}-devel
Summary:        Development files for libudev
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Other
Requires:       libudev%{?mini}1 = %{version}-%{release}
%if 0%{?bootstrap}
Provides:       libudev-devel = %{version}
Conflicts:      libudev1 = %{version}
Conflicts:      libudev-devel
%endif

%description -n libudev%{?mini}-devel
This package contains the development files for the library libudev, a
dynamic library, which provides access to udev device information.

%package coredump%{mini}
Summary:        Systemd tools for coredump management
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
%systemd_requires
Provides:       systemd:%{_bindir}/coredumpctl
%if 0%{?bootstrap}
Conflicts:      systemd-coredump
%endif

%description coredump%{mini}
Systemd tools to store and manage coredumps.

This package contains systemd-coredump, coredumpctl.

%package container%{?mini}
Summary:        Systemd tools for container management
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
%systemd_requires
Provides:       systemd:%{_bindir}/systemd-nspawn
%if 0%{?bootstrap}
Conflicts:      systemd-container
%endif

%description container%{?mini}
Systemd tools to spawn and manage containers and virtual machines.

This package contains systemd-nspawn, machinectl, systemd-machined,
and systemd-importd.

%if %{with networkd} || %{with resolved}
%package network
Summary:        Systemd tools for networkd and resolved
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Provides:       systemd:/usr/lib/systemd/systemd-networkd
Provides:       systemd:/usr/lib/systemd/systemd-resolved
%systemd_requires

%description network
Systemd tools to manage network settings using networkd and
resolver tools for resolved
%endif

%if ! 0%{?bootstrap}
%package logger
Summary:        Journal only logging
License:        LGPL-2.1-or-later
Group:          System/Base
Provides:       syslog
Provides:       sysvinit(syslog)
Requires(post): /usr/bin/systemctl
Conflicts:      otherproviders(syslog)

%description logger
This package marks the installation to not use syslog but only the journal.

%package -n nss-systemd
Summary:        Plugin for local virtual host name resolution
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n nss-systemd
This package contains a plugin for the Name Service Switch (NSS),
which enables resolution of all dynamically allocated service
users. (See the DynamicUser= setting in unit files.)

To activate this NSS module, you will need to include it in
/etc/nsswitch.conf, see nss-systemd(8) manpage for more details.

%package -n nss-myhostname
Summary:        Plugin for local system host name resolution
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n nss-myhostname
This package contains a plug-in module for the Name Service Switch
(NSS), primarly providing hostname resolution for the locally
configured system hostname as returned by gethostname(2). For example,
it resolves the local hostname to locally configured IP addresses, as
well as "localhost" to 127.0.0.1/::1.

To activate this NSS module, you will need to include it in
/etc/nsswitch.conf, see nss-hostname(8) manpage for more details.
%endif

%if %{with resolved}
%package -n nss-resolve
Summary:        Plugin for local hostname resolution via systemd-resolved
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n nss-resolve
This package contains a plug-in module for the Name Service Switch
(NSS), which enables host name resolutions via the systemd-resolved(8)
local network name resolution service. It replaces the nss-dns plug-in
module that traditionally resolves hostnames via DNS.

To activate this NSS module, you will need to include it in
/etc/nsswitch.conf, see nss-resolve(8) manpage for more details.
%endif

%if %{with machined}
%package -n nss-mymachines
Summary:        Plugin for local virtual host name resolution
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n nss-mymachines
This package contains a plugin for the Name Service Switch (NSS),
providing host name resolution for all local containers and virtual
machines registered with systemd-machined to their respective IP
addresses. It also maps UID/GIDs ranges used by containers to useful
names.

To activate this NSS module, you will need to include it in
/etc/nsswitch.conf, see nss-mymachines(8) manpage for more details.
%endif

%if %{with journal_remote}
%package journal-remote
Summary:        Gateway for serving journal events over the network using HTTP
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description journal-remote
This extends the journal functionality to keep a copy of logs on a
remote server by providing programs to forward journal entries over
the network, using encrypted HTTP, and to write journal files from
serialized journal contents.

This package contains systemd-journal-gatewayd,
systemd-journal-remote, and systemd-journal-upload.
%endif

%package bash-completion
Summary:        Bash completion support for systemd
License:        LGPL-2.1-or-later
Group:          System/Base
Requires:       bash-completion
BuildArch:      noarch
%if 0%{?bootstrap}
Conflicts:      systemd-bash-completion
%endif

%description bash-completion
Some systemd commands offer bash completion, but it is an optional dependency.

%prep
%setup -q -n systemd-v%{version}%{suse_version}
%autopatch -p1

%build
%if 0%{?is_opensuse}
ntp_servers=({0..3}.opensuse.pool.ntp.org)
%else
ntp_servers=({0..3}.suse.pool.ntp.org)
%endif

./autogen.sh

# keep split-usr until all packages have moved their systemd rules to /usr
%configure \
        --docdir=%{_docdir}/systemd \
        --with-pamlibdir=/%{_lib}/security \
        --with-dbuspolicydir=%{_sysconfdir}/dbus-1/system.d \
        --with-dbussessionservicedir=%{_datadir}/dbus-1/services \
        --with-dbussystemservicedir=%{_datadir}/dbus-1/system-services \
        --with-certificate-root=%{_sysconfdir}/pki/systemd \
        --with-ntp-servers="${ntp_servers[*]}" \
%if 0%{?bootstrap}
        --disable-myhostname \
        --disable-manpages \
%endif
        --enable-split-usr \
        --disable-static \
        --disable-lto \
        --disable-tests \
        --without-kill-user-processes \
        --with-default-hierarchy=hybrid \
        --with-rc-local-script-path-start=/etc/init.d/boot.local \
        --with-rc-local-script-path-stop=/etc/init.d/halt.local \
        --with-debug-shell=/bin/bash \
        --disable-smack \
        --disable-ima \
        --disable-adm-group \
        --disable-wheel-group \
        --disable-ldconfig \
        --disable-gshadow \
%if %{without machined}
        --disable-machined \
%endif
%if %{without sysvcompat}
        --with-sysvinit-path= \
        --with-sysvrcnd-path= \
%endif
%if %{without journal_remote}
        --disable-remote \
%endif
%if %{without networkd}
        --disable-networkd \
%endif
%if %{without resolved}
        --disable-resolved \
%endif
        --disable-kdbus

%make_build V=e

%install
%make_install
find %{buildroot} -type f -name '*.la' -delete

# move to %{_lib}
%if ! 0%{?bootstrap}
mv %{buildroot}%{_libdir}/libnss_myhostname.so.2 %{buildroot}/%{_lib}
%else
rm %{buildroot}%{_libdir}/libnss_systemd.so*
%endif

# FIXME: these symlinks should die.
mkdir -p %{buildroot}/{sbin,lib,bin}
ln -sf %{_bindir}/udevadm %{buildroot}/sbin/udevadm
ln -sf %{_bindir}/systemd-ask-password %{buildroot}/bin/systemd-ask-password
ln -sf %{_bindir}/systemctl %{buildroot}/bin/systemctl
ln -sf %{_prefix}/lib/systemd/systemd-udevd %{buildroot}/sbin/udevd

install -m644 -D %{S:2000} %{buildroot}/%{_prefix}/lib/udev/rules.d/80-acpi-container-hotplug.rules
install -m644 -D %{S:2001} %{buildroot}/%{_prefix}/lib/udev/rules.d/99-wakeup-from-idle.rules
install -m644 -D %{S:2002} %{buildroot}/%{_prefix}/lib/udev/rules.d/80-hotplug-cpu-mem.rules
install -m644 -D %{S:2003} %{buildroot}/%{_prefix}/lib/udev/rules.d/60-io-scheduler.rules

mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/sysv-convert
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/migrated

install -m0755 -D %{S:3}  %{buildroot}/%{_sbindir}/systemd-sysv-convert
install -m0755 -D %{S:12} %{buildroot}/%{_prefix}/lib/systemd/systemd-sysv-install

# Package the scripts used to fix all packaging issues. Also drop the
# "scripts-{systemd/udev}" prefix which is used because osc doesn't
# allow directory structure...
for s in %{S:100} %{S:101} %{S:102}; do
	install -m0755 -D $s %{buildroot}%{_prefix}/lib/systemd/scripts/${s#*/scripts-systemd-}
done
for s in %{S:200}; do
	install -m0755 -D $s %{buildroot}%{_prefix}/lib/udev/scripts/${s#*/scripts-udev-}
done

ln -s ../usr/lib/systemd/systemd %{buildroot}/bin/systemd
ln -s ../usr/lib/systemd/systemd %{buildroot}/sbin/init
ln -s ../usr/bin/systemctl %{buildroot}/sbin/reboot
ln -s ../usr/bin/systemctl %{buildroot}/sbin/halt
ln -s ../usr/bin/systemctl %{buildroot}/sbin/shutdown
ln -s ../usr/bin/systemctl %{buildroot}/sbin/poweroff
ln -s ../usr/bin/systemctl %{buildroot}/sbin/telinit
ln -s ../usr/bin/systemctl %{buildroot}/sbin/runlevel
rm -rf %{buildroot}/etc/systemd/system/*.target.wants

# Make sure we don't ship static enablement symlinks in /etc during
# installation, presets should be honoured instead.
rm -rf %{buildroot}/etc/systemd/system/*.target.{requires,wants}
rm -f %{buildroot}/etc/systemd/system/default.target

# Overwrite /etc/pam.d/systemd-user shipped by upstream with one
# customized for openSUSE distros.
install -m0644 %{S:2} %{buildroot}%{_sysconfdir}/pam.d/

# Remove tmp.mount from the unit search path as /tmp doesn't use tmpfs
# by default on SUSE distros. We still keep a copy in /var for those
# who want to switch to tmpfs: it's still can be copied in /etc.
rm %{buildroot}/%{_unitdir}/local-fs.target.wants/tmp.mount
mv %{buildroot}/%{_unitdir}/tmp.mount %{buildroot}/%{_datadir}/systemd/

# don't enable wall ask password service, it spams every console (bnc#747783)
rm %{buildroot}%{_unitdir}/multi-user.target.wants/systemd-ask-password-wall.path

# Remove .so file for the shared library, it's not supposed to be
# used.
rm %{buildroot}%{_libexecdir}/systemd/libsystemd-shared.so

# do not ship sysctl defaults in systemd package, will be part of
# aaa_base (in procps for now)
rm -f %{buildroot}%{_prefix}/lib/sysctl.d/50-default.conf

# Make sure systemd-network polkit rules file starts with a suitable
# number prefix so it takes precedence over our polkit-default-privs.
%if %{with networkd}
mv %{buildroot}%{_datadir}/polkit-1/rules.d/systemd-networkd.rules \
        %{buildroot}%{_datadir}/polkit-1/rules.d/60-systemd-networkd.rules
%else
# A temporary workaround due to the fact that these files are
# unconditionnally installed by Makefile.am
rm -f %{buildroot}%{_prefix}/lib/systemd/network/80-container-host0.network \
      %{buildroot}%{_prefix}/lib/systemd/network/80-container-ve.network \
      %{buildroot}%{_prefix}/lib/systemd/network/80-container-vz.network
%endif

# since v207 /etc/sysctl.conf is no longer parsed (commit
# 04bf3c1a60d82791), however backward compatibility is provided by
# /usr/lib/sysctl.d/99-sysctl.conf.
ln -s ../../../etc/sysctl.conf %{buildroot}%{_sysctldir}/99-sysctl.conf

# The definition of the basic users/groups are defined by system-user
# on SUSE (bsc#1006978).
rm -f %{buildroot}%{_sysusersdir}/basic.conf

# Remove README file in init.d as (SUSE) rpm requires executable files
# in this directory... oh well.
rm -f %{buildroot}/etc/init.d/README

# legacy link
ln -s /usr/lib/udev %{buildroot}/lib/udev

# Create the /var/log/journal directory to change the volatile journal
# to a persistent one
mkdir -p %{buildroot}%{_localstatedir}/log/journal/

# This dir must be owned (and thus created) by systemd otherwise the
# build system will complain. This is odd since we simply own a ghost
# file in it...
mkdir -p %{buildroot}%{_sysconfdir}/X11/xorg.conf.d

# Make sure directories in /var exist
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/coredump
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/catalog
# Create ghost databases
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database
touch %{buildroot}%{_sysconfdir}/udev/hwdb.bin

# Make sure the NTP units dir exists
mkdir -p %{buildroot}%{_prefix}/lib/systemd/ntp-units.d/

# Make sure the shutdown/sleep drop-in dirs exist
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-shutdown/
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-sleep/

# Make sure these directories are properly owned
mkdir -p %{buildroot}%{_unitdir}/basic.target.wants
mkdir -p %{buildroot}%{_unitdir}/default.target.wants
mkdir -p %{buildroot}%{_unitdir}/dbus.target.wants
mkdir -p %{buildroot}%{_unitdir}/halt.target.wants
mkdir -p %{buildroot}%{_unitdir}/kexec.target.wants
mkdir -p %{buildroot}%{_unitdir}/poweroff.target.wants
mkdir -p %{buildroot}%{_unitdir}/reboot.target.wants
mkdir -p %{buildroot}%{_unitdir}/shutdown.target.wants

# Make sure the generator directories are created and properly owned.
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-generators
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-generators
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-preset

# create drop-in to prevent tty1 to be cleared (bnc#804158)
mkdir -p %{buildroot}%{_unitdir}/getty@tty1.service.d/
cat << EOF > %{buildroot}%{_unitdir}/getty@tty1.service.d/noclear.conf
[Service]
# ensure tty1 isn't cleared (bnc#804158)
TTYVTDisallocate=no
EOF

# create drop-in to prevent delegate=yes for root user (bsc#954765,
# bnc#953241, fate#320421)
mkdir -p %{buildroot}%{_unitdir}/user@0.service.d/
cat >%{buildroot}%{_unitdir}/user@0.service.d/nodelagate.conf <<EOF
[Service]
Delegate=no
EOF

# Remove TasksMax limit for both system services and users (jsc#SLE-10123)
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system.conf.d
cat >%{buildroot}%{_prefix}/lib/systemd/system.conf.d/20-suse-defaults.conf <<EOF
[Manager]
DefaultTasksMax=infinity
EOF

mkdir -p %{buildroot}%{_unitdir}/user-.slice.d
cat >%{buildroot}%{_unitdir}/user-.slice.d/20-suse-defaults.conf <<EOF
[Slice]
TasksMax=infinity
EOF

# ensure after.local wrapper is called
install -m 644 %{S:11} %{buildroot}/%{_unitdir}/
ln -s ../after-local.service %{buildroot}/%{_unitdir}/multi-user.target.wants/

# ghost directories with default permissions.
mkdir -p %{buildroot}%{_localstatedir}/lib/systemd/backlight

# ghost files with default permisssions.
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
touch %{buildroot}%{_sysconfdir}/vconsole.conf
touch %{buildroot}%{_sysconfdir}/locale.conf
touch %{buildroot}%{_sysconfdir}/machine-info
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database
touch %{buildroot}%{_localstatedir}/lib/systemd/i18n-migrated

%fdupes -s %{buildroot}%{_mandir}

# packaged in systemd-rpm-macros
rm -f %{buildroot}/%{_prefix}/lib/rpm/macros.d/macros.systemd

# Make sure to disable all services by default. The Suse branding
# presets package takes care of defining the right policies.
rm -f %{buildroot}%{_prefix}/lib/systemd/system-preset/*.preset
echo 'disable *' >%{buildroot}%{_prefix}/lib/systemd/system-preset/99-default.preset
echo 'disable *' >%{buildroot}%{_prefix}/lib/systemd/user-preset/99-default.preset

# Add entries for xkeyboard-config converted keymaps; mappings, which
# already exist in original systemd mapping table are being ignored
# though, i.e. not overwritten; needed as long as YaST uses console
# keymaps internally and calls localectl to convert from vconsole to
# X11 keymaps. Ideally YaST should switch to X11 layout names (the
# mapping table wouldn't be needed since each X11 keymap has a
# generated xkbd keymap) and let localectl initialize
# /etc/vconsole.conf and /etc/X11/xorg.conf.d/00-keyboard.conf
# (FATE#319454).
if [ -f /usr/share/systemd/kbd-model-map.xkb-generated ]; then
        cat /usr/share/systemd/kbd-model-map.xkb-generated \
                >>%{buildroot}%{_datarootdir}/systemd/kbd-model-map
fi

# kbd-model-map.legacy is used to provide mapping for legacy keymaps,
# which may still be used by yast.
cat %{S:14} >>%{buildroot}%{_datarootdir}/systemd/kbd-model-map

%find_lang systemd

%pre
# Build of installation images uses an hard coded list of some
# packages with a %pre that needs to be run during the
# build. Unfortunately, systemd in one of them so we need to keep this
# section even if it's empty.
if [ $1 -gt 1 ] ; then
        case "$(systemctl show -pFragmentPath tmp.mount)" in
        FragmentPath=/usr/lib/systemd/system/tmp.mount)
                ln -sf %{_datadir}/systemd/tmp.mount /etc/systemd/system/ || :
        esac
fi

%post
# Make /etc/machine-id an empty file during package installation. On
# the first boot, machine-id is initialized and either committed (if
# /etc/ is writable) or the system/image runs with a transient machine
# ID, that changes on each boot (if the image is read-only). This is
# especially important for appliance builds to avoid an identical
# machine ID in all images.
if [ $1 -eq 1 ]; then
	touch     %{_sysconfdir}/machine-id
	chmod 444 %{_sysconfdir}/machine-id
fi

# /etc/machine-id might have been created writeable incorrectly
# (boo#1092269).
if [ "$(stat -c%a %{_sysconfdir}/machine-id)" != 444 ]; then
        echo "Incorrect file mode bits for /etc/machine-id which should be 0444, fixing..."
        chmod 444 %{_sysconfdir}/machine-id
fi

%sysusers_create /usr/lib/sysusers.d/systemd.conf
%if ! 0%{?bootstrap}
pam-config -a --systemd || :
%endif
[ -e %{_localstatedir}/lib/random-seed ] && mv %{_localstatedir}/lib/random-seed %{_localstatedir}/lib/systemd/ || :
/usr/lib/systemd/systemd-random-seed save || :

if [ $1 -gt 1 ]; then
        systemctl daemon-reexec || :
fi

%journal_catalog_update
%tmpfiles_create

# Create default config in /etc at first install.
# Later package updates should not overwrite these settings.
if [ $1 -eq 1 ]; then
        # Enable systemd services according to the distro defaults.
        # Note: systemctl might abort prematurely if it fails on one
        # unit.
        systemctl preset machines.target  || :
        systemctl preset remote-fs.target || :
        systemctl preset remote-cryptsetup.target || :
        systemctl preset getty@.service   || :
        systemctl preset systemd-timesyncd.service || :
fi >/dev/null

# v228 wrongly set world writable suid root permissions on timestamp
# files used by permanent timers. Fix the timestamps that might have
# been created by the affected versions of systemd (bsc#1020601).
for stamp in $(ls /var/lib/systemd/timers/stamp-*.timer 2>/dev/null); do
        chmod 0644 $stamp
done

# Same for user lingering created by logind.
for username in $(ls /var/lib/systemd/linger/* 2>/dev/null); do
        chmod 0644 $username
done

# This includes all hacks needed when upgrading from SysV.
%{_prefix}/lib/systemd/scripts/upgrade-from-pre-210.sh || :

# Migrate the i18n settings that could be previously configured in
# /etc/sysconfig but now defined in the systemd official places
# (/etc/locale.conf, /etc/vconsole.conf, etc...). This is done only
# once during either installation or update. It's done during package
# installation because of migration from SLE11.
%{_prefix}/lib/systemd/scripts/migrate-sysconfig-i18n.sh || :

%postun
%systemd_postun
# Avoid restarting logind until fixed upstream (issue #1163)
%systemd_postun_with_restart systemd-journald.service
%systemd_postun_with_restart systemd-timesyncd.service

%pre -n udev%{?mini}
# New installations uses the last compat symlink generation number
# (currently at 2), which basically disables all compat symlinks. On
# old systems, the file doesn't exist. This is equivalent to
# generation #1, which enables the creation of all compat symlinks.
if [ $1 -eq 1 ]; then
	echo "COMPAT_SYMLINK_GENERATION=2">/usr/lib/udev/compat-symlink-generation
fi

%post -n udev%{?mini}
%regenerate_initrd_post
%udev_hwdb_update

# add KERNEL name match to existing persistent net rules
sed -ri '/KERNEL/ ! { s/NAME="(eth|wlan|ath)([0-9]+)"/KERNEL=="\1*", NAME="\1\2"/}' \
    /etc/udev/rules.d/70-persistent-net.rules 2>/dev/null || :

# cleanup old stuff
rm -f /etc/sysconfig/udev
rm -f /etc/udev/rules.d/{20,55,65}-cdrom.rules

%postun -n udev%{?mini}
%regenerate_initrd_post
systemctl daemon-reload || :
# On package update: the restart of the socket units will probably
# fail as the daemon is most likely running. It's not really an issue
# since we restart systemd-udevd right after and that will pull in the
# socket units again. We should be informed at that time if something
# really went wrong the first time we started the socket units.
%systemd_postun_with_restart systemd-udevd-{control,kernel}.socket 2>/dev/null
%systemd_postun_with_restart systemd-udevd.service

%posttrans -n udev%{?mini}
%regenerate_initrd_posttrans
%{_prefix}/lib/udev/scripts/convert-lib-udev-path.sh || :

%post -n libudev%{?mini}1 -p /sbin/ldconfig
%post -n libsystemd0%{?mini} -p /sbin/ldconfig

%postun -n libudev%{?mini}1 -p /sbin/ldconfig
%postun -n libsystemd0%{?mini} -p /sbin/ldconfig

%post container%{?mini}
%tmpfiles_create systemd-nspawn.conf
if [ $1 -gt 1 ]; then
	# Convert /var/lib/machines subvolume to make it suitable for
	# rollbacks, if needed. See bsc#992573. The installer has been fixed
	# to create it at installation time.
	#
	# The convertion might only be problematic for openSUSE distros
	# (TW/Factory) where previous versions had already created the
	# subvolume at the wrong place (via tmpfiles for example) and user
	# started to populate and use it. In this case we'll let the user fix
	# it manually.
	#
	# For SLE12 this subvolume was only introduced during the upgrade from
	# v210 to v228 when we added this workaround. Note that the subvolume
	# is still created at the wrong place due to the call to
	# tmpfiles_create macro previously however it's empty so there
	# shouldn't be any issues.
	%{_prefix}/lib/systemd/scripts/fix-machines-btrfs-subvol.sh || :
fi

%if ! 0%{?bootstrap}
%post logger
%tmpfiles_create -- --prefix=%{_localstatedir}/log/journal/
if [ "$1" -eq 1 ]; then
        # tell journal to start logging on disk if directory didn't exist before
        systemctl --no-block restart systemd-journal-flush.service >/dev/null || :
fi

%post   -n nss-myhostname -p /sbin/ldconfig
%postun -n nss-myhostname -p /sbin/ldconfig

%post   -n nss-systemd -p /sbin/ldconfig
%postun -n nss-systemd -p /sbin/ldconfig
%endif

%if %{with networkd} || %{with resolved}
%pre network
%if %{with networkd}
%service_add_pre systemd-networkd.service
%service_add_pre systemd-networkd-wait-online.service
%endif
%if %{with resolved}
%service_add_pre systemd-resolved.service
%endif

%post network
%if %{with networkd}
%service_add_post systemd-networkd.service
%service_add_post systemd-networkd-wait-online.service
%endif
%if %{with resolved}
%service_add_post systemd-resolved.service
%endif

%preun network
%if %{with networkd}
%service_del_preun systemd-networkd.service
%service_del_preun systemd-networkd-wait-online.service
%endif
%if %{with resolved}
%service_del_preun systemd-resolved.service
%endif

%postun network
%if %{with networkd}
%service_del_postun systemd-networkd.service
%service_del_postun systemd-networkd-wait-online.service
%endif
%if %{with resolved}
%service_del_postun systemd-resolved.service
%endif
%endif

%if %{with resolved}
%post   -n nss-resolve -p /sbin/ldconfig
%postun -n nss-resolve -p /sbin/ldconfig
%endif

%if %{with machined}
%post   -n nss-mymachines -p /sbin/ldconfig
%postun -n nss-mymachines -p /sbin/ldconfig
%endif

%if %{with journal_remote}
%pre journal-remote
%service_add_pre systemd-journal-gatewayd.socket systemd-journal-gatewayd.service
%service_add_pre systemd-journal-remote.socket systemd-journal-remote.service
%service_add_pre systemd-journal-upload.service

%post journal-remote
%sysusers_create %{_sysusersdir}/systemd-remote.conf
%tmpfiles_create %{_tmpfilesdir}/systemd-remote.conf
%service_add_post systemd-journal-gatewayd.socket systemd-journal-gatewayd.service
%service_add_post systemd-journal-remote.socket systemd-journal-remote.service
%service_add_post systemd-journal-upload.service

%preun  journal-remote
%service_del_preun systemd-journal-gatewayd.socket systemd-journal-gatewayd.service
%service_del_preun systemd-journal-remote.socket systemd-journal-remote.service
%service_del_preun systemd-journal-upload.service

%postun journal-remote
%service_del_postun systemd-journal-gatewayd.socket systemd-journal-gatewayd.service
%service_del_postun systemd-journal-remote.socket systemd-journal-remote.service
%service_del_postun systemd-journal-upload.service
%endif

%clean

%files -f systemd.lang
%defattr(-,root,root)
/bin/systemd
/bin/systemd-ask-password
/bin/systemctl
%{_bindir}/busctl
%{_bindir}/bootctl
%{_bindir}/kernel-install
%{_bindir}/hostnamectl
%{_bindir}/localectl
%{_bindir}/systemctl
%{_bindir}/systemd-analyze
%{_bindir}/systemd-delta
%{_bindir}/systemd-escape
%{_bindir}/systemd-firstboot
%{_bindir}/systemd-path
%{_bindir}/systemd-sysusers
%{_bindir}/systemd-mount
%{_bindir}/systemd-umount
%{_bindir}/systemd-notify
%{_bindir}/systemd-run
%{_bindir}/journalctl
%{_bindir}/systemd-ask-password
%{_bindir}/loginctl
%{_bindir}/systemd-inhibit
%{_bindir}/systemd-tty-ask-password-agent
%{_bindir}/systemd-tmpfiles
%{_bindir}/systemd-machine-id-setup
%{_bindir}/systemd-socket-activate
%{_bindir}/systemd-stdio-bridge
%{_bindir}/systemd-detect-virt
%{_bindir}/timedatectl
%{_sbindir}/systemd-sysv-convert
%{_bindir}/systemd-cgls
%{_bindir}/systemd-cgtop
%{_bindir}/systemd-cat
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/50-depmod.install
%{_prefix}/lib/kernel/install.d/90-loaderentry.install
%dir %{_prefix}/lib/systemd
%dir %{_prefix}/lib/systemd/user
%dir %{_prefix}/lib/systemd/system
%dir %{_prefix}/lib/systemd/network
%if %{with journal_remote}
%exclude %{_prefix}/lib/systemd/systemd-journal-gatewayd
%exclude %{_prefix}/lib/systemd/systemd-journal-remote
%exclude %{_prefix}/lib/systemd/systemd-journal-upload
%exclude %{_unitdir}/systemd-journal-gatewayd.*
%exclude %{_unitdir}/systemd-journal-remote.*
%exclude %{_unitdir}/systemd-journal-upload.*
%endif
%exclude %{_prefix}/lib/systemd/systemd-coredump
%exclude %{_prefix}/lib/systemd/systemd-udevd
%exclude %{_unitdir}/systemd-udev*.*
%exclude %{_unitdir}/*.target.wants/systemd-udev*.*
%exclude %{_unitdir}/initrd-udevadm-cleanup-db.service
%exclude %{_unitdir}/systemd-nspawn@.service
%exclude %{_unitdir}/systemd-coredump*
%exclude %{_unitdir}/sockets.target.wants/systemd-coredump.socket
%if %{with machined}
%exclude %{_prefix}/lib/systemd/systemd-machined
%exclude %{_unitdir}/systemd-machined.service
%exclude %{_unitdir}/dbus-org.freedesktop.machine1.service
%exclude %{_unitdir}/var-lib-machines.mount
%exclude %{_unitdir}/machine.slice
%exclude %{_unitdir}/machines.target.wants
%exclude %{_unitdir}/*.target.wants/var-lib-machines.mount
%endif
%if %{with importd}
%exclude %{_prefix}/lib/systemd/systemd-import*
%exclude %{_prefix}/lib/systemd/systemd-pull
%exclude %{_prefix}/lib/systemd/import-pubring.gpg
%exclude %{_unitdir}/systemd-importd.service
%exclude %{_unitdir}/dbus-org.freedesktop.import1.service
%endif
%if %{with networkd}
%exclude %{_prefix}/lib/systemd/systemd-networkd
%exclude %{_prefix}/lib/systemd/systemd-networkd-wait-online
%exclude %{_unitdir}/systemd-networkd.service
%exclude %{_unitdir}/systemd-networkd.socket
%exclude %{_unitdir}/systemd-networkd-wait-online.service
%if %{with resolved}
%exclude %{_bindir}/systemd-resolve
%exclude %{_prefix}/lib/systemd/systemd-resolved
%exclude %{_unitdir}/systemd-resolved.service
%endif
%endif

%{_prefix}/lib/systemd/system.conf.d
%{_unitdir}/*.automount
%{_unitdir}/*.service
%{_unitdir}/*.slice
%{_unitdir}/*.target
%{_unitdir}/*.mount
%{_unitdir}/*.timer
%{_unitdir}/*.socket
%{_unitdir}/*.wants
%{_unitdir}/*.path
%{_unitdir}/user-.slice.d/
%{_prefix}/lib/systemd/user/*.target
%{_prefix}/lib/systemd/user/*.service
%{_prefix}/lib/systemd/systemd-*
%{_prefix}/lib/systemd/systemd
%{_prefix}/lib/systemd/libsystemd-shared-*.so
%{_prefix}/lib/systemd/scripts
%exclude %{_prefix}/lib/systemd/scripts/fix-machines-btrfs-subvol.sh
%dir %{_prefix}/lib/systemd/catalog
%{_prefix}/lib/systemd/catalog/systemd.catalog
%{_prefix}/lib/systemd/catalog/systemd.*.catalog
%{_prefix}/lib/systemd/system-preset
%{_prefix}/lib/systemd/user-preset
%{_prefix}/lib/systemd/system-generators
%{_prefix}/lib/systemd/user-generators
%{_prefix}/lib/systemd/user-environment-generators
%dir %{_prefix}/lib/systemd/ntp-units.d/
%dir %{_prefix}/lib/systemd/system-shutdown/
%dir %{_prefix}/lib/systemd/system-sleep/
%dir %{_unitdir}/getty@tty1.service.d
%dir %{_unitdir}/user@0.service.d
%{_unitdir}/getty@tty1.service.d/noclear.conf
%{_unitdir}/user@0.service.d/nodelagate.conf
/%{_lib}/security/pam_systemd.so

%if %{with gnuefi}
%dir %{_prefix}/lib/systemd/boot
%dir %{_prefix}/lib/systemd/boot/efi
%{_prefix}/lib/systemd/boot/efi/*.efi
%{_prefix}/lib/systemd/boot/efi/*.stub
%endif

%dir %{_libexecdir}/modules-load.d
%dir %{_sysconfdir}/modules-load.d

%dir %{_sysusersdir}
%{_sysusersdir}/systemd.conf

%dir %{_sysconfdir}/tmpfiles.d
%{_tmpfilesdir}/
%exclude %{_tmpfilesdir}/systemd-nspawn.conf
%if %{with journal_remote}
%exclude %{_tmpfilesdir}/systemd-remote.conf
%endif

%{_libexecdir}/environment.d/

%dir %{_libexecdir}/binfmt.d
%dir %{_sysconfdir}/binfmt.d

%dir %{_libexecdir}/sysctl.d
%dir %{_sysconfdir}/sysctl.d
%{_sysctldir}/99-sysctl.conf

%dir %{_sysconfdir}/X11/xinit
%dir %{_sysconfdir}/X11/xinit/xinitrc.d
%dir %{_sysconfdir}/X11/xorg.conf.d
%dir %{_sysconfdir}/dbus-1
%dir %{_sysconfdir}/dbus-1/system.d
%dir %{_sysconfdir}/systemd
%dir %{_sysconfdir}/systemd/network
%dir %{_sysconfdir}/systemd/system
%dir %{_sysconfdir}/systemd/user
%dir %{_sysconfdir}/xdg/systemd
%{_sysconfdir}/xdg/systemd/user
%{_sysconfdir}/X11/xinit/xinitrc.d/50-systemd-user.sh

%config(noreplace) %{_sysconfdir}/pam.d/systemd-user
%config(noreplace) %{_sysconfdir}/systemd/timesyncd.conf
%config(noreplace) %{_sysconfdir}/systemd/system.conf
%config(noreplace) %{_sysconfdir}/systemd/logind.conf
%config(noreplace) %{_sysconfdir}/systemd/journald.conf
%config(noreplace) %{_sysconfdir}/systemd/user.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.locale1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.login1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.systemd1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.hostname1.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.timedate1.conf

# Some files created by us.
%ghost %config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
%ghost %config(noreplace) %{_sysconfdir}/vconsole.conf
%ghost %config(noreplace) %{_sysconfdir}/locale.conf
%ghost %config(noreplace) %{_sysconfdir}/machine-info
%ghost %attr(0444,root,root) %config(noreplace) %{_sysconfdir}/machine-id

%{_datadir}/systemd
%{_datadir}/factory

%if %{with journal_remote}
%exclude %{_datadir}/systemd/gatewayd
%endif

%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%dir %{_datadir}/dbus-1/system-services
%{_datadir}/dbus-1/services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.locale1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.login1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.hostname1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.timedate1.service

%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.freedesktop.systemd1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.hostname1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.locale1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.timedate1.policy
%{_datadir}/polkit-1/actions/org.freedesktop.login1.policy

%if ! 0%{?bootstrap}
%{_mandir}/man1/[a-rt-z]*ctl.1*
%{_mandir}/man1/systemc*.1*
%{_mandir}/man1/systemd*.1*
%{_mandir}/man5/[a-tv-z]*
%{_mandir}/man5/user*
%{_mandir}/man7/[bdfks]*
%{_mandir}/man8/kern*
%{_mandir}/man8/pam_*
%{_mandir}/man8/systemd-[a-gik-tv]*
%{_mandir}/man8/systemd-h[aioy]*
%{_mandir}/man8/systemd-journald*
%{_mandir}/man8/systemd-u[ps]*
%{_mandir}/man8/30-systemd-environment-d-generator.*
%exclude %{_mandir}/man1/coredumpctl*
%exclude %{_mandir}/man5/coredump.conf*
%exclude %{_mandir}/man8/systemd-coredump*
%exclude %{_mandir}/man*/*nspawn*
%if %{with machined}
%exclude %{_mandir}/man*/machinectl*
%exclude %{_mandir}/man*/systemd-machined*
%endif
%if %{with importd}
%exclude %{_mandir}/man*/systemd-importd*
%endif
%if %{with journal_remote}
%exclude %{_mandir}/man5/journal-remote.conf*
%exclude %{_mandir}/man5/journal-upload.conf*
%endif
%endif
%{_docdir}/systemd

%{_prefix}/lib/udev/rules.d/70-uaccess.rules
%{_prefix}/lib/udev/rules.d/71-seat.rules
%{_prefix}/lib/udev/rules.d/73-seat-late.rules
%{_prefix}/lib/udev/rules.d/99-systemd.rules
%dir %{_localstatedir}/lib/systemd
%dir %{_localstatedir}/lib/systemd/sysv-convert
%dir %{_localstatedir}/lib/systemd/migrated
%dir %{_localstatedir}/lib/systemd/catalog
%ghost %{_localstatedir}/lib/systemd/catalog/database
%ghost %{_localstatedir}/lib/systemd/backlight
%ghost %{_localstatedir}/lib/systemd/i18n-migrated
%ghost %attr(0600,root,root) %{_localstatedir}/lib/systemd/random-seed
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/*
%{_datadir}/pkgconfig/systemd.pc

%files devel
%defattr(-,root,root,-)
%{_libdir}/libsystemd.so
%{_libdir}/pkgconfig/libsystemd.pc
%{_includedir}/systemd/
%if ! 0%{?bootstrap}
%{_mandir}/man3/SD*.3*
%{_mandir}/man3/sd*.3*
%endif

%files sysvinit
%defattr(-,root,root,-)
/sbin/init
/sbin/reboot
/sbin/halt
/sbin/shutdown
/sbin/poweroff
/sbin/telinit
/sbin/runlevel
%if ! 0%{?bootstrap}
%{_mandir}/man1/init.1*
%{_mandir}/man8/halt.8*
%{_mandir}/man8/reboot.8*
%{_mandir}/man8/shutdown.8*
%{_mandir}/man8/poweroff.8*
%{_mandir}/man8/telinit.8*
%{_mandir}/man8/runlevel.8*
%endif

%files -n udev%{?mini}
%defattr(-,root,root)
/sbin/udevd
/sbin/udevadm
# keep for compatibility
%ghost /lib/udev
%{_bindir}/udevadm
%{_bindir}/systemd-hwdb
%dir %{_prefix}/lib/udev/
%{_prefix}/lib/udev/ata_id
%{_prefix}/lib/udev/path_id_compat
%{_prefix}/lib/udev/cdrom_id
%{_prefix}/lib/udev/collect
%{_prefix}/lib/udev/mtd_probe
%{_prefix}/lib/udev/scsi_id
%{_prefix}/lib/udev/v4l_id
%ghost %{_prefix}/lib/udev/compat-symlink-generation
%{_prefix}/lib/udev/rule_generator.functions
%{_prefix}/lib/udev/write_net_rules
%dir %{_prefix}/lib/udev/rules.d/
%exclude %{_prefix}/lib/udev/rules.d/70-uaccess.rules
%exclude %{_prefix}/lib/udev/rules.d/71-seat.rules
%exclude %{_prefix}/lib/udev/rules.d/73-seat-late.rules
%exclude %{_prefix}/lib/udev/rules.d/99-systemd.rules
%{_prefix}/lib/udev/rules.d/*.rules
%{_prefix}/lib/udev/hwdb.d/
%{_prefix}/lib/udev/scripts/
%dir %{_sysconfdir}/udev/
%dir %{_sysconfdir}/udev/rules.d/
%ghost %{_sysconfdir}/udev/hwdb.bin
%config(noreplace) %{_sysconfdir}/udev/udev.conf
%if ! 0%{?bootstrap}
%{_mandir}/man5/udev*
%{_mandir}/man7/hwdb*
%{_mandir}/man7/udev*
%{_mandir}/man8/systemd-hwdb*
%{_mandir}/man8/systemd-udev*
%{_mandir}/man8/udev*
%endif
%dir %{_prefix}/lib/systemd/system
%{_prefix}/lib/systemd/systemd-udevd
%{_unitdir}/systemd-udev*.service
%{_unitdir}/systemd-udevd*.socket
%{_unitdir}/initrd-udevadm-cleanup-db.service
%dir %{_unitdir}/sysinit.target.wants
%{_unitdir}/sysinit.target.wants/systemd-udev*.service
%dir %{_unitdir}/sockets.target.wants
%{_unitdir}/sockets.target.wants/systemd-udev*.socket
%{_prefix}/lib/systemd/network/99-default.link
%{_datadir}/pkgconfig/udev.pc

%files -n libsystemd0%{?mini}
%defattr(-,root,root)
%{_libdir}/libsystemd.so.*

%files -n libudev%{?mini}1
%defattr(-,root,root)
%{_libdir}/libudev.so.*

%files -n libudev%{?mini}-devel
%defattr(-,root,root)
%{_includedir}/libudev.h
%{_libdir}/libudev.so
%{_libdir}/pkgconfig/libudev.pc
%if ! 0%{?bootstrap}
%{_mandir}/man3/*udev*.3*
%endif

%files coredump%{?mini}
%defattr(-,root,root)
%{_bindir}/coredumpctl
%{_prefix}/lib/systemd/systemd-coredump
%{_unitdir}/systemd-coredump*
%{_unitdir}/sockets.target.wants/systemd-coredump.socket
%{_sysctldir}/50-coredump.conf
%config(noreplace) %{_sysconfdir}/systemd/coredump.conf
%dir %{_localstatedir}/lib/systemd/coredump
%if ! 0%{?bootstrap}
%{_mandir}/man1/coredumpctl*
%{_mandir}/man5/coredump.conf*
%{_mandir}/man8/systemd-coredump*
%endif

%files container%{?mini}
%defattr(-,root,root)
%{_bindir}/systemd-nspawn
%{_unitdir}/systemd-nspawn@.service
%{_tmpfilesdir}/systemd-nspawn.conf
%if %{with machined}
%{_bindir}/machinectl
%{_prefix}/lib/systemd/systemd-machined
%{_unitdir}/systemd-machined.service
%{_unitdir}/dbus-org.freedesktop.machine1.service
%{_unitdir}/var-lib-machines.mount
%{_unitdir}/machine.slice
%{_unitdir}/machines.target.wants
%{_unitdir}/*.target.wants/var-lib-machines.mount
%{_prefix}/lib/systemd/scripts/fix-machines-btrfs-subvol.sh
%{_datadir}/dbus-1/system-services/org.freedesktop.machine1.service
%{_datadir}/polkit-1/actions/org.freedesktop.machine1.policy
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.machine1.conf
%endif
%if %{with importd}
%{_prefix}/lib/systemd/systemd-import*
%{_prefix}/lib/systemd/systemd-pull
%{_prefix}/lib/systemd/import-pubring.gpg
%{_unitdir}/systemd-importd.service
%{_unitdir}/dbus-org.freedesktop.import1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.import1.service
%{_datadir}/polkit-1/actions/org.freedesktop.import1.policy
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.import1.conf
%endif
%if ! 0%{?bootstrap}
%{_mandir}/man*/*nspawn*
%if %{with machined}
%{_mandir}/man*/machinectl*
%{_mandir}/man*/systemd-machined*
%endif
%if %{with importd}
%{_mandir}/man*/systemd-importd*
%endif
%endif

%if %{with networkd} || %{with resolved}
%files network
%defattr(-,root,root)
%if %{with networkd}
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.network1.conf
%{_bindir}/networkctl
%{_datadir}/dbus-1/system-services/org.freedesktop.network1.service
%{_datadir}/polkit-1/rules.d/60-systemd-networkd.rules
%{_prefix}/lib/systemd/network/*.network
%{_prefix}/lib/systemd/systemd-networkd
%{_prefix}/lib/systemd/systemd-networkd-wait-online
%{_unitdir}/systemd-networkd.service
%{_unitdir}/systemd-networkd.socket
%{_unitdir}/systemd-networkd-wait-online.service
%endif
%if %{with resolved}
%{_bindir}/systemd-resolve
%{_prefix}/lib/systemd/systemd-resolved
%config(noreplace) %{_sysconfdir}/systemd/resolved.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.resolve1.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.resolve1.service
%{_prefix}/lib/systemd/resolv.conf
%{_unitdir}/systemd-resolved.service
%endif
%endif

%if ! 0%{?bootstrap}
%files logger
%defattr(-,root,root)
%dir %attr(2755,root,systemd-journal) %{_localstatedir}/log/journal/
%doc %{_localstatedir}/log/README

%files -n nss-myhostname
%defattr(-, root, root)
/%{_lib}/*nss_myhostname*
%{_mandir}/man8/libnss_myhostname.*
%{_mandir}/man8/nss-myhostname.*

%files -n nss-systemd
%defattr(-, root, root)
%{_libdir}/libnss_systemd.so*
%{_mandir}/man8/libnss_systemd.so.*
%{_mandir}/man8/nss-systemd.*
%endif

%if %{with resolved}
%files -n nss-resolve
%defattr(-, root, root)
%{_libdir}/libnss_resolve.so.2
%{_mandir}/man8/libnss_resolve.*
%{_mandir}/man8/nss-resolve.*
%endif

%if %{with machined}
%files -n nss-mymachines
%defattr(-,root,root)
%{_libdir}/libnss_mymachines.so*
%{_mandir}/man8/libnss_mymachines.*
%{_mandir}/man8/nss-mymachines.*
%endif

%if %{with journal_remote}
%files journal-remote
%defattr(-, root, root)
%config(noreplace) %{_sysconfdir}/systemd/journal-remote.conf
%config(noreplace) %{_sysconfdir}/systemd/journal-upload.conf
%{_unitdir}/systemd-journal-gatewayd.*
%{_unitdir}/systemd-journal-remote.*
%{_unitdir}/systemd-journal-upload.*
%{_prefix}/lib/systemd/systemd-journal-gatewayd
%{_prefix}/lib/systemd/systemd-journal-remote
%{_prefix}/lib/systemd/systemd-journal-upload
%{_sysusersdir}/systemd-remote.conf
%{_tmpfilesdir}/systemd-remote.conf
%{_mandir}/man5/journal-remote.conf*
%{_mandir}/man5/journal-upload.conf*
%{_mandir}/man8/systemd-journal-gatewayd.*
%{_mandir}/man8/systemd-journal-remote.*
%{_mandir}/man8/systemd-journal-upload.*
%{_datadir}/systemd/gatewayd
%endif

%files bash-completion
%defattr(-,root,root,-)
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/*

%changelog
* Wed Jan 13 2021 Franck Bui <fbui@suse.com>
- Import commit 080062ed5f90b8a4085a89f2ad30ee320fab27c9
  80e37dcacc busctl: add a timestamp to the output of the busctl monitor command (bsc#1180225)
  2ee6877bb3 core: make sure to restore the control command id, too
  d1b9949337 scope: on unified, make sure to unwatch all PIDs once they've been moved to the cgroup scope
  af5945c2f4 fileio: tweak write_string_stream_ts() to write out trailing \n in one go even if buffering is off
  a28c165efa fileio: write_string_stream_ts: check for file errors immediately
  dc122eb771 fileio: write_string_stream_ts: return errors from fputs and fputc
  14c89b1424 fileio: make write_string_stream() accept flags parameter
  2959e7dfe6 journal: do not trigger assertion when journal_file_close() get NULL (bsc#1179824)
  08db1ac361 cgroup: drastically simplify caching of cgroups members mask (bsc#1175458)
  bb59042ab4 cgroup: extend comment on what unit_release_cgroup() is for
  ead2955f65 cgroup: document what the various masks variables are used for
  805fe8ecdf cgroup: extend cg_mask_supported() comment a bit
  305806da38 cgroup: tweak log message, so that it doesn't claim we always enable controllers when we actually disable them
  d02ce63463 cgroup-util: disable buffering for cg_enable_everywhere() when writing to cgroup attributes
  b4e9893f5d cgroup-util: fix enabling of controllers (#8816)
  e7dd277c1b cgroup: propagate errors when we cannot open cgroup.subtree_control
  7c8f19714f cgroup-util: optimization — open subtree_control file only once for all controllers
  7999763781 cgroup: add explanatory comment
  2829342e7a cgroup: units that aren't loaded properly should not result in cgroup controllers being pulled in
  48a0d85047 cgroup: make unit_get_needs_bpf_firewall() static too
  888dc39134 cgroup: make some functions static
  6c0efa2f01 cgroup: suffix settings with "=" in log messages where appropriate
  e69d9927c6 cgroup: use structured initialization
  5174fb9622 core: fix message about detected memory hierarchy
  3b6443e1ee core: use safe_fclose() where we can
  906dcf1f6b udev: Fix sound.target dependency (bsc#1179363)
  2c9866d55a rules: enable hardware-related targets also for user instances
  127e546608 sd-event: fix delays assert brain-o (#17790)
  b98b6d230c core: serialize u->pids until the processes have been moved to the scope cgroup (bsc#1174436)
  2f50b9ecf1 time-util: treat /etc/localtime missing as UTC (bsc#1141597)
* Wed Oct 21 2020 Franck Bui <fbui@suse.com>
- Import commit cff0063e30f8cd06995810a4725bfb042191c472
  33f68e8062 build-sys: optionnally disable support of journal over the network (bsc#1177458)
  34d79e6216 ask-password: prevent buffer overrow when reading from keyring (bsc#1177510)
  36e567dc68 ask-password: add extra paranoid overflow check
  5dd29e9219 More polite passphrase prompt
  f922299b3c mount: don't propagate errors from mount_setup_unit() further up
- Rework the enablement of 'journal_remote' support to rely on the new
  build option --disable-remote. This allows to drop the workaround
  that consisted in cleaning journal-upload files and
  {sysusers.d,tmpfiles.d}/systemd-remote.conf manually when
  'journal_remote' support was disabled.
* Tue Oct 20 2020 Andreas Herrmann <aherrmann@suse.com>
- Remove mq-deadline selection from 60-io-scheduler.rules (bsc#1177490)
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Move journal-{remote,upload}.conf.5.gz man pages into systemd-journal_remote sub package
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Make sure {sysusers.d,tmpfiles.d}/systemd-remote.conf are not
  shipped with --without=journal_remote (bsc#1177458)
  These files were incorrectly packaged in the main package when
  systemd-journal_remote was disabled (autools build only affected).
* Mon Oct 19 2020 Franck Bui <fbui@suse.com>
- Make use of %%{_unitdir} and %%{_sysusersdir}
* Wed Oct  7 2020 Franck Bui <fbui@suse.com>
- Import commit ff3ecd97a4ef0f973d5e97f959ce042f12fab969
  2794bdf836 seccomp: shm{get,at,dt} now have their own numbers everywhere (bsc#1173422)
  99eff504a1 test-seccomp: log function names
  2355b45978 test-seccomp: add log messages when skipping tests
  0246b221d1 add false option for tests (#7778)
  2fba565329 basic/virt: Detect PowerVM hypervisor (bsc#1176800)
  3c43c83144 fs-util: suppress world-writable warnings if we read /dev/null
- Drop 0001-test-seccomp-add-log-messages-when-skipping-tests.patch
  Drop 0002-test-seccomp-log-function-names.patch
  Drop 0003-seccomp-shm-get-at-dt-now-have-their-own-numbers-eve.patch
  These patches have been imported in SUSE/v234 branch
* Fri Oct  2 2020 Franck Bui <fbui@suse.com>
- Import commit e72f953aa84be08beb97cb4a7630e51e01639377
  da944a39f8 udevadm: rename option '--log-priority' into '--log-level'
  64b89364ee udev: rename kernel option 'log_priority' into 'log_level'
  46d1536437 fstab-generator: add 'nofail' when  NFS 'bg' option is used (bsc#1176513)
* Wed Sep 16 2020 Franck Bui <fbui@suse.com>
- Fix bsc#1167471 bsc#1154935
  Add 0010-core-accept-MemorySwapMax-properties-that-are-scaled.patch
  Add 0011-bus-unit-util-add-proper-MemorySwapMax-serialization.patch
  Add 0012-core-cgroup-accepts-MemorySwapMax-0-8366.patch
  Add 0013-cgroup-Support-0-value-for-memory-protection-directi.patch
  Add 0014-cgroup-Make-empty-assignments-reset-to-default.patch
  Add 0015-cgroup-Parse-infinity-properly-for-memory-protection.patch
* Mon Sep 14 2020 Franck Bui <fbui@suse.com>
- Import commit 859d8235c2c2f0a2d160a0e9778f7e54d304a596 (bsc#1104902 bsc#1165502)
  It contains a patchset that backports user-runtime-dir@.service,
  which is improves latency and reliability when users log in/out
  repeatedly and quickly during a relative short period of time.
* Mon Aug  3 2020 Franck Bui <fbui@suse.com>
- Import commit 8bd880f8097b9bfc7e73262c18fbbac03b12e60f
  0509116a5d pid1: improve message when setting up namespace fails
  40510f1a7a execute: let's close glibc syslog channels too
  e22977f3b2 execute: normalize logging in execute.c
  ed52035555 execute: fix typo in error message (#6881)
  7f2feba719 execute: drop explicit log_open()/log_close() now that it is unnecessary
  dbc8525a68 execute: make use of the new logging mode in execute.c
  89d456e4c7 log: add a mode where we open the log fds for every single log message
  32cdae2fe6 log: let's make use of the fact that our functions return the negative error code for log_oom() too
  30a5b8d428 execute: downgrade a log message ERR → WARNING, since we proceed ignoring its result
  f52bed2823 execute: rework logging in setup_keyring() to include unit info
  91cbb68dec execute: improve and augment execution log messages
  These are simple commits that improve logging when PID1 fails at
  setting a namespace up when spawning a command specified by
  'Exec*='. This should help us track a hard to reproduce bug which
  prevent apache from reloading (bsc#1172824, bsc#1142733)
* Mon Aug  3 2020 Franck Bui <fbui@suse.com>
- Import commit 7525132a61f00e16566c9eb6ee7e139fcb7050cc
  85561b1819 vconsole-setup: downgrade log message when setting font fails on dummy console (bsc#1172195 bsc#1173539)
  0138e54629 cryptsetup: fix infinite timeout (#6486) (bsc#1158336)
  b2aa39af7d bpf: mount bpffs by default on boot (bsc#1146991)
  5adfe116ed man: explain precedence for options which take a list (#7010)
  392e0bb83f man: unify titling, fix description of precedence in sysusers.d(5)
  c45abe3a2f udev-event: fix timeout log messages
* Mon Jun 29 2020 Franck Bui <fbui@suse.com>
- Fix bsc#1173422
  Add 0001-test-seccomp-add-log-messages-when-skipping-tests.patch
  Add 0002-test-seccomp-log-function-names.patch
  Add 0003-seccomp-shm-get-at-dt-now-have-their-own-numbers-eve.patch
* Wed Jun 24 2020 Franck Bui <fbui@suse.com>
- migrate-sysconfig-i18n.sh: fix marker handling  (bsc#1173229)
  The marker is used to make sure the script is run only once. Instead
  of storing it in /usr, use /var which is more appropriate for such
  file.
  Also make it owned by systemd package.
* Tue Jun 23 2020 Franck Bui <fbui@suse.com>
- Fix inconsistent file modes for some ghost files (bsc#1173227)
  Ghost files are assumed by rpm to have mode 000 by default which is
  not consistent with file permissions set at runtime.
  Also /var/lib/systemd/random-seed was tracked wrongly as a
  directory.
  Also don't track (ghost) /etc/systemd/system/runlevel*.target
  aliases since we're not supposed to track units or aliases user
  might define/override.
* Tue Jun  2 2020 Franck Bui <fbui@suse.com>
- Import commit dca9b964628d1527a25d633f7728fe979f422358
  8c875b2d97 units: starting suspend.target should not fail when suspend is successful (#6678) (bsc#1172072)
  b7d5310937 core/mount: do not add Before=local-fs.target or remote-fs.target if nofail mount option is set
  2a0e7062ff mount: let mount_add_extras() take care of remote-fs.target deps (bsc#1169488)
  29c6b6b725 mount: set up local-fs.target/remote-fs.target deps in mount_add_default_dependencies() too
  20a35f0bf0 udev: rename the persistent link for ATA devices (bsc#1164538)
  7dea560956 shared/install: try harder to find enablement symlinks when disabling a unit (bsc#1157315)
  5a660c1d53 tmpfiles: remove unnecessary assert (bsc#1171145)
  2f86bc54bd test-engine: manager_free() was called too early
  cc5170fcef pid1: by default make user units inherit their umask from the user manager (bsc#1162698)
* Fri May 29 2020 Franck Bui <fbui@suse.com>
- Split off networkd and resolved into separate subpackage "network"
  Although resolved is still not built by default.
* Fri Apr 17 2020 Franck Bui <fbui@suse.com>
- Import commit ac52edce0f820ffefa5110b6fc4b03e35bf68d61
  96a7639970 udev/net-id: Fix check for address to keep interface names stable (#8458) (bsc#1168076)
  ce5953a877 login: use free_and_replace() and TAKE_PTR()
  e5190b4b51 logind: remove manager_start_slice()
  cdeb8d1a48 logind: use free_and_replace in one spot
  109aac4b67 logind: drop unnecessary braces
  9194610e7e systemd-mount: don't check for non-normalized WHAT for network FS (bsc#1165011)
  12b63cb73a systemd-mount: allow to specify an arbitrary string for arg_mount_what when vfs is used (bsc#1165011)
* Wed Mar 18 2020 Franck Bui <fbui@suse.com>
- Import commit 7c246f16a6358516a586629091375ee5d45739ec
  2205963ee2 manager: fix job mode when signalled to shutdown etc (bsc#1161262)
  e9b76da147 manager: remove fallback for user/exit.target
  fa4a1155e7 man: dbus method Manager.Exit() does not start exit.target
  dc0ec526f2 units: do not install rescue.target for alt-↑
  e3ba383bf8 Add %%j/%%J unit specifiers
* Tue Mar 10 2020 Andreas Herrmann <aherrmann@suse.com>
- Replace 60-ssd-scheduler.rules with 60-io-scheduler.rules from TW
  This adds support for I/O scheduler selection with blk-mq
  (bsc#1165579, bsc#1164717).
* Thu Mar  5 2020 Franck Bui <fbui@suse.com>
- Add 60-ssd-scheduler.rules
  This rules file which select the default IO scheduler for SSDs is
  being moved out from the git repo since this is not related to
  systemd or udev at all and is maintained by the kernel team.
* Thu Mar  5 2020 Franck Bui <fbui@suse.com>
- Import commit 7e52d0c21a0c895d4f0ae2319f1eb4f2246147ba
  eedd149d6c core: coldplug possible nop_job (bsc#1139459)
  09405f8eee Revert "udev: use 'deadline' IO scheduler for SSD disks"
  57cab4a328 Fix typo in function name
  f846231c1a polkit: when authorizing via PK let's re-resolve callback/userdata instead of caching it (bsc#1162108 CVE-2020-1712)
  f799fd5371 sd-bus: introduce API for re-enqueuing incoming messages
  8a0214f61d polkit: on async pk requests, re-validate action/details
* Thu Mar  5 2020 Franck Bui <fbui@suse.com>
- Drop 0001-core-coldplug-possible-nop_job.patch
  It's been imported in SUSE/v234 branch.
* Thu Mar  5 2020 Franck Bui <fbui@suse.com>
- Drop 0001-polkit-on-async-pk-requests-re-validate-action-detai.patch
  Drop 0002-sd-bus-introduce-API-for-re-enqueuing-incoming-messa.patch
  Drop 0003-polkit-when-authorizing-via-PK-let-s-re-resolve-call.patch
  They have been imported in SUSE/v234 branch.
* Tue Feb 18 2020 Franck Bui <fbui@suse.com>
- Remove TasksMax limit for both user and system slices (jsc#SLE-10123)
* Mon Feb 17 2020 Franck Bui <fbui@suse.com>
- Import commit 4695ebe0b91ec6a23ba9ea238e61a7348474fbc5
  Backport support of dash-truncated dropins.
  The new mechanism is used (since v239) to configure TasksMax limit
  for user slices and therefore is used to replace UserTasksMax=
  option in logind.conf as it's more flexible.
  The old option is still supported thanks to a generator that creates
  a dash-truncated dropin at boot. It also warns about the use of the
  old option. This will hopefully allow us to remove the support of
  UserTasksMax option in the next major version of SLE.
  ec0bddf1f4 logind: keep backward compatibility with UserTasksMax= in logind.conf
  7804fb95bd logind: move two functions to logind_core utility lib
  fb99d7bc4c login: fix typo in log message
  15a8ffa5cc Use a dash-truncated drop-in for user-%%j.slice configuration
  c5bf60565e man: document the new dash truncation drop-in directories
  38fb5d11cb test: add test for prefix unit loading
  7669c783e8 dropin: when looking for dropins for a unit, also look within "-" prefix unit dirs
  de1d19b8fb systemctl: fix indentation in output of "systemcl status" if there are multiple drop-in dirs
  5da4984f6f unit-name: add new unit_name_build_from_type() helper
  278643dc78 tests: skip tests when cg_pid_get_path fails (#7033)
  a77203d893 shared/dropin: improve error message
* Mon Feb 17 2020 Franck Bui <fbui@suse.com>
- Import commit d2826c2ca2eab2b9f6fc08ff2010faafd4c1b9f9
  Backport IP filtering feature (jsc#SLE-7743)
  e6b00a63dc main: when bumping RLIMIT_MEMLOCK, save the previous value to pass to children (bsc#1160595)
  b7b5a3ba5d main: introduce a define HIGH_RLIMIT_MEMLOCK similar to HIGH_RLIMIT_NOFILE
  61d77e2bda def: add a "high" limit for RLIMIT_NOFILE
  51a8b7fe9b core: bump mlock ulimit to 64Mb
  4a53ff678c Move warning about unsupported BPF firewall right before the firewall would be created
  f26201d72c core: refactor bpf firewall support into a pseudo-controller
  3c6af31da6 core: rename cgroup_queue → cgroup_realize_queue
  12ac94d9d4 cgroup: improve cg_mask_to_string a bit, and add tests for it
  6e049a2f46 unit: initialize bpf cgroup realization state properly
  cfbb2dfb1b cgroup: always invalidate "cpu" and "cpuacct" together
  55a0d5a690 main: bump RLIMIT_MEMLOCK for the root user substantially
  3c0ec7c460 bpf-firewall: always use log_unit_xyz() insteadof log_xyz()
  f8e7b8530a core: fix the check if CONFIG_CGROUP_BPF is on
  a3950086e4 tree-wide: avoid assignment of r just to use in a comparison
  92ad831159 Fix three uses of bogus errno value in logs (and returned value in one case)
  8f9b4436fa bpf: reset "extra" IP accounting counters when turning off IP accounting for a unit
  4edd970f68 bpf: rework how we keep track and attach cgroup bpf programs
  b6152deaa1 bpf-program: make bpf_program_load_kernel() idempotent
  49fa5c4f73 bpf: use BPF_F_ALLOW_MULTI flag if it is available
  089bac557e bpf-program: optionally take fd of program to detach
  aed6959d28 bpf: beef up bpf detection, check if BPF_F_ALLOW_MULTI is supported
  c548f48cb2 bpf: add new bpf.h header copy from 4.15 kernel
  54cc371347 bpf-firewall: fix warning text
  c08bb273ac ip-address-access: let's exit the loop after invalidating our entry a (#7803)
  3dc5591f72 bpf-firewall: actually invoke BPF_PROG_ATTACH to check whether cgroup/bpf is available
  c5f34b169e cgroup: drop unused parameter from function
  b519973b49 core: only warn about BPF/cgroup missing once per runtime (#7319)
  cbeb2f95ac run: also show IP traffic accounting data on "systemd-run --wait"
  3ff2299ccb core: improve dbus-cgroup error message
  2f0c48782e bpf-firewall: properly handle kernels where BPF cgroup is disabled but TRIE maps are enabled (#7298)
  867a8bf0d7 fix compile error on musl
  8d3314daf3 bpf: set BPF_F_ALLOW_OVERRIDE when attaching a cgroup program if Delegate=yes is set
  c6a029bcc0 cgroup: refuse to return accounting data if accounting isn't turned on
  33ef892f4b core: when coming back from reload/reexec, reapply all cgroup properties
  4bb809e720 core: serialize/deserialize IP accounting across daemon reload/reexec
  ec63d2a10c core: when creating the socket fds for a socket unit, join socket's cgroup first
  5efe9d8b24 socket-label: let's use IN_SET, so that we have to call socket_address_family() only once
  35bf6b235f core: warn loudly if IP firewalling is configured but not in effect
  e62a2ae266 Add test for eBPF firewall code
  d936dbdb8c ip-address-access: minimize IP address lists
  df69bcd8d5 core: support IP firewalling to be configured for transient units
  c03104bf21 cgroup: dump the newly added IP settings in the cgroup context
  693934ae53 man: document the new ip accounting and filting directives
  7a7b7f97d8 systemctl: report accounted network traffic in "systemctl status"
  3079fcd21c manager: hook up IP accounting defaults
  44e2578544 cgroup, unit, fragment parser: make use of new firewall functions
  61cff5ed0c Add firewall eBPF compiler
  3fabe4de90 cgroup: add fields to accommodate eBPF related details
  031f1b27f4 Add IP address address ACL representation and parser
  7f9545d053 Add abstraction model for BPF programs
  d44583412a build-sys: add new kernel bpf.h drop-in
  80842fbc20 in-addr-util: add new helper call in_addr_prefix_from_string_auto()
  f5909b1007 in-addr-util: prefix return parameters with ret_
  4de91e22b7 in-addr-util: be more systematic with naming our functions
  877cc03ac4 tests: when running a manager object in a test, migrate to private cgroup subroot first (#6576)
* Tue Feb  4 2020 Franck Bui <fbui@suse.com>
- Fix bsc#1162108 CVE-2020-1712
  Add 0001-polkit-on-async-pk-requests-re-validate-action-detai.patch
  Add 0002-sd-bus-introduce-API-for-re-enqueuing-incoming-messa.patch
  Add 0003-polkit-when-authorizing-via-PK-let-s-re-resolve-call.patch
* Mon Feb  3 2020 Franck Bui <fbui@suse.com>
- Use suse.pool.ntp.org server pool on SLE distros (jsc#SLE-7683)
* Mon Feb  3 2020 Franck Bui <fbui@suse.com>
- Import commit 938b0a2f966d2606cbb20f4bcce7509995aaa7dc
  1d7de5e8c2 libblkid: open device in nonblock mode. (bsc#1084671)
  87d18b8209 udev/cdrom_id: Do not open CD-rom in exclusive mode. (bsc#1154256)
  277ab600b0 bus_open leak sd_event_source when udevadm trigger。 (bsc#1161436 CVE-2019-20386)
  6558c318fc fileio: introduce read_full_virtual_file() for reading virtual files in sysfs, procfs (bsc#1133495 bsc#1159814)
  0c6fb31abb fileio: initialize errno to zero before we do fread()
  0baf4768d3 fileio: try to read one byte too much in read_full_stream()
  3226d763f7 logind: consider "greeter" sessions suitable as "display" sessions of a user (bsc#1158485)
  5aa70da60d logind: never elect a session that is stopping as display
* Fri Dec 13 2019 Franck Bui <fbui@suse.com>
- Import commit be5eeb6c7d0bbb8147ff894227140d3d21639aeb
  24fc1e1ff6 journal: include kmsg lines from the systemd process which exec()d us (#8078)
  b213992a3d udevd: don't use monitor after manager_exit()
  28998ada7d udevd: capitalize log messages in on_sigchld()
  6065eee5f8 udevd: merge conditions to decrease indentation
  d727a42d46 Revert "udevd: fix crash when workers time out after exit is signal caught"
  0e6ff3b3d1 core: fragments of masked units ought not be considered for NeedDaemonReload (#7060) (bsc#1156482)
  3523d5a0c8 udevd: fix crash when workers time out after exit is signal caught
  787b2f859f udevd: wait for workers to finish when exiting (bsc#1106383)
* Wed Nov 13 2019 Franck Bui <fbui@suse.com>
- Import commit 71778a1423b0f599ede9faa96d20add61d24db36
  98c082a6ca shell-completion: systemctl: do not list template units in {re,}start
  816d6111fc shell-completion: systemctl: pass current word to all list_unit*
  e8b40b6b10 bash-completion: systemctl: pass current partial unit to list-unit* (bsc#1155207)
  7cdab60839 bash-completion: systemctl: use systemctl --no-pager
  8844419dc8 bash-completion: also suggest template unit files
  6f0e7ca3d1 bash-completion: systemctl: add missing options and verbs
  4f4d2d4c1b bash-completion: use the first argument instead of the global variable (#6457)
  A bunch of commits which improves bash completion support. It only
  touches the shell completion and hence is pretty safe.
* Wed Nov 13 2019 Franck Bui <fbui@suse.com>
- Import commit cff9adac2f06cc0876dc905d5642d271b69e755d
  3f5a84b97c networkd: VXLan Make group and remote variable separate (bsc#1156213)
  9c4571d6b2 networkd: vxlan require Remote= to be a non multicast address (#8117) (bsc#1156213)
  7f1b579fc6 fs-util: let's avoid unnecessary strerror()
  49e51f69b5 fs-util: introduce inotify_add_watch_and_warn() helper
  454c094294 ask-password: improve log message when inotify limit is reached (bsc#1155574)
  012115b8dd shared/install: failing with -ELOOP can be due to the use of an alias in install_error() (bsc#1151377)
  caa9e284af man: alias names can't be used with enable command (bsc#1151377)
* Fri Nov  8 2019 Franck Bui <fbui@suse.com>
- No need to daemon-reexec at package installation time.
  During package installation PID1 is obviously not being run.
* Thu Nov  7 2019 Franck Bui <fbui@suse.com>
- Add 0001-mount-swap-cryptsetup-introduce-an-option-to-prevent.patch (jsc#SLE-7689)
* Mon Sep 30 2019 Franck Bui <fbui@suse.com>
- Add 0001-core-coldplug-possible-nop_job.patch
  This likely fixes bsc#1139459 but it's not been confirmed
  yet. That's the reason why it's been put in the quarantine area so
  we can mark this patch as a fix once it will be verified before
  merging it in our git repo. See https://github.com/systemd/systemd/pull/13124
  for a reproducer and the fix.
  In any cases it fixes a real bug that could be easily reproduced and
  the fix verified.
* Fri Sep 27 2019 Franck Bui <fbui@suse.com>
- Import commit 1b9a7a16f19285e04646b879a7ee932d677a13a6 (jsc#SLE-7687)
  2833eac013 man: add a note about _netdev usage
  61b562b76f units: replace remote-cryptsetup-pre.target with remote-fs-pre.target
  3731059465 units: add [Install] section to remote-cryptsetup.target
  06a3b90ac0 cryptsetup: ignore _netdev, since it is used in generator (#7282)
  52ff0e4815 cryptsetup-generator: use remote-cryptsetup.target when _netdev is present (jsc#SLE-7687)
  1fd79aece7 cryptsetup-generator: add a helper utility to create symlinks
  850cfa58c9 units: add remote-cryptsetup.target and remote-cryptsetup-pre.target
  a17ff04b54 man: add an explicit description of _netdev to systemd.mount(5)
  2cf21cc2af man: order fields alphabetically in crypttab(5)
  166efe2295 man: make crypttab(5) a bit easier to read
  2228e044f9 units: order cryptsetup-pre.target before cryptsetup.target
  853d13eb3c Fix reporting of enabled-runtime units
* Fri Sep 27 2019 Franck Bui <fbui@suse.com>
- Import commit 76231a9c1f76ab1e2b4b4a60a3333685f0c05793
  801458cee2 sd-bus: deal with cookie overruns (bsc#1150595)
  39d50c7395 rules: Add by-id symlinks for persistent memory (bsc#1140631)
* Thu Sep 19 2019 Martin Vidner <mvidner@suse.com>
- Allow YaST to select Iranian (Persian, Farsi) keyboard layout
  (bsc#1092920)
* Mon Aug 26 2019 Franck Bui <fbui@suse.com>
- Buildrequire polkit so /usr/share/polkit-1/rules.d subdir can be
  only owned by polkit (boo#1145023)
  Otherwise we need to own the directory (or rpmlink checking would
  complain that the dir has no owners) and make sure that the perms
  are in sync with the ones defined by polkit.
* Tue Jun 18 2019 Franck Bui <fbui@suse.com>
- Import commit 097c4e66dc457e3406fbf914bcf1966da93dcbb9
  76e278fe1f conf-parse: remove 4K line length limit (bsc#1137053)
  8538cad002 udevd: change the default value of udev.children-max (again) (bsc#1107617)
  2bb79d8bb5 meson: stop creating enablement symlinks in /etc during installation (sequel)
* Mon Jun 17 2019 Franck Bui <fbui@suse.com>
- Fix build for Leap 15+
* Tue Jun 11 2019 Franck Bui <fbui@suse.com>
- Make sure we don't ship any static enablement symlinks in /etc
  Those symlinks must only be created by the presets. There are no
  changes in practice since systemd/udev doesn't ship such symlinks in
  /etc but let's make sure no future changes will introduce new ones
  by mistake.
  It's been done in Factory since a while now.
* Fri May 10 2019 Franck Bui <fbui@suse.com>
- Import commit 835729c9d137d8c79e575d61b0d1a1c67cc54e59
  62bdc40549 units: turn on RestrictSUIDSGID= in most of our long-running daemons
  276401ea84 seccomp: rework how the S[UG]ID filter is installed
  4b616cb995 test-seccomp: fix compilation on arm64
  5a07cdd48a core: fix build failure if seccomp is disabled
  0512aa6ea8 core: imply NNP and SUID/SGID restriction for DynamicUser=yes service (bsc#1133506 bsc#1133509 CVE-2019-3843 CVE-2019-3844)
  d377ee5360 man: document the new RestrictSUIDSGID= setting
  afcbed619f man: note that `systemctl show` does not overridden value
  89982813ca core: expose SUID/SGID restriction as new unit setting RestrictSUIDSGID=
  0da1ea2aed test: add test case for restrict_suid_sgid()
  898c724e6c seccomp: introduce seccomp_restrict_suid_sgid() for blocking chmod() for suid/sgid files
  4b56b9e8d7 meson: stop creating enablement symlinks in /etc during installation
  d1ee97533e networkd: do not install the socket when networkd is not enabled
  972d0a0bdf udevd: notify when max number value of children is reached only once per batch of events (bsc#1132400)
  7dd4d8ff02 sd-bus: bump message queue size again (bsc#1132721)
* Mon Apr 29 2019 Franck Bui <fbui@suse.com>
- systemd-coredump: generate a stack trace of all core dumps (jsc#SLE-5933)
  Stack traces are logged into the journal.
* Tue Apr 23 2019 Franck Bui <fbui@suse.com>
- Drop "BuildRequires:  -post-build-checks" from the specfile (bsc#1130230)
  The syntax of this directive is obsolete and should be replaced by
  "#!BuildIgnore: post-build-checks".
  However there's no reasons to disable these SUSE extra checks
  especially since the package still builds fine with them turned
  ON. So simply drop the line from the spec file.
* Fri Apr 12 2019 Franck Bui <fbui@suse.com>
- Import commit ecb92848f361fa2b2baebb61a37d861213756ad0
  fdafcf8151 pam-systemd: use secure_getenv() rather than getenv() (bsc#1132348 CVE-2019-3842)
  a9793105c6 bus: fix memleak on invalid message
  a90e01ef50 logind: fix killing of scopes (bsc#1125604)
  a9c0babb8b namespace: make MountFlags=shared work again (bsc#1124122)
  7a776a1518 man: document the new PrivateMounts= setting
  ae2abcb517 rules: load drivers only on "add" events (bsc#1126056)
  a50d2c6c33 Allocate temporary strings to hold dbus paths on the heap (bsc#1125352 CVE-2019-6454)
  a8d74361ff Refuse dbus message paths longer than BUS_PATH_SIZE_MAX limit. (bsc#1125352 CVE-2019-6454)
  78a06c1a87 sysctl: Don't pass null directive argument to '%%s' (bsc#1121563)
* Thu Mar 14 2019 Franck Bui <fbui@suse.com>
- Drop sg.conf, it's been taking over by suse-module-tools
  See bsc#1036463 for details.
* Wed Mar  6 2019 Michal Suchanek <msuchanek@suse.de>
- Do not automagically online memory on s390x (bsc#1127557)
  On s390 memory that is not online is typically 'reserve' memory that
  should be only activated by the system administrator.
  There is no way to detect reserve memory from information provided
  by the kernel so the state of the art is to not activate memory
  automagically if the platform is s390.
* Tue Feb 19 2019 Franck Bui <fbui@suse.com>
- Drop 0001-systemd-PID1-crash-with-specially-crafted-D-Bus-mess.patch
  Its upstream counterparts have been imported in SUSE/v234
* Thu Feb 14 2019 Franck Bui <fbui@suse.com>
- Add 0001-systemd-PID1-crash-with-specially-crafted-D-Bus-mess.patch (bsc#1125352 CVE-2019-6454)
* Thu Feb 14 2019 Franck Bui <fbui@suse.com>
- Import commit 98de7a2368c96c3914bca239b35d5b1de6bffcc2
  434d2010d0 sd-bus: if we receive an invalid dbus message, ignore and proceeed
  0cbdb75339 automount: don't pass non-blocking pipe to kernel.
* Thu Feb  7 2019 Franck Bui <fbui@suse.com>
- Import commit 7902374f4046d3515973c2292fe764967cfc2309
  b808bd8f67 units: make sure initrd-cleanup.service terminates before switching to rootfs (bsc#1123333)
  58a5ac4cca logind: fix bad error propagation
  fb118b996e login: log session state "closing" (as well as New/Removed)
  e0065eec98 logind: fix borked r check
  4a978123cd login: don't remove all devices from PID1 when only one was removed
  c7af85fa55 login: we only allow opening character devices
  d21d3f32d1 login: correct comment in session_device_free()
  a5c15fde73 login: remember that fds received from PID1 need to be removed eventually
  12ed3e765a login: fix FDNAME in call to sd_pid_notify_with_fds()
  d16ea1c77a logind: fd 0 is a valid fd
  06546129b3 logind: rework sd_eviocrevoke()
  5b40830fcb logind: check file is device node before using .st_rdev
  5d69862a26 logind: use the new FDSTOREREMOVE=1 sd_notify() message (bsc#1124153)
  6b10a71597 core: add a new sd_notify() message for removing fds from the FD store again
  767e6baa0e logind: make sure we don't trip up on half-initialized session devices (bsc#1123727)
  95828c00c4 fd-util: accept that kcmp might fail with EPERM/EACCES
  c1448fc331 core: Fix use after free case in load_from_path() (bsc#1121563)
* Wed Feb  6 2019 Franck Bui <fbui@suse.com>
- Import commit 72e2d92e01b6e4686e6ac0b9cea391eb2ad4bc02
  fc4e41ca9e core: include Found state in device dumps
  8f795776b1 device: fix serialization and deserialization of DeviceFound
  2af4971594 fix path in btrfs rule (#6844)
  f8ac04cffb assemble multidevice btrfs volumes without external tools (#6607) (bsc#1117025)
  c96249b50c Update systemd-system.conf.xml (bsc#1122000)
  37245007a7 units: inform user that the default target is started after exiting from rescue or emergency mode
* Tue Jan 15 2019 Franck Bui <fbui@suse.com>
- Import commit 9874ecb0457fd43cdde01085a878acdf2fa5af36
  96313ee86a pull: initialize libgcrypt before calling any functions provided by libgcrypt
  08870024dc hwdb: remove stray 'i' in hwdb match string for the HP Spectre (#9571)
  f09d3f3648 cryptsetup: Add dependency on loopback setup to generated units
  3dfe6375a9 journal-gateway: use localStorage["cursor"] only when it has valid value
  44af6bc697 journal-gateway: explicitly declare local variables
  a780ac41ce analyze: actually select longest activated-time of services
  f57d448ff8 sd-bus: fix implicit downcast of bitfield reported by LGTM
  02e8443486 install: fix error handling in is_symlink_with_known_name()
  5d4d445912 resolve: fix return value type of dns_answer_has_dname_for_cname()
  4bfb5d31d5 resolve: dns_scope_network_good() does not returns negative errno
  c7028bd00a core: free lines after reading them (bsc#1123892)
  63b4e1c44b pam_systemd: reword message about not creating a session (boo#1111498)
  7811bf8e80 pam_systemd: suppress LOG_DEBUG log messages if debugging is off (boo#1111498)
* Thu Jan 10 2019 Franck Bui <fbui@suse.com>
- Import commit b3fe3bed57dbf0a8c280caa4b45323e689f683e2
  e3666c6e3e journal-remote: set a limit on the number of fields in a message (CVE-2018-16865 bsc#1120323)
  a6d9216e7a journal-remote: verify entry length from header
  6d319eb61e journald: set a limit on the number of fields (1k) (CVE-2018-16865 bsc#1120323)
  f9c666991a coredump: fix message when we fail to save a journald coredump
  2ad2d953c7 journald: do not store the iovec entry for process commandline on stack (bsc#1120323 CVE-2018-16864)
  10f19f0bbf journald: remove unnecessary {}
  eec4fdb05c coredump: remove duplicate MESSAGE= prefix from message
* Wed Jan  9 2019 Franck Bui <fbui@suse.com>
- Import commit 8f7529bfb001e99ebaab8f50d611ab750b96917d (CVE-2018-6954 bsc#1080919)
  61043b6fd3 Add macro for checking if some flags are set
  c15f0a33a2 test: Run qemu/nspawn tests with "set -e"
  2c818c539a test: Factorize common integration test functions (#6540)
  aa07d4eef4 test: Write state and log files into $BUILD_DIR
  0207cea661 tmpfiles: fold five lines into two
  9b622de3ad tmpfiles: "e" takes globs
  2f1f321b26 tmpfiles: don't adjust qgroups on existing subvolumes (bsc#1093753)
  32bc657d2b tmpfiles: use fd_get_path() even less excessively
  c0a4ee798f test: make TEST-22 easier to debug, by outputting to /dev/console
  4e6c4d3147 test: don't use "nobody:nogroup" for tests
  1c22e03b53 tmpfiles: return correct error variable after fd_reopen()
  3147f8b81b tmpfiles: reindent one comment less weirdly
  52c5e3dcce tmpfiles: use correct error variable
  34395ac640 tmpfiles: clarify that we ignore file attribute setting errors
  2e68b99078 tmpfiles: add log message where we previously failed silently
  4b4025ebf4 tmpfiles: use fd_get_path() less excessively
  f004d24b2a tmpfiles: add more tests
  a516490b24 test: don't send image building output to /dev/null (#8886)
  d827068b53 tmpfiles: don't follow unsafe transitions in path_set_*()
  f38c092871 fs-util: add new CHASE_NOFOLLOW flag to chase_symlinks()
  0fd2349ec9 tmpfiles: make create_fifo() safe
  0c40e5f0fd fs-util: introduce mkfifoat_atomic() helper
  cfaa792ef9 fileio: make tempfn_random_child() accept empty string as path
  842dcb66f7 tmpfiles: introduce create_fifo()
  37aac5922d tmpfiles: introduce empty_directory()
  a3ee4deb69 tmpfiles: introduce create_directory() and create_subvolume() and make them safe
  c46af42ca2 basic/stat-util: introduce is_dir_fd()
  15c9a82bce btrfs-util: unfuck tmpfiles' subvol creation
  56728ebf2c btrfs-util: introduce btrfs_subvol_make_fd()
  6c125e3be7 basic/label: introduce mkdirat_label()/mkdirat_errno_wrapper() helpers
  18fe67c959 selinux: introduce mac_selinux_create_file_prepare_at()
  1b711db4b6 path-util: introduce new safe_getcwd() wrapper
  d770b8db30 smack: introduce mac_smack_fix_at()
  0ffb1013bc smack: make mac_smack_fix() deal somewhat sensible with non-absolute paths
  55e7a0cd2a Fix compilation w/o smack (#8593)
  84e8ac537b label: rework label_fix() implementations (#8583)
  3686673f0a tmpfiles: introduce create_directory_or_subvolume()
  1a2573fadf tmpfiles: make create_device() safe
  5c9a660957 tmpfiles: introduce create_device()
  c177df34c8 tmpfiles: make copy_files() safe
  06a5290c63 tmpfiles: introduce copy_files() routine
  6d641c23a8 tmpfiles: make write_one_file() safe
  1782e90f3d tmpfiles: make truncate_file() safe
  5101dfbff7 tmpfiles: introduce truncate_file() which deals with 'F' exclusively
  1886d7636f tmpfiles: introduce create_file() which deals with 'f'/'F' exclusively
  c7f0d990b5 tmpfiles: make the stat struct parameter in fd_set_*() optional
  04ce630755 tmpfiles: stat file in item_do() rather than in its callers
  04883c43b7 tmpfiles: set only default acls to folders #9545 (#9599)
  e6720dda59 tree-wide: some O_NDELAY → O_NONBLOCK fixes
  8f2444bccd tmpfiles: fix up and complain paths referring to /var/run (instead of /run) automatically
  92cafeb3ab tmpfiles: 'e' is supposed to accept shell-style globs
  0ad95b0f9a tmpfiles: 'e' is supposed to operate on directory only
  a1ba1e298b fs-util: introduce fchmod_opath()
  6774858c3e tmpfiles: remove spurious curly braces in create_item()
  ff7b2a2149 tmpfiles: create parent directories if they are missing for more line types
  4d225f603f fd-util: introduce fd_reopen() helper for reopening an fd
  bcec6544d6 test: add tests for systemd-tmpfiles
  281d06a8fa tmpfiles: don't resolve pathnames when traversing recursively through directory trees
  69a3a957d4 tmpfiles: fstat() works with fd opened with O_PATH since Linux 3.6
  5e2146a435 tmpfiles: make hardlink_vulnerable() argument constant
  f871a58fe7 tmpfiles: make "f" lines behaviour match what the documentation says
  3583d83776 tmpfiles: shortcut path_set_perms() if there's nothing to do
  465416b058 tmpfiles: fix check for figuring out whether to call chmod()
  baf3ea541c tmpfiles: avoid using wrong type for strlen() result
  a8d6590e17 basic/fs-util: remove logically dead code
  3768f894ed fs-util: add new CHASE_STEP flag to chase_symlinks()
  cd09a3129d macro: introduce new TAKE_FD() macro
  0feee55455 macro: introduce TAKE_PTR() macro
  58987f02cb fs-util: add shortcut for chase_symlinks() when it is called like open(O_PATH)
  662fe953fb fs-util: chase_symlinks(): support empty root
  accfcc9d5c fs-util: refuse taking a relative path to chase if "root" is specified and CHASE_PREFIX_ROOT is set
  6caab72812 fs-util: extra chase_symlink() safety check on "path" parameter
  996c2c2fa6 fs-util: extra safety checks on chase_symlinks() root parameter
  1252ee00da fs-util: remove comment about non-existing function
  b42e2bb5f9 nspawn: make sure we don't leak the fd in chase_symlinks_and_update
  41fff37ee3 fs-util: add new chase_symlinks() flag CHASE_OPEN
  67f388cc93 user-util: add UID_NOBODY defines that resolve to (uid_t) 65534
  4b036c36a1 fs-util: use _cleanup_close_ attribute
  0390eb2077 fs-util: chase_symlinks(): prevent double free
  4c495215e3 fs-util: add new CHASE_SAFE flag to chase_symlinks()
  9242f48c29 fs-util: chase_symlinks(): remove unnecessary slash at the head
  17ae72b9b0 Move mkdir_label() to mkdir-label.c
  581192d868 Move selinux-related stuff from btrfs-util.c to label.c
  008a35deb6 Add mkdir_errno_wrapper() and use instead of mkdir() in various places
  fa77d89b43 mkdir: introduce follow_symlink flag to mkdir_safe{,_label}()
  b8c314823d mkdir: chmod_and_chown() returns errors as "return -errno", not in errno itself
  e9231b19eb tmpfiles: check if not too many symbolic links. (#7423)
  48a7365e7f tmpfiles: with "e" don't attempt to set permissions when file doesn't exist (#6682)
  ad2c7f6a04 basic/macros: add STRLEN() to get length of string literal as constant expression
* Wed Jan  9 2019 Franck Bui <fbui@suse.com>
- Import commit c7f08cbe22b95d97a0eea4832991c8390cc86866
  c152c950d4 vconsole-setup: fonts copy will fail if the current terminal is in graphical mode (bsc#1114933)
  827dc868bd 6647 - use path_startswith("/dev") in cryptsetup (#6732) (bsc#1119971)
  5d1e170e05 logind: stop managing VT switches if no sessions are registered on that VT (bsc#1101591)
  07fc858f25 terminal-util: introduce vt_release() helper
  eee33c6e5d terminal-util: introduce vt_restore() helper
  a133c368a4 terminal: unify code for resetting kbd utf8 mode a bit (#6692)
  2a487a79ea terminal reset should honour default_utf8 kernel setting (#6606)
  a33d12fd73 logind: make session_restore_vt() static
  ef799fb7ec udev/net-id: check all snprintf return values
  46343b3248 core: don't include libmount.h in a header file (#8580)
  2763be9d36 udev: downgrade message when we fail to set inotify watch up (bsc#1005023)
  f66ba2d179 namespace: always use a root directory when setting up namespace (bsc#1045723)
  98d173e12e core: ReadWritePaths= and friends assume '+' prefix when BindPaths= or freinds are set
  5d581cee2f namespace: properly handle bind mounts from the host
  7b0b2e418b namespace: create /dev, /proc, /sys when needed
  84736215a4 coredump: only install coredump.conf when ENABLED_COREDUMP=true
* Fri Nov 23 2018 Franck Bui <fbui@suse.com>
- Fix the test for figuring out if /etc/machine-id is writable in %%post (bsc#1117063)
  "test -w" always returns true for root user even if the writable
  mode bits are not set. Fix this by testing the file mode bit value
  instead.
* Thu Nov 22 2018 Lee, Chun-Yi <jlee@suse.com>
- udev: ignore the exit code of systemd-detect-virt for memory hot-add (bsc#1076696)
  In 80-hotplug-cpu-mem.rules on SLE12-SP3, there have a memory
  hot-add rule uses systemd-detect-virt to detect non-zvm
  environment. The systemd-detect-virt returns exit failure code when
  it detected _none_ state.  The exit failure code causes that the
  hot-add memory block can not be set to online.
  See: https://www.spinics.net/lists/systemd-devel/msg00341.html
* Wed Oct 31 2018 Franck Bui <fbui@suse.com>
- Import commit ceefdbf8afbc95dc2728999ce0cd7493411357e4
  43b790123 dhcp6: make sure we have enough space for the DHCP6 option header (bsc#1113632 CVE-2018-15688)
  96eba195c dhcp6: split assert_return() to be more debuggable when hit
  38c94b4bf core: skip unit deserialization and move to the next one when unit_deserialize() fails
  ef058a4f9 core: when deserializing state always use read_line(…, LONG_LINE_MAX, …) (bsc#1113665 CVE-2018-15686)
  5581cd610 core: properly handle deserialization of unknown unit types (#6476)
  e2933aa92 core: don't create Requires for workdir if "missing ok" (bsc#1113083)
  794443b1c logind: use manager_get_user_by_pid() where appropriate
  986d63b00 logind: rework manager_get_{user|session}_by_pid() a bit
  83d0f831e login: fix user@.service case, so we don't allow nested sessions (#8051) (bsc#1112024)
  f2a73744c core: be more defensive if we can't determine per-connection socket peer (#7329)
  fc9172ff8 core: introduce systemd.early_core_pattern= kernel cmdline option
  cd2ed8f59 core: add missing 'continue' statement
  c6c6cc19c core/mount: fstype may be NULL
  1da4c5dd4 journald: don't ship systemd-journald-audit.socket (bsc#1109252)
  7bb6768b3 core: make "tmpfs" dependencies on swapfs a "default" dep, not an "implicit" (bsc#1110445)
  5aa2ccd69 mount: make sure we unmount tmpfs mounts before we deactivate swaps (#7076)
  57cc22fef detect-virt: do not try to read all of /proc/cpuinfo (bsc#1109197)
  3c4503ec6 emergency: make sure console password agents don't interfere with the emergency shell
  7a1eb19d7 man: document that 'nofail' also has an effect on ordering
  e0326fc41 journald: take leading spaces into account in syslog_parse_identifier
  a09b1acab journal: do not remove multiple spaces after identifier in syslog message
  e7a85abe6 syslog: fix segfault in syslog_parse_priority()
  6d66aca0f journal: fix syslog_parse_identifier()
  be15909f3 install: drop left-over debug message (#6913)
* Tue Oct 16 2018 Franck Bui <fbui@suse.com>
- Ship systemd-sysv-install helper via the main package
  This script was part of systemd-sysvinit sub-package but it was
  wrong since systemd-sysv-install is a script used to redirect
  enable/disable operations to chkconfig when the unit targets are
  sysv init scripts. Therefore it's never been a SySV init tool.
* Mon Sep 17 2018 fbui@suse.com
- Import commit 5da416950ebe9c4d834ffb8382b0dcaee1941aa8
  9d0d3c2bb tmpfiles: don't adjust qgroups on existing subvolumes (bsc#1093753)
  828198433 socket-util: attempt SO_RCVBUFFORCE/SO_SNDBUFFORCE only if SO_RCVBUF/SO_SNDBUF fails (bsc#991901)
  043f75c0d user@.service: don't kill user manager at runlevel switch (bsc#1091677)
  21eae45f7 units: make sure user@.service runs with dbus still up
  27f607ce7 fix race between daemon-reload and other commands (v234) (bsc#1105031)
  83126307c nspawn: always use mode 555 for /sys (bsc#1107640)
  8a77eed0a cryptsetup: do not define arg_sector_size if libgcrypt is v1.x (#9990)
  7ebb0643c cryptsetup: add support for sector-size= option (#9936) (fate#325697)
* Fri Sep 14 2018 fbui@suse.com
- Enable or disable machines.target according to the presets (bsc#1107941)
  Enable or disable machines.target according to the distro's presets.
* Fri Aug 31 2018 fbui@suse.com
- Import commit f26a4b03baf10f479951bdffa0f70eff6b5451c1
  5af898dfe core/service: rework the hold-off time over message
  a4aa80162 systemctl: load unit if needed in "systemctl is-active" (bsc#1102908)
  72f8ae153 core: don't freeze OnCalendar= timer units when the clock goes back a lot (bsc#1090944)
  ed49f225e man: SystemMaxUse= clarification in journald.conf(5) (bnc#1101040)
  c47c1fd5e core: in --user mode, report READY=1 as soon as basic.target is reached (#7102)
  ee9d1567c sd-bus: extend D-Bus authentication timeout considerably (#6813)
* Thu Aug 23 2018 fbui@suse.com
- Add 0002-udev-optionally-disable-the-generation-of-the-partla.patch (bsc#1089761)
  This patch adds "udev.no-partlabel-links" kernel command-line option
  that can be used to disable the generation of the by-partlabel
  symlinks regardless of the name used. This might be useful to
  prevent the generation of such symlinks on big setups where it could
  have a bad impact on the performance of the boot process.
  This will allow user to workaround bsc#1089761 whatever the
  partlabel used for disks (previous patch was only dealing with
  "primary" and "logical" names).
  DISCLAIMER: this new option must be used to workaround the previous
  bug *only* as it will be dropped as soon as the udev perf issue will
  be addressed.
* Thu Jul  5 2018 fbui@suse.com
- Import commit 2bf8d0f79760dd75bc221f9e91d294e4957e6c95
  181ae456a udev: use MAC address match only for ibmveth/ibmvnic/mlx4 (bsc#1095096)
  5a1aa8454 compat-rules: generate more compat by-id symlinks for NVMe devices (bsc#1095096)
* Mon Jun 25 2018 fbui@suse.com
- Import commit 455f9b8841be896cb9a46a76f441a68a54187b29
  be5d72795 systemctl: mask always reports the same unit names when different unknown units are passed (bsc#1095973)
  d484e8167 systemctl: check existence of all units, not just the first one
  b33745be7 scsi_id: Fixup prefix for pre-SPC inquiry reply (bsc#1039099)
  f141e98a0 device: make sure to always retroactively start device dependencies (take #2) (bsc#1088052)
  cc7cfdc06 locale-util: on overlayfs FTW_MOUNT causes nftw(3) to not list *any* files
  c10206dad Fix pattern to detect distribution
  7b8f97e93 basic/macros: rename noreturn into _noreturn_ (#8456)
  f4836f05a install: "user" and "global" scopes are equivalent for user presets (boo#1093851)
  8f3fb5638 install: search preset files in /run (#7715)
  e871d6192 install: consider globally enabled units as "enabled" for the user (bsc#1093851)
  a25169127 install: consider non-Alias=/non-DefaultInstance= symlinks as "indirect" enablement
  c4635e551 install: only consider names in Alias= as "enabling"
  1b78301a5 install: move and rename to lowercase two functions
  e79156aee udev: whitelist mlx4_core locally-administered MAC addresses in the persistent rule generator (bsc#1083158)
  6c565351b man: updated systemd-analyze blame description for service-units with Type=simple (#8834) (bsc#1091265)
  380e80633 fileio.c: fix incorrect mtime
  0ae375c66 fileio: support writing atomic files with timestamp
* Mon Jun 25 2018 fbui@suse.com
- Drop runtime dependency on dracut (bsc#1098569)
  Otherwise systemd pulls in tools to generate the initrd even in
  container/chroot installations that don't have a kernel anyways.
  For environments where initrd matters, dracut should be pulled via a
  pattern.
* Fri May 18 2018 fbui@suse.com
- Import commit d5dfab21f033c8af518e169a4cc79365a26974e2
  e79156aee udev: whitelist mlx4_core locally-administered MAC addresses in the persistent rule generator (bsc#1083158)
* Fri May 18 2018 fbui@suse.com
- Disable user services by default (bsc#1090785)
* Thu May 17 2018 fbui@suse.com
- Add 0001-udev-don-t-create-by-partlabel-primary-and-.-logical.patch (bsc#1089761)
* Mon May 14 2018 fbui@suse.com
- Make sure /etc/machine-id has correct permissions (boo#1092269)
  This should be only needed for those who keep a Beta/RC
  installations.
* Mon Apr 23 2018 fbui@suse.com
- Move 80-container-v[ez].network in systemd-container sub-package
- Move 80-container-host0.network from udev to systemd
* Mon Apr 23 2018 fbui@suse.com
- Import commit d5dfab21f033c8af518e169a4cc79365a26974e2
  92bf37b0a device: skip deserialization of device units when udevd is not running
  0a8984996 device: make sure to always retroactively start device dependencies (bsc#1088052)
  88df88129 cryptsetup-generator: do not bind to the decrypted device unit (#6538) (bsc#1089693)
* Fri Apr 20 2018 fbui@suse.com
- Ship 99-sysctl.conf instead of creating it during package installation/update (bsc#1088769)
  Previously this symlink was created in /etc/sysctl.d during %%post
  which made the symlink not owned and more importantly it was created
  only if /etc/sysctl.conf is already installed which is not always
  the case during the installation process it seems.
  So ship the symlink unconditionally and put it in /usr/lib/sysctl.d
  instead since it's a distro default behavior that might be overriden
  by sysadmin later.
* Wed Apr 18 2018 fbui@suse.com
- Import commit 9c35953dd19e90e4bfb03ad41380f3a5f9ae3ce7
  a374ad328 Drop busname unit type (bsc#1089376)
  85a01da56 shared/dissect-image: adapt to LUKS2 format
  a0ac1823c dissect: add a bit of debug logging if dm-crypt fails on us
  386ae68a0 cryptsetup: support LUKS2 on-disk format (bsc#1083571)
  5f3b66fdb systemd-udevd: limit children-max by available memory (#8668) (bsc#1086785 bsc#1066422)
  54833e3ab tmpfiles: fix directory removal with force symlink (#8619)
  04ef8e535 rules: fix syntax inconsistency in 75-persistent-net-generator.rules spotted by rule syntax checker
* Wed Apr 18 2018 fbui@suse.com
- Drop dangling symlinks when systemd-container is not installed (bsc#1089376)
  - /usr/lib/systemd/system/remote-fs.target.wants/var-lib-machines.mount
    symlink is now part of systemd-container.
  - Dangling org.freedesktop.*.busname symlinks have been dropped
    completely and the support of busname has been removed from the
    git repo since it was dead code (kdbus was rejected).
* Mon Apr 16 2018 jlee@suse.com
- systemd: add offline environmental condition to 80-acpi-container-hotplug.rules (bsc#1082485)
  Add the offline event environmental condition to restrict the rule
  that is can only be triggered when the change event is received with
  the "offline" environmental data. The 27664c581 "ACPI / scan: Send
  change uevent with offine environmental data" kernel patch changed
  the corresponding code in kernel.
  This change prevents the udev rules for acpi container be triggered
  by "udevadm trigger" from user space.
* Thu Apr  5 2018 fbui@suse.com
- Split systemd-coredump sub-package off (bsc#1083849)
* Wed Mar 28 2018 fbui@suse.com
- Rename the tarball to reflect the exact version used (bsc#1087323)
  So it's clear that it contains some additional patches on top of the
  upstream version. Use the commit hash in the name so the exact
  version can easily be identified.
  Provide _service file which can be used to retrieve the tarball from
  the git repo (with "osc service disabledrun").
* Wed Mar 28 2018 fbui@suse.com
- Import commit b83c42d5d91a5ace2b4aa7420e83c98292e6f9e3
  a59988ee5 sysusers: make sure to reset errno before calling fget*ent()
  98ddbf6b3 sysusers: also add support for NIS entries in /etc/shadow
  586c08f63 sysusers: do not append entries after the NIS ones (bsc#1085062 bsc#1045092)
  3993df26a compat-rules: fix error detected by the rule syntax checker
* Tue Mar 27 2018 fbui@suse.com
- Don't ship machines.target in systemd-container but in systemd main package
  machines.target is supposed to be a standard target for
  starting/stopping all containers. systemd-nspawn is the main user of
  it but other container managers could also make use of it.
* Tue Mar 27 2018 fbui@suse.com
- Create systemd-container-mini package
  So we don't have to manually track and remove all files that should
  be shipped by systemd-container in the case of a bootstrap build.
* Thu Mar 22 2018 fbui@suse.com
- Run migrate-sysconfig-i18n.sh also during package installation (bsc#1086164)
  This is needed when we upgrade from SLE11.
* Thu Mar 15 2018 fbui@suse.com
- Split systemd-container sub-package off (fate#325469)
  This split off has been in Factory/TW since a couple of weeks now
  without any reported problems and I think it makes also sense to
  have it in SLE.
* Fri Mar  9 2018 fbui@suse.com
- Import commit 6efb938f152b60c905b8496980697400b13e02a7
  06d5d0701 rules: maintain 80-hotplug-cpu-mem.rules in the package
  01db63eeb rule-syntax-check: allow commas inside quoted strings
  8247f6155 rule-syntax-check: add support for escaped double quotes
  a6354c05b rule-syntax-check: values can contain escaped double quotes
  5c8d9a358 rule-syntax-check: PROGRAM is not supposed to get value assigned
  88174ae85 compat-rules: fix syntax errors spotted by test/rule-syntax-check.py
  f4f94ab2e meson: install rules/80-hotplug-cpu-mem.rules
  2901aa9b9 meson: install rules/60-ssd-scheduler.rules
  db1d8eacd compat-rules: make path_id_compat build with meson
* Thu Mar  8 2018 fbui@suse.com
- Fix hotplug memory in 80-hotplug-cpu-mem.rules
  Drop broken script udev-remount-tmpfs.
  When new memory was hotplugged, the rule was supposed to call the
  external script (udev-remount-tmpfs) to remount all tmpfs. However
  the script was broken since its introduction (commit rev=715,
  14/07/2014) and had no effects... this makes me wonder if we
  shouldn't get rid of this...
  The logic is now embedded in the rule file.
* Wed Feb 28 2018 Thomas.Blume@suse.com
- Add basic user space support for suspend to idle (fate#323814)
  Add 99-wakeup-from-idle.rules
  Currently this only covers the power button and usb/AT keyboards
  as wakeup devices. It is planned to make that configurable in
  the future.
* Fri Feb 23 2018 fbui@suse.com
- Add dmi conditions to 80-acpi-container-hotplug.rules (bsc#1078358, bsc#1081170, bsc#1075743)
  Patch sent by Lee, Chun-Yi <jlee@suse.com> to @systemd-maintainers.
    http://mailman.suse.de/mailman/private/systemd-maintainers/2018-February/032177.html
  Commit message:
  Add dmi/id conditions to 80-acpi-container-hotplug.rules to
  restrict the rule that it can only be triggered on Huawei Kunlun
  9008, 9016 and 9032 machines. (bsc#1078358, bsc#1081170,
  bsc#1075743)
* Mon Feb 19 2018 fbui@suse.com
- Re-enable systemd-firstboot
  It's used by the installer and also by JeOS.
* Mon Feb 19 2018 fbui@suse.com
- Import commit 0987985db5a5797db8dc708e67166d329fa74858
  1293c0056 core: use id unit when retrieving unit file state (#8038) (bsc#1075801)
  596b2b241 Revert "vconsole-setup: add SUSE specific settings for font/keyboard in sysconfig"
  0b595da04 Revert "locale-setup: handle locale at boot time well"
  2a181fc6f insserv-generator: make it build with meson
  7b0401da4 build-sys: don't build networkctl if networkd is disabled
  b1e0a348d fileio: include sys/mman.h
  f1fa784cb meson: update header file to detect memfd_create()
  8838ba7ec meson: define _GNU_SOURCE to detect copy_file_range() (#7734)
* Tue Feb 13 2018 fbui@suse.com
- Disable systemd-firstboot
  I don't think there's any use case for it currently.
* Tue Feb 13 2018 fbui@suse.com
- Drop unused code dealing with tmp.mount
  Commit "Don't ship /usr/lib/systemd/system/tmp.mnt at all
  (bsc#1071224)" forgot to delete this chunk of code which is no more
  needed.
* Mon Feb 12 2018 fbui@suse.com
- Make systemd-timesyncd use the openSUSE NTP servers by default
  Previously systemd-timesyncd used the Google Public NTP servers
  time{1..4}.google.com
* Fri Feb  9 2018 fbui@suse.com
- Drop 0001-Revert-locale-setup-handle-locale-at-boot-time-well.patch
    0002-Revert-vconsole-setup-add-SUSE-specific-settings-for.patch
  These 2 patches have been merged in branch "SUSE/v234"
* Fri Feb  9 2018 fbui@suse.com
- Don't ship /usr/lib/systemd/system/tmp.mnt at all (bsc#1071224)
  But we still ship a copy in /usr/share/systemd.
  Users who want to use tmpfs on /tmp are supposed to add a symlink in
  /etc/ pointing to the copy shipped in /usr/share.
  To support the update path we automatically create the symlink if
  tmp.mount in use is located in /usr/lib.
* Fri Feb  9 2018 fbui@suse.com
- Enable systemd-networkd on Leap distros only (bsc#1071311)
* Tue Feb  6 2018 fbui@suse.com
- Don't build seccomp support in the mini package
* Tue Feb  6 2018 fbui@suse.com
- Don't build-require selinux for the mini package
* Tue Feb  6 2018 fbui@suse.com
- Drop libgcrypt.m4
  The mini package builds fine without it so it doesn't seem necessary
  anymore.
* Mon Feb  5 2018 fbui@suse.com
- Import commit d5a5df298ccf490eb1da5cd671922dcda5ec17e1
  531a00c84 Restore "restore /var/run and /var/lock bind mount if they aren't symlink""
* Mon Feb  5 2018 fbui@suse.com
- Import commit fd4e9389d87901c420a5a05dd016a002bc9e85b2
  7fb9ea39a Revert "restore /var/run and /var/lock bind mount if they aren't symlink"
  23ce1207a meson.build: make docdir configurable (#8068)
* Fri Feb  2 2018 fbui@suse.com
- Import commit 08eebc34ac22b2175321f3a8814ed0aca3bc88bb
  07c6ee3eb compat-rules: get rid of scsi_id when generating compat symlinks for NVMe devices (bsc#1051465)
* Fri Feb  2 2018 fbui@suse.com
- Drop 0001-compat-rules-get-rid-of-scsi_id-when-generating-comp.patch
  It's been merged in branch "compats/udev-compat-symlinks" which was
  merged in branch "SLE15" in its turn.
* Fri Feb  2 2018 fbui@suse.com
- Import commit b4e4c090b2238e80f4d82b11739bc428d3f0e00f
  37da1facb core: disable session keyring per system sevice entirely for now (bnc#1045886)
  8a1ae0449 strv: fix buffer size calculation in strv_join_quoted()
  2b8971b8a tmpfiles: refuse to chown()/chmod() files which are hardlinked, unless protected_hardlinks sysctl is on (bsc#1077925 CVE-2017-18078)
  8c2bcac25 tmpfiles: change ownership of symlinks too
* Fri Feb  2 2018 fbui@suse.com
- Drop 0001-core-disable-session-keyring-per-system-sevice-entir.patch
  It's been merged in branch "SUSE/v234".
* Fri Jan 26 2018 fbui@suse.com
- Import commit b8dab767c4df0fba4766f1e2b9977a2cd329b20e
  3d60486f7 core/timer: Prevent timer looping when unit cannot start (bsc#1068588)
  54c0add7c logind: store a timestamp when the ACPI power button is pressed (bsc#981830 bsc#888612 bsc#1072933)
  460bd0cd6 Revert "handle SYSTEMCTL_OPTIONS environment variable" (fate#323393)
* Fri Jan 26 2018 fbui@suse.com
- Drop 0001-Revert-handle-SYSTEMCTL_OPTIONS-environment-variable.patch
  The patch has been merged in SUSE/v234 since its counterpart in YaST
  has been accepted in Factory and SLE15.
* Wed Jan 24 2018 fbui@suse.com
- Drop 0001-logind-store-a-timestamp-when-the-ACPI-power-button-.patch
  The patch has been verified on Beta5 and hence has been merged in
  "SLE15" branch.
* Tue Jan 16 2018 fbui@suse.com
- Import commit c2ed2c6dc3aed4b3c22cfcd4b8fd28da01f6471e
  aa3eba828 delta: don't ignore PREFIX when the given argument is PREFIX/SUFFIX
  b1ea0173a delta: extend skip logic to work on full directory paths (prefix+suffix) (bsc#1070428)
  77c5065f9 delta: check if a prefix needs to be skipped only once
  db32866d1 Fix parsing of features in detect_vm_xen_dom0 (#7890) (bsc#1048510)
  11d40461a sd-bus: use -- when passing arguments to ssh (#6706)
* Fri Jan 12 2018 rbrown@suse.com
- Edit scripts-systemd-fix-machines-btrfs-subvol.sh
  We shouldn't be creating a /var/lib/machines subvolume if /var is
  already a seperate partition or subvolume. /var/lib/machines will
  already be excluded from snapper & similar tooling in this case.
* Thu Jan 11 2018 fbui@suse.com
- Import commit 290129a57006338211f8c139a52402cb1ccebbf7
  1148d99f6 tmpfiles: consider /etc uninitialized also when /etc/machine-id is present but empty (#7849) (bsc#1075179)
  3a95f69bf tmpfiles: downgrade warning about duplicate line
* Wed Jan 10 2018 fbui@suse.com
- Import commit e1f3d0784798d2a31e7492a26ce660fda2b0ddb8
  8c7f0c449 service: Don't stop unneeded units needed by restarted service (bsc#1066156)
  869be64ce sysctl: use raw file descriptor in sysctl_write (#7753)
  0c2400810 sysctl: disable buffer while writing to /proc (bsc#1071558)
  9eb1f30b8 Use read_line() and LONG_LINE_MAX to read values configuration files. (bsc#1071558)
  4dbea654f def: add new constant LONG_LINE_MAX
  48f14cd71 fileio: add new helper call read_line() as bounded getline() replacement
* Thu Dec 28 2017 fbui@suse.com
- Add 0001-Revert-handle-SYSTEMCTL_OPTIONS-environment-variable.patch
  Patch has been quarantined. The only user of SYSTEMCTL_OPTIONS was
  yast2-installation and its usage has been removed in SLE15 (the
  changes are still pending for Factory).
* Mon Dec 18 2017 fbui@suse.com
- Import commit d4267fb7c1c6718015309275d303e652155705f8
  861e1a222 build-sys: udevadm should have LOG_REALM=LOG_REALM_UDEV
  8ed5cf3fb meson: libudev_core and udevadm should have LOG_REALM=LOG_REALM_UDEV (#7666)
  a9f93f1d0 virt: use XENFEAT_dom0 to detect the hardware domain (#6442, #6662) (#7581) (bsc#1048510)
  fe56abdf9 seccomp: arm64/x32 do not have _sysctl (bsc#1069239)
  c9194fe37 seccomp: arm64 does not have mmap2 (bsc#1069239)
  31d9b3c32 fs-util: small tweak in chase_symlinks()
  9dd0bc7a3 meson: do not include man/meson.build if xsltproc not found
  7e29e2b07 analyze: replace --no-man with --man=no in the man page (bsc#1068251)
* Fri Dec 15 2017 fbui@suse.com
- Add missing /etc/systemd/network directory
  backported from Factory
* Fri Dec 15 2017 fbui@suse.com
- Add (back) 0001-logind-store-a-timestamp-when-the-ACPI-power-button-.patch (bsc#1072933)
  Patch added in the quarantine area. Once tested it could be moved
  to the SLE15 branch.
* Wed Dec  6 2017 fbui@suse.com
- Stop importing i18n settings from /etc/sysconfig (fate#319454)
  Add the 2 following patches in the quarantine area:
  0001-Revert-locale-setup-handle-locale-at-boot-time-well.patch
  0002-Revert-vconsole-setup-add-SUSE-specific-settings-for.patch
* Wed Nov 29 2017 fbui@suse.com
- Import commit 00dc7ae09282e074a16b37a7329296371cb9efda
  63481b24b firstboot: do not write vconsole.conf when arg_keymap is empty (bsc#1070124)
* Wed Nov 29 2017 fbui@suse.com
- Add 0001-compat-rules-get-rid-of-scsi_id-when-generating-comp.patch (bsc#1051465)
  This patch is not yet merged in the 'compats/udev-compat-symlinks'
  branch: we asked to upstream if it would be possible to introduce a
  new specifier that wouldn't strip trailing whitespaces , see
  https://github.com/systemd/systemd/issues/7462
  Also this allows to give the patch more testing before merging it in
  the git repo.
* Thu Nov 23 2017 fbui@suse.com
- Drop a useless rm(1) from the specfile
* Thu Nov 23 2017 fbui@suse.com
- Add 80-acpi-container-hotplug.rules (bsc#1040800)
  A "temporary" rule file that is maintained by the kernel team until
  a proper solution is found in the kernel.
  It doesn't belong to udev normally but for convenience purpose we
  welcome this homeless rule.
* Thu Nov 23 2017 kukuk@suse.de
- Remove requires for pwdutils, we don't need the shadow tools
  anymore [bsc#1069150]
* Fri Nov 17 2017 fbui@suse.com
- Drop 0001-systemd-firstboot-add-vconsole-keymap-support.patch
  It's not needed since it's been merged in the git repo (see commit
  86804326f).
* Fri Nov 17 2017 fbui@suse.com
- Import commit 79ede6be5b01b6031637e3ac95248a9bf392ce7c
  22dcb1d04 tmpfiles: when /etc is not fully initialized, some specifiers are expected to be unresolvable (#6860) (bsc#1055664)
  216beb768 tmpfiles: Allow create symlink on directories (#6039)
  baf85eb79 udev: net_setup_link: don't error out when we couldn't apply link config (#7328)
  86804326f systemd-firstboot: add vconsole keymap support (#7035) (bsc#1046436)
- Remove stderr redirection to /dev/null when calling %%tmpfiles_create
  since it's not needed anymore due to commit 22dcb1d04. Indeed the
  messages are no more emitted at LOG_WARN but LOG_NOTICE.
* Thu Nov  2 2017 fbui@suse.com
- Fork Factory and create a dedicated project for SLE15. It will
  contain all SLE15 dedicated bits:
  - forward port all SLE dedicated patches
  - merge compats/persistent-nic-names (bsc#1061883)
  - update with compats/udev-compat-symlinks
  - update with SUSE/v234
  - disble networkd, resolved, journal-remote
- Import commit 0053b83a1d913954f0d2eb22bb2a0df2ef252e19
  9b64225e9 (origin/SUSE/v234, SUSE/v234) resolved: fix loop on packets with pseudo dns types (bsc#1065276 CVE-2017-15908)
  261a4ef38 (origin/compats/udev-compat-symlinks, compats/udev-compat-symlinks) compat-rules: generate compat by-id symlinks with 'nvme' prefix missing (bsc#1063249)
  9707249bc udev: add option to generate old 'buggy' SCSI serials
  52cf64d2b journald: turn ForwardToSyslog= on by default (bsc#1065301)
  e2f3cf5f2 logind: disable RemoveIPC by default
  7a2a3b134 (origin/compats/persistent-nic-names, compats/persistent-nic-names) udev: add a persistent rule for ibmvnic devices
  74b2d3b88 udev: disable predictable network interface names by default
  ef9f437a0 udev: Revert the use of -DNET_IFNAME=1 to use persistent name by default
  e61a078ed udev: move persistent net rule generator to SCRIPTS
  9c95cc9ac udev: rework KVM persistent rules generatior (again)
  760a6f70d udev: fix persistent netrule generator for KVM
  9d173534c udev: better checks in write_net_rules() in persistent net rule generator
  5540a0b7c udev: fix duplicated rules with layer3 interfaces in persistent net rule generator
  d87359c59 udev: re-enable dev_id conditionally in persistent net rule generator
  5a0c34683 udev: disable usage of dev_id in persistent net rule generator
  73fa44a85 udev: re-add persistent net rule generator
  a7d25354d Revert "udev: network device renaming - immediately give up if the target name isn't available"
* Thu Oct 26 2017 fbui@suse.com
- Import commit e44237e76f6e133e62ff6c681d3fd06ebf12f66d
  a4e02c099 udev-rules: all values can contain escaped double quotes now (#6890)
  d2b767a76 tmpfiles: remove old ICE and X11 sockets at boot (#6979)
* Thu Oct 19 2017 fbui@suse.com
- Add 0001-systemd-firstboot-add-vconsole-keymap-support.patch (bsc#1046436)
  Temporary patch until it's been merged by upstream, see
  https://github.com/systemd/systemd/pull/7035
* Fri Oct  6 2017 fbui@suse.com
- Damn forgot to drop 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch in
  the spec file
* Fri Oct  6 2017 fbui@suse.com
- Import commit 6dea894131d78b20b9e0482f75afa6ee4dec8627
  1cdd944b0 unit: when JobTimeoutSec= is turned off, implicitly turn off JobRunningTimeoutSec= too (bsc#1004995)
  This make 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch
  not needed anymore.
* Thu Oct  5 2017 fbui@suse.com
- Import commit 93688f8e53b4e482a55a7d4aba2d927ddedebdde
  c53522be3 compat-rules: allow to specify the generation number through the kernel cmdline
* Wed Oct  4 2017 fbui@suse.com
- Import commit c1e8af7d1e8b09c2878a5b17f513bfc41ae46dc6
  982754275 build-sys: make sure 61-persitent-storage-compat.rules is installed with meson
  9ac2e8b9b udev: proc_cmdline_get_key() FTW! (#6925)
* Tue Sep 26 2017 fbui@suse.com
- Import commit 9e0985dc330b1cf04bc44049962343bdf4ba851a
  4fd7cd041 pam_logind: skip leading /dev/ from PAM_TTY field before passing it on
  dd6312828 logind: make sure we don't process the same method call twice (#6583)
* Tue Sep 26 2017 fbui@suse.com
- Update scripts-systemd-upgrade-from-pre-210.sh script
  - drop dependency on awk
  - fallback to runlevel #3 if something goes wrong
  Note: I'm not sure how this is supposed to work as /etc/inittab is
  likely to be missing in my understanding. Indeed this file is part
  of the aaa_base package which might be upgraded before systemd is
  installed...
* Tue Sep 26 2017 fbui@suse.com
- Drop macros.systemd.upstream as it's not used
* Thu Sep 14 2017 fbui@suse.com
- Import commit 58ea3c819cca1639ef8c922505c573ba5e262b3d
  334945091 shutdown: fix incorrect fscanf() result check (#6806)
  027202892 shutdown: don't remount,ro network filesystems. (#6588) (bsc#1035386)
  bc77b53a5 shutdown: don't be fooled when detaching DM devices with BTRFS (boo#1055641)
  d9d293847 util: make get_block_device() available
  421ce7382 tmpfiles: silently ignore any path that passes through autofs (#6506) (bsc#1045472)
  ca8f90e62 device: make sure to remove all device units sharing the same sysfs path (#6679)
* Thu Sep 14 2017 fbui@suse.com
- Make use of "%%tmpfiles_create" in %%post of the logger subpackage
* Thu Sep 14 2017 fbui@suse.com
- Add scripts-udev-convert-lib-udev-path.sh (bsc#1050152)
  This script takes care of converting /lib/udev into a symlink
  pointing to /usr/lib/udev when upgrading a distro using an old
  version of udev.
* Thu Sep 14 2017 fbui@suse.com
- Make use of "%%make_build" rpm macro
* Thu Sep 14 2017 fbui@suse.com
- Renumber scripts to start at index 100
* Thu Sep 14 2017 fbui@suse.com
- Introduce scripts-systemd-upgrade-from-pre-210.sh
  It collects all existing hacks done in %%post to fix old/deprecated
  settings in systemd older than 210. This includes hacks needed to
  fix system that are migrating from SysV.
  There shouldn't be any functional changes.
* Thu Sep 14 2017 fbui@suse.com
- Move scripts for packaging workaround/fixes in /usr/lib/systemd/scripts
  It also renames fix-machines-subvol-for-rollbacks.sh into
  scripts-systemd-fix-machines-btrfs-subvol.sh
  Note that the "scripts-systemd-" prefix is used for those scripts so
  we can gather them. Why not using a directory instead ? because osc
  doesn't allow that.
* Wed Aug 30 2017 fbui@suse.com
- Add 0001-Revert-core-device-Use-JobRunningTimeoutSec-for-devi.patch (bsc#1048605)
  It's a temporary but urgent fix for a regression discovered in bug
  1048605. The fix is still under discussion with upstream but we need
  to make progress here and limit the number of affected users.
  Consequently this fix reintroduces bsc#1004995 (the bug report has
  been re-opened) but this one is far less critical and a workaround
  was provided.
  The final solution will fix both bugs.
* Tue Aug 29 2017 fbui@suse.com
- Import commit 2bed4bf99cf7f24eafda490f778ed5e109f8d7f1
  7a4935268 compat-rules: drop the boggus 'import everything' rule (bsc#1046268)
* Tue Aug  1 2017 fbui@suse.com
- %%regenerate_initrd_post is suppsed to be used in %%post (not %%pre) section
* Fri Jul 28 2017 fbui@suse.com
- Import commit 6887cc21f23e33ac37801a01d76176e5c16fd8ea
  9dcc6c04e pid1: forward port console specificities handling for s390 arch to v234
* Fri Jul 28 2017 fbui@suse.com
- Import commit 986e98fd5a75470ba17e21fea12d7d4e966c1ecc
  4706ebc62 call chase_symlinks without the /sysroot prefix (#6411) (boo#1051172)
* Thu Jul 27 2017 fbui@suse.com
- Remove the unneeded hack forcing systemd-crypsetup binary to be linked against the just built libudev
  I don't remember why it was added but it looks unnecessary: most of
  all systemd components are linked againt libsystemd-shared.so which
  includes all the just built symbols.
  Also I don't see why it was done only for systemd-cryptsetup since
  all other binaries should have had suffered from the same issue.
* Wed Jul 26 2017 fbui@suse.com
- Import commit c5705e01800bdadd6a4fa7dc50d47b13eb697211
  8ea065d44 compat-rules: don't rely on ID_SERIAL when generating 'by-id' symlinks for NVMe devices (bsc#1048679)
* Wed Jul 26 2017 fbui@suse.com
- Import commit 06bed720274d9436405a7c27c8238d7d1aefca2b
  66fffdf12 build-sys: don't hook var-lib-machined.mount to remote-fs.target when machined is disabled
  96c232066 Revert "core: don't load dropin data multiple times for the same unit (#5139)"
* Wed Jul 26 2017 fbui@suse.com
- Drop support of compression from the mini package
  Hence remove the relevant build-requires from the mini package.
* Fri Jul 21 2017 fbui@suse.com
- Upgrade to v234 (commit 78af11131da1b2760778206806c0ebe8616a5284)
  - package /etc/systemd/system/dbus-org.freedesktop.network1.service
  - /usr/lib/systemd/resolv.conf is not installed if resolved is disabled
* Fri Jul  7 2017 jengelh@inai.de
- Edit pkgconfig(liblz4) dependency: liblz4 now uses 1.x *again*
* Thu Jul  6 2017 fbui@suse.com
- Added 0001-core-disable-session-keyring-per-system-sevice-entir.patch (bnc#1045886)
  Temporary patch to disable the session keyring stuff as it's
  currently broken and may introduce some security holes.
* Thu Jul  6 2017 fbui@suse.com
- Import commit 21827ea0875ff197e16e72003b2bfaa1c6e8daad
  1ad06735f core: fail when syntactically invalid values for User=/Group= fields are detected (bsc#1047023)
  d563972e2 timesyncd: don't use compiled-in list if FallbackNTP has been configured explicitly
  f4e0c16f5 gpt-auto-generator: fix the handling of the value returned by fstab_has_fstype() in add_swap() (#6280)
  e1345aac5 fix add_esp() in the gpt-auto-generator.c (#6251)
  c591ece9a automount: don't lstat(2) upon umount request (#6086) (bsc#1040968)
  643ab2eea gpt-auto-generator: disable gpt auto logic for swaps if at least one is defined in fstab
  f07d2022f fstab-util: introduce fstab_has_fstype() helper
  bf735bb35 fstab-util: don't eat up errors in fstab_is_mount_point()
  a4b40fbed resolved: simplify alloc size calculation (bsc#1045290 CVE-2017-9445)
  8b960bec0 only check signature job error if signature job exists (#6118) (boo#1043758)
  1418bfb5b job: Ensure JobRunningTimeoutSec= survives serialization (#6128) (bsc#1004995)
  19b6d5f08 udev: turn off -Wformat-nonliteral for one safe case
  717ace439 udev: net_id add support for platform bus (ACPI, mostly arm64) devices (#5933)
  a3bf2e6b5 core/mount: pass "-c" flag to /bin/umount (#6093)
* Wed Jul  5 2017 fbui@suse.com
- Add minimal support for boot.d/* scripts in systemd-sysv-convert (boo#1046750)
  While at it, the handling of the symlink priorities is also removed
  since it doesn't appear to be used at all.
* Thu Jun 22 2017 fbui@suse.com
- Don't try to restart networkd/resolved if they're disabled (boo#1045521)
  "systemctl try-restart/preset" wants the unit files exist.
* Thu Jun 22 2017 fbui@suse.com
- Stop shipping /usr/lib/sysusers.d/basic.conf (bsc#1006978)
  Ok looks like the previous change was the right thing to do and we
  continue to follow this path by relying on the new user/group scheme
  Therefore the basic system user/group are now managed and created by
  system-sysusers and udev also relies on this for the groups it uses
  in its rule files.
  Ideally we should have listed all of the groups in the deps (with
  "Requires: group(disk)" but the list of the groups is rather long
  and the risk for those groups to be re-organized is probably low, so
  currently we simply use "Requires: system-group-hardware" as a
  shortcut.
* Fri Jun 16 2017 fbui@suse.com
- Make sure "lock" group is created
  On SUSE distros, /run/lock must be owned by "lock" group (see
  boo#733523).
  This group was previously created by another package but since a
  recent changes it doesn't seem to be true anymore or at least this
  package isn't pulled in anymore when building the rescue system.
  For now make systemd creates the group by adding
  "Requires: group(lock)".
  I'm currently not sure why we don't use sysusers.d stuff for that
  purpose and if the "lock" group on /run/lock is still
  mandatory. This should be revisited later.
* Wed Jun  7 2017 fbui@suse.com
- Make sure dracut (if installed) will embed the new compat rule
  The new compat rule must be embedded in the initramfs so make sure
  that the installed dracut supports it.
* Wed May 24 2017 fbui@suse.com
- Upgrade to v233 (commit 330b55d5e28d17f361062dba66426e46fb7d7857)
  - package new systemd-umount binary
  - package new environment generator stuff
  - drop /dev/root symlink support
  - /etc/pam.d/systemd-user is not patched anymore but we ship a
    dedicated file for SUSE now.
  - manage compat symlink generation in a dedicated branch (bsc#1040153)
* Wed May 17 2017 fbui@suse.com
- Fix systemd-sysv-convert when a package starts shipping service units (bsc#982303)
  The database might be missing when upgrading a package which was
  shipping no sysv init scripts nor unit files (at the time --save was
  called) but the new version start shipping unit files.
* Wed May 17 2017 fbui@suse.com
- Fix indentation in systemd-sysv-convert
  While at it, strip trailing whitespaces.
  No functional changes.
* Thu May 11 2017 fbui@suse.com
- Disable group shadow support (bsc#1029516)
  The new configure option will be imported during the next tarball
  update.
* Tue May  2 2017 fbui@suse.com
- Ship /var/log/README
  Unfortunately it's not possible to also ship /etc/init.d/README
  because of rpm "sanity" checks that prevent executable in
  /etc/init.d
* Tue May  2 2017 fbui@suse.com
- Drop systemd-{journalctl,loginctl} legacy symlinks.
* Tue May  2 2017 fbui@suse.com
- Drop %%preun section
  Currently the only use of this section is to remove the symlinks
  enabling systemd services on package removal. Those symlinks were
  initially installed by the systemd package installation but could
  have been overriden by the sysadmin later. If so the symlinks
  shouldn't be uninstalled.
  Also in a near futur disabling services will install a symlink to
  /dev/null.
* Tue May  2 2017 fbui@suse.com
- Import commit 9e33c2ae69fbb705e8ad143536e419a231e93020
  04ef0eab8 importd: support SUSE style checksums supplementary (#5800)
  fb601ad9a importd: support SUSE style checksums (#5206) (fate#322054)
  b76b27c76 hwdb: fix warning "atkbd serio0: Unknown key pressed" (#5772) (boo#1010220)
  cb0d991f6 loginctl: fix typo causing ignoring multiple session IDs (#5732)
* Tue May  2 2017 fbui@suse.com
- Make use of %%systemd_postun()
* Tue May  2 2017 fbui@suse.com
- Restart a couple of systemd services on package update
  Those services (most notably journald) should support restarting
  these days. However logind still doesn't but that should be fixed
  pretty soon, well I hope :)
* Tue May  2 2017 fbui@suse.com
- Don't buildrequire pam-config, it's not used at this step.
  Also drop the use of it in %%postun as it can't realistically
  happen...
* Thu Apr 20 2017 fbui@suse.com
- Don't call /sbin/ldconfig in %%post of the main package
  systemd main package doesn't ship any shared libs so there's no
  point in calling ldconfig in %%post/%%postun
* Thu Apr 20 2017 fbui@suse.com
- Silent %%tmpfiles_create in %%post (bsc#1034938)
  Due to bsc#1024740, we stopped generating /etc/machine-id during
  systemd package installation making the specifier '%%m' unavailable
  in the tmpfiles.d configuration files at this time.
  Make it simple for now and silent %%tmpfiles_create, after all that's
  how the macro was implemented originally.
* Mon Apr 10 2017 fbui@suse.com
- Import commit f0325620d23a247682c629d28883a364e4a7a8c4
  327814841 core: when a unit's SourcePath points to API VFS pretend we are never out-of-date (#5487)
  f4b9fb58e units: move Before deps for quota services to remote-fs.target (#5627) (bsc#1028263)
  44b9d27f8 udev: net_id - support predictable ifnames on vio buses (#5675) (bnc#1029183)
  64f4761c9 units: apply plymouth warning fix to in rescue mode as well (#5615)
  77607b887 units: do not throw a warning in emergency mode if plymouth is not installed (#5528) (bsc#1025398)
  336d6016c core: downgrade "Time has been changed" to debug (#4906) (bsc#1028610)
* Wed Mar 22 2017 fbui@suse.com
- Consider chroot updates in fix-machines-subvol-for-rollbacks.sh (bsc#1030290)
* Tue Mar 14 2017 fbui@suse.com
- Initialize /etc/machine-id during the first boot (bsc#1024740)
  Previously that was done at package installation but it didn't fit
  well for appliance builds.
* Tue Mar  7 2017 fbui@suse.com
- Import commit 68fc0a749a83d16d4cde8471d5030bc6254ffd96
  76d4d05fb udev: fix variable assignment
  473df8cc4 udev-rules: perform whitespace replacement for symlink subst values (bsc#1025886)
  d6c3ff647 udev-event: add replace_whitespace param to udev_event_apply_format
  30ad15f7c libudev-util: change util_replace_whitespace to return number of chars in dest
* Fri Mar  3 2017 fbui@suse.com
- Import commit 103259b3226251d06f79ca627f7b0ba0bd49f4bc
  0ee7890dd automount: if an automount unit is masked, don't react to activation anymore (#5445)
  99865a181 core: make sure to destroy all name watching bus slots when we are kicked off the bus (#5294) (bsc#1006687)
  f34234c54 build-sys: add check for gperf lookup function signature (#5055)
  44e39538f sd-event: "when exiting no signal event are pending" is a wrong assertion (#5271) (boo#995936 bsc#1022014)
  471b26807 sd-event: when an event source fails, don't assume the type of it is still set
* Mon Feb 20 2017 fbui@suse.com
- Don't ship systemd-resolved for now (bsc#1024897)
  If resolved is enabled , systemd-tmpfiles creates a wrong symlink in
  /etc/resolv.conf which confuses the network manager actually used.
* Thu Feb  9 2017 fbui@suse.com
- More indentation cleanup (no functional changes)
* Wed Feb  8 2017 kukuk@suse.de
- Remove obsolete insserv requirements for udev again [bsc#999841]
* Mon Feb  6 2017 fbui@suse.com
- Import commit cd97d5d5fef79ab9d957bf6504d085c0faca6bfc
  e587b6ce0 disable RestrictAddressFamilies on all architectures but x86_64 one (bsc#1023460)
  c8ae05632 journald: don't flush to /var/log/journal before we get asked to (bsc#1004094)
  7261eaf3e sd-event: fix sd_event_source_get_priority() (#4712)
* Fri Feb  3 2017 fbui@suse.com
- Move fix for permission set on /var/lib/systemd/linger/* (no functional changes)
  Move that part after the fix on timer timestamp files otherwise the
  comment doesn't make sense.
* Wed Feb  1 2017 fbui@suse.com
- Import commit 028fd9b60580976dffb09b3576a2b652ee35137c
  cc2ca55ff build-sys: do not install ctrl-alt-del.target symlink twice
  ececae77a device: Avoid calling unit_free(NULL) in device setup logic (#4748)
* Wed Feb  1 2017 fbui@suse.com
- Ship systemd-resolved but it's disabled by default (bsc#1018387)
  The NSS plugin will also be disabled, users need to enable it
  manually.
* Wed Jan 25 2017 fbui@suse.com
- Don't ship ldconfig.service anymore
  This service was introduced to support stateless systems that
  support offline /usr updates properly.
  AFAIK we don't support any such system for now, so disable it. If
  it's wrong it's easy enough to restore it back.
  Related to bsc#1019470.
* Wed Jan 25 2017 fbui@suse.com
- Be more consistent with indentation (*no* functional changes)
  Indentation should use 8 spaces now (no tabs).
* Wed Jan 25 2017 fbui@suse.com
- Import commit 2559bc0c076b58f0a649056e79ca90fe5f1d556c
  9c4a759ab systemctl: 'show' don't exit with a failure status if the requested property does not exist [SUSE] (bsc#1021062)
  f9194193b systemctl: remove duplicate entries showed by list-dependencies (#5049) (bsc#1012266)
  2a6653335 rule: don't automatically online standby memory on s390x (bsc#997682)
* Wed Jan 25 2017 fbui@suse.com
- Fix permission set on /var/lib/systemd/linger/*
  Those files are created by logind which run with umask(0022), so
  they are not world writable and shouldn't be affected by
  bsc#1020601. But it's cleaner to not let files forever with their
  setuid bit set for no good reason.
* Wed Jan 25 2017 fbui@suse.com
- Fix permissions set on permanent timer timestamp files (bsc#1020601) (CVE-2016-10156)
  This change makes sure to fix the permissions of the timestamp files
  which could have been created by an affected version of systemd.
  Local unprivileged users could have run arbitrary code as root if
  systemd previously created world writable suid root files such as
  permanent timer stamp files.
* Tue Jan 10 2017 fbui@suse.com
- Import commit 3edb876e3b80437a95502aa5d31d454606ea94bd
  27b544224 core: make sure to not call device_is_bound_by_mounts() when dev is null (#5033) (bsc#1018399)
* Fri Jan  6 2017 fbui@suse.com
- Use the %%{resolved} build conditional for the nss-resolve subpackage
* Thu Jan  5 2017 fbui@suse.com
- /usr/bin/systemd-resolve was missing from the filelist
* Thu Jan  5 2017 fbui@suse.com
- Silent warnings emitted when udev socket units are restarted during package upgrade (bsc#1018214)
* Mon Dec 19 2016 fbui@suse.com
- Upgrade to v232, commit de62e96da6a62ac61a7dea45cc558f5fa4342032
  - a4dff165d nspawn: resolv.conf might not be created initially (#4799)
  - b543fe907 nspawn: fix condition for mounting resolv.conf (#4622)
  - 1aed89e55 core: make mount units from /proc/self/mountinfo possibly bind to a device (#4515) (boo#909418 bsc#912715 bsc#945340)
  - bfb54ecdc coredumpctl: let gdb handle the SIGINT signal (#4901) (bsc#1012591)
* Wed Dec 14 2016 fbui@suse.com
- Really include legacy kbd maps in kbd-model-map (bsc#1015515)
  Instead of fix-machines-subvol-for-rollbacks.sh...
* Thu Dec  8 2016 fbui@suse.com
- Enable lz4 (which becomes the default)
  It's much faster than xz and thus should be more appropriate to
  compress journals and coredumps.
  The LZ4 logic is now officially supported and no longer considered
  experimental.
  The new frame api was released in v125.
* Tue Dec  6 2016 fbui@suse.com
- Good by compatlibs support
  There's no longer need for enabling/disabling the support for the
  compatlibs as it's been dropped from the source code.
* Tue Nov 29 2016 fbui@suse.com
- Drop /usr/lib/systemd/libsystemd-shared-%%{version}.so from the 32bit package
  This shared library is not for public use, and is neither API nor
  ABI stable, but is likely to change with every new released
  update. Only systemd binaries are supposed to link against it.
  This also prevents from the 32bit package to conflit with the 64bit
  one if this lib was installed by both packages.
* Tue Nov 22 2016 fbui@suse.com
- Upgrade to v232, commit c5c3445825981e2a5c3ed71214127d5b1b9de802:
  - Dropped backported commits which has been merged
  - Forward-port Suse specific patches
  - Added --disable-lto option to ./configure
  - Added systemd-mount
  - Removed in %%file /usr/lib/systemd/user/*.socket: since
    798c486fbcdce3346cd86 units/systemd-bus-proxyd.socket has been
    removed.
  - Removed in %%file %%{_sysconfdir}/systemd/bootchart.conf
    since commit 232c84b2d22f2d96982b3c bootchart is not part of systemd
    anymore.
  - Backward compat libs have been disabled since it's been dropped from
    the source code.
  - Added /usr/bin/systemd-socket-activate in %%file
  - Added --without-kill-user-processes ./configure option
  - Bump libseccomp build require (>= 2.3.1) as described in README
  - Specifiy version of libmount as required in the README
* Fri Nov 18 2016 meissner@suse.com
- libudev-devel 32bit is needed for building 32bit wine now.
* Mon Nov 14 2016 fbui@suse.com
- specfile: conflict systemd-bash-completion and systemd-mini-bash-completion
  Otherwise the build system detects that systemd-bash-completion and
  its mini variant are conflicting at files level even though those
  packages can't be installed on the same system.
* Thu Nov 10 2016 fbui@suse.com
- specfile: clean up nss-* plugins descriptions and drop
  nss-myhostname-config script for now.
  Currently /etc/nsswitch.conf is supposed to be edited by the
  sysadmin to enable the modules. However for some reasons only
  nss-myhostname is removed from the conf file when the corresponding
  package is uninstalled. This is inconsistent so let's remove it.
  Actually I'm wondering if we shouldn't make those NSS plugins part
  of the main package and get rid of all those sub-packages...
* Thu Nov 10 2016 fbui@suse.com
- specfile: remove old comments and unneeded sed command
* Thu Nov 10 2016 fbui@suse.com
- specfile: no need to create systemd-update-utmp-runlevel.service symlinks anymore
  The symlinks in /usr/lib/systemd/system/<target>.target.wants/systemd-update-utmp-runlevel.service
  are created in Makefile.am since commit d5d8429a12c4b1.
  'reboot' and 'poweroff' targets initially had the symlinks but
  there's not point since the latter conflicts shutdown.target whereas
  the 2 targets pull it in.
  See: https://github.com/systemd/systemd/pull/4429
* Thu Nov 10 2016 fbui@suse.com
- specfile: remove the following warnings:
  [  256s] warning: File listed twice: /usr/lib/systemd/system/dbus.target.wants
  [  256s] warning: File listed twice: /usr/lib/systemd/system/default.target.wants
* Wed Oct 26 2016 fbui@suse.com
- Own a couple of directories even if they don't belong to systemd
  otherwise the build system will complain.
  Some directories (owned by others packages) are simply used by
  systemd to ship some scripts or config files to customize others
  * optional* components. Since thos components are not build required
  by systemd those directories are not owned by any packages and the
  BS complains...
* Wed Oct 26 2016 fbui@suse.com
- Import commit
  15ea716 journal-remote: change owner of /var/log/journal/remote and create /var/lib/systemd/journal-upload (bsc#1006372)
* Mon Oct 24 2016 fbui@suse.com
- %%sysusers_create and %%tmpfiles_create must be called in %%post
  Calling %%pre is broken since the respective conf files are not yet
  installed.
* Mon Oct 24 2016 fbui@suse.com
- %%{_libexecdir}/{tmpfiles.d,sysusers.d}/systemd-remote.conf are
  part of systemd-journal-remote package (only).
* Mon Oct 24 2016 fbui@suse.com
- systemd-journal-{gatewayd,remote,upload} units are only part of
  "systemd-journal-remote" package.
  So exclude them from the main package.
* Mon Oct 24 2016 fbui@suse.com
- Import commit a1c145e6ad6588555dca64402f9103fb1e02b1a0
  7f34037 man: explain that *KeyIgnoreInhibited only apply to a subset of locks
  df5798b Revert "logind: really handle *KeyIgnoreInhibited options in logind.conf" (bsc#1001790 bsc#1005404)
  f79fee7 Revert "kbd-model-map: add more mappings offered by Yast"
  3760c10 manager: tighten incoming notification message checks
  d6efd71 core: only warn on short reads on signal fd
  6eebd91 manager: be stricter with incomining notifications, warn properly about too large ones
  fdf2dc3 manager: don't ever busy loop when we get a notification message we can't process
* Thu Oct 20 2016 fbui@suse.com
- Rename kbd-model-map-extra into kbd-model-map.legacy
* Wed Oct 19 2016 fbui@suse.com
- Remove tcpd-devel build requirement.
  tcpwrap support has been removed since v212, see commit
  7f8aa67131cfc03ddcbd31c0420754864fc122f0
* Tue Oct 18 2016 fbui@suse.com
- remove all dummy "aliases" to /etc/init.d (as it was already done by
  factory more than 1 year ago).
  Even if a sysvinit script is still requiring one of those dummy
  symlinks this should not be an issue since this is requirement is
  translated into a weak dependency.
* Tue Oct 18 2016 fbui@suse.com
- specfile:
  - do not own /usr/share/zsh directory
  - do not own /etc/dbus-1 and /etc/dbus-1/system.d dirs
  - do not own /usr/share/dbus-1 dir
* Tue Oct 18 2016 fbui@suse.com
- specfile: %%{_prefix}/lib/systemd/system-preset was mentioned twice
  in %%files section.
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - use curly braces with rpm macros
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - %%ghost files doesn't need (anymore) to be created in %%builroot
  - do not own /etc/X11/xorg.conf.d and /etc/X11/xinit
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup: no need to protect the manpages with %%bootstrap
  condition in nss-myhostname package since the package itself is
  already protected.
* Tue Oct 18 2016 fbui@suse.com
- fix nss-resolve sub package:
  - add a %%files section
  - add a package description
  - libnss_resolve.so.2 is now part of this subpackage
  - add %%post and %%postun sections
* Tue Oct 18 2016 fbui@suse.com
- Specfile cleanup:
  - reorganize some files in %%files by types
  - some config files were missing the "noreplace" attribute
* Tue Oct 18 2016 fbui@suse.com
- Use %%config(noreplace) for %%{_sysconfdir}/pam.d/systemd-user
* Tue Oct 18 2016 fbui@suse.com
- Rework systemd-gatewayd package:
  - some gateway's files were still in the main package
  - it now includes all progs dealing with remote journals
  - it can be turned off (SP2 does that currently)
  - it's been renamed systemd-journal-remote to reflect that
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - only specify once %%{_prefix}/lib/systemd/system-shutdown in %%file
  - no need to list the content of %%{_prefix}/lib/systemd/user-generators in %%file
  - machined is not built when %%bootstrap = 1
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - There's no point in listing all generators in %%file
    explicitly. The default is to include all of them and if for some
    reason one must be excluded then it should be done explicitly.
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - remove explicit call to make for building man pages. This is not
    needed and was maybe useful when generated doc was pre-built and
    shipped in the tarball.
* Mon Oct 17 2016 fbui@suse.com
- Specfile cleanup:
  - break overly long and unreadable line using mkdir
  - gather directory creations
* Mon Oct 17 2016 fbui@suse.com
- Stop providing udevd.8
  systemd-udevd has replaced udevd for some time already and usage of
  udevd should be avoided. Therefore don't encourage this and stop
  documenting it.
* Mon Oct 17 2016 fbui@suse.com
- Import from factory:
  - Thu Feb  4 11:05:37 UTC 2016 - lnussel@suse.de
  - curl also causes building of journal-upload. That one has rather
    unusal certificate usage, set it's ca root to /etc/pki/systemd
    instead of the built-in default /etc/ssl as journal-remote and
    journal-upload think they can put stuff in /etc/ssl/certs then
    but that directory is managed by p11-kit and doesn't serve the
    purpose those programs think.
* Thu Oct 13 2016 fbui@suse.com
- Package rootsymlink-generator helper. It was forgotten when
  switching to the git repo but re-added back.
  That said this thing should be removed as it's broken as soon as
  there's no direct link between the root fs and its backend device
  node (i.e. BTRFS).
* Thu Oct 13 2016 fbui@suse.com
- Add kbd-model-map-extra file which contains the additional legacy
  keymaps needed by yast.
  This was previously directly patched in the systemd source code.
* Mon Oct 10 2016 fbui@suse.com
- Imported e251b8d7fb5c801fdfa3a023257ba0e4d514f3b0
  - Re-add back /dev/root symlink generation (although this must be
    deprecated and finally removed).
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  Third step:
  - Re-enable networkd (disabled by default in SLE12)
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  Second step:
  - Import the specfile
  - Import the tarball generated from the git repo
  - Import lastest changes for the different scripts
* Fri Oct  7 2016 fbui@suse.com
- Migrating to the Suse Systemd git repo:
  First step: drop all patches and drop the tar ball.
  The dropped patches are:
    fix-support-for-boot-prefixed-initscript-bnc-746506.patch
    set-and-use-default-logconsole.patch
    ensure-ask-password-wall-starts-after-getty-tty1.patch
    0001-rules-block-add-support-for-pmem-devices-3683.patch
    Fix-run-lock-directories-permissions-to-follow-openSUSE-po.patch
    1007-physical-hotplug-cpu-and-memory.patch
    1066-udev-add-compatibility-links-for-truncated-by-id-links.patch
    watch_resolv.conf_for_become_changed.patch
    0019-make-completion-smart-to-be-able-to-redirect.patch
    systemd-add-user-keep.patch
    0001-core-re-sync-bus-name-list-after-deserializing-durin.patch
    systemd-228-nspawn-make-journal-linking-non-fatal-in-try-and-auto.diff
    avoid-random-hangs-on-timeouts-due-lost-cwd.patch
    1037-udev-exclude-cd-dvd-from-block-device.patch
    0001-add-network-device-after-NFS-mount-units.patch
    journald-advice-about-use-of-memory.patch
    1011-64-btrfs.rules-skip-btrfs-check-if-devices-are-not-r.patch
    1006-udev-always-rename-network.patch
    handle-numlock-value-in-etc-sysconfig-keyboard.patch
    use-rndaddentropy-ioctl-to-load-random-seed.patch
    0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
    0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
    0001-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    0001-bnc888612-logind-polkit-acpi.patch
    avoid-divide-by-zero-sigtrap.patch
    1035-99-systemd.rules-Ignore-devices-with-SYSTEMD_READY-0.patch
    suse-sysv-bootd-support.diff
    ensure-shortname-is-set-as-hostname-bnc-820213.patch
    parse-crypttab-for-noauto-option.patch
    tty-ask-password-agent-on-console.patch
    0001-pid1-process-zero-length-notification-messages-again.patch
    handle-root_uses_lang-value-in-etc-sysconfig-language.patch
    0001-core-exclude-.slice-units-from-systemctl-isolate.patch
    vhangup-on-all-consoles.patch
    0001-systemctl-pid1-do-not-warn-about-missing-install-inf.patch
    apply-ACL-for-nvidia-device-nodes.patch
    make-emergency.service-conflict-with-syslog.socket.patch
    0001-journal-warn-when-we-fail-to-append-a-tag-to-a-journ.patch
    1096-new-udev-root-symlink-generator.patch
    1099-Add-default-rules-for-valve-steam-controller-to-work.patch
    0001-journal-set-STATE_ARCHIVED-as-part-of-offlining-2740.patch
    systemd-install-compat_pkgconfig-always.patch
    1012-Skip-persistent-device-link-creation-on-multipath-de.patch
    0001-avoid-abort-due-timeout-at-user-service.patch
    insserv-generator.patch
    apply-ACL-for-nvidia-uvm-device-node.patch
    restore-var-run-and-var-lock-bind-mount-if-they-aren-t-sym.patch
    systemd-pam_config.patch
    systemd-dbus-system-bus-address.patch
    let-linker-find-libudev-for-libdevmapper.patch
    1098-systemd-networkd-alias-network-service.patch
    0001-let-systemctl-completion-ignore-at-names.patch
    boot-local-start.patch
    1095-set-ssd-disk-to-use-deadline-scheduler.patch
    tomcat6-var-lock-subsys-legacy.patch
    let-vconsole-setup-get-properties-only-once-to-copy-them.patch
    plymouth-quit-and-wait-for-emergency-service.patch
    respect-nfs-bg-option.patch
    0001-If-the-notification-message-length-is-0-ignore-the-m.patch
    1062-rules-set-default-permissions-for-GenWQE-devices.patch
    rescue-emergency-target-conflicts.patch
    Correct_assert_on_unexpected_error_code.patch
    1097-udevd-increase-maximum-number-of-children.patch
    0001-core-fix-bus-name-synchronization-after-daemon-reloa.patch
    1005-create-default-links-for-primary-cd_dvd-drive.patch
    allow-multiple-sulogin-to-be-started.patch
    systemd-230-cgroup2-use-new-fstype-for-unified-hierarchy.patch
    0010-do-not-install-sulogin-unit-with-poweroff.patch
    1003-udev-netlink-null-rules.patch
    1002-rules-create-by-id-scsi-links-for-ATA-devices.patch
    0001-nss-mymachines-do-not-allow-overlong-machine-names.patch
    shut-up-rpmlint-on-var-log-journal.patch
    systemd-tmp-safe-defaults.patch
    portmap-wants-rpcbind-socket.patch
    hostname-NULL.patch
    0001-pid1-more-informative-error-message-for-ignored-noti.patch
    0001-journal-fix-HMAC-calculation-when-appending-a-data-o.patch
    handle-disable_caplock-and-compose_table-and-kbd_rate.patch
    kbd-model-map.patch
    systemctl-set-default-target.patch
    0014-journald-with-journaling-FS.patch
    0001-On_s390_con3270_disable_ANSI_colour_esc.patch
* Fri Sep 30 2016 fbui@suse.com
- Import a better fix from upstream for bsc#1001765
  - Added:
    0001-pid1-more-informative-error-message-for-ignored-noti.patch
    0001-pid1-process-zero-length-notification-messages-again.patch
  - Updated (no code changes, only patch metadata)
    0001-If-the-notification-message-length-is-0-ignore-the-m.patch
    0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
* Thu Sep 29 2016 fbui@suse.com
- Re add back "udev: don't require nsserv and fillup"
  Did this in the wrong project... it was a complicated day today ;)
* Thu Sep 29 2016 fbui@suse.com
- Added 2 patches to fix bsc#1001765
  0001-If-the-notification-message-length-is-0-ignore-the-m.patch
  0001-pid1-don-t-return-any-error-in-manager_dispatch_noti.patch
* Thu Sep 29 2016 fbui@suse.com
- Revert "udev: don't require nsserv and fillup"
  It's been judged too late for being part of SLE12 final release.
  Nevertheless it's part of Factory and will be reintroduced after the
  final release is out (ie through an update).
* Mon Sep 26 2016 fbui@suse.com
- systemd-sysv-convert: make sure that
  /var/lib/systemd/sysv-convert/database is always initialized (bsc#982211)
  If "--save" command was used and the sysv init script wasn't enabled
  at all the database file wasn't created at all. This makes the
  subsequent call to "--apply" fail even though this should not
  considered as an error.
* Mon Sep 26 2016 fbui@suse.com
- Added patches to fix journal with FSS protection enabled (bsc#1000435)
  0001-journal-fix-HMAC-calculation-when-appending-a-data-o.patch
  0001-journal-set-STATE_ARCHIVED-as-part-of-offlining-2740.patch
  0001-journal-warn-when-we-fail-to-append-a-tag-to-a-journ.patch
* Wed Sep 21 2016 fbui@suse.com
- udev: don't require nsserv and fillup (bsc#999841)
  udev has no LSB init scripts nor fillup templates anymore.
* Fri Sep 16 2016 fbui@suse.com
- Build require python and python-lxml in order to generate
  systemd.directives man page (bsc#986952)
* Fri Sep 16 2016 fbui@suse.com
- Add rules: block: add support for pmem devices (#3683) (bsc#988119)
  0001-rules-block-add-support-for-pmem-devices-3683.patch
* Tue Sep  6 2016 tbechtold@suse.com
- Fix is-enabled check in systemd-sysv-install (bsc#997268)
* Wed Aug 24 2016 dimstar@opensuse.org
- Only BuildRequire gnu-efi when building the 'real' systemd
  package.
* Tue Aug 23 2016 fbui@suse.com
- Add a script to fix /var/lib/machines to make it suitable for
  rollbacks (bsc#992573)
* Wed Aug 10 2016 meissner@suse.com
- reverted the systemctl split-off on request of Franck Bui.
* Fri Jul 29 2016 jengelh@inai.de
- Add sysusers to the new split "systemctl" subpackage
* Tue Jul 26 2016 jengelh@inai.de
- Split systemctl and tmpfiles into a separate package
* Tue Jul 19 2016 develop7@develop7.info
- Fix 1099-Add-default-rules-for-valve-steam-controller-to-work.patch
  to enable missing functionality of Steam Controller
* Sun Jul 17 2016 asarai@suse.com
- Backport unified_cgroup_hierarchy fix for Linux >= 4.4. boo#989276
  + systemd-230-cgroup2-use-new-fstype-for-unified-hierarchy.patch
* Sat Jun 18 2016 arvidjaar@gmail.com
- drop 1060-udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
  it breaks btrfs on multiple device-mapper devices (boo#984516). The problem
  it tried to fix is already fixed in rule shipped with btrfsprogs (see
  boo#912170).
* Wed May  4 2016 Thomas.Blume@suse.com
- fix warning about missing install info during preset (boo#970293)
  0001-systemctl-pid1-do-not-warn-about-missing-install-inf.patch
* Thu Apr  7 2016 schwab@suse.de
- Avoid bootstrap cycle with sg3_utils
* Tue Apr  5 2016 werner@suse.de
- Fix patch patch handle-numlock-value-in-etc-sysconfig-keyboard.patch
  that is do not close a file descriptor twice (boo#973907)
* Sat Mar 26 2016 jengelh@inai.de
- Add two patches which address logind/networkd disappearing from
  dbus (and busctl) even while the units and processes continue
  running.
  0001-core-fix-bus-name-synchronization-after-daemon-reloa.patch
  0001-core-re-sync-bus-name-list-after-deserializing-durin.patch
* Mon Mar 14 2016 fbui@suse.com
- drop all compiler/linker option customizations:
  - -pipe option is used by default since day 0
  - get rid of cflags() function which is not needed
  - --hash-size has no impact specially in runtime
  IOW, use the default options for the compiler and the linker,
  there's no point in making systemd different from other package in
  this regards.
* Mon Mar 14 2016 fbui@suse.com
- use %%make_build instead of 'make %%{?_smp_mflags}'
* Mon Mar 14 2016 fbui@suse.com
- be more strict on own lib version requirements
* Mon Mar 14 2016 fbui@suse.com
- systemd should require udev with the exact same version
* Thu Mar 10 2016 werner@suse.de
- Modify patch handle-numlock-value-in-etc-sysconfig-keyboard.patch
  to allow that open, seek, and read of /dev/mem may fail e.g.
  on XEN based virtual guests (bsc#961120)
* Tue Mar  1 2016 werner@suse.de
- Add upstream patch
  0001-core-exclude-.slice-units-from-systemctl-isolate.patch
  this fixes forced logouts on isolate target aka changing runlevel
  (boo#966535)
* Thu Feb  4 2016 lnussel@suse.de
- require curl and bzip2 to build importd
- curl also causes building of journal-upload. That one has rather
  unusal certificate usage, set it's ca root to /etc/pki/systemd
  instead of the built-in default /etc/ssl as journal-remote and
  journal-upload think they kan put stuff in /etc/ssl/certs then but
  that directory is managed by p11-kit and doesn't serve the purpose
  those programs think.
- /var/lib/systemd/random-seed is a file
- own /var/lib/machines
- add systemd-228-nspawn-make-journal-linking-non-fatal-in-try-and-auto.diff
* Sat Jan  9 2016 afaerber@suse.de
- systemd-sysv-install: Fix chkconfig argument for disable op
* Thu Jan  7 2016 olaf@aepfle.de
- Create groups adm,input,tape in fixed order (boo#944660)
* Mon Dec 21 2015 fbui@suse.com
- Make sure we don't use tmpfs on /tmp by default (bsc#940522)
* Mon Dec 21 2015 jengelh@inai.de
- Avoid enabling readahead services; they have been removed.
- In %%install, only process kbd-model-map.xkb-generated if it
  exists. Resolves a build failure in 13.2/42.1.
* Wed Dec  9 2015 crrodriguez@opensuse.org
- spec: update minimum kernel version to 3.11
- Update minimum util-linux version to 2.27.1
* Thu Dec  3 2015 tchvatal@suse.com
- Add patch to enable working steam controller:
  * 1099-Add-default-rules-for-valve-steam-controller-to-work.patch
* Mon Nov 30 2015 thomas.blume@suse.com
- fix CVE-2015-7510: Stack overflow in nss-mymachines (boo#956712)
  Add 0001-nss-mymachines-do-not-allow-overlong-machine-names.patch
* Wed Nov 18 2015 jengelh@inai.de
- Update to new upstream release 228
  * The various memory-related resource limit settings (such as
  LimitAS=) now understand the usual K, M, G, ... suffixes to
  the base of 1024 (IEC). Similar, the time-related settings
  understand the usual min, h, day, ... suffixes now.
  * CPUAffinity= now takes CPU index ranges in addition to just
  individual indexes.
  * A number of properties previously only settable in unit
  files are now also available as properties to set when
  creating transient units programmatically via the bus.
- Remove 0001-Make-sure-the-mount-units-pulled-by-RequiresMountsFo.patch
  (merged upstream)
* Fri Nov 13 2015 sor.alexei@meowr.ru
- Update to 227.
- Rebase systemd-pam_config.patch,
  handle-root_uses_lang-value-in-etc-sysconfig-language.patch,
  0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch,
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch,
  0014-journald-with-journaling-FS.patch,
  0019-make-completion-smart-to-be-able-to-redirect.patch,
  avoid-divide-by-zero-sigtrap.patch, systemd-add-user-keep.patch,
  set-and-use-default-logconsole.patch,
  tty-ask-password-agent-on-console.patch,
  0001-bnc888612-logind-polkit-acpi.patch,
  watch_resolv.conf_for_become_changed.patch,
  1097-udevd-increase-maximum-number-of-children.patch.
- Remove
  0002-units-enable-waiting-for-unit-termination-in-certain.patch,
  1001-re-enable-by_path-links-for-ata-devices.patch,
  rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch:
  fixed upstream.
* Thu Nov 12 2015 werner@suse.de
- Modify patch handle-root_uses_lang-value-in-etc-sysconfig-language.patch
  to handle locale at boot time well (boo#927250)
- Be able to use build service environments several times
* Tue Nov 10 2015 schwab@suse.de
- 1096-new-udev-root-symlink-generator.patch: fix substitution in
  ExecStart value
* Wed Oct 21 2015 dmueller@suse.com
- enable seccomp for aarch64 (fate#318444)
* Thu Oct 15 2015 fbui@suse.com
- Fix again UEFI for mini package
* Thu Oct 15 2015 jengelh@inai.de
- Drop one more undesirable Obsoletes/Provides. This should have
  been a Conflicts. (There was already a Conflicts, and since
  Conflicts go both ways, we won't need a second one.)
* Thu Oct 15 2015 werner@suse.de
- No UEFI for systemd-mini
* Mon Oct 12 2015 fbui@suse.com
- Add 2 upstream patches to fix boo#949574 and bsc#932284
  0001-Make-sure-the-mount-units-pulled-by-RequiresMountsFo.patch
  0002-units-enable-waiting-for-unit-termination-in-certain.patch
* Fri Oct  9 2015 fbui@suse.com
- Disable systemd-boot on aarch64 since it fails to build.
  Error while compiling src/boot/efi/util.o is:
  usr/include/efi/aarch64/efibind.h:2:20: fatal error: stdint.h: No such file or directory
* Fri Oct  9 2015 fbui@suse.com
- Fix UEFI detection logic: basically we let configure.ac figure out
  if UEFI is supported by the current build environment. No need to
  clutter the spec file with a new conditionnal %%has_efi.
- Provide systemd-bootx64.efi (aka gummiboot)
* Tue Oct  6 2015 werner@suse.de
- Modify patch tty-ask-password-agent-on-console.patch to reflect
  the changes done for pull request 1432
* Thu Oct  1 2015 jengelh@inai.de
- Undo Obsoletes/Provides (from Aug 11), creates too big a cycle.
- Provide systemd-sysv-install program/link [bnc#948353]
* Fri Sep 25 2015 werner@suse.de
- Fix patch tty-ask-password-agent-on-console.patch not to crash
  away but enable it to ask on all devices of /dev/console
* Wed Sep 23 2015 jengelh@inai.de
- Avoid "file not found /etc/udev/rules.d/70-persistent-net.rules"
  waring occurring in %%post
* Wed Sep 23 2015 werner@suse.de
- Add patch let-vconsole-setup-get-properties-only-once-to-copy-them.patch
  to avoid broken virtual console mapping due stressed ioctl API
  for the virtual consoles (boo#904214)
* Mon Sep  7 2015 werner@suse.de
- Fix last change that is use the new name for udev packages in %%pretrans.
* Mon Sep  7 2015 fbui@suse.com
- restore usage of LUA in %%pretrans.
* Mon Sep  7 2015 werner@suse.de
- Try to generate the systemd users and groups always in same order
  to avoid republish other packages (boo#944660)
* Fri Aug 21 2015 fbui@suse.com
- cleanup specfile by removing commands that were dealing with systemd
  pre-generated files: we're now using systemd tarball generated directly
  from the git repo which doesn't contain any of these files.
- there's no point in using LUA in %%pretrans
* Wed Aug 19 2015 fbui@suse.com
- Drop 0009-make-xsltproc-use-correct-ROFF-links.patch
  This patch was initialy added to workaround bsc#842844. But it
  appears that man(1) was fixed (included since 13.2 at least) to
  handle manual pages that consist only of a .so directive such as
  '.so <page>'.
* Thu Aug 13 2015 werner@suse.de
- Change use-rndaddentropy-ioctl-to-load-random-seed.patch to
  make it work on big endian
* Tue Aug 11 2015 jengelh@inai.de
- Use Obsolete/Provides strategy from
  windows:mingw:mingw64/mingw64-cross-gcc to do the bootstrap
  cycle and kick out -mini afterwards.
* Tue Aug 11 2015 jengelh@inai.de
- Update to new upstream release 224
  * systemd-networkd gained a number of new configuration options
  for DHCP, tunnels and bridges
  * systemd-efi-boot-generator functionality was merged into
  systemd-gpt-auto-generator.
* Mon Aug 10 2015 sndirsch@suse.com
- /usr/share/systemd/kbd-model-map: added entries for
  xkeyboard-config converted keymaps; mappings, which already
  exist in original systemd mapping table are being ignored
  though, i.e. not overwritten; needs kbd in buildrequires
  (FATE#318426)
* Wed Jul 29 2015 meissner@suse.com
- hostname-NULL.patch: Work around a crash on XEN hosts
  in OBS. /etc/hostname is not present and systemd then does
  strchr(hostname,soemthing) with hostname NULL.
* Wed Jul 29 2015 werner@suse.de
- Add Correct_assert_on_unexpected_error_code.patch to work around
  a problem of an assert on ENODEV for closing fd on an input
  event device (boo#939571)
* Mon Jul 13 2015 jengelh@inai.de
- Remove udev-generate-rules.sh, apparently not used by anything in
  the systemd nor udev-persistent-ifnames package.
* Wed Jul  8 2015 crrodriguez@opensuse.org
- Systemd v222, bugfix release.
- Drop upstream patches
  0006-pam_systemd-Properly-check-kdbus-availability.patch
  0023-core-fix-reversed-dependency-check-in-unit_check_unn.patch
  0031-install-fix-bad-memory-access.patch
  1032-ata_id-unbotch-format-specifier.patch
- Drop SUSE patch 1013-no-runtime-PM-for-IBM-consoles.patch
  udev does no longer enable USB HID power management at all.
- The udev accelerometer helper was removed, obsoleted by
  iio-sensor-proxy package.
- networkd gained a new configuration option IPv6PrivacyExtensions.
- udev does not longer support the WAIT_FOR_SYSFS= key in udev
  rules. There are no known issues with current sysfs,
  and udev does not need or should be used to work around such bugs.
* Tue Jul  7 2015 jengelh@inai.de
- Avoid restarting logind [bnc#934901]
- Do not suppress errors in any case, even if they are ignored
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Fix devel package requires (both mini and real required real libsystemd0)
* Fri Jul  3 2015 werner@suse.de
- Rework patch  tty-ask-password-agent-on-console.patch to fit the
  requisition of https://bugs.freedesktop.org/show_bug.cgi?id=82004
* Wed Jul  1 2015 jengelh@inai.de
- Rework "-mini" package logic to not conflict with itself and
  then add libsystemd0 to mini.
* Wed Jul  1 2015 crrodriguez@opensuse.org
- remove SysVStartPriority= from after-local.service,
  unsupported since v218.
  Note that this option was only parsed and that's it. the logic
  to give "start priority" was never implemented.
* Wed Jul  1 2015 crrodriguez@opensuse.org
- change the default fallback ntp servers to the opensuse
  pool.ntp.org vendor zone.
- We still need to run systemd-sysctl.service after local-fs.target
  otherwise it works only when /boot is in the root filesystem but
  not when it is a separate partition.
* Fri Jun 26 2015 sbrabec@suse.com
- Obsolete pm-utils and suspend (boo#925873).
- Remove pm-utils support
  (remove Forward-suspend-hibernate-calls-to-pm-utils.patch).
* Thu Jun 25 2015 crrodriguez@opensuse.org
- remove patch sysctl-handle-boot-sysctl.conf-kernel_release.patch
  from the filelist.
* Thu Jun 25 2015 crrodriguez@opensuse.org
- libpcre, glib2 and libusb are not used by systemd, remove
  from buildrequires.
* Thu Jun 25 2015 crrodriguez@opensuse.org
- 1032-ata_id-unbotch-format-specifier.patch: fix udev ata_id
  output.
- 0023-core-fix-reversed-dependency-check-in-unit_check_unn.patch
  fix StopWhenUnneeded=true in combination with a Requisite=
  dependency.
- 0031-install-fix-bad-memory-access.patch: Fix Bad memory access
-  0006-pam_systemd-Properly-check-kdbus-availability.patch: if
  kdbus is enabled (i.e boot with kdbus=1) DBUS_SESSION_BUS_ADDRESS
  must not be exported.
- spec: add a min_kernel_version macro to ensure the package
  conflicts with kernel versions in which systemd cannot run.
* Wed Jun 24 2015 crrodriguez@opensuse.org
- sysctl-handle-boot-sysctl.conf-kernel_release.patch dropped,
  replaced by a tmpfiles.d snippet "current-kernel-sysctl.conf"
  (feature implemented in v220 just for our usecase)
* Wed Jun 24 2015 crrodriguez@opensuse.org
- fix build when resolved is enabled
- remove fsck -l test in spec file, systemd requires util-linux
  2.26 or later where this feature is already available.
* Wed Jun 24 2015 hrvoje.senjan@gmail.com
- Fix bootstrap build by guarding filelists (man pages don't get
  built in bootstrap mode)
- Drop commented sections from baselibs.conf, allows format_spec_file
  to have a successful run
* Wed Jun 24 2015 mpluskal@suse.com
- Install 50-coredump.conf as coredumpctl is now installed by
  default and does not use journal anymore as default storage
* Fri Jun 19 2015 jengelh@inai.de
- Update to new upstream release 221
  * From 220:
  * libgudev was moved into a package of its own
  * Runlevels 2, 3 and 4 are no longer distinct, they all map to
  multi-user.target.
  * The EFI System Partition mounted to /boot will be unmounted
  2 minutes after boot.
  * systemd does not support direct live-upgrades (via `systemctl
  daemon-reexec`) from versions older than v44 anymore.
  * systemd-nspawn may now be called as part of a shell pipeline.
  * systemd-shutdownd has been removed. This service was
  previously responsible for implementing scheduled shutdowns
  as exposed in /usr/bin/shutdown's time parameter. This
  functionality has now been moved into systemd-logind and is
  accessible via a bus interface.
  * udev will no longer call blkid and create symlinks for all
  block devices, but merely those from a whitelist
  (cf. 60-persistent-storage.rules).
  * /usr/lib/os-release gained a new optional field VARIANT=
  * Details at
  http://lists.freedesktop.org/archives/systemd-devel/2015-May/032147.html
  * From 221:
  * New sd-bus and sd-event APIs in libsystemd
  * If there is both a systemd unit and a SysV init script for the
  same service name, and `systemctl enable` or other operation is
  run, both will now be enabled (or execute the related operation
  on both), not just the unit.
- Split libsystemd0 to support systemd-less nspawn containers
- Redo manpage file lists without %%exclude, tends to hide
  unpackaged files.
- hwdb belongs to udev
- Resolve memory leak and add missing _cleanup_free_ to
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
- Remove systemd-powerd-initctl-support.patch
  (no longer builds because shutdownd is gone)
- Remove quilt-patches/0001-core-rework-device-state-logic.patch,
  0001-Let-some-boolean-survive-a-daemon-reload.patch
  (merged upstream),
  0001-Let-some-boolean-survive-a-daemon-reload.patch
  (obsolete)
* Thu Jun 11 2015 werner@suse.de
- Remove libudev0 from baselibs.conf
* Thu Jun 11 2015 werner@suse.de
- Drop 1055-let-9719859c07aa13539ed2cd4b31972cd30f678543-apply.patch
  as now upstream code
- Add 0001-Let-some-boolean-survive-a-daemon-reload.patch to fix
  bsc#933365 and boo#934077
* Tue Jun  2 2015 pwieczorkiewicz@suse.com
- Add 1098-systemd-networkd-alias-network-service.patch to alias
  network.service the same way NetworkManager and wicked does.
  This is needed by yast2 and other parts of the system. boo#933092
* Mon May 18 2015 werner@suse.de
- Modify patch 1021-udev-re-add-persistent-net-rules.patch to use
  the new return values of proc_cmdline() in enable_name_policy()
  this should fix boo#931165
* Mon May 18 2015 jengelh@inai.de
- Drop 1021-udev-re-add-persistent-net-rules.patch,
  1036-rules-disable-usage-of-dev_id-in-persistent-rules.patch,
  1040-re-enable-dev_id-conditionally-in-persistent-rules.patch,
  1046-fix-duplicated-rules-with-layer3-interfaces.patch,
  1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch,
  1051-check-if-NAME-has-a-value.patch,
  1053-better-checks-in-write_net_rules.patch,
  1088-drop-renaming-of-virtual-interfaces-in-guest.patch.
  1021 originally broke parsing of net.ifnames=0 [bnc#931165],
  and given that neither the kernel command line needs to be
  touched nor the source be patched to reach the unpredictable
  naming setup for SLE, all these parts are moved to a separate
  package.
* Mon Mar 16 2015 werner@suse.de
- Add upstream patch
  0001-core-don-t-change-removed-devices-to-state-tentative.patch
  to fix the fix of the last backport (bsc#921898)
* Thu Mar  5 2015 jengelh@inai.de
- Reenable networkd which was silently disabled on Feb 18
* Tue Mar  3 2015 jengelh@inai.de
- Add 0001-core-rework-device-state-logic.patch to fix spurious
  automated umount after mount.
* Wed Feb 18 2015 meissner@suse.com
- mark more subpackages as !bootstrap for systemd-mini usage.
* Wed Feb 18 2015 crrodriguez@opensuse.org
- spec : remove --with-firmware-path, firmware loader was removed in v217
- spec: remove --disable-multi-seat-x, gone.(fixed in xorg)
- spec: Do not enable systemd-readahead-collect.service and
  systemd-readahead-replay.service as these do not exist anymore.
- spec: drop timedate-add-support-for-openSUSE-version-of-etc-sysconfig.patch
  Yast was fixed to write all timezone changes exactly how timedated expects
  things to be done.
- spec: remove handle-etc-HOSTNAME.patch, since late 2014 the netcfg
  package handles the migration from /etc/HOSTNAME to /etc/hostname
  and owns both files.
-spec: remove boot.udev and systemd-journald.init as they currently
  serve no purpose.
- suse-sysv-bootd-support.diff: Remove HAVE_SYSVINIT conditions, we
  are in sysvcompat-only codepath, also remove the code targetting other
  distributions, never compiled as the TARGET_$DISTRO macros are never defined.
- systemd-powerd-initctl-support.patch guard with HAVE_SYSV_COMPAT
- set-and-use-default-logconsole.patch: fix HAVE_SYSV_COMPAT guards
- insserv-generator.patch: Only build when sysvcompat is enabled
- vhangup-on-all-consoles.patch add a comment indicating this is a workaround
  for a kernel bug.
- spec: Add option to allow disabling sysvinit compat at build time.
- spec: Add option to enable resolved at build time.
- spec: Remove all %%ifs for !factory products, current systemd releases can
  neither be built nor installed in older products without upgrading
  several components of the base system.
  (removed: 1008-add-msft-compability-rules.patch was only for =< 13.1)
- spec: remove all dummy "aliases" to /etc/init.d, that made sense only when
  those init scripts still existed. (dummy localfs.service source: gone)
- systemd-sleep-grub: moved to the grub2 package where it belongs as a
  suspend/resume hook (SR#286533) (drops prepare-suspend-to-disk.patch)
- remove LFS_CFLAGS from CFLAGS, never needed in systemd as it force feds
  config.h everywhere in the preprocessor cmdline.
* Mon Feb 16 2015 jengelh@inai.de
- Update to new upstream release 219
  * systemd units can now be "unsupported" (like, for example,
  .device in a containers), similar to the "skipped" state in
  SUSE's prior sysvinit scripts.
  * tmpfiles gained the 'v' type for creating btrfs subvolumes.
  * tmpfiles gained the 'a' type for setting ACLs.
  * systemd-nspawn gained new switches: --ephemeral, --template
  * The /var/lib/containers location is deprecated and replaced by
  /var/lib/machines.
  * machinectl gained the copy-from and copy-to commands.
  * machinectl now knows a "bind" command (for use with nspawn)
  * new "systemd-importd" daemon to download container images and run
  them as nspawn containers.
  * networkd collects LLDP network announcements, if available, and
  so shown in networkctl.
  * The fallback terminal type was changed from "vt102" to "vt220",
  allowing PgUp/PgDn keys to work.
  * Pressing Ctrl-Alt-Del 7x in 2 seconds forces a umount+reboot now,
  useful should the regular shutdown hang.
  * Removing storage will cause systemd to unmount the associated
  mountpoints so that they don't linger around.
* Mon Feb 16 2015 jengelh@inai.de
- Add suse-sysv-bootd-support.diff (reinstate old
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch)
* Mon Feb 16 2015 jengelh@inai.de
- Update to systemd v218-1050-g38ab096
- Remove patches
  use-usr-sbin-sulogin-for-emergency-service.patch (upstream fixed it)
- Reinstate and improve (remove huge indents from)
  tty-ask-password-agent-on-console.patch,
  0014-journald-with-journaling-FS.patch, rootsymlink_generator.
* Mon Feb 16 2015 meissner@suse.com
- disable systemd-resolved for now as it interacts not well with
  our methods and security has concerns regarding spoofing. bsc#917781
* Tue Jan 20 2015 werner@suse.de
- Add patch kbd-model-map.patch to add missed keyboard layouts
  which are offered by YaST2 (bsc#910643 and boo#897803)
* Fri Jan  9 2015 jengelh@inai.de
- Update to new upstream release 218
  * New utilities: systemd-timesyncd (SNTP client),
  systemd-resolved, systemd-networkd, networkctl,
  systemd-sysusers
  * machinectl gained a "poweroff" command for clean container shutdown
  * The udev hwdb now contains DPI information for mice.
  * Userspace firmware loading support has been removed and
  the minimum supported kernel version is thus bumped to 3.7.
- Remove patches:
  G=gone locally, is upstream;
  D=dropped: no longer needed;
  N=no longer applies to source nor is it deemed needed;
  K=killed: no longer applicable and too complex to resolve:
  - ---
  G 0002-rfkill-rework-how-we-generate-file-names-from-rfkill.patch
  G avoid-assertion-if-invalid-address-familily-is-passed-to-g.patch
  K service-flags-sysv-service-with-detected-pid-as-RemainAfte.patch
  K remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch
  K handle-SYSTEMCTL_OPTIONS-environment-variable.patch
  K 0018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  K log-target-null-instead-kmsg.patch
  K tty-ask-password-agent-on-console.patch
  K 513-nspawn-veth.patch
  K 1087-infinit-timeout-for-kmod-loaded-modules.patch
  D module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  D avoid-leaking-socket-descriptors.patch
  D 0001-make-fortify-happy-with-ppoll.patch
  N fix-owner-of-var-log-btmp.patch
  N disable-nss-myhostname-warning-bnc-783841.patch
  N Revert-service-drop-support-for-SysV-scripts-for-the-early.patch
  N 0001-make-209-working-on-older-dist.patch
  N 0001-Don-t-snprintf-a-potentially-NULL-pointer.patch
  N tmpfiles-do-not-clean-for-mandb-index-files.patch
  G 0001-sd-bus-don-t-look-for-a-64bit-value-when-we-only-hav.patch
  G avoid-assertion-if-invalid-address-familily-is-passed-to-g.patc
  G optionally-warn-if-nss-myhostname-is-called.patch
  G 0001-units-systemd-sysctl.service.in-run-after-load-modul.patch
  G 0004-getty-generator-properly-escape-instance-names.patch
  G rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  G 0008-Reset-signal-mask-on-re-exec-to-init.patch
  G 0001-login-fix-pos-array-allocation.patch
  G 0002-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  G 0003-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  G 0004-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  G 0005-Replace-var-run-with-run-in-remaining-places.patch
  G 0006-Revert-back-to-var-run-at-a-couple-of-problems.patch
  G 0007-README-document-that-var-run-must-be-a-symlink-run.patch
  G 0008-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  G 0009-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  G 0010-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  G 0011-logs-show-fix-corrupt-output-with-empty-messages.patch
  G 0012-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  G 0014-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  G 0001-Fix-systemd-stdio-bridge-symlink.patch
  G 0002-execute-free-directory-path-if-we-fail-to-remove-it-.patch
  G 0003-Do-not-print-invalid-UTF-8-in-error-messages.patch
  G 0004-man-document-missing-options-of-systemd-run.patch
  G 0005-systemd-run-add-some-extra-safety-checks.patch
  G 0006-journal-assume-that-next-entry-is-after-previous-ent.patch
  G 0007-journal-forget-file-after-encountering-an-error.patch
  G 0008-core-correctly-unregister-PIDs-from-PID-hashtables.patch
  G 0009-logind-fix-reference-to-systemd-user-sessions.servic.patch
  G 0010-man-update-link-to-LSB.patch
  G 0011-man-systemd-bootchart-fix-spacing-in-command.patch
  G 0012-man-add-missing-comma.patch
  G 0013-units-Do-not-unescape-instance-name-in-systemd-backl.patch
  G 0001-core-busname-add-lookup-string-for-BUSNAME_FAILURE_S.patch
  G 0002-manager-flush-memory-stream-before-using-the-buffer.patch
  G 0003-busname-don-t-drop-service-from-the-result-string.patch
  G 0004-fix-off-by-one-error-in-array-index-assertion.patch
  G 0005-logind-fix-policykit-checks.patch
  G 0006-rules-mark-loop-device-as-SYSTEMD_READY-0-if-no-file.patch
  G 0008-man-multiple-sleep-modes-are-to-be-separated-by-whit.patch
  G 0001-gpt-auto-generator-don-t-return-OOM-on-parentless-de.patch
  G 0002-bus-fix-memory-leak-when-kdbus-is-not-enabled.patch
  G 0006-Do-not-return-1-EINVAL-on-allocation-error.patch
  G 0007-networkd-fix-typo.patch
  G 0008-sd-bus-don-t-access-invalid-memory-if-a-signal-match.patch
  G 0009-sd-bus-don-t-choke-if-somebody-sends-us-a-message-wi.patch
  G 0012-journald-remove-stray-reset-of-error-return-value.patch
  G 0013-core-libsystemd-systemd-timedate-udev-spelling-fixes.patch
  G 0001-cgroup-it-s-not-OK-to-invoke-alloca-in-loops.patch
  G 0002-machined-fix-Kill-bus-call-on-machine-objects-when-w.patch
  G 0003-sd-bus-don-t-use-assert_return-to-check-for-disconne.patch
  G 0004-core-don-t-try-to-relabel-mounts-before-we-loaded-th.patch
  G 0005-sd-daemon-fix-incorrect-variable-access.patch
  G 0006-sd-event-initialization-perturbation-value-right-bef.patch
  G 0007-sd-event-don-t-accidentally-turn-of-watchdog-timer-e.patch
  G 0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
  G 0009-ask-password-when-the-user-types-a-overly-long-passw.patch
  G 0001-journal-fix-export-of-messages-containing-newlines.patch
  G 0002-systemctl-update-NAME-to-PATTERN-in-help.patch
  G 0003-tty-ask-password-agent-return-negative-errno.patch
  G 0004-systemd-python-use-.hex-instead-of-.get_hex.patch
  G 0005-systemd-python-fix-failing-assert.patch
  G 0007-dbus-suppress-duplicate-and-misleading-messages.patch
  G 0001-reduce-the-amount-of-messages-logged-to-dev-kmsg-whe.patch
  G 0001-bash-completion-fix-__get_startable_units.patch
  G 0002-sysctl-replaces-some-slashes-with-dots.patch
  G 0003-delta-do-not-use-unicode-chars-in-C-locale.patch
  G 0004-implement-a-union-to-pad-out-file_handle.patch
  G shut-up-annoying-assertion-monotonic-clock-message.patch
  G 0001-sd-rtnl-message-append-fix-uninitialized-memory.patch
  G 0001-tmpfiles-fix-permissions-on-new-journal-files.patch
  G 0001-errno-make-sure-to-handle-the-3-errnos-that-are-alia.patch
  G 0003-analyze-fix-plot-with-bad-y-size.patch
  G 0004-job-add-waiting-jobs-to-run-queue-in-unit_coldplug.patch
  G 0005-job-always-add-waiting-jobs-to-run-queue-during-cold.patch
  G 0001-backlight-Avoid-restoring-brightness-to-an-unreadabl.patch
  G 0002-backlight-do-nothing-if-max_brightness-is-0.patch
  G 0003-backlight-unify-error-messages.patch
  G 0004-backlight-warn-if-kernel-exposes-backlight-device-wi.patch
  G 0005-backlight-handle-saved-brightness-exceeding-max-brig.patch
  G 0001-replace-more-dup-by-F_DUPFD_CLOEXEC.patch
  G 0002-pam_systemd-use-F_DUPFD_CLOEXEC-when-dupping-session.patch
  G 0001-core-close-socket-fds-asynchronously.patch
  G 0002-logind-bring-polkit-policy-for-hibernate-in-line-wit.patch
  G 0003-core-make-sure-to-serialize-jobs-for-all-units.patch
  G 0001-logind-ignore-lid-switch-if-more-than-1-display-is-c.patch
  G 0002-logind-fix-printf-format.patch
  G 0003-logind-ignore-lid-switch-events-for-30s-after-each-s.patch
  G 0004-logind-Do-not-fail-display-count-if-a-device-has-no-.patch
  G 0005-logind-move-lid-switch-handling-from-logind-main-to-.patch
  G 0006-man-clarify-that-the-ExecReload-command-should-be-sy.patch
  G 0007-man-readahead-fix-cmdline-switch-inconsistency-betwe.patch
  G 0008-man-update-journald-rate-limit-defaults.patch
  G 0009-nspawn-properly-format-container_uuid-in-UUID-format.patch
  G 0010-logind-allow-suspending-if-there-are-no-displays.patch
  G 0001-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0002-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0003-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0004-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0005-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-conf-parser-silently-ignore-sections-starting-with-X.patch
  G 0002-man-note-that-entire-sections-can-now-be-ignored.patch
  G 0004-machined-make-sure-GetMachineAddresses-is-available-.patch
  G 0005-core-Filter-by-state-behind-the-D-Bus-API-not-in-the.patch
  G 0006-login-add-mir-to-the-list-of-session-types.patch
  G 0007-logind-fix-Display-property-of-user-objects.patch
  G 0001-hwdb-update.patch
  G 0002-hwdb-update.patch
  G 0003-hwdb-PCI-include-primary-model-string-in-subsystem-m.patch
  G 0004-hwdb-update.patch
  G 0005-hwdb-update.patch
  G 0001-journal-cleanup-up-error-handling-in-update_catalog.patch
  G 0002-journal-properly-detect-language-specified-in-line.patch
  G 0003-man-mention-XDG_CONFIG_HOME-in-systemd.unit.patch
  G 0001-keymap-Add-Lenovo-Enhanced-USB-Keyboard.patch
  G 0002-keymap-Asus-EeePC-touchpad-toggle-key.patch
  G 0001-nspawn-allow-to-bind-mount-journal-on-top-of-a-non-e.patch
  G 0002-nspawn-restore-journal-directory-is-empty-check.patch
  G 0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  G 0004-socket-properly-handle-if-our-service-vanished-durin.patch
  G 0001-Do-not-unescape-unit-names-in-Install-section.patch
  G 0002-analyze-run-use-bus_open_transport_systemd-instead-o.patch
  G 0001-virt-rework-container-detection-logic.patch
  G 0002-fsck-include-device-name-in-the-message-about-missin.patch
  G 0003-units-use-KillMode-mixed-for-systemd-nspawn-.service.patch
  G 0004-util-ignore_file-should-not-allow-files-ending-with.patch
  G 0006-tty-ask-password-agent-Do-tell-what-directory-we-fai.patch
  G 0007-keyboard-add-Plantronics-.Audio-mute-button.patch
  G 0001-build-sys-use-glibc-s-xattr-support-instead-of-requi.patch
  G 0001-hwdb-fix-case-sensitive-match.patch
  G 0001-sd-event-restore-correct-timeout-behaviour.patch
  G 0002-bus-make-use-of-sd_bus_try_close-in-exit-on-idle-ser.patch
  G 0001-umount-modernizations.patch
  G 0002-namespace-when-setting-up-an-inaccessible-mount-poin.patch
  G 0003-core-allow-transient-mount-units.patch
  G 0004-systemd-detect-virt-only-discover-Xen-domU.patch
  G 0005-backlight-Do-not-clamp-brightness-for-LEDs.patch
  G 0006-log-honour-the-kernel-s-quiet-cmdline-argument.patch
  G 0001-core-fix-invalid-free-in-killall.patch
  G 0003-install-fix-invalid-free-in-unit_file_mask.patch
  G 0001-systemd-detect-virt-detect-s390-virtualization.patch
  G 0001-core-sysvcompat-network-should-be-equivalent-to-netw.patch
  G 0002-units-add-missing-caps-so-that-GetAddresses-can-work.patch
  G 0003-units-order-systemd-tmpfiles-clean.service-after-tim.patch
  G 0005-po-add-Greek-translation.patch
  G 0006-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0007-po-add-German-translation.patch
  G 0009-core-clean-up-signal-reset-logic-when-reexec.patch
  G 0010-util-treat-fuse.sshfs-as-a-network-filesystem.patch
  G 0011-build-sys-add-pthread-flag-for-libsystemd-shared.patch
  G 0012-core-transaction-avoid-misleading-error-message-when.patch
  G 0001-vconsole-also-copy-character-maps-not-just-fonts-fro.patch
  G 0002-core-make-sure-Environment-fields-passed-in-for-tran.patch
  G 0003-core-You-can-not-put-the-cached-result-of-use_smack-.patch
  G 0004-cryptsetup-don-t-add-unit-dependency-on-dev-null-dev.patch
  G 0005-man-fix-path-in-crypttab-5.patch
  G 0001-units-order-network-online.target-after-network.targ.patch
  G 0001-core-use-correct-format-string-for-UIDs.patch
  G 0002-core-transaction-fix-cycle-break-attempts-outside-tr.patch
  G 0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
  G 0001-main-uid_to_name-might-fail-due-to-OOM-protect-again.patch
  G 0002-journald-make-MaxFileSec-really-default-to-1month.patch
  G 0003-units-remove-RefuseManualStart-from-units-which-are-.patch
  G 0004-util-refuse-considering-UID-0xFFFF-and-0xFFFFFFFF-va.patch
  G 0005-nspawn-block-open_by_handle_at-and-others-via-seccom.patch
  G 0006-tmpfiles-don-t-do-automatic-cleanup-in-XDG_RUNTIME_D.patch
  G 0007-units-skip-mounting-tmp-if-it-is-a-symlink.patch
  G 0001-parse_uid-return-ENXIO-for-1-uids.patch
  G 0002-util-when-unescaping-strings-don-t-allow-smuggling-i.patch
  G 0003-localed-consider-an-unset-model-as-a-wildcard.patch
  G 0004-sd-bus-when-an-event-loop-terminates-explicitly-clos.patch
  G 0005-bus-close-a-bus-that-failed-to-connect.patch
  G 0006-hwdb-update.patch
  G 0007-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-architecture-Add-tilegx.patch
  G 0002-architecture-Add-cris.patch
  G 0003-arch-add-crisv32-to-uname-check.patch
  G 0004-architecture-remove-cris-from-uname-list.patch
  G 0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch
  G 0002-namespace-fix-uninitialized-memory-access.patch
  G 0001-machine-don-t-return-uninitialized-variable.patch
  G 0002-vconsole-setup-run-setfont-before-loadkeys.patch
  G 0001-util-consider-0x7F-a-control-chracter-which-it-is-DE.patch
  G 0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  G 0003-architecture-add-string-table-entries-for-mips-le-ar.patch
  G 0004-core-Added-support-for-ERRNO-NOTIFY_SOCKET-message-p.patch
  G 0005-service-don-t-accept-negative-ERRNO-notification-mes.patch
  G 0006-systemctl-show-StatusErrno-value-in-systemctl-status.patch
  G 0007-service-flush-status-text-and-errno-values-each-time.patch
  G 0001-journal-compress-return-early-in-uncompress_startswi.patch
  G 0002-journal-compress-improve-xz-compression-performance.patch
  G 0001-logind-allow-switching-to-unused-VTs-via-SwitchTo.patch
  G 0002-hostnamed-add-a-new-chassis-type-for-watches.patch
  G 0001-units-make-ExecStopPost-action-part-of-ExecStart.patch
  G 0001-event-pull-in-sd-event.h-from-event-util.h.patch
  G 0002-util-fix-has-cc-check-and-add-test.patch
  G 0003-sd-event-always-call-epoll_ctl-on-mask-updates-if-ed.patch
  G 0004-fileio-quote-more-shell-characters-in-envfiles.patch
  G 0001-Clear-up-confusion-wrt.-ENTRY_SIZE_MAX-and-DATA_SIZE.patch
  G 0002-units-serial-getty-.service-use-the-default-RestartS.patch
  G 0001-po-add-Ukrainian-translation.patch
  G 0002-man-document-yearly-and-annually-in-systemd.time-7.patch
  G 0003-core-nicer-message-when-inotify-watches-are-exhauste.patch
  G 0001-detect-virt-Fix-Xen-domU-discovery.patch
  G 0002-Be-more-verbose-when-bind-or-listen-fails.patch
  G 0003-Add-quotes-to-warning-message.patch
  G 0004-systemd-return-the-first-error-from-manager_startup.patch
  G 0001-bash-completion-p-option-for-journalctl.patch
  G 0002-journalctl-man-allow-only-between-terms.patch
  G 0003-systemd-use-pager-for-test-and-help.patch
  G 0001-bus-proxyd-fix-incorrect-comparison.patch
  G 0002-shell-completion-prevent-mangling-unit-names.patch
  G 0003-Always-check-asprintf-return-code.patch
  G 0004-bash-completion-use-list-unit-files-to-get-all-units.patch
  G 0005-core-only-set-the-kernel-s-timezone-when-the-RTC-run.patch
  G 0006-parse_boolean-require-exact-matches.patch
  G 0007-drop_duplicates-copy-full-BindMount-struct.patch
  G 0008-shell-completion-prevent-mangling-unit-names-bash.patch
  G 0009-journald-always-add-syslog-facility-for-messages-com.patch
  G 0001-sysv-order-initscripts-which-provide-network-before-.patch
  G 0002-keymap-Add-microphone-mute-keymap-for-Dell-Latitude.patch
  G 0003-keymap-Annotate-all-micmute-workarounds.patch
  G 0007-hwdb-update.patch
  G 0001-nspawn-fix-truncation-of-machine-names-in-interface-.patch
  G 0002-switch-root-umount-the-old-root-correctly.patch
  G 0003-bootchart-it-s-not-OK-to-return-1-from-a-main-progra.patch
  G 0004-login-set_controller-should-fail-if-prepare_vt-fails.patch
  G 0005-sd-resolve-fix-allocation-if-query-ids-never-reuse-t.patch
  G 0006-login-share-VT-signal-handler-between-sessions.patch
  G 0007-journald-also-increase-the-SendBuffer-of-dev-log-to-.patch
  G 0008-mount-setup-fix-counting-of-early-mounts-without-SMA.patch
  G 0009-journald-Fix-off-by-one-error-in-Missed-X-kernel-mes.patch
  G 0010-machine_kill-Don-t-kill-the-unit-when-killing-the-le.patch
  G 0011-units-fix-BindsTo-logic-when-applied-relative-to-ser.patch
  G 0012-util-try-to-be-a-bit-more-NFS-compatible-when-checki.patch
  G 0001-hwdb-keymaps-for-Samsung-900X3E-900X3F.patch
  G 0002-Add-hwdb-entry-for-Samsung-Series-7-Ultra.patch
  G 0003-keymap-Fix-HP-Pavillon-DV7.patch
  G 0004-hwdb-update-format-description-and-document-reloadin.patch
  G 0008-hwdb-update.patch
  G 0001-systemctl-Correct-error-message-printed-when-bus_pro.patch
  G 0002-units-order-systemd-fsck-.service-after-local-fs-pre.patch
  G 0003-keymap-Adjust-for-more-Samsung-900X4-series.patch
  G 0001-login-fix-memory-leak-on-DropController.patch
  G 0002-util-fix-minimal-race-where-we-might-miss-SIGTERMs-w.patch
  G 0003-sd-journal-properly-convert-object-size-on-big-endia.patch
  G 0004-sd-journal-verify-that-object-start-with-the-field-n.patch
  G 0001-nspawn-fix-network-interface.patch
  G 0001-completion-filter-templates-from-restartable-units.patch
  G 0002-systemd-fix-error-message.patch
  G 0003-Quote-unit-names-in-suggested-systemctl-commandlines.patch
  G 0004-config-parser-fix-mem-leak.patch
  G 0005-login-fix-mem-leak.patch
  G 0001-login-simplify-controller-handling.patch
  G 0001-initrd-parse-etc.service-ignore-return-code-of-daemo.patch
  G 0008-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0009-hwdb-update.patch
  G 0001-systemctl-allow-to-change-the-default-target-without.patch
  G 0001-activate-fix-fd-leak-in-do_accept.patch
  G 0002-analyze-avoid-a-null-dereference.patch
  G 0003-analyze-fix-mem-leak.patch
  G 0004-backlight-Avoid-error-when-state-restore-is-disabled.patch
  G 0005-bus-avoid-using-m-kdbus-after-freeing-it.patch
  G 0006-bus-unref-buscreds-on-failure.patch
  G 0007-core-fix-a-potential-mem-leak.patch
  G 0008-core-smack-setup-Actually-allow-for-succesfully-load.patch
  G 0009-journal-do-not-leak-mmaps-on-OOM.patch
  G 0010-manager-use-correct-cleanup-function.patch
  G 0001-core-fix-resource-leak-in-manager_environment_add.patch
  G 0002-util-remove-a-unnecessary-check.patch
  G 0003-udev-event-explicitly-don-t-read-from-invalid-fd.patch
  G 0004-shared-conf-parser.patch
  G 0005-logind-fix-typo.patch
  G 0006-systemctl-fix-resource-leak-CID-1237747.patch
  G 0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  G 0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patch
  G 0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
  G 0001-journal-Do-not-count-on-the-compiler-initializing-fo.patch
  G 0002-include-fcntl.h-rather-than-sys-fcntl.h.patch
  G 0003-mount-order-options-before-other-arguments-to-mount.patch
  G 0004-shared-wtmp-utmp-don-t-clear-store_wtmp-in-utmp_put_.patch
  G 0005-shared-label.h-add-missing-stdio.h-include.patch
  G 0006-shared-sparse-endian.h-add-missing-byteswap.h-includ.patch
  G 0001-login-pause-devices-before-acknowledging-VT-switches.patch
  G 0001-nspawn-don-t-try-to-create-veth-link-with-too-long-i.patch
  G 0001-socket-introduce-SELinuxContextFromNet-option.patch
  G 0002-util-avoid-non-portable-__WORDSIZE.patch
  G 0001-Fix-warning-about-unused-variable-with-SELINUX.patch
  G 0002-bus-remove-unused-check.patch
  G 0001-systemd-tmpfiles-Fix-IGNORE_DIRECTORY_PATH-age-handl.patch
  G 0001-logind-add-support-for-Triton2-Power-Button.patch
  G 0002-logind-add-support-for-TPS65217-Power-Button.patch
  G 0001-shutdownd-clean-up-initialization-of-struct.patch
  G 0003-bootchart-parse-userinput-with-safe_atoi.patch
  G 0004-bootchart-check-return-of-strftime.patch
  G 0005-bootchart-Do-not-try-to-access-data-for-non-existing.patch
  G 0001-journalctl-do-not-output-reboot-markers-when-running.patch
  G 0002-udev-hwdb-New-Entry-for-Dell-XPS12-9Q33-keyboard.patch
  G 0001-core-swap-only-make-configured-units-part-of-swap.ta.patch
  G 0009-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-virt-detect-that-we-are-running-inside-the-docker-co.patch
  G 0002-bootchart-use-n-a-if-PRETTY_NAME-is-not-found.patch
  G 0003-fileio-label-return-error-when-writing-fails.patch
  G 0001-sd-event-don-t-require-a-signal-event-source-to-be-e.patch
  G 0004-sd-event-check-the-value-of-received-signal.patch
  G 0005-sd-id128-do-stricter-checking-of-random-boot-id.patch
  G 0001-keymap-Fix-touchpad-toggle-on-Toshiba-Satellite-P75-.patch
  G 0001-units-introduce-network-pre.target-as-place-to-hook-.patch
  G 0002-keymap-Fix-touchpad-toggle-key-on-Asus-laptops.patch
  G 0003-sd-bus-check-return-value-of-vasprintf.patch
  G 0004-core-map-the-rescue-argument-to-rescue.target.patch
  G 0005-util-avoid-double-close-of-fd.patch
  G 0001-systemctl-when-mangle-unit-names-for-the-isolate-suf.patch
  G 0001-tmpfiles-compare-return-against-correct-errno.patch
  G 0001-shell-completion-fix-completion-of-inactive-units.patch
  G 0002-shell-completion-propose-templates-for-disable-re-en.patch
  G 0003-man-we-don-t-have-Wanted-dependency.patch
  G 0004-selinux-fix-potential-double-free-crash-in-child-pro.patch
  G 0001-systemd-continue-switch-root-even-if-umount-fails.patch
  G 0002-systemd-try-harder-to-bind-to-notify-socket.patch
  G 0001-strv-add-an-additional-overflow-check-when-enlarging.patch
  G 0002-hwdb-Add-mapping-for-special-keys-on-compaq-ku-0133-.patch
  G 0003-journald-add-CAP_MAC_OVERRIDE-in-journald-for-SMACK-.patch
  G 0004-journal-do-server_vacuum-for-sigusr1.patch
  G 0005-cryptsetup-fix-an-OOM-check.patch
  G 0002-shutdown-pass-own-argv-to-run-initramfs-shutdown.patch
  G 0001-manager-Linux-on-hppa-has-fewer-rtsigs-hence-avoid-u.patch
  G 0002-time-also-support-infinity-syntax-in-parse_nsec.patch
  G 0003-time-earlier-exit-from-format_timestamp_relative-on-.patch
  G 0004-sd-bus-if-we-don-t-manage-to-properly-allocate-the-e.patch
  G 0005-journalctl-correct-help-text-for-until.patch
  G 0006-calendarspec-fix-typo-in-annually.patch
  G 0007-systemctl-do-not-ignore-errors-in-symlink-removal.patch
  G 0008-util-introduce-sethostname_idempotent.patch
  G 0009-util-fix-copy-paste-error-and-actually-set-the-new-h.patch
  G 0010-shutdown-do-final-unmounting-only-if-not-running-ins.patch
  G 0011-selinux-make-sure-we-do-not-try-to-print-missing-fie.patch
  G 0012-manager-do-not-print-anything-while-passwords-are-be.patch
  G 0001-sd-bus-properly-handle-removals-of-non-existing-matc.patch
  G 0002-keymap-Ignore-brightness-keys-on-Dell-Inspiron-1520-.patch
  G 0001-core-don-t-allow-enabling-if-unit-is-masked.patch
  G 0002-snapshot-return-error-when-snapshot-exists.patch
  G 0003-shared-install-avoid-prematurely-rejecting-missing-u.patch
  G 0004-Raise-level-of-Found-dependency.-lines.patch
  G 0005-units-order-sd-journal-flush-after-sd-remount-fs.patch
  G 0006-journald-fix-minor-memory-leak.patch
  G 0007-journald-also-check-journal-file-size-to-deduce-if-i.patch
  G 0008-journald-fix-memory-leak-on-error-path.patch
  G 0009-units-make-systemd-journald.service-Type-notify.patch
  G 0010-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  G 0001-login-rerun-vconsole-setup-when-switching-from-vgaco.patch
  G 0002-shutdown-fix-arguments-to-run-initramfs-shutdown.patch
  G 0003-utf8-when-looking-at-the-next-unichar-honour-the-siz.patch
  G 0001-keymap-Add-support-for-IBM-ThinkPad-X41-Tablet.patch
  G 0002-keymap-Fix-special-keys-on-ThinkPad-X60-X61-Tablet.patch
  G 0001-systemctl-let-list-units-unit-files-honour-type.patch
  G 0002-systemctl-obey-state-in-list-unit-files.patch
  G 0002-core-watchdog-bus-properties-cannot-be-both-writable.patch
  G 0003-sd-bus-refuse-properties-that-claim-to-be-both-writa.patch
  G 0001-units-make-sure-rfkill-service-is-bount-to-the-actua.patch
  G 0001-selinux-access-fix-broken-ternary-operator.patch
  G 0002-systemctl-show-BindsTo-BoundBy-in-list-dependencies.patch
  G 0003-cryptsetup-default-to-no-hash-when-keyfile-is-specif.patch
  G 0004-core-fix-transaction-destructiveness-check-once-more.patch
  G 0001-units-tmpfiles-setup-dev-allow-unsafe-file-creation-.patch
  G 0002-man-tmpfiles.d-recommend-using-b-and-c.patch
  G 1009-cdrom_id-use-the-old-MMC-fallback.patch
  G 1010-udev-increase-result-size-for-programs.patch
  G 1014-udev-update-net_id-comments.patch
  G 1015-udev-persistent-naming-we-cannot-use-virtio-numbers-.patch
  G 1016-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  G 1017-udev-serialize-synchronize-block-device-event-handli.patch
  G 1018-udev-do-not-skip-the-execution-of-RUN-when-renaming-.patch
  G 1019-udev-avoid-use-of-uninitialized-err.patch
  G 1020-udev-keyboard-also-hook-into-change-events.patch
  G 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
  G 1023-udev-builtin-keyboard-do-tell-on-which-device-EVIOCS.patch
  G 1024-udev-always-close-lock-file-descriptor.patch
  G 1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
  G 1026-udevd-inotify-modernizations.patch
  G 1027-udev-synthesize-change-events-for-partitions-when-to.patch
  G 1028-udev-link-config-fix-mem-leak.patch
  G 1029-udev-try-first-re-reading-the-partition-table.patch
  G 1030-udev-guard-REREADP-logic-with-open-O_ECXL.patch
  G 1031-udev-make-sure-we-always-get-change-for-the-disk.patch
  G 1032-udev-guard-REREADPT-by-exclusive-lock-instead-of-O_E.patch
  G 1033-udev-really-exclude-device-mapper-from-block-device.patch
  G 1034-udev-check-the-return-value-from-udev_enumerate_scan.patch
  G 1038-udev-fix-invalid-free-in-enable_name_policy.patch
  G 1039-udevadm-settle-fixed-return-code-for-empty-queue.patch
  G 1041-libudev-fix-udev_queue_get_queue_is_empty-logic.patch
  G 1042-libudev-queue-provide-file-descriptor-to-watch-busy-.patch
  G 1043-libudev-queue-watch-entire-directory-to-allow-the-re.patch
  G 1044-rules-update-qemu-hid-rules.patch
  G 1045-rules-don-t-enable-usb-pm-for-Avocent-devices.patch
  G 1047-udev-net_setup_link-builtin-should-print-the-reason-.patch
  G 1048-udev-net_setup_link-add-a-bit-more-logging.patch
  G 1049-udev-link_config-ignore-errors-due-to-missing-MAC-ad.patch
  G 1052-rules-uaccess-add-ID_SOFTWARE_RADIO.patch
  G 1054-udev-exclude-MD-from-block-device-ownership-event-lo.patch
  G 1056-udevd-add-event-timeout-commandline-option.patch
  G 1057-udev-unify-event-timeout-handling.patch
  G 1058-udev-unify-event-timeout-handling.patch
  G 1059-udev-fixup-commit-dd5eddd28a74a49607a8fffcaf960040db.patch
  G 1061-rules-allow-systemd-to-manage-loop-device-partitions.patch
  G 1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patch
  G 1064-udev-hwdb-do-not-look-at-usb_device-parents.patch
  G 1065-udev-bump-event-timeout-to-60-seconds.patch
  G 1067-udev-always-resolve-correctly-database-names-on-chan.patch
  G 1068-udev-net_setup_link-export-the-.link-filename-applie.patch
  G 1069-rules-net-setup-link-preserve-ID_NET_LINK_FILE-and-I.patch
  G 1070-rules-net-setup-link-remove-stray-linebreak.patch
  G 1071-udev-import-the-full-db-on-MOVE-events-for-devices-w.patch
  G 1072-udev-netif_rename-don-t-log-to-kmsg.patch
  G 1073-udev-drop-print_kmsg.patch
  G 1074-udev-fix-copy-paste-error-in-log-message.patch
  G 1075-udev-timeout-increase-timeout.patch
  G 1076-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch
  G 1077-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch
  G 1078-udev-remove-userspace-firmware-loading-support.patch
  G 1079-udev-remove-userspace-firmware-loading-support.patch
  G 1080-udevd-parse_argv-warn-if-argumens-are-invalid.patch
  G 1081-udevd-check-return-of-various-functions.patch
  G 1082-udevadm-hwdb-check-return-value-of-fseeko.patch
  G 1083-udev-node-warn-if-chmod-chown-fails.patch
  G 1084-udev-ctrl-log-if-setting-SO_PASSCRED-fails.patch
  G 1085-udev-fix-typos.patch
  G 1086-udevd-don-t-fail-if-run-udev-exists.patch
  G 1089-fix-cgroup-device-controller.patch
  G 1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  G 1091-udev-path_id-update-comments.patch
  G 1092-libudev-do-not-accept-invalid-log-levels.patch
  G 1093-udev-Fix-parsing-of-udev.event-timeout-kernel-parame.patch
  G 1094-udev-avoid-magic-constants-in-kernel-cmdline-parsers.patch
  G 1098-udev-link_setup-respect-kernel-name-assign-policy.patch
* Wed Jan  7 2015 arvidjaar@gmail.com
- update set-and-use-default-logconsole.patch - fix comparison of
  console log facility that caused journald to skip output to console
  (boo#912030)
* Thu Dec 18 2014 werner@suse.de
- Use Robert's latest patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which drops NAMEPOLICY_KERNEL as this breaks all on current
  systems out there
* Wed Dec 17 2014 thomas.blume@suse.com
- remove 0022-systemd-tmpfiles-ownerkeep.patch since this is now
  implemented into the systemd-tmpfiles binary
- add user based ignore statements in tmpfiles removal directives
  (bnc#903009)
  add systemd-add-user-keep.patch
* Tue Dec 16 2014 thomas.blume@suse.com
- use --boot option in systemd-tmpfiles-setup-dev.service (bnc#908476)
  add upstream patches:
  0001-units-tmpfiles-setup-dev-allow-unsafe-file-creation-.patch
  0002-man-tmpfiles.d-recommend-using-b-and-c.patch (adapted)
* Tue Dec 16 2014 werner@suse.de
- Update patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  to Robert's version
* Mon Dec 15 2014 werner@suse.de
- Add upstream patches
  0001-selinux-access-fix-broken-ternary-operator.patch
  0002-systemctl-show-BindsTo-BoundBy-in-list-dependencies.patch
  0003-cryptsetup-default-to-no-hash-when-keyfile-is-specif.patch
  0004-core-fix-transaction-destructiveness-check-once-more.patch
- Avoid old net devices naming scheme on openSUSE 13.2 and less
  maybe caused by patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
* Thu Dec 11 2014 thomas.blume@suse.com
- fix systemd-nspawn network-veth support (bnc#906709)
  add 513-nspawn-veth.patch
* Fri Dec  5 2014 werner@suse.de
- Add upstream patch
  1098-udev-link_setup-respect-kernel-name-assign-policy.patch
  which may solve bsc#907318
* Fri Dec  5 2014 werner@suse.de
- Add upstream patches
  0001-units-make-sure-rfkill-service-is-bount-to-the-actua.patch
  0002-rfkill-rework-how-we-generate-file-names-from-rfkill.patch
* Fri Nov 28 2014 rmilasan@suse.com
- Change the maximum number of children from CPU_COUNT * 256 to
  CPU_COUNT * 64.
  Update 1097-udevd-increase-maximum-number-of-children.patch
* Thu Nov 27 2014 rmilasan@suse.com
- Increase number of children/workers to CPU_COUNT * 256 to avoid
  'maximum number of children reached' (bnc#907393).
  Add 1097-udevd-increase-maximum-number-of-children.patch
* Tue Nov 25 2014 rmilasan@suse.com
- Fix error return in rootsymlink_generator.c
  Update 1096-new-udev-root-symlink-generator.patch
* Fri Nov 21 2014 werner@suse.de
- Remove upstream patch
  0001-systemd-logind.service-set-Type-notify.patch
  as systemd-logind.service is already from DBus type, compare with
  upstream commit eab459bc0639b81b32735f36d3e929e4bfa2cb4b
* Thu Nov 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-logind.service-set-Type-notify.patch
  0002-core-watchdog-bus-properties-cannot-be-both-writable.patch
  0003-sd-bus-refuse-properties-that-claim-to-be-both-writa.patch
* Thu Nov 20 2014 werner@suse.de
- Re-add directory /usr/lib/systemd/system/basic.target.wants
* Wed Nov 19 2014 gber@opensuse.org
- remove pm-utils-hooks-compat.sh again, pm-utils built-in hooks
  partially duplicate hooks run by systemd which may potentially
  lead to problems, instead temporarily re-enable
  Forward-suspend-hibernate-calls-to-pm-utils.patch until
  boo#904828 can be addressed properly
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashisms in write_net_rules script
- update patches:
  * 1053-better-checks-in-write_net_rules.patch
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-let-list-units-unit-files-honour-type.patch
  0002-systemctl-obey-state-in-list-unit-files.patch
  which allows to use --type in the systemctl command list-units
  and list-unit-files.
* Tue Nov 18 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Add-support-for-IBM-ThinkPad-X41-Tablet.patch
  0002-keymap-Fix-special-keys-on-ThinkPad-X60-X61-Tablet.patch
* Thu Nov 13 2014 rmilasan@suse.com
- New root symlink rule generator
  Add 1096-new-udev-root-symlink-generator.patch
- Remove write_dev_root_rule and systemd-udev-root-symlink
* Thu Nov 13 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip hdflush as well as hddown but only use halt as fallback
  for poweroff as well as synch in systemctl before any reboot command
  (compare with commit 4a3ad39957399c4a30fc472a804e72907ecaa4f9)
* Thu Nov 13 2014 rmilasan@suse.com
- Create rule to set I/O scheduler to deadline if device attribute
  'rotational' equals 0, usually SSDs (bnc#904517).
  Add 1095-set-ssd-disk-to-use-deadline-scheduler.patch
* Thu Nov 13 2014 thomas.blume@suse.com
- fix systemd-fstab-generator crypttab parsing (bnc#903963)
* Tue Nov 11 2014 gber@opensuse.org
- Add pm-utils-hooks-compat.sh in order to run pm-utils sleep hooks
  from systemd (boo#904828)
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-login-rerun-vconsole-setup-when-switching-from-vgaco.patch
  0002-shutdown-fix-arguments-to-run-initramfs-shutdown.patch
  0003-utf8-when-looking-at-the-next-unichar-honour-the-siz.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  0001-core-don-t-allow-enabling-if-unit-is-masked.patch
  0002-snapshot-return-error-when-snapshot-exists.patch
  0003-shared-install-avoid-prematurely-rejecting-missing-u.patch
  0004-Raise-level-of-Found-dependency.-lines.patch
  0005-units-order-sd-journal-flush-after-sd-remount-fs.patch
  0006-journald-fix-minor-memory-leak.patch
  0007-journald-also-check-journal-file-size-to-deduce-if-i.patch
  0008-journald-fix-memory-leak-on-error-path.patch
  0009-units-make-systemd-journald.service-Type-notify.patch
  0010-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Mon Nov 10 2014 werner@suse.de
- Add upstream patches
  1092-libudev-do-not-accept-invalid-log-levels.patch
  1093-udev-Fix-parsing-of-udev.event-timeout-kernel-parame.patch
  1094-udev-avoid-magic-constants-in-kernel-cmdline-parsers.patch
* Fri Nov  7 2014 werner@suse.de
- Add patch watch_resolv.conf_for_become_changed.patch to add an
  inotify watch on /etc/resolv.conf which enables the reload of
  a changed resolver configuration on the fly (bsc#902901)
- Do not apply patch 0022-systemd-tmpfiles-ownerkeep.patch in case
  if the script /usr/bin/systemd-tmpfiles-keep is missed
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  0001-sd-bus-properly-handle-removals-of-non-existing-matc.patch
  0002-keymap-Ignore-brightness-keys-on-Dell-Inspiron-1520-.patch
* Mon Nov  3 2014 werner@suse.de
- Add upstream patches
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  1091-udev-path_id-update-comments.patch
  which will be applied if patch
  1090-udev-path_id-set-supported_parent-for-well-known-SCS.patch
  is applied a this may fix the trouble with iSCSI (bnc#898233)
* Thu Oct 30 2014 werner@suse.de
- Add upstream patches
  0001-manager-Linux-on-hppa-has-fewer-rtsigs-hence-avoid-u.patch
  0002-time-also-support-infinity-syntax-in-parse_nsec.patch
  0003-time-earlier-exit-from-format_timestamp_relative-on-.patch
  0004-sd-bus-if-we-don-t-manage-to-properly-allocate-the-e.patch
  0005-journalctl-correct-help-text-for-until.patch
  0006-calendarspec-fix-typo-in-annually.patch
  0007-systemctl-do-not-ignore-errors-in-symlink-removal.patch
  0008-util-introduce-sethostname_idempotent.patch
  0009-util-fix-copy-paste-error-and-actually-set-the-new-h.patch
  0010-shutdown-do-final-unmounting-only-if-not-running-ins.patch
  0011-selinux-make-sure-we-do-not-try-to-print-missing-fie.patch
- Replace patch
  keep-crypt-password-prompt.patch as this with
  upstream patch
  0012-manager-do-not-print-anything-while-passwords-are-be.patch
* Fri Oct 24 2014 werner@suse.de
- Add upstream patch
  0002-shutdown-pass-own-argv-to-run-initramfs-shutdown.patch
- Add patch journald-advice-about-use-of-memory.patch to use mmap()
  flags as well as madvise(2) for journal files.
* Thu Oct 23 2014 werner@suse.de
- Add upstream patches
  0001-strv-add-an-additional-overflow-check-when-enlarging.patch
  0002-hwdb-Add-mapping-for-special-keys-on-compaq-ku-0133-.patch
  0003-journald-add-CAP_MAC_OVERRIDE-in-journald-for-SMACK-.patch
  0004-journal-do-server_vacuum-for-sigusr1.patch
  0005-cryptsetup-fix-an-OOM-check.patch
* Wed Oct 22 2014 werner@suse.de
- Add upstream patch 1089-fix-cgroup-device-controller.patch
  to avoid trouble on existing /dev/console with nspawn (bsc#902240)
* Tue Oct 21 2014 werner@suse.de
- Modify patch avoid-leaking-socket-descriptors.patch to close
  file descriptors for incomming connections in pam module in case
  of short memory.
* Mon Oct 20 2014 werner@suse.de
- Add upstream patches
  0001-systemd-continue-switch-root-even-if-umount-fails.patch
  0002-systemd-try-harder-to-bind-to-notify-socket.patch
- Add patch avoid-leaking-socket-descriptors.patch to close
  file descriptors if an incomming connection can not be handled
  due e.g. short memory. Could be related to bsc #901481
* Wed Oct 15 2014 werner@suse.de
- Add upstream patches
  0001-shell-completion-fix-completion-of-inactive-units.patch
  0002-shell-completion-propose-templates-for-disable-re-en.patch
  0003-man-we-don-t-have-Wanted-dependency.patch
  0004-selinux-fix-potential-double-free-crash-in-child-pro.patch
* Wed Oct 15 2014 werner@suse.de
- Adapt patch
  rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  to make it work even with patch #438 and #439
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-when-mangle-unit-names-for-the-isolate-suf.patch
  0001-tmpfiles-compare-return-against-correct-errno.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-keymap-Fix-touchpad-toggle-on-Toshiba-Satellite-P75-.patch
  0001-units-introduce-network-pre.target-as-place-to-hook-.patch
  0002-keymap-Fix-touchpad-toggle-key-on-Asus-laptops.patch
  0003-sd-bus-check-return-value-of-vasprintf.patch
  0004-core-map-the-rescue-argument-to-rescue.target.patch
  0005-util-avoid-double-close-of-fd.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-virt-detect-that-we-are-running-inside-the-docker-co.patch
  0002-bootchart-use-n-a-if-PRETTY_NAME-is-not-found.patch
  0003-fileio-label-return-error-when-writing-fails.patch
  0001-sd-event-don-t-require-a-signal-event-source-to-be-e.patch
  0004-sd-event-check-the-value-of-received-signal.patch
  0005-sd-id128-do-stricter-checking-of-random-boot-id.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-core-swap-only-make-configured-units-part-of-swap.ta.patch
  0009-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-journalctl-do-not-output-reboot-markers-when-running.patch
  0002-udev-hwdb-New-Entry-for-Dell-XPS12-9Q33-keyboard.patch
* Tue Oct 14 2014 werner@suse.de
- Add upstream patches
  0001-logind-add-support-for-Triton2-Power-Button.patch
  0002-logind-add-support-for-TPS65217-Power-Button.patch
- Add upstream patches
  0001-shutdownd-clean-up-initialization-of-struct.patch
  0003-bootchart-parse-userinput-with-safe_atoi.patch
  0004-bootchart-check-return-of-strftime.patch
  0005-bootchart-Do-not-try-to-access-data-for-non-existing.patch
* Thu Oct  2 2014 lduncan@suse.com
- Revert patch 1063, which incorrectly disallows
  /dev/disk/by-path links for iSCSI (and other)
  devices. Will be corrected and re-added once
  upstream is consulted. (bnc#898233).  Disable:
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patc
* Fri Sep 26 2014 werner@suse.de
- Add upstream patch
  0001-systemd-tmpfiles-Fix-IGNORE_DIRECTORY_PATH-age-handl.patch
  for bsc#893797
* Fri Sep 26 2014 rmilasan@suse.com
- Drop renaming virtual interfaces in a guest (bnc#898432).
  Add 1088-drop-renaming-of-virtual-interfaces-in-guest.patch
* Thu Sep 25 2014 werner@suse.de
- Rename patch 0001-infinit-timeout-for-kmod-loaded-modules.patch
  to patch 1087-infinit-timeout-for-kmod-loaded-modules.patch
  and apply this one
* Thu Sep 25 2014 werner@suse.de
- Change patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  to fix bsc#898240
* Thu Sep 25 2014 werner@suse.de
- Add upstream patches
  0001-Fix-warning-about-unused-variable-with-SELINUX.patch
  0002-bus-remove-unused-check.patch
* Wed Sep 24 2014 werner@suse.de
- Add patch 0001-infinit-timeout-for-kmod-loaded-modules.patch to
  be able to avoid killing a running kmod/modprobe (bnc#889297)
* Wed Sep 24 2014 werner@suse.de
- Update patch 0001-bnc888612-logind-polkit-acpi.patch
* Wed Sep 24 2014 werner@suse.de
- Add upstream patches
  0001-login-pause-devices-before-acknowledging-VT-switches.patch
  May help that history of the shell is saved
  0001-nspawn-don-t-try-to-create-veth-link-with-too-long-i.patch
  0001-socket-introduce-SELinuxContextFromNet-option.patch (bsc#897801)
  0002-util-avoid-non-portable-__WORDSIZE.patch
* Fri Sep 19 2014 werner@suse.de
- Add patch 0001-bnc888612-logind-polkit-acpi.patch from Frederic
  to solve bnc#888612 - AUDIT-0: Power button press at gdm login
  should not prompt for credentials
* Fri Sep 19 2014 werner@suse.de
- Add upstream bugfix patches
  0001-journal-Do-not-count-on-the-compiler-initializing-fo.patch
  0002-include-fcntl.h-rather-than-sys-fcntl.h.patch
  0003-mount-order-options-before-other-arguments-to-mount.patch
  0004-shared-wtmp-utmp-don-t-clear-store_wtmp-in-utmp_put_.patch
  0005-shared-label.h-add-missing-stdio.h-include.patch
  0006-shared-sparse-endian.h-add-missing-byteswap.h-includ.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patch
  1080-udevd-parse_argv-warn-if-argumens-are-invalid.patch
  1081-udevd-check-return-of-various-functions.patch
  1082-udevadm-hwdb-check-return-value-of-fseeko.patch
  1083-udev-node-warn-if-chmod-chown-fails.patch
  1084-udev-ctrl-log-if-setting-SO_PASSCRED-fails.patch
  1085-udev-fix-typos.patch
  1086-udevd-don-t-fail-if-run-udev-exists.patch
* Thu Sep 18 2014 werner@suse.de
- Add upstream bugfix patches
  0001-core-fix-resource-leak-in-manager_environment_add.patch
  0002-util-remove-a-unnecessary-check.patch
  0003-udev-event-explicitly-don-t-read-from-invalid-fd.patch
  0004-shared-conf-parser.patch
  0005-logind-fix-typo.patch
  0006-systemctl-fix-resource-leak-CID-1237747.patch
  0007-libudev-monitor-warn-if-we-fail-to-request-SO_PASSCR.patch
  0008-shared-conf-parser-don-t-leak-memory-on-error-in-DEF.patc
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
- Remove 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch as
  0009-bus-fix-bus_print_property-to-use-int-for-booleans.patch
  is the upstream solution
* Wed Sep 17 2014 werner@suse.de
- Add patch 0001-sizeof-bool-used-by-gcc-depends-on-arch.patch to
  fix for the size of the gcc builtin type bool also known as _Bool
  from the include header stdbool.h.
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches as real fixes
  0001-activate-fix-fd-leak-in-do_accept.patch
  0002-analyze-avoid-a-null-dereference.patch
  0003-analyze-fix-mem-leak.patch
  0004-backlight-Avoid-error-when-state-restore-is-disabled.patch
  0005-bus-avoid-using-m-kdbus-after-freeing-it.patch
  0006-bus-unref-buscreds-on-failure.patch
  0007-core-fix-a-potential-mem-leak.patch
  0008-core-smack-setup-Actually-allow-for-succesfully-load.patch
  0009-journal-do-not-leak-mmaps-on-OOM.patch
  0010-manager-use-correct-cleanup-function.patch
- Intergrate the work of Robert and rename the patch
  1068-udev-remove-userspace-firmware-loading-support.patch
  to 1078-udev-remove-userspace-firmware-loading-support.patch
  Also add patch
  1079-udev-remove-userspace-firmware-loading-support.patch
  to apply the same change for opensuse 13.2 and above
* Tue Sep 16 2014 werner@suse.de
- Add upstream patch
  0001-systemctl-allow-to-change-the-default-target-without.patch
  to allow to override default target without --force (bnc#896664)
* Tue Sep 16 2014 werner@suse.de
- Add upstream patches for udev
  1068-udev-net_setup_link-export-the-.link-filename-applie.patch
  1069-rules-net-setup-link-preserve-ID_NET_LINK_FILE-and-I.patch
  1070-rules-net-setup-link-remove-stray-linebreak.patch
  1071-udev-import-the-full-db-on-MOVE-events-for-devices-w.patch
  1072-udev-netif_rename-don-t-log-to-kmsg.patch
  1073-udev-drop-print_kmsg.patch
  1074-udev-fix-copy-paste-error-in-log-message.patch
  1075-udev-timeout-increase-timeout.patch (bnc#889297)
  1076-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
  1077-udev-timeout-warn-after-a-third-of-the-timeout-befor.patch (bnc#889297)
* Tue Sep 16 2014 rmilasan@suse.com
- udev: remove userspace firmware loading support (bnc#889297).
  Add 1068-udev-remove-userspace-firmware-loading-support.patch
* Sat Sep 13 2014 rmilasan@suse.com
- udev: always resolve correctly database names on 'change' event (bnc#864745).
  Add 1067-udev-always-resolve-correctly-database-names-on-chan.patch
* Tue Sep  9 2014 werner@suse.de
- Add upstream patch 0009-hwdb-update.patch
* Mon Sep  8 2014 werner@suse.de
- Add upstream patches
  0001-initrd-parse-etc.service-ignore-return-code-of-daemo.patch
  0008-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Sep  4 2014 werner@suse.de
- Disable patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  for SLES-12 as well as for openSUSE-13.2 (bnc#895087)
* Tue Sep  2 2014 rmilasan@suse.com
- udev: add option to generate old 'buggy' serials (bnc#886852)
  Add 1066-udev-add-compatibility-links-for-truncated-by-id-links.patch
* Tue Sep  2 2014 werner@suse.de
- Add upstream patch
  0001-login-simplify-controller-handling.patch
* Mon Sep  1 2014 werner@suse.de
- Add upstream patches
  0001-completion-filter-templates-from-restartable-units.patch
  0002-systemd-fix-error-message.patch
  0003-Quote-unit-names-in-suggested-systemctl-commandlines.patch
  0004-config-parser-fix-mem-leak.patch
  0005-login-fix-mem-leak.patch
  1065-udev-bump-event-timeout-to-60-seconds.patch
* Fri Aug 29 2014 werner@suse.de
- Add upstream patch 0001-nspawn-fix-network-interface.patch to
  make option network-interface of systemd-nspawn work
* Thu Aug 28 2014 werner@suse.de
- Add upstream patches
  0001-login-fix-memory-leak-on-DropController.patch
  0002-util-fix-minimal-race-where-we-might-miss-SIGTERMs-w.patch
  0003-sd-journal-properly-convert-object-size-on-big-endia.patch
  0004-sd-journal-verify-that-object-start-with-the-field-n.patch
- Add upstream patch
  1064-udev-hwdb-do-not-look-at-usb_device-parents.patch
  to avoid that hwdb ID's for unrecognised USB device are taken
  from the USB hub.
* Wed Aug 27 2014 werner@suse.de
- Add upstream patches
  0001-systemctl-Correct-error-message-printed-when-bus_pro.patch
  0002-units-order-systemd-fsck-.service-after-local-fs-pre.patch
  0003-keymap-Adjust-for-more-Samsung-900X4-series.patch
* Wed Aug 27 2014 werner@suse.de
- Add patch use-rndaddentropy-ioctl-to-load-random-seed.patch to
  use RNDADDENTROPY ioctl to load random-seed and to increase
  entropy count as well (bnc#892096)
* Tue Aug 26 2014 werner@suse.de
- Add upstream patches for hwdb
  0001-hwdb-keymaps-for-Samsung-900X3E-900X3F.patch
  0002-Add-hwdb-entry-for-Samsung-Series-7-Ultra.patch
  0003-keymap-Fix-HP-Pavillon-DV7.patch
  0004-hwdb-update-format-description-and-document-reloadin.patch
  0008-hwdb-update.patch
* Tue Aug 26 2014 werner@suse.de
- Port back and add the missed upstream patches from 2014/08/22
  0004-login-set_controller-should-fail-if-prepare_vt-fails.patch
  0006-login-share-VT-signal-handler-between-sessions.patch
* Fri Aug 22 2014 werner@suse.de
- Add upstream patches
  0001-nspawn-fix-truncation-of-machine-names-in-interface-.patch
  0002-switch-root-umount-the-old-root-correctly.patch
  0003-bootchart-it-s-not-OK-to-return-1-from-a-main-progra.patch
  0005-sd-resolve-fix-allocation-if-query-ids-never-reuse-t.patch
  0007-journald-also-increase-the-SendBuffer-of-dev-log-to-.patch
  0008-mount-setup-fix-counting-of-early-mounts-without-SMA.patch
  0009-journald-Fix-off-by-one-error-in-Missed-X-kernel-mes.patch
  0010-machine_kill-Don-t-kill-the-unit-when-killing-the-le.patch
  0011-units-fix-BindsTo-logic-when-applied-relative-to-ser.patch
  0012-util-try-to-be-a-bit-more-NFS-compatible-when-checki.patch
  1063-udev-path_id-suppress-ID_PATH-for-devices-with-an-un.patch
* Fri Aug 22 2014 crrodriguez@opensuse.org
- man pages from section 3 are developer docs, move them to
  the -devel package.
* Wed Aug 20 2014 werner@suse.de
- Add patch 0001-let-systemctl-completion-ignore-at-names.patch to
  remove error messages for tab completion for systemctl isolate (bnc#892162)
* Mon Aug 18 2014 werner@suse.de
- Disable the usage of the systemd groups wheel and adm (bnc#892300)
* Fri Aug  8 2014 rmilasan@suse.com
- Set default permissions for GenWQE device nodes to 0666 (bnc#890977).
  Add 1062-rules-set-default-permissions-for-GenWQE-devices.patch
* Fri Aug  1 2014 werner@suse.de
- Add upstream patches
  0007-hwdb-update.patch
  1061-rules-allow-systemd-to-manage-loop-device-partitions.patch
* Thu Jul 31 2014 rmilasan@suse.com
- Rename:
  udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
  to
  1060-udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 jeffm@suse.com
- udev: use device mapper target name for btrfs device ready (bnc#888215).
- Add udev-use-device-mapper-target-name-for-btrfs-device-ready.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tomcat6-var-lock-subsys-legacy.patch to add the
  compatibility directory /var/lock/subsys (bnc#889357)
* Wed Jul 30 2014 werner@suse.de
- Add portabiltiy patch
  1055-let-9719859c07aa13539ed2cd4b31972cd30f678543-apply.patch
* Wed Jul 30 2014 werner@suse.de
- Port and add upstream patch
  0001-sysv-order-initscripts-which-provide-network-before-.patch
  0002-keymap-Add-microphone-mute-keymap-for-Dell-Latitude.patch
  0003-keymap-Annotate-all-micmute-workarounds.patch
* Wed Jul 30 2014 werner@suse.de
- Add patch tty-ask-password-agent-on-console.patch that is for system
  console do ask passphrases on all devices of the console (bnc#886211)
* Wed Jul 30 2014 werner@suse.de
- Add former SUSE and/now upstream patches (bnc#889297)
  1056-udevd-add-event-timeout-commandline-option.patch
  1057-udev-unify-event-timeout-handling.patch
  1058-udev-unify-event-timeout-handling.patch (backport for
  compatibility if patch 1022 is not applied)
  1059-udev-fixup-commit-dd5eddd28a74a49607a8fffcaf960040db.patch
* Mon Jul 28 2014 werner@suse.de
- Add patch shut-up-rpmlint-on-var-log-journal.patch to avoid
  rpmlink warning
- Add upstream patches
  0001-bus-proxyd-fix-incorrect-comparison.patch
  0002-shell-completion-prevent-mangling-unit-names.patch
  0003-Always-check-asprintf-return-code.patch
  0004-bash-completion-use-list-unit-files-to-get-all-units.patch
  0005-core-only-set-the-kernel-s-timezone-when-the-RTC-run.patch
  0006-parse_boolean-require-exact-matches.patch
  0007-drop_duplicates-copy-full-BindMount-struct.patch
  0008-shell-completion-prevent-mangling-unit-names-bash.patch
  0009-journald-always-add-syslog-facility-for-messages-com.patch
* Fri Jul 25 2014 werner@suse.de
- Disable blkrrpart for SLES12 and below
* Fri Jul 25 2014 werner@suse.de
- Add upstream patch
  1054-udev-exclude-MD-from-block-device-ownership-event-lo.patch
- Add with condition blkrrpart to be able to disable the patches
  1025, 1027, 1029, 1030, 1031, 1032, 1033, 1034, 1037, and 1054
  which uses the BLKRRPART ioctl for e.g. synthesize change events
  which may interfere with other tools like parted.
* Thu Jul 24 2014 fcrozat@suse.com
- Update
  handle-disable_caplock-and-compose_table-and-kbd_rate.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch: read
  /etc/vconsole.conf after /etc/sysconfig/(keyboard,console)
  otherwise empty value in /etc/sysconfig/keyboard might override
  /etc/vconsole.conf values.
- Update :
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
  apply-ACL-for-nvidia-device-nodes.patch
  keep-crypt-password-prompt.patch
  log-target-null-instead-kmsg.patch
  parse-crypttab-for-noauto-option.patch
  set-and-use-default-logconsole.patch: fix all warnings in code
- Remove 0001-compress-fix-return-value.patch: not relevant to
  systemd v210 code.
* Thu Jul 24 2014 werner@suse.de
- Also change udev-generate-peristent-rule to udev-generate-persistent-rule
  in file list
* Thu Jul 24 2014 rmilasan@suse.com
- Rename (fix typo in script name):
  udev-generate-peristent-rule.sh to udev-generate-persistent-rule.sh
* Wed Jul 23 2014 rmilasan@suse.com
- Enable better checks in write_net_rules to skip adding duplicated
  entries in the generate rules (bnc#888178).
  Add 1053-better-checks-in-write_net_rules.patch
* Wed Jul 23 2014 werner@suse.de
- Change patch set-and-use-default-logconsole.patch to avoid to
  write security/authorization (private) messages to console
* Tue Jul 22 2014 werner@suse.de
- Add patch set-and-use-default-logconsole.patch to use and set
  the default logging console for both journald and kernel messages
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-bash-completion-p-option-for-journalctl.patch
  0002-journalctl-man-allow-only-between-terms.patch
  0003-systemd-use-pager-for-test-and-help.patch
* Mon Jul 21 2014 werner@suse.de
- Use verify scripts and add permission files for systemd logger
- Avoid useless warning about static systemd unit files
- Make pam file a config file
- Remove non-break-space from this changelog
* Mon Jul 21 2014 werner@suse.de
- Add upstream patches
  0001-compress-fix-return-value.patch
  0002-Be-more-verbose-when-bind-or-listen-fails.patch
  0003-Add-quotes-to-warning-message.patch
  0004-systemd-return-the-first-error-from-manager_startup.patch
* Mon Jul 21 2014 werner@suse.de
- Replace patch 0001-fix-only-discover-Xen-domU.patch with
  upstream patch 0001-detect-virt-Fix-Xen-domU-discovery.patch
- Replace patch 0001-detect-s390-virt.patch with upstream
  patch 0001-systemd-detect-virt-detect-s390-virtualization.patch
* Thu Jul 17 2014 werner@suse.de
- Add upstream patches
  0001-po-add-Ukrainian-translation.patch
  0002-man-document-yearly-and-annually-in-systemd.time-7.patch
  0003-core-nicer-message-when-inotify-watches-are-exhauste.patch
- Add patch 0001-fix-only-discover-Xen-domU.patch to fix upstream
  patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
* Thu Jul 17 2014 rmilasan@suse.com
- Check if NAME key has a value before going thru the rule (bnc#885232).
  Add 1051-check-if-NAME-has-a-value.patch
* Wed Jul 16 2014 werner@suse.de
- Add upstream patches
  0001-Clear-up-confusion-wrt.-ENTRY_SIZE_MAX-and-DATA_SIZE.patch
  0002-units-serial-getty-.service-use-the-default-RestartS.patch
  1052-rules-uaccess-add-ID_SOFTWARE_RADIO.patch
* Tue Jul 15 2014 rmilasan@suse.com
- Only rename SRIOV-VF devices if device name start with eth (bnc#885232).
  Add 1050-only-rename-SRIOV-VF-devices-when-name-starts-with-eth.patch
* Tue Jul 15 2014 werner@suse.de
- Add patch vhangup-on-all-consoles.patch that is do a vhangup on
  lines (bnc#886599)
* Tue Jul 15 2014 jlee@suse.com
- Removed %%{_libexecdir}/modules-load.d/efivars.conf because the kernel
  patch of autoload efivars driver accepted by linux-efi upstream.
  (bnc#881559)
  https://git.kernel.org/cgit/linux/kernel/git/mfleming/efi.git/commit/?h=next&id=be756a5327fe3d4686d74d3e9b273010424e230c
* Mon Jul 14 2014 werner@suse.de
- Update patch
  1007-physical-hotplug-cpu-and-memory.patch (bnc#869603)
- Add script systemd-remount-tmpfs (bnc#869603) as helper script
  for the rule changed in patch 1007-physical-hotplug-cpu-and-memory.patch
* Mon Jul 14 2014 werner@suse.de
- Add upstream patch
  0001-event-pull-in-sd-event.h-from-event-util.h.patch
  0002-util-fix-has-cc-check-and-add-test.patch
  0003-sd-event-always-call-epoll_ctl-on-mask-updates-if-ed.patch
  0004-fileio-quote-more-shell-characters-in-envfiles.patch
* Fri Jul 11 2014 werner@suse.de
- Only on SLES12 seccomp is available on ppc64 and s390x
* Thu Jul 10 2014 werner@suse.de
- Port and add upstream patch
  0001-units-make-ExecStopPost-action-part-of-ExecStart.patch
* Wed Jul  9 2014 werner@suse.de
- Add patches
  0001-logind-allow-switching-to-unused-VTs-via-SwitchTo.patch
  0002-hostnamed-add-a-new-chassis-type-for-watches.patch
- Port and add upstream patches
  0001-journal-compress-return-early-in-uncompress_startswi.patch
  0002-journal-compress-improve-xz-compression-performance.patch
* Wed Jul  9 2014 meissner@suse.com
- enable seccomp also for ppc64 and s390x
* Tue Jul  8 2014 werner@suse.de
- Port and add upstream patches
  0001-util-consider-0x7F-a-control-chracter-which-it-is-DE.patch
  0002-util-don-t-consider-tabs-special-in-string_has_cc-an.patch
  0003-architecture-add-string-table-entries-for-mips-le-ar.patch
  0004-core-Added-support-for-ERRNO-NOTIFY_SOCKET-message-p.patch
  0005-service-don-t-accept-negative-ERRNO-notification-mes.patch
  0006-systemctl-show-StatusErrno-value-in-systemctl-status.patch
  0007-service-flush-status-text-and-errno-values-each-time.patch
* Tue Jul  8 2014 werner@suse.de
- Add upstream patch
  1049-udev-link_config-ignore-errors-due-to-missing-MAC-ad.patch
* Mon Jul  7 2014 werner@suse.de
- Add upstream patch
  0001-machine-don-t-return-uninitialized-variable.patch
- Port and add upstream patch
  0002-vconsole-setup-run-setfont-before-loadkeys.patch
* Mon Jul  7 2014 rmilasan@suse.com
- Rename
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  to
  1048-udev-net_setup_link-add-a-bit-more-logging.patch
* Fri Jul  4 2014 werner@suse.de
- Port and add upstream patches
  0001-udev-net_setup_link-add-a-bit-more-logging.patch
  0003-namespace-make-sure-tmp-var-tmp-and-dev-are-writable.patch
  0002-namespace-fix-uninitialized-memory-access.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0001-architecture-Add-tilegx.patch
  0002-architecture-Add-cris.patch
  0003-arch-add-crisv32-to-uname-check.patch
  0004-architecture-remove-cris-from-uname-list.patch
* Fri Jul  4 2014 werner@suse.de
- Add upstream patches
  0006-hwdb-update.patch
  0007-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Thu Jul  3 2014 werner@suse.de
- Add upstream patches
  0001-parse_uid-return-ENXIO-for-1-uids.patch
  0002-util-when-unescaping-strings-don-t-allow-smuggling-i.patch
  0003-localed-consider-an-unset-model-as-a-wildcard.patch
  0004-sd-bus-when-an-event-loop-terminates-explicitly-clos.patch
  0005-bus-close-a-bus-that-failed-to-connect.patch
  1047-udev-net_setup_link-builtin-should-print-the-reason-.patch
* Wed Jul  2 2014 rmilasan@suse.com
- Fix duplicated rules when having layer3 interfaces (bnc#882714).
  Add 1046-fix-duplicated-rules-with-layer3-interfaces.patch
* Tue Jul  1 2014 werner@suse.de
- Require correct pam-config version overall even for scriptlets (bnc#885288)
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  0001-main-uid_to_name-might-fail-due-to-OOM-protect-again.patch
  0002-journald-make-MaxFileSec-really-default-to-1month.patch
  0003-units-remove-RefuseManualStart-from-units-which-are-.patch
  0004-util-refuse-considering-UID-0xFFFF-and-0xFFFFFFFF-va.patch
  0005-nspawn-block-open_by_handle_at-and-others-via-seccom.patch
  0006-tmpfiles-don-t-do-automatic-cleanup-in-XDG_RUNTIME_D.patch
  0007-units-skip-mounting-tmp-if-it-is-a-symlink.patch
* Tue Jul  1 2014 werner@suse.de
- Be aware that close_nointr_nofail() may fail whereas safe_close() not
* Tue Jul  1 2014 werner@suse.de
- Add upstream patches
  1042-libudev-queue-provide-file-descriptor-to-watch-busy-.patch
  1043-libudev-queue-watch-entire-directory-to-allow-the-re.patch
  1044-rules-update-qemu-hid-rules.patch
  1045-rules-don-t-enable-usb-pm-for-Avocent-devices.patch
* Fri Jun 27 2014 werner@suse.de
- Add upstream bug fix patch
  1041-libudev-fix-udev_queue_get_queue_is_empty-logic.patch (bnc#882714)
* Fri Jun 27 2014 werner@suse.de
- Update of patch 0001-detect-s390-virt.patch (bnc#880438)
* Thu Jun 26 2014 werner@suse.de
- Shut up stupid check scripts crying for not mentioned systemd-mini-rpmlintrc
* Thu Jun 26 2014 werner@suse.de
- Add upstream patchs
  0001-core-use-correct-format-string-for-UIDs.patch
  0002-core-transaction-fix-cycle-break-attempts-outside-tr.patch
  0003-fsck-consider-a-fsck-implementation-linked-to-bin-tr.patch
* Thu Jun 26 2014 werner@suse.de
- Add upstream patch
  0001-units-order-network-online.target-after-network.targ.patch
  to make sure that etwork-online.target follows network.target
* Wed Jun 25 2014 rmilasan@suse.com
- rules: re-enable dev_id conditionally in persistent rules
  (bnc#884403 and bnc#882714).
  Add 1040-re-enable-dev_id-conditionally-in-persistent-rules.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patches
  0001-vconsole-also-copy-character-maps-not-just-fonts-fro.patch
  0002-core-make-sure-Environment-fields-passed-in-for-tran.patch
  0003-core-You-can-not-put-the-cached-result-of-use_smack-.patch
  0004-cryptsetup-don-t-add-unit-dependency-on-dev-null-dev.patch
  0005-man-fix-path-in-crypttab-5.patch
* Wed Jun 25 2014 werner@suse.de
- Add upstream patch
  1039-udevadm-settle-fixed-return-code-for-empty-queue.patch it
  fixes udevadm settle exit code which may had broken dracut scripts
  (bnc#884271 comment#18)
* Wed Jun 25 2014 werner@suse.de
- Temporary disable patch 1022 (bnc#884271 and bnc#882714).
* Tue Jun 24 2014 rmilasan@suse.com
- Rename 0002-udev-fix-invalid-free-in-enable_name_policy.patch
  to 1038-udev-fix-invalid-free-in-enable_name_policy.patch
* Tue Jun 24 2014 werner@suse.de
- Replace patches
  0001-systemd-empty-sigmask-on-reexec.patch with
  upstream 0008-Reset-signal-mask-on-re-exec-to-init.patch
  ensure-sysctl-are-applied-after-modules-are-loaded.patch with
  upstream 0001-units-systemd-sysctl.service.in-run-after-load-modul.patch
  getty-generator-with-serial-3270-tty.patch with
  upstream 0004-getty-generator-properly-escape-instance-names.patch
- Add upstream patches
  0002-units-add-missing-caps-so-that-GetAddresses-can-work.patch
  0003-units-order-systemd-tmpfiles-clean.service-after-tim.patch
  0005-po-add-Greek-translation.patch
  0006-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0007-po-add-German-translation.patch
  0009-core-clean-up-signal-reset-logic-when-reexec.patch
  0010-util-treat-fuse.sshfs-as-a-network-filesystem.patch
  0011-build-sys-add-pthread-flag-for-libsystemd-shared.patch
  0012-core-transaction-avoid-misleading-error-message-when.patch
* Tue Jun 24 2014 werner@suse.de
- Invert of the boolean for locking scheme of fsck (bnc#881125)
- Remove the ghost entry /etc/hostname and require the netcfg
* Mon Jun 23 2014 arvidjaar@gmail.com
- make sure legacy services that depend on network are started after
  network is available (bnc#883565)
  * 0001-core-sysvcompat-network-should-be-equivalent-to-netw.patch
  * update insserv-generator.patch to translate $network into
    network-online.target
* Wed Jun 18 2014 werner@suse.de
- Add patch 0001-detect-s390-virt.patch from Thomas Blume (bnc#880438)
  to detect the virtualization layers on s390x as well
* Wed Jun 18 2014 werner@suse.de
- Do not generate synthesize change for cd/dvd (bnc#882714, comment #51)
  add patch 1037-udev-exclude-cd-dvd-from-block-device.patch from
  Roberts suggestion as well as readd
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue Jun 17 2014 werner@suse.de
- Add upstream patches
  0001-core-fix-invalid-free-in-killall.patch
  0002-udev-fix-invalid-free-in-enable_name_policy.patch
  0003-install-fix-invalid-free-in-unit_file_mask.patch
* Tue Jun 17 2014 rmilasan@suse.com
- rules: disable usage of dev_id in persistent rules (bnc#882714).
  add: 1036-rules-disable-usage-of-dev_id-in-persistent-rules.patch
- Disable patch (bnc#882714).
  1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Thu Jun 12 2014 werner@suse.de
- Add patch
  1035-99-systemd.rules-Ignore-devices-with-SYSTEMD_READY-0.patch
  from Hannes Reinecke to avoid a race condition between variable
  'SYSTEMD_READY=0' and 'systemd' tag within udev rules (bnc#881942)
* Thu Jun 12 2014 werner@suse.de
- Add workaround for bnc#882393 by adding the systemd update utmp
  runlevel service to the wanted unit of e.g. the graphical target
- Add some later on created files to our file list
* Thu Jun 12 2014 jlee@suse.com
- Generate %%{_libexecdir}/modules-load.d/efivars.conf so we load efivars
  module at boot time not from udev (bnc#881559).
* Wed Jun 11 2014 crrodriguez@opensuse.org
- Do not build EFI support code in architectures on which
  the kernel does not support CONFIG_EFI, it won't work.
  (ia64 also supports it, but that's dead so is not included)
* Wed Jun 11 2014 werner@suse.de
- Add patch tmpfiles-do-not-clean-for-mandb-index-files.patch
  there is no need to clean out all 30 days the index data base
  files nor the cachedir tags of mandb.  Those files are used
  for whatis(1) as well as for apropos(1).
* Wed Jun 11 2014 werner@suse.de
- Do not override predictable names for openSUSE
* Wed Jun 11 2014 werner@suse.de
- Remove systemd-detect-xendom.patch as it becomes obsolete with
  upstream patch 0004-systemd-detect-virt-only-discover-Xen-domU.patch
- Add upstream patches
  0001-umount-modernizations.patch
  0002-namespace-when-setting-up-an-inaccessible-mount-poin.patch
  0003-core-allow-transient-mount-units.patch
  0004-systemd-detect-virt-only-discover-Xen-domU.patch
  0005-backlight-Do-not-clamp-brightness-for-LEDs.patch
  0006-log-honour-the-kernel-s-quiet-cmdline-argument.patch
* Tue Jun 10 2014 rmilasan@suse.com
- Add upstream patches
  1033-udev-really-exclude-device-mapper-from-block-device.patch
  1034-udev-check-the-return-value-from-udev_enumerate_scan.patch
* Tue Jun 10 2014 werner@suse.de
- Change detection of new locking scheme of fsck
* Tue Jun 10 2014 werner@suse.de
- Change 1021-udev-re-add-persistent-net-rules.patch to use persistent
  rules as a default on SLES-12 and predictable rules as a default
  otherwise
- Add cflags shell function to check possible flags for the compiler
  as well as for the linker
* Mon Jun  9 2014 rmilasan@suse.com
- Add upstream patches
  1025-udev-exclude-device-mapper-from-block-device-ownersh.patch
  1026-udevd-inotify-modernizations.patch
  1027-udev-synthesize-change-events-for-partitions-when-to.patch
  1028-udev-link-config-fix-mem-leak.patch
  1029-udev-try-first-re-reading-the-partition-table.patch
  1030-udev-guard-REREADP-logic-with-open-O_ECXL.patch
  1031-udev-make-sure-we-always-get-change-for-the-disk.patch
  1032-udev-guard-REREADPT-by-exclusive-lock-instead-of-O_E.patch
* Fri Jun  6 2014 werner@suse.de
- Add upstream patches
  0001-sd-event-restore-correct-timeout-behaviour.patch
  0002-bus-make-use-of-sd_bus_try_close-in-exit-on-idle-ser.patch
* Thu Jun  5 2014 werner@suse.de
- Add upstream patch 0001-hwdb-fix-case-sensitive-match.patch
* Thu Jun  5 2014 werner@suse.de
- Add dynamic detection of util-linux version to be able to
  disable the fsck option -l for version less than 2.25.0
* Thu Jun  5 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * The patches
    delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch and
    ensure-DM-and-LVM-are-started-before-local-fs-pre-target.patch
    indeed mention unit files which do not exist anymore.
- Make sure that systemd-ask-password-wall.service has a tty as
  it is not sure that a tty1 exists
- Avoid broken firmware loading on newer distributions as 13.1
* Thu Jun  5 2014 werner@suse.de
- Correct version check for the tcp-devel drop
- Use correct permissions for /var/log/journal
- Use ACLs for /var/log/journal as described in man:systemd-journald.service(8)
* Thu Jun  5 2014 crrodriguez@opensuse.org
- Correct the libseccomp distribution version test must be >= 13.1
-  In order to use unit directive AppArmorProfile= libapparmor-devel
  must be present in buildRequires.
* Tue Jun  3 2014 sndirsch@suse.com
- apply-ACL-for-nvidia-uvm-device-node.patch: set ACL on nvidia-uvm
  device (bnc#879767).
* Tue Jun  3 2014 werner@suse.de
- Add changes from Cristian Rodríguez:
  * fix keep-crypt-password-prompt.patch which floods the system
    logs with bogus opendir failures, still the wrong thing to do however.
  * Use %%find_lang to collect locale files
  * systemd-no-libattr.patch: systemd does not require  libattr
    but just sys/xattr.h, therefore drop the dependency.
    (from upstream)
  * Again, drop tcp-devel from buildRequires, this time it is not a
    SUSE specific feature removal, tcpd supportdisappeared in systemd
    212 and we shouldn't keep it around.
- Add patch 0001-build-sys-use-glibc-s-xattr-support-instead-of-requi.patch
  that is rename systemd-no-libattr.patch to git format
- Drop tcp-devel only for *next* openSUSE and not for SLES-12 nor
  for openSUSE 13.1
* Tue Jun  3 2014 werner@suse.de
- Add upstream patches
  0001-virt-rework-container-detection-logic.patch
  0002-fsck-include-device-name-in-the-message-about-missin.patch
  0003-units-use-KillMode-mixed-for-systemd-nspawn-.service.patch
  0004-util-ignore_file-should-not-allow-files-ending-with.patch
  0006-tty-ask-password-agent-Do-tell-what-directory-we-fai.patch
- Add upstream patches to update keyboard data base
  0007-keyboard-add-Plantronics-.Audio-mute-button.patch
- Add upstream patches for udev
  1023-udev-builtin-keyboard-do-tell-on-which-device-EVIOCS.patch
  1024-udev-always-close-lock-file-descriptor.patch
* Tue Jun  3 2014 rmilasan@suse.com
- Fix enabling predictable rules when using net.ifnames=1.
  update: 1021-udev-re-add-persistent-net-rules.patch
* Fri May 30 2014 rmilasan@suse.com
- Re-add persistent rules as a default and make predictable rules as
  fallback (bnc#880732).
  add: 1021-udev-re-add-persistent-net-rules.patch
- udev: remove seqnum API and all assumptions about seqnums
  add: 1022-udev-remove-seqnum-API-and-all-assumptions-about-seq.patch
* Tue May 27 2014 werner@suse.de
- Add upstream patches
  0001-Do-not-unescape-unit-names-in-Install-section.patch
  0002-analyze-run-use-bus_open_transport_systemd-instead-o.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patch
  1020-udev-keyboard-also-hook-into-change-events.patch
* Mon May 26 2014 werner@suse.de
- Add upstream patches to update keyboard data base
  0001-keymap-Add-Lenovo-Enhanced-USB-Keyboard.patch
  0002-keymap-Asus-EeePC-touchpad-toggle-key.patch
- Add upstream patches
  0001-nspawn-allow-to-bind-mount-journal-on-top-of-a-non-e.patch
  0002-nspawn-restore-journal-directory-is-empty-check.patch
  0003-core-never-consider-failure-when-reading-drop-ins-fa.patch
  0004-socket-properly-handle-if-our-service-vanished-durin.patch
* Wed May 21 2014 coolo@suse.com
- fix file list of systemd.pc
* Wed May 21 2014 werner@suse.de
- Add a workaround for old distributions like 13.1 to avoid
  deadlocks due NFS shares stopped after network
* Wed May 21 2014 werner@suse.de
- Add upstream patches
  0001-journal-cleanup-up-error-handling-in-update_catalog.patch
  0002-journal-properly-detect-language-specified-in-line.patch
  0003-man-mention-XDG_CONFIG_HOME-in-systemd.unit.patch
* Wed May 21 2014 werner@suse.de
- Add upstream patches to update usb and pci company identifiers
  0001-hwdb-update.patch
  0002-hwdb-update.patch
  0003-hwdb-PCI-include-primary-model-string-in-subsystem-m.patch
  0004-hwdb-update.patch
  0005-hwdb-update.patch
* Wed May 21 2014 werner@suse.de
- Move systemd.pc and udev.pc to their main packages (bnc#876587)
* Tue May 20 2014 werner@suse.de
- Add upstream patches
  0001-conf-parser-silently-ignore-sections-starting-with-X.patch
  0002-man-note-that-entire-sections-can-now-be-ignored.patch
  0004-machined-make-sure-GetMachineAddresses-is-available-.patch
  0005-core-Filter-by-state-behind-the-D-Bus-API-not-in-the.patch
  0006-login-add-mir-to-the-list-of-session-types.patch
  0007-logind-fix-Display-property-of-user-objects.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to update BluTooth company identifiers
  0001-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0002-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0003-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0004-hwdb-Update-database-of-Bluetooth-company-identifier.patch
  0005-hwdb-Update-database-of-Bluetooth-company-identifier.patch
* Tue May 20 2014 werner@suse.de
- Add upstream patches to allow processes to serialize block device
  events, also do execute the RUN tag if rename of a network device
  fails:
  1016-udev-serialize-synchronize-block-device-event-handli.patch
  1017-udev-do-not-skip-the-execution-of-RUN-when-renaming-.patch
  1018-udev-avoid-use-of-uninitialized-err.patch
- Rename 0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  to 1016-udev-warn-when-name_to_handle_at-is-not-implemented.patch
* Mon May 19 2014 werner@suse.de
- Add upstream patches mainly for better lid handling (bnc#878525
  and bnc#868019)
  0001-logind-ignore-lid-switch-if-more-than-1-display-is-c.patch
  0002-logind-fix-printf-format.patch
  0003-logind-ignore-lid-switch-events-for-30s-after-each-s.patch
  0004-logind-Do-not-fail-display-count-if-a-device-has-no-.patch
  0005-logind-move-lid-switch-handling-from-logind-main-to-.patch
  0006-man-clarify-that-the-ExecReload-command-should-be-sy.patch
  0007-man-readahead-fix-cmdline-switch-inconsistency-betwe.patch
  0008-man-update-journald-rate-limit-defaults.patch
  0009-nspawn-properly-format-container_uuid-in-UUID-format.patch
  0010-logind-allow-suspending-if-there-are-no-displays.patch
* Fri May 16 2014 werner@suse.de
- Make baselibs.conf aware to use the appropiate %%post and %%postun
  scriptlets which includes pam-config (bnc#877674)
* Fri May 16 2014 werner@suse.de
- Add upstream patches
  0001-core-close-socket-fds-asynchronously.patch
  0002-logind-bring-polkit-policy-for-hibernate-in-line-wit.patch
  0003-core-make-sure-to-serialize-jobs-for-all-units.patch
* Wed May 14 2014 werner@suse.de
- Add upstream patches
  0001-replace-more-dup-by-F_DUPFD_CLOEXEC.patch
  0002-pam_systemd-use-F_DUPFD_CLOEXEC-when-dupping-session.patch
  to avoid that in pam session unwanted file descriptors are inherited
* Tue May 13 2014 werner@suse.de
- Add patch log-target-null-instead-kmsg.patch from Thomas Blume
  to enable the kernel developers to see a clean kmsg ring buffer
  without any systemd/udev messages included (bnc#877021)
* Mon May 12 2014 werner@suse.de
- Add upstream patches for backlight
  0001-backlight-Avoid-restoring-brightness-to-an-unreadabl.patch
  0002-backlight-do-nothing-if-max_brightness-is-0.patch
  0003-backlight-unify-error-messages.patch
  0004-backlight-warn-if-kernel-exposes-backlight-device-wi.patch
  0005-backlight-handle-saved-brightness-exceeding-max-brig.patch
* Mon May 12 2014 werner@suse.de
- Add upstream patches
  0001-errno-make-sure-to-handle-the-3-errnos-that-are-alia.patch
  0002-udev-warn-when-name_to_handle_at-is-not-implemented.patch
  0003-analyze-fix-plot-with-bad-y-size.patch
  0004-job-add-waiting-jobs-to-run-queue-in-unit_coldplug.patch
  0005-job-always-add-waiting-jobs-to-run-queue-during-cold.patch
* Mon May 12 2014 rmilasan@suse.com
- Drop upstream-net_id-changes.patch and replace them with the correct
  patches from upstream and their commits:
  add: 1014-udev-update-net_id-comments.patch
  add: 1015-udev-persistent-naming-we-cannot-use-virtio-numbers-.patch
* Wed May  7 2014 werner@suse.de
- Add patch parse-crypttab-for-noauto-option.patch from Thomas Blume
  to handle the option 'noauto' in /etc/crypttab (bnc#742774)
* Wed May  7 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to have the correct terminal type used with agetty
- Add patch 0001-tmpfiles-fix-permissions-on-new-journal-files.patch
  to allow users to access systemd user journal (bnc#876694)
* Mon May  5 2014 werner@suse.de
- Port upstream patch
  0001-sd-rtnl-message-append-fix-uninitialized-memory.patch
  back to 210
- Add patch keep-crypt-password-prompt.patch from Thomas Blume
  to fix bnc#875502 - fails to boot when swap space is encrypted
- Port upstream patch set for net_id back in patch
  upstream-net_id-changes.patch
* Fri May  2 2014 werner@suse.de
- Add patch shut-up-annoying-assertion-monotonic-clock-message.patch
  to avoid annyoing messages on failing dual_timestamp_is_set in the
  kernel's message ring buffer
* Wed Apr 30 2014 werner@suse.de
- Update udev-generate-peristent-rule.sh from latest git
* Wed Apr 30 2014 werner@suse.de
- Modify and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to avoid also ANSI escape sequences for busy jobs on s390
* Mon Apr 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-bash-completion-fix-__get_startable_units.patch
  0002-sysctl-replaces-some-slashes-with-dots.patch
  0003-delta-do-not-use-unicode-chars-in-C-locale.patch
  0004-implement-a-union-to-pad-out-file_handle.patch
- Add patch respect-nfs-bg-option.patch from Thomas Blume:
  System fails to boot if nfs mounts get added to fstab (bnc#874665)
* Wed Apr 23 2014 oneukum@suse.com
- Do not use runtime PM for some IBM consoles (bnc#868931)
  1013-no-runtime-PM-for-IBM-consoles.patch
* Thu Apr 17 2014 werner@suse.de
- Extend avoid-divide-by-zero-sigtrap.patch to make the crash
  handler know about SIGTRAP and SIGSYS
* Thu Apr 17 2014 werner@suse.de
- Add avoid-divide-by-zero-sigtrap.patch which fixes bnc#867663
  that is a divide by zero on a jobless system
* Wed Apr 16 2014 werner@suse.de
- Use latest regenerate-initrd rpm macros (fate#313506)
- Add rescue-emergency-target-conflicts.patch to avoid that
  emergency and rescue sulogin are fighting on console
* Tue Apr 15 2014 werner@suse.de
- Modify systemd-sleep-grub to let hybrid-sleep.target work even
  on XEN, changes from Thomas Blume (bnc#873432)
* Mon Apr 14 2014 werner@suse.de
- Add backported upstream patch
  0001-reduce-the-amount-of-messages-logged-to-dev-kmsg-whe.patch
- Add patch systemd-detect-xendom.patch from Thomas Blume
  to be able to detect XEN dom0 as well as domU
- systemd conflicts with sysvinit, ven if the package systemd-sysvinit
  does already conflict with sysvinit-init (bnc#873444)
* Thu Apr 10 2014 werner@suse.de
- Add two patches from hare@suse.com
  1011-64-btrfs.rules-skip-btrfs-check-if-devices-are-not-r.patch
  1012-Skip-persistent-device-link-creation-on-multipath-de.patch
  to solve bnc#872929
* Wed Apr  9 2014 rmilasan@suse.com
- Increase result size for programs stdout (bnc#867840).
  add: 1010-udev-increase-result-size-for-programs.patch
- Update udev-generate-peristent-rule.sh to the latest version.
- Clean-up spec file, re-arange patch to suit the setup, all udev
  patches start with 1XXX-*.{patch,diff}.
- Rename: 0013-cdrom_id-use-the-old-MMC-fallback.patch to
  1009-cdrom_id-use-the-old-MMC-fallback.patch
- Rename: 1009-make-xsltproc-use-correct-ROFF-links.patch to
  0009-make-xsltproc-use-correct-ROFF-links.patch
- Rename: 1010-do-not-install-sulogin-unit-with-poweroff.patch to
  0010-do-not-install-sulogin-unit-with-poweroff.patch
- Rename: 1014-journald-with-journaling-FS.patch to
  0014-journald-with-journaling-FS.patch
- Rename: 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch to
  0018-Make-LSB-Skripts-know-about-Required-and-Should.patch
- Rename: 1019-make-completion-smart-to-be-able-to-redirect.patch to
  0019-make-completion-smart-to-be-able-to-redirect.patch
- Rename: 1022-systemd-tmpfiles-ownerkeep.patch to
  0022-systemd-tmpfiles-ownerkeep.patch
* Tue Apr  8 2014 werner@suse.de
- Add patch portmap-wants-rpcbind-socket.patch to make sure that
  rpcbind socket as well as service is up with the target
- Add or port upstream bugfix patches:
  0001-journal-fix-export-of-messages-containing-newlines.patch
  0002-systemctl-update-NAME-to-PATTERN-in-help.patch
  0003-tty-ask-password-agent-return-negative-errno.patch
  0004-systemd-python-use-.hex-instead-of-.get_hex.patch
  0005-systemd-python-fix-failing-assert.patch
* Fri Mar 28 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-cgroup-it-s-not-OK-to-invoke-alloca-in-loops.patch
  0002-machined-fix-Kill-bus-call-on-machine-objects-when-w.patch
  0003-sd-bus-don-t-use-assert_return-to-check-for-disconne.patch
  0004-core-don-t-try-to-relabel-mounts-before-we-loaded-th.patch
  0005-sd-daemon-fix-incorrect-variable-access.patch
  0006-sd-event-initialization-perturbation-value-right-bef.patch
  0007-sd-event-don-t-accidentally-turn-of-watchdog-timer-e.patch
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
  0009-ask-password-when-the-user-types-a-overly-long-passw.patch
- Modify patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to work together with
  0008-systemctl-kill-mode-is-long-long-gone-don-t-mention-.patch
* Fri Mar 28 2014 werner@suse.de
- Use Robert's revised 1006-udev-always-rename-network.patch
* Tue Mar 25 2014 werner@suse.de
- Readd patch Forward-suspend-hibernate-calls-to-pm-utils.patch
  older code base as 13.1 only
- Add patch avoid-random-hangs-on-timeouts-due-lost-cwd.patch
  to be able to terminate the user manager even if cwd of the
  user is gone
* Tue Mar 25 2014 thomas.blume@suse.com
- add prepare-suspend-to-disk.patch
  enable suspend conditions check and preparation for systemd-sleep
  (fate#316824, bnc#856389, bnc#856392)
- remove Forward-suspend-hibernate-calls-to-pm-utils.patch since it is obsolete
  (bnc#856392#c20)
- add boot-local-start.patch
  fix startup for /etc/init.d/boot.local (bnc#869142)
* Mon Mar 24 2014 coolo@suse.com
- also autoreconf in systemd-mini to simplify spec file logic
  and fix build in staging:gcc49
  (obsoleting 0002-make-209-working-on-older-dist.patch)
* Wed Mar 19 2014 werner@suse.de
- Be sure that the refreshed manual pages are installed
* Wed Mar 19 2014 werner@suse.de
- Add patch systemctl-set-default-target.patch which explain how
  to override the default.target by using --force (bnc#868439)
* Tue Mar 18 2014 werner@suse.de
- Add Robert's udev-generate-peristent-rule shell script to
  udev's tool library
- Add or port upstream bugfix patches:
  0001-gpt-auto-generator-don-t-return-OOM-on-parentless-de.patch
  0002-bus-fix-memory-leak-when-kdbus-is-not-enabled.patch
  0006-Do-not-return-1-EINVAL-on-allocation-error.patch
  0007-networkd-fix-typo.patch
  0008-sd-bus-don-t-access-invalid-memory-if-a-signal-match.patch
  0009-sd-bus-don-t-choke-if-somebody-sends-us-a-message-wi.patch
  0012-journald-remove-stray-reset-of-error-return-value.patch
  0013-core-libsystemd-systemd-timedate-udev-spelling-fixes.patch
* Fri Mar 14 2014 werner@suse.de
- Add patch getty-generator-with-serial-3270-tty.patch to avoid
  harmless error messages on not existing getty@3270 files
* Fri Mar 14 2014 werner@suse.de
- Replace systemd-big-endian-reply-matching.patch with upstream
  0001-sd-bus-don-t-look-for-a-64bit-value-when-we-only-hav.patch
  to solve broken systemd communication with and over dbus (bnc#866732)
* Fri Mar 14 2014 werner@suse.de
- Readd patch 1008-add-msft-compability-rules.patch for
  older code base as 13.1
- Modify pre_checkin.sh to throw an error if a patch will be
  applied which modifies one of Makefile.am, Makefile.in, or
  configiure.ac as this breaks bootstrapping
- Add second version of make-209-working-on-older-dist.patch
  to be able to apply for bootstrapping version
* Thu Mar 13 2014 schwab@linux-m68k.org
- Don't require non-existing binutils-gold
* Thu Mar 13 2014 werner@suse.de
- Avoid file conflict between udev and systemd (bnc#868230)
* Wed Mar 12 2014 werner@suse.de
- Modify patch
  module-load-handle-SUSE-etc-sysconfig-kernel-module-list.patch
  to ignore if /etc/sysconfig/kernel does not exist (bnc#865834)
* Wed Mar 12 2014 werner@suse.de
- Add patch systemd-big-endian-reply-matching.patch
  make sure that systemd can talk with dbus-daemon even on big
  endian systems (bnc#866732)
* Tue Mar 11 2014 hrvoje.senjan@gmail.com
- Due to previous reason, resurrect systemd-dbus-system-bus-address.patch
- Removed pkgconfig(dbus-1) BuildRequires - with 209 and newer, itis only
  needed for quering default DBus directories, which we nowpass to configure.
  This also unbreaks libdbus <-> systemd-miniBuild Cycle
* Tue Mar 11 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-core-busname-add-lookup-string-for-BUSNAME_FAILURE_S.patch
  0002-manager-flush-memory-stream-before-using-the-buffer.patch
  0003-busname-don-t-drop-service-from-the-result-string.patch
  0004-fix-off-by-one-error-in-array-index-assertion.patch
  0005-logind-fix-policykit-checks.patch
  0006-rules-mark-loop-device-as-SYSTEMD_READY-0-if-no-file.patch
  0007-dbus-suppress-duplicate-and-misleading-messages.patch
  0008-man-multiple-sleep-modes-are-to-be-separated-by-whit.patch
* Tue Mar 11 2014 werner@suse.de
- Make compeletion file parser work (bnc#867664)
* Fri Mar  7 2014 hare@suse.de
- Integrate powerd handling in initctl service
  + Remove 1016-support-powerfail-with-powerstatus.patch
  + Remove systemd-powerfail
  + Add systemd-powerd-initctl-support.patch
- Remove 61-msft.rules; superseded by sg3_utils (bnc#866933)
- Persistent by-path links for ATA devices (FATE#317063)
  + Update 1001-re-enable-by_path-links-for-ata-devices.patch
* Fri Mar  7 2014 werner@suse.de
- Add or port upstream bugfix patches:
  0001-Fix-systemd-stdio-bridge-symlink.patch
  0002-execute-free-directory-path-if-we-fail-to-remove-it-.patch
  0003-Do-not-print-invalid-UTF-8-in-error-messages.patch
  0004-man-document-missing-options-of-systemd-run.patch
  0005-systemd-run-add-some-extra-safety-checks.patch
  0006-journal-assume-that-next-entry-is-after-previous-ent.patch
  0007-journal-forget-file-after-encountering-an-error.patch
  0008-core-correctly-unregister-PIDs-from-PID-hashtables.patch
  0009-logind-fix-reference-to-systemd-user-sessions.servic.patch
  0010-man-update-link-to-LSB.patch
  0011-man-systemd-bootchart-fix-spacing-in-command.patch
  0012-man-add-missing-comma.patch
  0013-units-Do-not-unescape-instance-name-in-systemd-backl.patch
* Fri Mar  7 2014 werner@suse.de
- Add linker scripts as place holder of the old systemd shared
  libraries now all included in libsystemd.so  (bnc#867128)
* Tue Mar  4 2014 werner@suse.de
- Make patch 1006-udev-always-rename-network.patch work again
  and add it again.
* Mon Mar  3 2014 thomas.blume@suse.com
- address missing owner functionality in systemd-tmpfiles (fate#314974)
  1022-systemd-tmpfiles-ownerkeep.patch
* Mon Mar  3 2014 werner@suse.de
- Generate the bash completion files on the fly for the case of
  not having the package bash-completion around
- Add or port upstream bugfix patches:
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  0002-cdrom_id-use-the-old-MMC-fallback.patch
  0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  0004-logs-show-fix-corrupt-output-with-empty-messages.patch
  0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  0008-README-document-that-var-run-must-be-a-symlink-run.patch
  0010-Replace-var-run-with-run-in-remaining-places.patch
  0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  0014-login-fix-pos-array-allocation.patch
* Mon Mar  3 2014 werner@suse.de
- Update to Release v210
  + systemd will now relabel /dev after loading the SMACK policy
    according to SMACK rules.
  + A new unit file option AppArmoreProfile= has been added to
    set the AppArmor profile for the processes of a unit.
  + A new condition check ConditionArchitecture= has been added
    to conditionalize units based on the system architecture, as
    reported by uname()'s "machine" field.
  + systemd-networkd now supports matching on the system
    virtualization, architecture, kernel command line, host name
    and machine ID.
  + logind is now a lot more aggressive when suspending the
    machine due to a closed laptop lid.
  + logind will now watch SW_DOCK switches and inhibit reaction
    to the lid switch if it is pressed.
  + nspawn will now make use of the devices cgroup controller by
    default, and only permit creation of and access to the usual
    API device nodes like /dev/null or /dev/random, as well as
    access to (but not creation of) the pty devices.
  + systemd will now understand the usual M, K, G, T suffixes
    according to SI conventions (i.e. to the base 1000) when
    referring to throughput and hardware metrics.
  + The DeviceAllow= setting in unit files now supports a syntax
    to whitelist an entire group of devices node majors at once,
    based on the /proc/devices listing. For example, with the
    string "char-pts" it is now possible to whitelist all
    current and future pseudo-TTYs at once.
  + sd-event learned a new "post" event source. Event sources of
    this type are triggered by the dispatching of any event
    source of a type that is not "post". This is useful for
    implementing clean-up and check event sources that are
    triggered by other work being done in the program.
  + The compatibility libraries for libsystemd-journal.so,
    libsystem-id128.so, libsystemd-login.so and
    libsystemd-daemon.so do not make use of IFUNC
    anymore.
- Dropped systemd patches as those are fixed upstream:
  * 0001-units-serial-getty-.service-add-Install-section.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patchc
  * 0001-make-tests-with-libseccomp-work.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-units-serial-getty-.service-add-Install-section.patch
- Dropped patches as those do not work anymore
  * 1006-udev-always-rename-network.patch
- Renamed systemd patches as seen from git log:
  * 0001-cdrom_id-use-the-old-MMC-fallback.patch
    become 0002-cdrom_id-use-the-old-MMC-fallback.patch
  * 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
    become 0003-journalctl-refuse-extra-arguments-with-verify-and-si.patch
  * 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
    become 0004-logs-show-fix-corrupt-output-with-empty-messages.patch
- Add several upstream bugfix patches which are missed:
  * 0001-build-sys-Add-setns-functions-if-not-in-the-C-librar.patch
  * 0001-build-sys-Fix-compilation-of-nspawn-when-seccomp-is-.patch
  * 0001-sd-event-Fix-systemd-crash-when-using-timer-units.patch
  * 0001-selinux-Don-t-attempt-to-load-policy-in-initramfs-if.patch
  * 0001-shared-architecture.h-fix-preprocessor-directives.patch
  * 0005-mount-don-t-fire-PropertiesChanged-signals-for-mount.patch
  * 0006-mount-don-t-send-out-PropertiesChanged-message-if-ac.patch
  * 0007-Use-var-run-dbus-system_bus_socket-for-the-D-Bus-soc.patch
  * 0008-README-document-that-var-run-must-be-a-symlink-run.patch
  * 0009-Revert-back-to-var-run-at-a-couple-of-problems.patch
  * 0010-Replace-var-run-with-run-in-remaining-places.patch
  * 0011-fix-typo-in-iDRAC-network-interface-name-irdac-idrac.patch
  * 0012-login-Allow-calling-org.freedesktop.login1.Seat.Swit.patch
  * 0013-login-set-pos-slot-to-fallback-on-pos-eviction.patch
  * 0014-login-fix-pos-array-allocation.patch
- Modified patches to make is build
  * 0001-add-network-device-after-NFS-mount-units.patch
- Reenable libseccomp for the architecture for which libseccomp exists
* Sun Mar  2 2014 ro@suse.de
- always install compat pkgconfig files, regardless if
  compat libs is enabled or not
* Sun Mar  2 2014 ro@suse.de
- disable use of libseccomp for sle12, library has not been ported
  to most architectures
- do not use binutils-gold on s390/s390x, does not exist there
- fix exclude statements for bootstrap case
* Fri Feb 28 2014 werner@suse.de
- Add upstream patches
  + 0001-cdrom_id-use-the-old-MMC-fallback.patch
  + 0001-logs-show-fix-corrupt-output-with-empty-messages.patch
  + 0001-journalctl-refuse-extra-arguments-with-verify-and-si.patch
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-systemd-empty-sigmask-on-reexec.patch
  which corrects sigmaks for reexec in initrd (bnc#864904)
* Fri Feb 28 2014 werner@suse.de
- Add patch
  0001-nspawn-fix-detection-of-missing-proc-self-loginuid.patch
  to avoid error on not existing file /proc/self/loginuid
* Fri Feb 28 2014 werner@suse.de
- Make patch
  0001-make-209-working-on-older-dist.patch
  more smart that is make configure script les restrictive
- Make patch
  apply-ACL-for-nvidia-device-nodes.patch
  apply to v209
* Fri Feb 28 2014 werner@suse.de
- Update to Release v209 on the base of the work of Stefan Brüns
  from declined submit request 223602:
  + A new tool "systemd-socket-proxyd" has been added
  + Add a new tool to save/restore rfkill state on
    shutdown/boot.
  + Save/restore state of keyboard backlights in addition to
    display backlights on shutdown/boot.
  + udev learned a new SECLABEL{} construct to label device
    nodes with a specific security label when they appear. For
    now, only SECLABEL{selinux} is supported, but the syntax is
    prepared for additional security frameworks.
  + When the User= switch is used in a unit file, also
    initialize $SHELL= based on the user database entry.
  + systemd no longer depends on libdbus. All communication is
    now done with sd-bus, systemd's low-level bus library
    implementation.
  + sd-bus: add a light-weight vtable implementation that allows
    defining objects on the bus with a simple static const
    vtable array of its methods, signals and properties.
  + systemd will not generate or install static dbus
    introspection data anymore to /usr/share/dbus-1/interfaces,
    as the precise format of these files is unclear, and
    nothing makes use of it.
  + A proxy daemon is now provided to proxy clients connecting
    via classic D-Bus AF_UNIX sockets to kdbus, to provide full
    compatibility with classic D-Bus.
  + A bus driver implementation has been added that supports the
    classic D-Bus bus driver calls on kdbus, also for
    compatibility purposes.
  + A new API "sd-event.h" has been added that implements a
    minimal event loop API built around epoll.
  + A new API "sd-rntl.h" has been added that provides an API
    around the route netlink interface of the kernel, similar in
    style to "sd-bus.h".
  + A new API "sd-dhcp-client.h" has been added that provides a
    small DHCPv4 client-side implementation. This is used by
    "systemd-networkd".
  + There is a new kernel command line option
    "systemd.restore_state=0|1". When set to "0", none of the
    systemd tools will restore saved runtime state to hardware
    devices. More specifically, the rfkill and backlight states
    are not restored.
  + The FsckPassNo= compatibility option in mount/service units
    has been removed. The fstab generator will now add the
    necessary dependencies automatically, and does not require
    PID1's support for that anymore.
  + journalctl gained a new switch, --list-boots, that lists
    recent boots with their times and boot IDs.
  + The various tools like systemctl, loginctl, timedatectl,
    busctl, systemd-run, ... have gained a new switch "-M" to
    connect to a specific, local OS container (as direct
    connection, without requiring SSH).
  + systemd-run and systemd-analyze also gained support for "-H"
    to connect to remote hosts via SSH. This is particularly
    useful for systemd-run because it enables queuing of jobs
    onto remote systems.
  + machinectl gained a new command "login" to open a getty
    login in any local container. This works with any container
    that is registered with machined (such as those created by
    libvirt-lxc or nspawn), and which runs systemd inside.
  + machinectl gained a new "reboot" command that may be used to
    trigger a reboot on a specific container that is registered
    with machined. This works on any container that runs an init
    system of some kind.
  + systemctl gained a new "list-timers" command to print a nice
    listing of installed timer units with the times they elapse
    next.
  + Alternative reboot() parameters may now be specified on the
    "systemctl reboot" command line and are passed to the
    reboot() system call.
  + systemctl gained a new --job-mode= switch to configure the
    mode to queue a job with. This is a more generic version of
  - -fail, --irreversible, and --ignore-dependencies, which are
    still available but not advertised anymore.
  + /etc/systemd/system.conf gained new settings to configure
    various default timeouts of units, as well as the default
    start limit interval and burst. These may still be overridden
    within each Unit.
  + PID1 will now export on the bus profile data of the security
    policy upload process (such as the SELinux policy upload to
    the kernel).
  + journald: when forwarding logs to the console, include
    timestamps (following the setting in
    /sys/module/printk/parameters/time).
  + OnCalendar= in timer units now understands the special
    strings "yearly" and "annually". (Both are equivalent)
  + The accuracy of timer units is now configurable with the new
    AccuracySec= setting. It defaults to 1min.
  + A new dependency type JoinsNamespaceOf= has been added that
    allows running two services within the same /tmp and network
    namespace, if PrivateNetwork= or PrivateTmp= are used.
  + A new command "cat" has been added to systemctl. It outputs
    the original unit file of a unit, and concatenates the
    contents of additional "drop-in" unit file snippets, so that
    the full configuration is shown.
  + systemctl now supports globbing on the various "list-xyz"
    commands, like "list-units" or "list-sockets", as well as on
    those commands which take multiple unit names.
  + journalctl's --unit= switch gained support for globbing.
  + All systemd daemons now make use of the watchdog logic so
    that systemd automatically notices when they hang.
  + If the $container_ttys environment variable is set,
    getty-generator will automatically spawn a getty for each
    listed tty. This is useful for container managers to request
    login gettys to be spawned on as many ttys as needed.
  + %%h, %%s, %%U specifier support is not available anymore when
    used in unit files for PID 1. This is because NSS calls are
    not safe from PID 1. They stay available for --user
    instances of systemd, and as special case for the root user.
  + loginctl gained a new "--no-legend" switch to turn off output
    of the legend text.
  + The "sd-login.h" API gained three new calls:
    sd_session_is_remote(), sd_session_get_remote_user(),
    sd_session_get_remote_host() to query information about
    remote sessions.
  + The udev hardware database now also carries vendor/product
    information of SDIO devices.
  + The "sd-daemon.h" API gained a new sd_watchdog_enabled() to
    determine whether watchdog notifications are requested by
    the system manager.
  + Socket-activated per-connection services now include a
    short description of the connection parameters in the
    description.
  + tmpfiles gained a new "--boot" option. When this is not used,
    only lines where the command character is not suffixed with
    "!" are executed. When this option is specified, those
    options are executed too.
  + systemctl gained a new "import-environment" command which
    uploads the caller's environment (or parts thereof) into the
    service manager so that it is inherited by services started
    by the manager. This is useful to upload variables like
    $DISPLAY into the user service manager.
  + A new PrivateDevices= switch has been added to service units
    which allows running a service with a namespaced /dev
    directory that does not contain any device nodes for
    physical devices. More specifically, it only includes devices
    such as /dev/null, /dev/urandom, and /dev/zero which are API
    entry points.
  + logind has been extended to support behaviour like VT
    switching on seats that do not support a VT. This makes
    multi-session available on seats that are not the first seat
    (seat0), and on systems where kernel support for VTs has
    been disabled at compile-time.
  + If a process holds a delay lock for system sleep or shutdown
    and fails to release it in time, we will now log its
    identity. This makes it easier to identify processes that
    cause slow suspends or power-offs.
  + When parsing /etc/crypttab, support for a new key-slot=
    option as supported by Debian is added. It allows indicating
    which LUKS slot to use on disk, speeding up key loading.
  + The sd_journald_sendv() API call has been checked and
    officially declared to be async-signal-safe so that it may
    be invoked from signal handlers for logging purposes.
  + Boot-time status output is now enabled automatically after a
    short timeout if boot does not progress, in order to give
    the user an indication what she or he is waiting for.
  + The boot-time output has been improved to show how much time
    remains until jobs expire.
  + The KillMode= switch in service units gained a new possible
    value "mixed". If set, and the unit is shut down, then the
    initial SIGTERM signal is sent only to the main daemon
    process, while the following SIGKILL signal is sent to
    all remaining processes of the service.
  + logind will now also track a "Desktop" identifier for each
    session which encodes the desktop environment of it. This is
    useful for desktop environments that want to identify
    multiple running sessions of itself easily.
  + A new SELinuxContext= setting for service units has been
    added that allows setting a specific SELinux execution
    context for a service.
  + Most systemd client tools will now honour $SYSTEMD_LESS for
    settings of the "less" pager.
  + systemd's "seccomp" hook-up has been changed to make use of
    the libseccomp library instead of using its own
    implementation. This has benefits for portability among
    other things.
- Dropped systemd patches as those are fixed upstream:
  * 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch
  * 0002-fix-lingering-references-to-var-lib-backlight-random.patch
  * 0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch
  * 0004-systemctl-fix-name-mangling-for-sysv-units.patch
  * 0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch
  * 0006-journald-add-missing-error-check.patch
  * 0007-bus-fix-potentially-uninitialized-memory-access.patch
  * 0008-dbus-fix-return-value-of-dispatch_rqueue.patch
  * 0009-modules-load-fix-error-handling.patch
  * 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch
  * 0011-strv-don-t-access-potentially-NULL-string-arrays.patch
  * 0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch
  * 0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch
  * 0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch
  * 0001-gpt-auto-generator-exit-immediately-if-in-container.patch
  * 0001-manager-when-verifying-whether-clients-may-change-en.patch
  * 0001-logind-fix-bus-introspection-data-for-TakeControl.patch
  * 0001-mount-check-for-NULL-before-reading-pm-what.patch
  * 0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch
  * 0001-systemd-serialize-deserialize-forbid_restart-value.patch
  * 0001-core-unify-the-way-we-denote-serialization-attribute.patch
  * 0001-journald-fix-minor-memory-leak.patch
  * 0001-do-not-accept-garbage-from-acpi-firmware-performance.patch
  * 0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch
  * 0001-login-fix-invalid-free-in-sd_session_get_vt.patch
  * 0001-login-make-sd_session_get_vt-actually-work.patch
  * 0001-Never-call-qsort-on-potentially-NULL-arrays.patch
  * 0001-dbus-common-avoid-leak-in-error-path.patch
  * 0001-drop-ins-check-return-value.patch
  * 0001-shared-util-Fix-glob_extend-argument.patch
  * 0001-Fix-bad-assert-in-show_pid_array.patch
  * 0001-analyze-set-white-background.patch
  * 0001-analyze-set-text-on-side-with-most-space.patch
  * analyze-fix-crash-in-command-line-parsing.patch
  * 0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
  * U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * build-sys-make-multi-seat-x-optional.patch
  * 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Dropped backported systemd patches as those are fixed upstream
  * 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  * 1011-check-4-valid-kmsg-device.patch
  * 0001-logind-garbage-collect-stale-users.patch
- Dropped udev patches as those are fixed fixed upstream:
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
- Modified patches
  * 1006-udev-always-rename-network.patch
- Replaced patches
  * the patch
    1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    is upstream now but has to be replaced by patch
    0001-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
    to fix an further issue similar to the upstream patch (bnc#852015)
  * the patch
    0001-upstream-systemctl-halt-reboot-error-handling.patch
    is upstream now, only the part with the halt after a failed poweroff
    has been added to the patch
    0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
* Thu Feb 27 2014 werner@suse.de
- Add patch 0001-make-209-working-on-older-dist.patch to make
  it usable on older distributions like 13.1
* Wed Feb 26 2014 werner@suse.de
- Add patch 0001-add-network-device-after-NFS-mount-units.patch to
  add "After" dependency to all NFS shares to the network interface
  device as this ensures at shutdown that the NFS share becomes
  unmounted before the interface is down (bnc#861489)
  +-------------------------------------------------------------------
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- enable compat-libs, BuildRequires binutils-gold
  ("old" ld fails on ifunc magic)
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- add network link configuration for udev
* Sun Feb 23 2014 stefan.bruens@rwth-aachen.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch,
  move to core and link in directly to avoid libudev dep all over
- Disable networkd
- Disable compat-libs, adapt files section
- add and remove some entries in the files section
* Fri Feb 21 2014 werner@suse.de
- Modify patch 1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to avoid WantedBy for Should-Start/Start-Before/Start-After SysVinit
  scripts (bnc#863217)
* Thu Feb 20 2014 werner@suse.de
- Modify patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to do a final sync() and flush the disks
* Fri Feb 14 2014 werner@suse.de
- Add several upstream bugfix patches which are missed:
  * 0018-core-do-not-add-what-to-RequiresMountsFor-for-networ.patch
  * 0026-udevadm.xml-document-resolve-names-option-for-test.patch
  * 0030-Fix-for-SIGSEGV-in-systemd-bootchart-on-short-living.patch
  * 0032-rules-don-t-limit-some-of-the-rules-to-the-add-actio.patch
  * 0031-man-document-the-b-special-boot-option.patch
  * 0033-tmpfiles-log-unaccessible-FUSE-mount-points-only-as-.patch
  * 0034-systemd-python-fix-booted-and-add-two-functions-to-d.patch
  * 0035-activate-mention-E-in-the-help-text.patch
  * 0036-activate-fix-crash-when-s-is-passed.patch
  * 0037-tmpfiles-adjust-excludes-for-the-new-per-service-pri.patch
  * 0038-core-socket-fix-SO_REUSEPORT.patch
  * 0039-journal-when-appending-to-journal-file-allocate-larg.patch
  * 0040-journal-optimize-bisection-logic-a-bit-by-caching-th.patch
  * 0041-journal-fix-iteration-when-we-go-backwards-from-the-.patch
  * 0042-journal-allow-journal_file_copy_entry-to-work-on-non.patch
  * 0043-journal-simplify-pre-allocation-logic.patch
  * 0044-journald-mention-how-long-we-needed-to-flush-to-var-.patch
  * 0046-util.c-check-if-return-value-from-ttyname_r-is-0-ins.patch
  * 0047-docs-remove-unneeded-the-s-in-gudev-docs.patch
  * 0048-man-explicitly-say-when-multiple-units-can-be-specif.patch
  * 0049-systemd-treat-reload-failure-as-failure.patch
- Add patch 0001-Don-t-snprintf-a-potentially-NULL-pointer.patch
  to avoid potential NULL pointer
- Reorder patches to reflect udev/systemd usage
* Tue Feb 11 2014 coolo@suse.com
- don't build bash-completions for bootstrap package
* Tue Feb 11 2014 coolo@suse.com
- add more requires to this-is-only-for-build-envs to avoid
  problems in kiwi configs
* Mon Feb 10 2014 werner@suse.de
- Add patch 0145-logind-use-correct-who-enum-values-with-KillUnit.patch
  to be able to kill sessions (bnc#860574)
* Mon Feb 10 2014 werner@suse.de
- Do not return from main shell script but simply exit (bnc#862789)
* Sun Feb  9 2014 werner@suse.de
- ... as only the systemd-analyze completion depends on
  bash-completion I prefere a without which has to be defined
  for SLES 12
* Sun Feb  9 2014 coolo@suse.com
- avoid bootstrap cycle with libusb and systemd-mini
* Sat Feb  8 2014 coolo@suse.com
- split bash-completion support into its own package,
  no need for sles_version
* Fri Feb  7 2014 werner@suse.de
- Split off systemd-rpm-macros as a separate package to avoid
  a rebuild of all packages due new systemd package
- Define a sles_version 12 for suse_version 1315
* Wed Feb  5 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to disable the workaround to find /dev/3270/tty1 as this now
  should be done by a) the kernel patch
  http://lkml.indiana.edu/hypermail/linux/kernel/1402.0/02319.html
  and the changed udev rule 99-systemd.rules
* Sun Feb  2 2014 ohering@suse.com
- Remove PreReq pidof from udev, nothing in this pkg uses it
* Fri Jan 31 2014 werner@suse.de
- Change and extend patch
  0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to re-enable colouring if 3270 console was enforced on the kernel
  command line as 3270 cna handle colour ANSI escape sequences.
  Also let the serial getty generator find the /dev/3270/tty1
  character device (bnc#861316)
* Thu Jan 30 2014 werner@suse.de
- Add patch 0001-On_s390_con3270_disable_ANSI_colour_esc.patch
  to strip the colouring ANSI escape sequences from the console
  messages (bnc#860937)
* Thu Jan 30 2014 werner@suse.de
- Change patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  to skip already by the kernel managed devices
* Wed Jan 29 2014 arvidjaar@gmail.com
- fix timeout stopping user@.service (bnc#841544)
  * 0001-core-introduce-new-KillMode-mixed-which-sends-SIGTER.patch
  * 0002-service-allow-KillMode-mixed-in-conjunction-with-PAM.patch
  * 0003-core-make-sure-to-always-go-through-both-SIGTERM-and.patch
* Tue Jan 28 2014 werner@suse.de
- Add patch 0001-upstream-systemctl-halt-reboot-error-handling.patch
  to be able to detect if the sysctl reboot() returns.
- Add patch 0001-add-hdflush-for-reboot-or-hddown-for-poweroff.patch
  A check for unmaintained disk like devices is added to be able to
  flush and maybe shut them down.  Also the missing sync() system
  call is added for the direct halt/reboot systemctl command. Then
  the system halt is used as fallback if poweroff fails for both
  the direct poweroff systemctl command as well as for the
  systemd-shutdown utility.
* Thu Jan 23 2014 werner@suse.de
- Make systemd-mini build
* Thu Jan 23 2014 werner@suse.de
- Make requires bash-completion a recommends
* Tue Jan 21 2014 werner@suse.de
- Add patch 1017-skip-native-unit-handling-if-sysv-already-handled.patch
  to avoid that enabled boot scripts will be handled as unit files
  by systemctl status command (bnc#818044)
* Tue Jan 21 2014 werner@suse.de
- Drop patch 1017-enforce-sufficient-shutdown-warnings.patch
  as the original code behaves exactly as the shutdown code of
  the old SysVinit (bnc#750845)
- Rename support-powerfail-with-powerstatus.patch to
  1016-support-powerfail-with-powerstatus.patch
* Mon Jan 20 2014 fcrozat@suse.com
- Add analyze-fix-crash-in-command-line-parsing.patch: fix crash in
  systemd-analyze (bnc#859365)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1019-make-completion-smart-to-be-able-to-redirect.patch
  to make redirections work with the bash command completions for
  for systemd command tools (bnc#856858, bnc#859072)
* Fri Jan 17 2014 werner@suse.de
- Add patch
  1018-Make-LSB-Skripts-know-about-Required-and-Should.patch
  to support the "+" to tag wanted dependencies as well as make
  sure that required dependencies are handles as required ones.
  This should fix bnc#858864 and bnc#857204.
* Thu Jan 16 2014 lnussel@suse.de
- apply preset also to service files that are new in upgrade
* Wed Jan 15 2014 werner@suse.de
- Change support-powerfail-with-powerstatus.patch to use BindsTo
  instead of BindTo
* Wed Jan 15 2014 werner@suse.de
- Add patch 1017-enforce-sufficient-shutdown-warnings.patch
  Warn once per hour in the last 3 hours, then all 30 minutes in last
  hour, all 15 minutes in the last 45 minutes, all 10 minutes in the
  last 15 minutes, and then all minute in the last 10 minutes (bnc#750845)
* Tue Jan 14 2014 werner@suse.de
- Add patch support-powerfail-with-powerstatus.patch and source
  file systemd-powerfail to implement SIGPWR support with evaluation
  of the file /var/run/powerstatus (bnc#737690)
* Fri Dec 20 2013 werner@suse.de
- Adapt patch
  1011-check-4-valid-kmsg-device.patch
  to fit current upstream version maybe related to bnc#854884
- Change patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to check if XDG_RUNTIME_DIR is set before the call of pam_putenv()
  may fix bnc#855160
* Fri Dec 20 2013 lbsousajr@gmail.com
- Disable multi-seat-x build, since package xorg-x11-server
  currently in Factory no longer needs it.
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Added 0001-logind-garbage-collect-stale-users.patch: Don't stop a
  running user manager from garbage-collecting the user. Original
  behavior caused bnc#849870
* Mon Dec 16 2013 lbsousajr@gmail.com
- Add build-sys-make-multi-seat-x-optional.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=bd441fa27a22b7c6e11d9330560e0622fb69f297
  * Now systemd-multi-seat-x build can be disabled with configure option
  - -disable-multi-seat-x. It should be done when xorg-x11-server
    no longer needs it (work in progress).
* Mon Dec 16 2013 fcrozat@suse.com
- Update insserv-generator.patch: fix crash in insserv generator
  (bnc#854314).
- Update apply-ACL-for-nvidia-device-nodes.patch with latest fixes
  for Nvidia cards (bnc#808319).
* Fri Dec  6 2013 werner@suse.de
- Add patch
  1014-journald-with-journaling-FS.patch
  which now uses the file system ioctls for switching off atime,
  compression, and copy-on-write of the journal directory of the
  the systemd-journald (bnc#838475)
- Let us build require the package config for libpcre (bnc#853293)
* Sat Nov 30 2013 arvidjaar@gmail.com
- Add patch
  0001-core-replace-OnFailureIsolate-setting-by-a-more-gene.patch
  Make sure emergency shell is not killed by attempt to start another unit
  (bnc#852021). Backported from d420282b28f50720e233ccb1c02547c562195653.
- Add patch
  make-emergency.service-conflict-with-syslog.socket.patch
  Previous patch did not fix problem if syslog connection request came
  after emergency shell was already started. So forcibly stop syslog.socket
  when starting emergency.service. (bnc#852232)
* Thu Nov 28 2013 lbsousajr@gmail.com
- Add U_logind_revert_lazy_session_activation_on_non_vt_seats.patch
  * See: http://cgit.freedesktop.org/systemd/systemd/commit/?id=3fdb2494c1e24c0a020f5b54022d2c751fd26f50
* Tue Nov 26 2013 werner@suse.de
- Add patch
  1012-pam_systemd_do_override_XDG_RUNTIME_DIR_of_the_original_user.patch
  to avoid (xdg-)su to set XDG_RUNTIME_DIR to the original user and
  avoid that e.g. pulseaudio will create /run/user/<pid>/pulse owned
  by root (bnc#852015)
* Thu Nov 21 2013 werner@suse.de
- Add patch
  1011-check-4-valid-kmsg-device.patch
  to avoid a busy systemd-journald (bnc#851393)
* Wed Nov  6 2013 werner@suse.de
- Add patch
  1010-do-not-install-sulogin-unit-with-poweroff.patch
  that is do not install console-shell.service in any system target
  as this will cause automatic poweroff at boot (bnc#849071)
* Mon Nov  4 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-text-on-side-with-most-space.patch
  to place the text on the side with most space
* Fri Oct 25 2013 werner@suse.de
- Add upstream patch
  0001-analyze-set-white-background.patch
  to make SVG output of systemd analyze readable
* Mon Oct 21 2013 werner@suse.de
- Add patch
  1009-make-xsltproc-use-correct-ROFF-links.patch
  to have valid ROFF links in manual pages working again (bnc#842844)
* Tue Oct 15 2013 fcrozat@suse.com
- Add
  0001-gpt-auto-generator-exit-immediately-if-in-container.patch:
  don't start gpt auto-generator in container (git).
- Add
  0001-manager-when-verifying-whether-clients-may-change-en.patch:
  fix reload check in selinux case (git).
- Add 0001-logind-fix-bus-introspection-data-for-TakeControl.patch:
  fix introspection for TakeControl (git).
- Add 0001-mount-check-for-NULL-before-reading-pm-what.patch: fix
  crash when parsing some incorrect unit (git).
- Add
  0001-shared-util-fix-off-by-one-error-in-tag_to_udev_node.patch:
  Fix udev rules parsing (git).
- Add
  0001-systemd-serialize-deserialize-forbid_restart-value.patch:
  Fix incorrect deserialization for forbid_restart (git).
- Add
  0001-core-unify-the-way-we-denote-serialization-attribute.patch:
  Ensure forbid_restart is named like other attributes (git).
- Add 0001-journald-fix-minor-memory-leak.patch: fix memleak in
  journald (git).
- Add
  0001-do-not-accept-garbage-from-acpi-firmware-performance.patch:
  Improve ACPI firmware performance parsing (git).
- Add
  0001-journald-remove-rotated-file-from-hashmap-when-rotat.patch:
  Fix journal rotation (git).
- Add
  0001-login-fix-invalid-free-in-sd_session_get_vt.patch:
  Fix memory corruption in sd_session_get_vt (git).
- Add 0001-login-make-sd_session_get_vt-actually-work.patch: Ensure
  sd_session_get_vt returns correct value (git).
- Add 0001-Never-call-qsort-on-potentially-NULL-arrays.patch: Don't
  call qsort on NULL arrays (git).
- Add 0001-dbus-common-avoid-leak-in-error-path.patch: Fix memleak
  in dbus-common code (git).
- Add 0001-drop-ins-check-return-value.patch: Fix return value for
  drop-ins checks (git).
- Add 0001-shared-util-Fix-glob_extend-argument.patch: Fix
  glob_extend argument (git).
- Add 0001-Fix-bad-assert-in-show_pid_array.patch: Fix bad assert
  in show_pid_array (git).
* Thu Oct  3 2013 fcrozat@suse.com
- Add 0001-acpi-fptd-fix-memory-leak-in-acpi_get_boot_usec.patch:
  fix acpi memleak.
- Add
  0002-fix-lingering-references-to-var-lib-backlight-random.patch:
  fix invalid path in documentation.
- Add
  0003-acpi-make-sure-we-never-free-an-uninitialized-pointe.patch:
  fix invalid memory free.
- Add 0004-systemctl-fix-name-mangling-for-sysv-units.patch: fix
  name mangling for sysv units.
- Add
  0005-cryptsetup-fix-OOM-handling-when-parsing-mount-optio.patch:
  fix OOM handling.
- Add 0006-journald-add-missing-error-check.patch: add missing
  error check.
- Add 0007-bus-fix-potentially-uninitialized-memory-access.patch:
  fix uninitialized memory access.
- Add 0008-dbus-fix-return-value-of-dispatch_rqueue.patch: fix
  return value.
- Add 0009-modules-load-fix-error-handling.patch: fix error
  handling.
- Add 0010-efi-never-call-qsort-on-potentially-NULL-arrays.patch:
  fix incorrect memory access.
- Add 0011-strv-don-t-access-potentially-NULL-string-arrays.patch:
  fix incorrect memory access.
- Add
  0012-mkdir-pass-a-proper-function-pointer-to-mkdir_safe_i.patch:
  fix invalid pointer.
- Add
  0014-tmpfiles.d-include-setgid-perms-for-run-log-journal.patch:
  fix permission on /run/log/journal.
- Add
  0001-systemd-order-remote-mounts-from-mountinfo-before-re.patch:
  order remote mount points properly before remote-fs.target.
* Wed Oct  2 2013 hrvoje.senjan@gmail.com
- Explicitly require pam-config for %%post of the main package
* Wed Oct  2 2013 fcrozat@suse.com
- Release v208:
  + logind gained support for facilitating privileged input and drm
    devices access for unprivileged clients (helps Wayland /
    kmscon).
  + New kernel command line luks.options= allows to specify LUKS
    options, when used with luks.uuid=
  + tmpfileS.d snippets can uses specifier expansion in path names
    (%%m, %%b, %%H, %%v).
  + New tmpfiles.d command "m" introduced to change
    owner/group/access mode of a file/directory only if it exists.
  + MemorySoftLimit= cgroup settings is no longer supported
    (underlying kernel cgroup attribute will disappear in the
    future).
  + memeory.use_hierarchy cgroup attribute is enabled for all
    cgroups systemd creates in memory cgroup hierarchy.
  + New filed _SYSTEMD_SLICE= is logged in journal messages related
    to a slice.
  + systemd-journald will no longer adjust the group of journal
    files it creates to "systemd-journal" group. Permissions and
    owernship is adjusted when package is upgraded.
  + Backlight and random seed files are now stored in
    /var/lib/systemd.
  + Boot time performance measurements included ACPI 5.0 FPDT
    informations if available.
- Drop merged patches:
  0001-cgroup-add-the-missing-setting-of-variable-s-value.patch,
  0002-cgroup-correct-the-log-information.patch,
  0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch,
  0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch,
  0005-core-cgroup-first-print-then-free.patch,
  0006-swap-fix-reverse-dependencies.patch,
  0008-swap-create-.wants-symlink-to-auto-swap-devices.patch,
  0009-polkit-Avoid-race-condition-in-scraping-proc.patch,
  Fix-timeout-when-stopping-Type-notify-service.patch,
  set-ignoreonisolate-noauto-cryptsetup.patch,
  0001-Fix-buffer-overrun-when-enumerating-files.patch,
  0007-libudev-fix-move_later-comparison.patch.
- Refresh patches
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  delay-fsck-cryptsetup-after-md-dmraid-lvm-are-started.patch,
  handle-root_uses_lang-value-in-etc-sysconfig-language.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch.
- Own more ghost files.
- Do not run pam-config in systemd-mini %%post.
- Add after-local.service to run after.local late during the boot
  process (bnc#778715).
* Tue Oct  1 2013 fcrozat@suse.com
- Update Fix-timeout-when-stopping-Type-notify-service.patch with
  upstream fix.
- No longer start ask-password-wall, was causing too much spam on
  terminals (bnc#747783).
* Mon Sep 30 2013 fcrozat@suse.com
- Add set-ignoreonisolate-noauto-cryptsetup.patch: ensure noauto
  encrypted mounts survives runlevel changes (bnc#843085).
- Add 0001-Fix-buffer-overrun-when-enumerating-files.patch: fix
  logind crash when /run/systemd/sessions was too big (bnc#840055,
  initial fix from hpj@suse.com).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  only check for /boot/sysctl.conf-<uname -r> presence.
- Add service wrapper for after.local (bnc#778715).
* Fri Sep 27 2013 fcrozat@suse.com
- Update use-usr-sbin-sulogin-for-emergency-service.patch to apply
  to all services using sulogin and remove generated files from
  upstream tarball (bnc#841398).
* Mon Sep 23 2013 arvidjaar@gmail.com
- Fix-timeout-when-stopping-Type-notify-service.patch
  Make sure MAINPID is watched when it becomes known (bnc#841544)
* Mon Sep 23 2013 fcrozat@suse.com
- Remove output and error redirection to /dev/null in install
  script, it might help tracing pam related issue (bnc#841573).
* Thu Sep 19 2013 fcrozat@suse.com
- Move symlink migration trigger to post (bnc#821800).
* Wed Sep 18 2013 crrodriguez@opensuse.org
- 0009-polkit-Avoid-race-condition-in-scraping-proc.patch
  VUL-0: polkit: process subject race condition [bnc#835827]
  CVE-2013-4288
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-ima as the openSUSE kernel
  does not support IMA (CONFIG_IMA is not set)
* Wed Sep 18 2013 crrodriguez@opensuse.org
- Build with --disable-smack as the openSUSE kernel
  does not support smack (CONFIG_SECURITY_SMACK is not set)
* Wed Sep 18 2013 fcrozat@suse.com
- Don't use a trigger to create symlink for sysctl.conf, always run
  the test on %%post (bnc#840864).
- Update sysctl-handle-boot-sysctl.conf-kernel_release.patch to
  ensure /boot is mounted before reading /boot/sysctl.conf-*
  (bnc#809420).
* Mon Sep 16 2013 crrodriguez@opensuse.org
- 0008-swap-create-.wants-symlink-to-auto-swap-devices.patch
  really fixes the swap unit problem mentioned in previous
  commit & the opensuse-factory mailing list.
* Sat Sep 14 2013 crrodriguez@opensuse.org
- 0001-cgroup-add-the-missing-setting-of-variable-s-value.patch
  missing important check on return value.
- 0002-cgroup-correct-the-log-information.patch fix misleading
  log information.
- 0003-cgroup-fix-incorrectly-setting-memory-cgroup.patch fix
  setting memory cgroup
- 0004-random-seed-we-should-return-errno-of-failed-loop_wr.patch
  should fail if write fails.
- 0005-core-cgroup-first-print-then-free.patch use-after-free
  will trigger if there is an error condition.
- 0006-swap-fix-reverse-dependencies.patch reported in
  opensuse-factory list, topic "swap isn't activated"
- 0007-libudev-fix-move_later-comparison.patch libudev
  invalid usage of "move_later".
* Sat Sep 14 2013 crrodriguez@opensuse.org
- while testing this new release I get in the logs ocassionally
  at boot "systemd[1]: Failed to open private bus connection:
  Failed to connect to socket /var/run/dbus/system_bus_socket:
  No such file or directory" indeed DBUS_SYSTEM_BUS_DEFAULT_ADDRESS
  is defined to /var/run/dbus/system_bus_socket instead of
  /run/dbus/system_bus_socket and that does not fly when /var/run
  is not yet available. (systemd-dbus-system-bus-address.patch)
* Fri Sep 13 2013 fcrozat@suse.com
- Enable Predictable Network interface names (bnc#829526).
* Fri Sep 13 2013 crrodriguez@opensuse.org
- version 207, distribution specific changes follow, for overall
  release notes see NEWS.
- Fixed:
  * Failed at step PAM spawning /usr/lib/systemd/systemd:
  Operation not permitted
  * Fix shutdown hang "a stop job is running for Session 1 of user root"
    that was reported in opensuse-factory list.
- systemd-sysctl no longer reads /etc/sysctl.conf however backward
  compatbility is to be provides by a symlink created at %%post.
- removed previously disabled upstream patches (merged):
  0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch,
  0004-disable-the-cgroups-release-agent-when-shutting-down.patch,
  0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch,
  0006-suppress-status-message-output-at-shutdown-when-quie.patch,
- removed upstream merged patches:
  exclude-dev-from-tmpfiles.patch,
  logind_update_state_file_after_generating_....patch
- Add systemd-pam_config.patch: use correct include name for PAM
  configuration on openSUSE.
* Mon Sep  9 2013 fcrozat@suse.com
- Add exclude-dev-from-tmpfiles.patch: allow to exclude /dev from
  tmpfiles (bnc#835813).
* Fri Sep  6 2013 fcrozat@suse.com
- Remove
  force-lvm-restart-after-cryptsetup-target-is-reached.patch and
  remove additional dependencies on LVM in other patches: LVM has
  now systemd support, no need to work around it anymore in
  systemd.
* Wed Aug 21 2013 idonmez@suse.com
- Add patch logind_update_state_file_after_generating_the_session_fifo_not_before.patch
  to fix https://bugs.freedesktop.org/show_bug.cgi?id=67273
* Tue Aug  6 2013 lnussel@suse.de
- explicitly enable getty@tty1.service instead of getty@.service as
  the tty1 alias has been removed from the file (bnc#833494)
* Thu Aug  1 2013 fcrozat@suse.com
- Ensure /usr/lib/systemd/system/shutdown.target.wants is created
  and owned by systemd package.
* Mon Jul 29 2013 fcrozat@suse.com
- Fix drop-in for getty@tty1.service
* Thu Jul 25 2013 fcrozat@suse.com
- Move systemd-journal-gateway to subpackage to lower dependencies
  in default install.
* Tue Jul 23 2013 crrodriguez@opensuse.org
- version 206 , highlights:
  * Unit files now understand the new %%v specifier which
  resolves to the kernel version string as returned by "uname-r".
  * "journalctl -b" may now be used to look for boot output of a
  specific boot. Try "journalctl -b -1"
  * Creation of "dead" device nodes has been moved from udev
  into kmod and tmpfiles.
  * The udev "keymap" data files and tools to apply keyboard
  specific mappings of scan to key codes, and force-release
  scan code lists have been entirely replaced by a udev
  "keyboard" builtin and a hwdb data file.
- remove patches now in upstream
- systemd now requires libkmod >=14 and cryptsetup >= 1.6.0
- systemd now require the kmod tool in addition to the library.
* Sun Jul 14 2013 arvidjaar@gmail.com
- use-usr-sbin-sulogin-for-emergency-service.patch
  emergency.service failed to start because sulogin is in /usr/sbin now
* Fri Jul 12 2013 mls@suse.de
- fix build with rpm-4.11.1: /etc/xdg/system/user is a symlink,
  not a directory
* Fri Jul  5 2013 crrodriguez@opensuse.org
- 0002-core-mount.c-mount_dump-don-t-segfault-if-mount-is-n.patch
  fix segfault at shutdown
- 0004-disable-the-cgroups-release-agent-when-shutting-down.patch
  disable the cgroups release agent when shutting down.
- 0005-cgroups-agent-remove-ancient-fallback-code-turn-conn.patch
  remove ancient fallback code; turn connection error into warning
- 006-suppress-status-message-output-at-shutdown-when-quie.patch
  make shutdown honour "quiet" kernel cmdline.
* Fri Jul  5 2013 crrodriguez@opensuse.org
- fix broken symlink, service is called systemd-random-seed now.
* Thu Jul  4 2013 fcrozat@suse.com
- Update to release 205:
  + two new unit types have been introduced:
  - Scope units are very similar to service units, however, are
    created out of pre-existing processes -- instead of PID 1
    forking off the processes.
  - Slice units may be used to partition system resources in an
    hierarchial fashion and then assign other units to them. By
    default there are now three slices: system.slice (for all
    system services), user.slice (for all user sessions),
    machine.slice (for VMs and containers).
  + new concept of "transient" units, which are created at runtime
    using an API and not based on configuration from disk.
  + logind has been updated to make use of scope and slice units to
    manage user sessions. Logind will no longer create cgroups
    hierchies itself but will relying on PID 1.
  + A new mini-daemon "systemd-machined" has been added which
    may be used by virtualization managers to register local
    VMs/containers. machinectl tool has been added to query
    meta-data from systemd-machined.
  + Low-level cgroup configuration options ControlGroup=,
    ControlGroupModify=, ControlGroupPersistent=,
    ControlGroupAttribute= have been removed. High-level attribute
    settings or slice units should be used instead?
  + A new bus call SetUnitProperties() has been added to alter
    various runtime parameters of a unit, including cgroup
    parameters. systemctl gained set-properties command to wrap
    this call.
  + A new tool "systemd-run" has been added which can be used to
    run arbitrary command lines as transient services or scopes,
    while configuring a number of settings via the command
    line.
  + nspawn will now inform the user explicitly that kernels with
    audit enabled break containers, and suggest the user to turn
    off audit.
  + Support for detecting the IMA and AppArmor security
    frameworks with ConditionSecurity= has been added.
  + journalctl gained a new "-k" switch for showing only kernel
    messages, mimicking dmesg output; in addition to "--user"
    and "--system" switches for showing only user's own logs
    and system logs.
  + systemd-delta can now show information about drop-in
    snippets extending unit files.
  + systemd will now look for the "debug" argument on the kernel
    command line and enable debug logging, similar to
    "systemd.log_level=debug" already did before.
  + "systemctl set-default", "systemctl get-default" has been
    added to configure the default.target symlink, which
    controls what to boot into by default.
  + "systemctl set-log-level" has been added as a convenient
    way to raise and lower systemd logging threshold.
  + "systemd-analyze plot" will now show the time the various
    generators needed for execution, as well as information
    about the unit file loading.
  + libsystemd-journal gained a new sd_journal_open_files() call
    for opening specific journal files. journactl also gained a
    new switch to expose this new functionality (useful for
    debugging).
  + systemd gained the new DefaultEnvironment= setting in
    /etc/systemd/system.conf to set environment variables for
    all services.
  + If a privileged process logs a journal message with the
    OBJECT_PID= field set, then journald will automatically
    augment this with additional OBJECT_UID=, OBJECT_GID=,
    OBJECT_COMM=, OBJECT_EXE=, ... fields. This is useful if
    system services want to log events about specific client
    processes. journactl/systemctl has been updated to make use
    of this information if all log messages regarding a specific
    unit is requested.
- Remove 0001-journal-letting-interleaved-seqnums-go.patch,
  0002-journal-remember-last-direction-of-search-and-keep-o.patch,
  0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch,
  0006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch,
  0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch,
  0160-mount-when-learning-about-the-root-mount-from-mounti.patch,
  0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch,
  Start-ctrl-alt-del.target-irreversibly.patch,
  systemctl-does-not-expand-u-so-revert-back-to-I.patch: merged
  upstream.
- Regenerate patches 1007-physical-hotplug-cpu-and-memory.patch,
  1008-add-msft-compability-rules.patch,
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch,
  fix-support-for-boot-prefixed-initscript-bnc-746506.patch,
  handle-SYSTEMCTL_OPTIONS-environment-variable.patch,
  handle-numlock-value-in-etc-sysconfig-keyboard.patch,
  insserv-generator.patch,
  optionally-warn-if-nss-myhostname-is-called.patch,
  remain_after_exit-initscript-heuristic-and-add-new-LSB-hea.patch,
  restore-var-run-and-var-lock-bind-mount-if-they-aren-t-sym.patch,
  service-flags-sysv-service-with-detected-pid-as-RemainAfte.patch.
- Update macros.systemd.upstream with latest upstream revision.
* Mon Jul  1 2013 fcrozat@suse.com
- Replace
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch
  patch with insserv-generator.patch: no longer patch systemd main
  binary but generate systemd drop-in files using a generator, for
  insserv.conf compatibility.
* Mon Jul  1 2013 coolo@suse.com
- systemd-mini doesn't need dbus-1, only dbus-1-devel
* Wed Jun 26 2013 rmilasan@suse.com
- Re-add fixed udev MSFT compability rules (bnc#805059, bnc#826528).
  add: 1008-add-msft-compability-rules.patch
* Wed Jun 26 2013 rmilasan@suse.com
- Drop 1007-add-msft-compability-rules.patch, breaks boot and links
  in /dev/disk/by-id, will need proper rework (bnc#826528).
* Mon Jun 24 2013 crrodriguez@opensuse.org
- 0160-mount-when-learning-about-the-root-mount-from-mounti.patch Another
  case where we are trying to umount the root directory at shutdown.
- 0185-core-only-attempt-to-connect-to-a-session-bus-if-one.patch
  only attempt to connect to a session bus if one likely exists
* Fri Jun 21 2013 rmilasan@suse.com
- Automatically online CPUs/Memory on CPU/Memory hotplug add events
  (bnc#703100, fate#311831).
  add: 1008-physical-hotplug-cpu-and-memory.patch
* Wed Jun 19 2013 mhrusecky@suse.com
- Dropped backward compatibility
- Added check for upstream rpm macros changes
* Tue Jun 18 2013 mhrusecky@suse.com
- Split out RPM macros into separate package to simplify dependencies
* Tue Jun 18 2013 crrodriguez@opensuse.org
- 0001-journal-letting-interleaved-seqnums-go.patch and
  0002-journal-remember-last-direction-of-search-and-keep-o.patch
  fix possible infinite loops in the journal code, related to
  bnc #817778
* Sun Jun 16 2013 jengelh@inai.de
- Explicitly list libattr-devel as BuildRequires
- More robust make install call. Remove redundant %%clean section.
* Thu Jun 13 2013 sbrabec@suse.cz
- Cleanup NumLock setting code
  (handle-numlock-value-in-etc-sysconfig-keyboard.patch).
* Wed Jun 12 2013 fcrozat@suse.com
- Only apply 1007-add-msft-compability-rules.patch when not
  building systemd-mini.
* Tue Jun 11 2013 rmilasan@suse.com
- Add udev MSFT compability rules (bnc#805059).
  add: 1007-add-msft-compability-rules.patch
- Add sg3_utils requires, need it by 61-msft.rules (bnc#805059).
- Clean-up spec file, put udev patches after systemd patches.
- Rebase patches so they would apply nicely.
* Tue Jun 11 2013 crrodriguez@opensuse.org
- 0004-journald-DO-recalculate-the-ACL-mask-but-only-if-it-.patch
  fixes :
  * systemd-journald[347]: Failed to set ACL on
  /var/log/journal/11d90b1c0239b5b2e38ed54f513722e3/user-1000.journal,
  ignoring: Invalid argument
- 006-systemctl-core-allow-nuking-of-symlinks-to-removed-u.patch
  systemctl disable should remove dangling symlinks.
- 0008-service-don-t-report-alien-child-as-alive-when-it-s-.patch
  alien childs are reported as alive when they are really dead.
* Wed May 29 2013 fcrozat@suse.com
- Update to release 204:
  + systemd-nspawn creates etc/resolv.conf in container if needed.
  + systemd-nspawn will store metadata about container in container
    cgroup including its root directory.
  + cgroup hierarchy has been reworked, all objects are now suffxed
    (with .session for user sessions, .user for users, .nspawn for
    containers). All cgroup names are now escaped to preven
    collision of object names.
  + systemctl list-dependencies gained --plain, --reverse, --after
    and --before switches.
  + systemd-inhibit shows processes name taking inhibitor lock.
  + nss-myhostname will now resolve "localhost" implicitly.
  + .include is not allowed recursively anymore and only in unit
    files. Drop-in files should be favored in most cases.
  + systemd-analyze gained "critical-chain" command, to get slowest
    chain of units run during boot-up.
  + systemd-nspawn@.service has been added to easily run nspawn
    container for system services. Just start
    "systemd-nspawn@foobar.service" and container from
    /var/lib/container/foobar" will be booted.
  + systemd-cgls has new --machine parameter to list processes from
    one container.
  + ConditionSecurity= can now check for apparmor and SMACK.
  + /etc/systemd/sleep.conf has been introduced to configure which
    kernel operation will be execute when "suspend", "hibernate" or
    "hybrid-sleep" is requrested. It allow new kernel "freeze"
    state to be used too. (This setting won't have any effect if
    pm-utils is installed).
  + ENV{SYSTEMD_WANTS} in udev rules will now implicitly escape
    passed argument if applicable.
- Regenerate some patches for this new release.
- Rename hostname-setup-shortname.patch to
  ensure-shortname-is-set-as-hostname-bnc-820213.patch to  be git
  format-patch friendly.
- Update apply-ACL-for-nvidia-device-nodes.patch to apply ACL to
  /dev/nvidia* (bnc#808319).
- Remove Ensure-debugshell-has-a-correct-value.patch, doable with a
  configure option.
- Add systemctl-does-not-expand-u-so-revert-back-to-I.patch: avoids
  expansion errors.
- Add Start-ctrl-alt-del.target-irreversibly.patch: ctrl-alt-del
  should be irreversible for reliability.
* Tue May 28 2013 crrodriguez@opensuse.org
- Drop Add-bootsplash-handling-for-password-dialogs.patch bootsplash
  support has been removed from the kernel.
- Drop ensure-systemd-udevd-is-started-before-local-fs-pre-for-lo.patch
  fixed in systemd v199, commit 89d09e1b5c65a2d97840f682e0932c8bb499f166
- Apply rules-add-lid-switch-of-ARM-based-Chromebook-as-a-power-sw.patch
  only on ARM, patch rejected upstream because is too generic.
- no such define TARGET_SUSE exists but it is used in
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch
  use HAVE_SYSV_COMPAT instead.
* Fri May 24 2013 fcrozat@suse.com
- Do no ship defaults for sysctl, they should be part of aaa_base
  (currently in procps).
- Add hostname-setup-shortname.patch: ensure shortname is set as
  hostname (bnc#820213).
* Fri May 17 2013 fcrozat@suse.com
- Rebase
  parse-etc-insserv.conf-and-adds-dependencies-accordingly.patch to
  fix memory corruption (thanks to Michal Vyskocil) (bnc#820454).
* Fri May 17 2013 fcrozat@suse.com
- Add sysctl-handle-boot-sysctl.conf-kernel_release.patch: ensure
  /boot/sysctl.conf-<kernel_release> is handled (bnc#809420).
* Wed May 15 2013 fcrozat@suse.com
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch: don't
  free variable whose content is still be used (bnc#819970).
* Tue May 14 2013 fcrozat@suse.com
- Add configure flags to ensure boot.local/halt.local are run on
  startup/shutdown.
* Mon May 13 2013 rmilasan@suse.com
- Fix firmware loading by enabling --with-firmware-path (bnc#817551).
* Mon Apr 29 2013 dschung@cs.uni-kl.de
- Fix systemd-sysv-convert, so empty runlevel folders don't lead
  to "line 44: [: too many arguments"
* Fri Apr 26 2013 fcrozat@suse.com
- Fix handle-etc-HOSTNAME.patch to properly set hostname at startup
  when using /etc/HOSTNAME.
* Thu Apr 25 2013 rmilasan@suse.com
- Rename remaning udev patches (clean-up).
- Generate %%{_libexecdir}/modules-load.d/sg.conf so we load sg module at
  boot time not from udev (bnc#761109).
- Drop unused patches:
  1001-Reinstate-TIMEOUT-handling.patch
  1005-udev-fix-sg-autoload-regression.patch
  1026-re-add-persistent-net.patch
* Tue Apr 23 2013 fcrozat@suse.com
- Use drop-in file to fix bnc#804158.
* Tue Apr 23 2013 coolo@suse.com
- add some more conflicts to make bootstrap work
* Mon Apr 22 2013 fcrozat@suse.com
- Do not provide %%{release} for systemd-analyze
- Add more conflicts to -mini packages
- Disable Predictable Network interface names until it has been
  reviewed by network team, with /usr/lib/tmpfiles.d/network.conf.
- Don't package /usr/lib/firmware/update (not used)
* Sun Apr 21 2013 crrodriguez@opensuse.org
- Fix packaging error, there is no syslog.target anymore
  do not pretend there is one.
* Fri Apr 19 2013 fcrozat@suse.com
- Update to release 202:
  + 'systemctl list-jobs' got some polishing. '--type=' argument
    may now be passed more than once. 'systemctl list-sockets' has
    been added.
  + systemd gained a new unit 'systemd-static-nodes.service'
    that generates static device nodes earlier during boot, and
    can run in conjunction with udev.
  + systemd-nspawn now places all containers in the new /machine
    top-level cgroup directory in the name=systemd hierarchy.
  + bootchart can now store its data in the journal.
  + journactl can now take multiple --unit= and --user-unit=
    switches.
  + The cryptsetup logic now understands the "luks.key=" kernel
    line switch. If a configured key file is missing, it
    will fallback to prompting the user.
- Rebase some patches
- Update handle-SYSTEMCTL_OPTIONS-environment-variable.patch to
  properly handle SYSTEMCTL_OPTIONS
* Fri Apr 19 2013 max@suse.com
- Fix regression in the default for tmp auto-deletion
  (systemd-tmp-safe-defaults.patch, FATE#314974).
* Fri Apr 12 2013 fcrozat@suse.com
- Update to release 201:
  + udev now supports different nameng policies for network
    interface for predictable names.
  + udev gained support for loading additional device properties
    from an indexed database. %%udev_hwdb_update macro should be
    used by packages adding entries to this database.
  + Journal gained support for "Message Catalog", indexed database
    to link up additional information with journal entries.
    %%journal_catalog_update macro should be used by packages adding
    %%entries to this database.
  + "age" field for tmpfiles entries can be set to 0, forcing
    removal of files matching this entry.
  + coredumpctl gained "gdb" verb to invoke gdb on selected
    coredump.
  + New rpm macros has been added: %%udev_rules_update(),
    %%_udevhwdbdir, %%_udevrulesdir, %%_journalcatalogdir,
    %%_tmpfilesdir, %%_sysctldir.
  + In service files, %%U can be used for configured user name of
    the service.
  + nspawn can be invoked without a controlling TTY.
  + systemd and nspawn can accept socket file descriptors when
    started for socket activation. This allow socket activated
    nspawn containers.
  + logind can now automatically suspend/hibernate/shutdown system
    on idle.
  + ConditionACPower can be used in unit file to detect if AC power
    source is connected or if system is on battery power.
  + EnvironmentFile= in unit files supports file globbing.
  + Behaviour of PrivateTmp=, ReadWriteDirectories=,
    ReadOnlyDirectories= and InaccessibleDirectories= has
    changed. The private /tmp and /var/tmp directories are now
    shared by all processes of a service (which means
    ExecStartPre= may now leave data in /tmp that ExecStart= of
    the same service can still access). When a service is
    stopped its temporary directories are immediately deleted
    (normal clean-up with tmpfiles is still done in addition to
    this though).
  + Resource limits (as exposed by cgroup controlers) can be
    controlled dynamically at runtime for all units, using
    "systemctl set-cgroup-attr foobar.server cgroup.attribute
    value". Those settings are stored persistenly on disk.
  + systemd-vconsole-setup will now copy all fonts settings to all
    allocated VTs.
  + timedated now exposes CanNTP property to indicate if a local
    NTP service is available.
  + pstore file system is mounted by default, if available.
  + SMACK policies are loaded at early boot, if available.
  + Timer units now support calendar time events.
  + systemd-detect-virt detect xen PVs.
  + Some distributions specific LSB targets has been dropped:
    $x-display-manager, $mail-transfer-agent,
    $mail-transport-agent, $mail-transfer-agent, $smtp, $null. As
    well mail-transfer-agent.target and syslog.target has been
    removed.
  + systemd-journal-gatewayd gained SSL support and now runs as
    unprivileged user/group
    "systemd-journal-gateway:systemd-journal-gateway"
  + systemd-analyze will read, when available, boot time
    performance from EFI variable from boot loader supporting it.
  + A new generator for automatically mounting EFI System Partition
    (ESP) to /boot (if empty and no other file system has been
    configured in fstab for it).
  + logind will now send out PrepareForSleep(false) out
    unconditionally, after coming back from suspend.
  + tmpfiles gained a new "X" line type, that allows
    configuration of files and directories (with wildcards) that
    shall be excluded from automatic cleanup ("aging").
  + udev default rules set the device node permissions now only
    at "add" events, and do not change them any longer with a
    later "change" event.
  + A new bootctl tool has been added that is an interface for
    certain EFI boot loader operations.
  + A new tool kernel-install has been added to install kernel
    images according to Boot Loader Specification.
  + A new tool systemd-activate can be used to test socket
    activation.
  + A new group "systemd-journal" is now owning journal files,
    replacing "adm" group.
  + journalctl gained "--reverse" to show output in reverse order,
    "--pager-end" to jump at the end of the journal in the
    pager (only less is supported) and "--user-unit" to filter for
    user units.
  + New unit files has been addedto ease for systemd usage in
    initrd.
  + "systemctl start" now supports "--irreversible" to queue
    operations which can be reserved. It is now used to make
    shutdown requests more robust.
  + Auke Kok's bootchart has been merged and relicensed to
    LGPLv2.1+.
  + nss-myhostname has been merged in systemd codebase.
  + some defaults sysctl values are now set by default: the safe
    sysrq options are turned on, IP route verification is turned
    on, and source routing disabled. The recently added hardlink
    and softlink protection of the kernel is turned on.
  + Add support for predictable network naming logic. It can be
    turned off with kernel command line switch: net.ifnames=0
  + journald will now explicitly flush journal files to disk at the
    latest 5 min after each write and will mark file offline until
    next read. This should increase reliability in case of crash.
  + remote-fs-setup.target target has been added to pull in
    specific services when at least one remote file system is to be
    mounted.
  + timers.target and paths.target have been added as canonical
    targets to pull user timer and path units, similar to
    sockets.targets.
  + udev daemon now sets default number of worker processes in
    parallel based on number of CPUs instead of RAM.
  + Most unit file settings which takes likst of items can now be
  reset by assigning empty string to them, using drop-in.
  + Add support for drop-in configuration file for units.
  + Most unit file settings which takes likst of items can now be
    reset by assigning empty string to them, using drop-in.
  + improve systemg-cgtop output.
  + improve 'systemctl status' output for socket, drop-in for units.
  + 'hostnamectl set-hostname' allows setting FQDN hostnames.
  + fractional time intervals are now parsed properly.
  + localectl can list available X11 keymaps.
  + systemd-analyze dot can filter for specific units and has been
    rewritten in C.
  + systemctl gained "list-dependencies" command.
  + Inhibitors are now honored no only in GNOME.
- Many patches has been dropped, being merged upstream.
- Many patches has been renamed and regenerated with git, to have
  consistent naming, authorship and comments embedded.
- Add
  Revert-service-drop-support-for-SysV-scripts-for-the-early.patch:
  re-add support for boot.* initscripts until they are all migrated
  to systemd unit files.
- Merge patches for nss-myhostname package to this package.
* Fri Apr 12 2013 rschweikert@suse.com
- Add chromebook lid switch as a power switch to logind rule to
  enable suspend on lid close
* Mon Apr  8 2013 fcrozat@suse.com
- Add improve-readahead-spinning.patch: improve readahead
  performance on spinning media with ext4.
- Add fix-journal-vacuum-logic.patch: fix vacuum logic in journal
  (bnc#789589).
- Add fix-lsb-provides.patch: ensure LSB provides are correctly
  handled if also referenced as dependencies (bnc#809646).
- Add fix-loopback-mount.patch: ensure udevd is started (and
  therefore static devices are created) before mounting
  (bnc#809820).
- Update systemd-sysv-convert to search services files in new
  location (bnc#809695).
- Add logind-nvidia-acl.diff: set ACL on nvidia devices
  (bnc#808319).
- Add do-no-isolate-on-fsck-failure.patch: do not turn off services
  if fsck fails (bnc#812874)
- Add wait-for-processes-killed.patch: wait for processes killed by
  SIGTERM before killing them with SIGKILL.
- Update systemctl-options.patch to only apply SYSTEMCTL_OPTIONS to
  systemctl command (bnc#801878).
* Tue Apr  2 2013 sbrabec@suse.cz
- Fixed disabling CapsLock and enabling NumLock (bnc#746595,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  systemd-numlock-suse.patch).
- Explicitly require libgcrypt-devel to fix build failure.
* Thu Mar 28 2013 rmilasan@suse.com
- udev: ensure that the network interfaces are renamed even if they
  exist (bnc#809843).
  add: 1027-udev-always-rename-network.patch
* Wed Mar 20 2013 rmilasan@suse.com
- udev: re-add persistent network rules (bnc#809843).
  add: 1026-re-add-persistent-net.patch
- rebase all patches, ensure that they apply properly.
* Thu Feb 21 2013 fcrozat@suse.com
- Add rbind-mount.patch: handle rbind mount points correctly
  (bnc#804575).
* Tue Feb 19 2013 fcrozat@suse.com
- Ensure journal is flushed on disk when systemd-logger is
  installed for the first time.
- Add improve-journal-perf.patch: improve journal performance on
  query.
- Add support-hybrid-suspend.patch: add support for hybrid suspend.
- Add forward-to-pmutils.patch: forward suspend/hibernation calls
  to pm-utils, if installed (bnc#790157).
* Tue Feb 19 2013 rmilasan@suse.com
- udev: usb_id: parse only 'size' bytes of the 'descriptors' buffer
  add: 1024-udev-usb_id-parse-only-size-bytes-of-the-descriptors.patch
- udev: expose new ISO9660 properties from libblkid
  add: 1025-udev-expose-new-ISO9660-properties-from-libblkid.patch
* Mon Feb 18 2013 jengelh@inai.de
- Create getty@tty1.service to restore traditional SUSE behavior
  of not clearing tty1. (bnc#804158)
- Better use of find -exec
* Fri Feb 15 2013 fcrozat@suse.com
- Add early-sync-shutdown.patch: start sync just when
  shutdown.target is beginning
- Update parse-multiline-env-file.patch to better handle continuing
  lines.
- Add handle-HOSTNAME.patch: handle /etc/HOSTNAME (bnc#803653).
- Add systemctl-print-wall-on-if-successful.patch: only print on
  wall if successful.
- Add improve-bash-completion.patch: improve bash completion.
* Fri Feb 15 2013 lnussel@suse.de
- disable nss-myhostname warning (bnc#783841)
  => disable-nss-myhostname-warning-bnc-783841.diff
* Wed Feb 13 2013 rmilasan@suse.com
- rework patch:
  1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- udev: use unique names for temporary files created in /dev.
  add: 1022-udev-use-unique-names-for-temporary-files-created-in.patch
- cdrom_id: add data track count for bad virtual drive.
  add: 1023-cdrom_id-add-data-track-count-for-bad-virtual-drive.patch
* Tue Feb 12 2013 rmilasan@suse.com
- usb_id: ensure we have a valid serial number as a string (bnc#779493).
  add: 1020-usb_id-some-strange-devices-have-a-very-bogus-or-strage-serial.patch
- cdrom_id: created links for the default cd/dvd drive (bnc#783054).
  add: 1021-create-default-links-for-primary-cd_dvd-drive.patch
* Fri Feb  1 2013 fcrozat@suse.com
- Add cryptsetup-accept-read-only.patch: accept "read-only" in
  addition to "readonly" in crypttab
- Update parse-multiline-env-file.patch to correctly handle
  commented lines (bnc#793411)
* Tue Jan 29 2013 rmilasan@suse.com
- udev: Fix device matching in the accelerometer
  add: 1019-udev-Fix-device-matching-in-the-accelerometer.patch
- keymap: add aditional support for some keyboard keys
  add: 1018-keymap-add-aditional-support.patch
- journalctl: require argument for --priority
  add: journalctl-require-argument-for-priority
- dropped useless patches:
  libudev-validate-argument-udev_enumerate_new.patch
  kmod-fix-builtin-typo.patch
- rename udev-root-symlink.service to systemd-udev-root-symlink.service.
- fix in udev package missing link in basic.target.wants for
  systemd-udev-root-symlink.service
* Mon Jan 28 2013 fcrozat@suse.com
- Add tmpfiles-X-type.patch: allow to clean directories with
  removing them.
- Add systemd-fix-merge-ignore-dependencies.patch: fix merging with
  - -ignore-dependencies waiting for dependencies (bnc#800365).
- Update systemd-numlock-suse.patch: udev-trigger.service is now
  called systemd-udev-trigger.service.
- Add improve-man-environment.patch: improve manpage regarding
  Environment value.
* Tue Jan 22 2013 fcrozat@suse.com
- Add systemctl-options.patch: handle SYSTEMCTL_OPTIONS internaly
  (bnc#798620).
- Update crypt-loop-file.patch to correctly detect crypto loop
  files (bnc#799514).
- Add journalctl-remove-leftover-message.patch: remove debug
  message in systemctl.
- Add job-avoid-recursion-when-cancelling.patch: prevent potential
  recursion when cancelling a service.
- Add sysctl-parse-all-keys.patch: ensure sysctl file is fully
  parsed.
- Add journal-fix-cutoff-max-date.patch: fix computation of cutoff
  max date for journal.
- Add reword-rescue-mode-hints.patch: reword rescue prompt.
- Add improve-overflow-checks.patch: improve time overflow checks.
- Add fix-swap-behaviour-with-symlinks.patch: fix swap behaviour
  with symlinks.
- Add hostnamectl-fix-set-hostname-with-no-argument.patch: ensure
  hostnamectl requires an argument when called with set-hostname
  option.
- Add agetty-overrides-term.patch: pass correctly terminal type to
  agetty.
- Add check-for-empty-strings-in-strto-conversions.patch: better
  check for empty strings in strto* conversions.
- Add strv-cleanup-error-path-loops.patch: cleanup strv on error
  path.
- Add cryptsetup-handle-plain.patch: correctly handle "plain"
  option in cryptsetup.
- Add fstab-generator-improve-error-message.patch: improve error
  message in fstab-generator.
- Add delta-accept-t-option.patch: accept -t option in
  systemd-delta.
- Add highlight-ordering-cycle-deletions.patch: highlight ordering
  cycle deletions in logs.
- Add core-interpret-escaped-semicolon-as-escaped.patch: accept \;
  in ExecStart.
- Add hostnamectl-fix-parsing-no-ask-password.patch: accept
  no-ask-password in hostnamectl.
- Add systemd-cgls-fix-piping-output.patch: fix piping output of
  systemd-cgls.
- Add core-load-fragment-improve-error-message.patch: improve error
  message when parsing fragments.
- Add fix-potential-bad-mem-access.patch: fix potential bad memory
  access.
- Add socket-improve-error-message.patch: improve error message in
  socket handling.
- Add journal-send-always-send-syslog_identifier.patch: always send
  syslog_identifier if available for journal.
- Add crypsetup-handle-nofail.patch: handle nofail in cryptsetup.
- Add crypsetup-generator-state-file-name-in-error-message.patch:
  add filename in error message from crypsetup-generator.
- Add fstab-generator-error-message-on-duplicates.patch: improve
  error message on duplicate in fstab-generator.
- Add systemctl-verbose-message-on-missing-install.patch: reword
  missing install error message in systemctl.
- Add shutdown-improvements.patch: various improvements at
  shutdown.
- Add localectl-fix-assertion.patch: fix assertion in localectl.
- Add path-util-fix-potential-crash.patch: fix potential crash in
  path-util.
- Add coredumpctl-fix-crash.patch: fix crash in coredumpctl.
- Add socket-verbose-error-message.patch: add more verbose error
  message in socket handling.
- Add pam-properly-handle-ssh-logins-without-pam-tty-field.patch:
  handle properly ssh-logins without pam tty field.
- Add fstab-generator-properly-detect-bind-mounts.patch: properly
  detect bind-mounts in fstab-generator.
- Add localectl-support-systems-without-locale-archive.patch:
  localectl now supports systemd without locale-archive file.
- Add logind-capability-making-seats-without-fb.patch: allows
  capability of making seats without fb.
- Add service-forking-ignore-exit-status-main-process.patch: ignore
  exit-statis of main process when forking, if specified in unit
  file.
- Add systemctl-no-assert-on-reboot-without-dbus.patch: don't
  assert on reboot if dbus isn't there.
- Add logind-ignore-non-tty-non-x11-session-on-shutdown.patch:
  ignore non tty non-x11 session on shutdown.
- Add journalctl-quit-on-io-error.patch: fix journalctl quit on io
  error.
- Add do-not-make-sockets-dependent-on-lo.patch: do not make
  sockets dependent on lo interface.
- Add shutdown-dont-force-mnt-force-on-final-umount.patch: don't
  force MNT_FORCE on final umount at shutdown.
- Add shutdown-ignore-loop-devices-without-backing-file.patch:
  ignore loop devices without backing file at shutdown.
- Add fix-bad-mem-access.patch: fix bad memory access
- Add parse-multiline-env-file.patch: correctly parse multiline
  environment files (bnc#793411).
* Thu Jan 10 2013 fcrozat@suse.com
- Add multiple-sulogin.patch: allows multiple sulogin instance
  (bnc#793182).
* Wed Jan  9 2013 rmilasan@suse.com
- udev: path_id - handle Hyper-V devices
  add: 1008-udev-path_id-handle-Hyper-V-devices.patch
- keymap: Update the list of Samsung Series 9 models
  add: 1009-keymap-Update-the-list-of-Samsung-Series-9-models.patch
- keymap: Add Samsung 700T
  add: 1010-keymap-Add-Samsung-700T.patch
- libudev: avoid leak during realloc failure
  add: 1011-libudev-avoid-leak-during-realloc-failure.patch
- libudev: do not resolve $attr{device} symlinks
  add: 1012-libudev-do-not-resolve-attr-device-symlinks.patch
- libudev: validate 'udev' argument to udev_enumerate_new()
  add: 1013-libudev-validate-udev-argument-to-udev_enumerate_new.patch
- udev: fix whitespace
  add: 1014-udev-fix-whitespace.patch
- udev: properly handle symlink removal by 'change' event
  add: 1015-udev-properly-handle-symlink-removal-by-change-event.patch
- udev: builtin - do not fail builtin initialization if one of
  them returns an error
  add: 1016-udev-builtin-do-not-fail-builtin-initialization-if-o.patch
- udev: use usec_t and now()
  add: 1017-udev-use-usec_t-and-now.patch
* Tue Jan  8 2013 rmilasan@suse.com
- udevd: add missing ':' to getopt_long 'e'.
  add: 1007-udevd-add-missing-to-getopt_long-e.patch
- clean up systemd.spec, make it easy to see which are udev and
  systemd patches.
- make 'reload' and 'force-reload' LSB compliant (bnc#793936).
* Tue Dec 11 2012 crrodriguez@opensuse.org
- detect-btrfs-ssd.patch: Fix btrfs detection on SSD.
- timedated-donot-close-bogus-dbus-connection.patch: Avoid
  closing an non-existent dbus connection and getting assertion
  failures.
* Mon Dec 10 2012 coolo@suse.com
- add conflicts between udev-mini and udev-mini-devel to libudev1
* Thu Dec  6 2012 crrodriguez@opensuse.org
- revert-of-9279749b84cc87c7830280b7895a48bed03c9429.patch:
  do not consider failure to umount / and /usr an error.
* Wed Dec  5 2012 fcrozat@suse.com
- Add fix-devname-prefix.patch: fix modules.devname path, it isn't
  in /usr.
- Move post script to fix symlinks in /etc/systemd/system to a
  trigger to run it after old systemd is uninstalled.
* Tue Dec  4 2012 fcrozat@suse.com
- Add fix-debugshell.patch: use /bin/bash if sushell isn't
  installed (bnc#789052).
- Add handle-root-uses-lang.patch: handle ROOT_USES_LANG=ctype
  (bnc#792182).
- Ensure libudev1 and libudev-mini1 conflicts.
* Thu Nov 22 2012 rmilasan@suse.com
- Fix creation of /dev/root link.
* Tue Nov 20 2012 fcrozat@suse.com
- Add remount-ro-before-unmount.patch: always remount read-only
  before unmounting in final shutdown loop.
- Add switch-root-try-pivot-root.patch: try pivot_root before
  overmounting /
* Tue Nov 20 2012 fcrozat@suse.com
- links more manpages for migrated tools (from Christopher
  Yeleighton).
- disable boot.localnet service, ypbind service will do the right
  thing now (bnc#716746)
- add xdm-display-manager.patch: pull xdm.service instead of
  display-manager.service (needed until xdm initscript is migrated
  to native systemd service).
- Add fix-permissions-btmp.patch: ensure btmp is owned only by root
  (bnc#777405).
- Have the udev package create a tape group, as referenced by
  50-udev-default.rules and 60-persistent-storage-tape.rules
  (DimStar).
- Add fix-bad-memory-access.patch: fix crash in journal rotation.
- Add fix-dbus-crash.patch: fix D-Bus caused crash.
- Add sync-on-shutdown.patch: ensure sync is done when initiating
  shutdown.
- Add mount-efivars.patch: mount efivars if booting on UEFI.
* Thu Nov 15 2012 fcrozat@suse.com
- Ship a empty systemd-journald initscript in systemd-logger to
  stop insserv to complain about missing syslog dependency.
- Update
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch
  with bug fixes from Debian.
* Wed Nov 14 2012 fcrozat@suse.com
- /var/log/journal is now only provided by systemd-logger (journal
  won't be persistent for people using another syslog
  implementation).
- install README in /var/log (in systemd-logger) and /etc/init.d
- create adm group when installing systemd.
- fix path in udev-root-symlink.systemd.
- Enforce Requires(post) dependency on libudev in main systemd
  package (help upgrade).
- Ensure configuration is reloaded when upgrading and save random
  seed when installing.
- Create /lib/udev symlink, if we do a fresh install.
- Add fix-build-glibc217.patch: fix build with latest glibc.
- Add libgcrypt.m4: copy of autoconf macro from libgcrypt, only
  used to bootstrap systemd-mini.
* Tue Nov  6 2012 coolo@suse.com
- adding a package systemd-logger that blocks syslog implementations
  from installation to make an installation that only uses the journal
* Mon Nov  5 2012 fcrozat@suse.com
- Don't hardcode path for systemctl in udev post script.
- Ensure systemd-udevd.service is shadowing boot.udev when booting
  under systemd.
- Fix udev daemon upgrade under both systemd and sysvinit.
- Add fix-logind-pty-seat.patch: fix logind complaining when doing
  su/sudo in X terminal.
* Sat Nov  3 2012 coolo@suse.com
- add libudev1 to baselibs.conf
* Fri Nov  2 2012 coolo@suse.com
- udev is GPL-2.0, the rest remains LGPL-2.1+ (bnc#787824)
* Mon Oct 29 2012 fcrozat@suse.com
- Add var-run-lock.patch: make sure /var/run and /var/lock are
  handled as bind mount if they aren't symlinks.
- Update storage-after-cryptsetup.patch with new systemctl path.
- Migrate broken symlinks in /etc/systemd/system due to new systemd
  location.
* Fri Oct 26 2012 fcrozat@suse.com
- Update to release 195:
  + journalctl agained --since and --until, as well as filtering
    for units with --unit=/-u.
  + allow ExecReload properly for Type=oneshot (needed for
    iptables.service, rpc-nfsd.service).
  + journal daemon supports time-based rotation and vaccuming.
  + journalctl -F allow to list all values of a certain field in
    journal database.
  + new commandline clients for timedated, locald and hostnamed
  + new tool systemd-coredumpctl to list and extract coredumps from
    journal.
  + improve gatewayd: follow mode, filtering, support for
    HTML5/JSON Server-Sent-Events.
  + reload support in SysV initscripts is now detected when file is
    parted.
  + "systemctl status --follow" as been removed, use "journalctl -fu
    instead"
  + journald.conf RuntimeMinSize and PersistentMinSize settings
    have been removed.
- Add compatibility symlink for systemd-ask-password and systemctl
  in /bin.
* Thu Oct 18 2012 fcrozat@suse.com
- Create and own more systemd drop-in directories.
* Tue Oct 16 2012 fcrozat@suse.com
- Improve mini packages for bootstrapping.
- do not mount /tmp as tmpfs by default.
* Tue Oct 16 2012 fcrozat@suse.com
- Fix install script when there is no inittab
* Mon Oct 15 2012 fcrozat@suse.com
- Create a systemd-mini specfile to prevent cycle in bootstrapping
* Thu Oct  4 2012 fcrozat@suse.com
- udev and its subpackages are now generated by systemd source
  package.
- migrate udev and systemd to /usr
- Update to version 194:
  + if /etc/vconsole.conf is non-existent or empty and if
    /etc/sysconfig/console:CONSOLE_FONT (resp
    /etc/sysconfig/keyboard:KEYTABLE) set, console font (resp
    keymap) is not modified.
- Changes from version 44 to 193:
  + journalctl gained --cursor= to show entries starting from a
    specified location in journal.
  + Size limit enforced to 4K for fields exported with "-o json" in
    journalctl. Use --all to disable this behavior.
  + Optional journal gateway daemon
    (systemd-journal-gatewayd.service) to access journal via HTTP
    and JSON. Use "wget http://localhost:19531/entries" to get
    /var/log/messages compatible format and
    'curl -H"Accept: application/json"
    http://localhost:19531/entries' for JSON formatted content.
    HTML5 static page is also available as explained on
    http://0pointer.de/public/journal-gatewayd
  + do not mount cpuset controler, doesn't work well by default
    ATM.
  + improved nspawn behaviour with /etc/localtime
  + journald logs its maximize size on disk
  + multi-seat X wrapper (partially merged in upstream X server).
  + HandleSleepKey has been splitted into HandleSuspendKey and
    HandleHibernateKey.
  + systemd and logind now handle system sleep states, in
    particular suspending and hibernating.
  + new cgroups are mounted by default (cpu, cpuacct,
    net_cls, net_pri)
  + sync at shutdown is now handled by kernel
  + imported journalctl output (colors, filtering, pager, bash
    completion).
  + suffix ".service" may now be ommited on most systemctl command
    involving service unit names.
  + much improved nspawn containers support.
  + new conditions added : ConditionFileNotEmpty, ConditionHost,
    ConditionPathIsReadWrite
  + tmpfiles "w" supports file globbing
  + logind handles lid switch, power and sleep keys all the time,
    unless systemd-inhibit
  - -what=handle-power-key:handle-sleep-key:handle-lid-switch is
    run by Desktop Environments.
  + support for reading structured kernel message is used by
    default (need kernel >= 3.5). /proc/kmsg is now used only by
    classic syslog daemons.
  + Forward Secure Sealing is now support for Journal files.
  + RestartPrevenExitStatus and SuccessExitStatus allow configure
    of exit status (exit code or signal).
  + handles keyfile-size and keyfile-offset in /etc/crypttab.
  + TimeoutSec settings has been splitted into TimeoutStartSec and
    TimeoutStopSec.
  + add SystemCallFilters option to add blacklist/whitelist to
    system calls, using SECCOMP mode 2 of kernel >= 3.5.
  + systemctl udevadm info now takes a /dev or /sys path as argument:
  - udevadm info /dev/sda
  + XDG_RUNTIME_DIR now uses numeric UIDs instead of usernames.
  + systemd-loginctl and systemd-journalctl have been renamed
    to loginctl and journalctl to match systemctl.
  + udev: RUN+="socket:..."  and udev_monitor_new_from_socket() is
    no longer supported. udev_monitor_new_from_netlink() needs to
    be used to subscribe to events.
  + udev: when udevd is started by systemd, processes which are left
    behind by forking them off of udev rules, are unconditionally
    cleaned up and killed now after the event handling has finished.
    Services or daemons must be started as systemd services.
    Services can be pulled-in by udev to get started, but they can
    no longer be directly forked by udev rules.
  + For almost all files, license is now LGPL2.1+ (from previous
    GPL2.0+). Exception are some minor stuff in udev (will be
    changed to LGPL2.1 eventually) and MIT license sd-daemon.[ch]
    library.
  + var-run.mount and var-lock.mount are no longer provided
    (should be converted to symlinks).
  + A new service type Type=idle to avoid ugly interleaving of
    getty output and boot status messages.
  + systemd-delta has been added, a tool to explore differences
    between user/admin configuration and vendor defaults.
  + /tmp mouted as tmpfs by default.
  + /media is now longer mounted as tmpfs
  + GTK tool has been split off to systemd-ui package.
  + much improved documentation.
- Merge BuildRequires from udev package:
  gobject-introspection-devel, gtk-doc, libsepol-devel,
  libusb-devel, pkgconfig(blkid), pkgconfig-glib-2.0),
  pjgconfig(libcryptsetup), pkgconfig(libpci),
  pkgconfig(libqrencode), pkgconfig(libselinux),
  pkgconfig(usbutils).
- Add pkgconfig(libqrencode) and pkgconfig(libmicrohttpd)
- Merge sources from udev package: boot.udev, write_dev_root.rules,
  udev-root-symlink.systemd.
- Merge patches from udev package: numbered started from 1000):
  0001-Reinstate-TIMEOUT-handling.patch,
  0013-re-enable-by_path-links-for-ata-devices.patch,
  0014-rules-create-by-id-scsi-links-for-ATA-devices.patch,
  0026-udev-netlink-null-rules.patch,
  0027-udev-fix-sg-autoload-regression.patch.
- Remove following patches, merged upstream:
  0001-util-never-follow-symlinks-in-rm_rf_children.patch,
  fixppc.patch, logind-logout.patch, fix-getty-isolate.patch,
  fix-swap-priority.patch, improve-restart-behaviour.patch,
  fix-dir-noatime-tmpfiles.patch, journal-bugfixes.patch,
  ulimit-support.patch, change-terminal.patch,
  fix-tty-startup.patch, fix-write-user-state-file.patch,
  fix-analyze-exception.patch, use_localtime.patch,
  journalctl-pager-improvement.patch,
  avoid-random-seed-cycle.patch,
  0001-add-sparse-support-to-detect-endianness-bug.patch,
  drop-timezone.patch.
- Rebase the following patches:
  0001-Add-bootsplash-handling-for-password-dialogs.patch,
  0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch,
  0001-service-Fix-dependencies-added-when-parsing-insserv..patch,
  0001-service-flags-sysv-service-with-detected-pid-as-Rema.patch,
  crypt-loop-file.patch,
  delay-fsck-cryptsetup-after-md-lvm-dmraid.patch,
  dm-lvm-after-local-fs-pre-target.patch, fastboot-forcefsck.patch,
  fix-enable-disable-boot-initscript.patch, modules_on_boot.patch,
  new-lsb-headers.patch, storage-after-cryptsetup.patch,
  support-suse-clock-sysconfig.patch, support-sysvinit.patch,
  sysctl-modules.patch, systemd-numlock-suse.patch, tty1.patch.
* Thu Aug 23 2012 fcrozat@suse.com
- Add use_localtime.patch: use /etc/localtime instead of
  /etc/timezone (bnc#773491)
- Add support-suse-clock-sysconfig.patch: read SUSE
  /etc/sysconfig/clock file.
- Add drop-timezone.patch: drop support for /etc/timezone, never
  supported on openSUSE.
- Add journalctl-pager-improvement.patch: better handle output when
  using pager.
- Add fix-enable-disable-boot-initscript.patch: support boot.*
  initscripts for systemctl enable /disable (bnc#746506).
* Mon Jul 30 2012 fcrozat@suse.com
- Ensure systemd macros never fails (if systemd isn't install)
* Mon Jul 23 2012 fcrozat@suse.com
- Add fix-analyze-exception.patch: prevent exception if running
  systemd-analyze before boot is complete (bnc#772506)
* Fri Jul 20 2012 sbrabec@suse.cz
- Fix NumLock detection/set race condition (bnc#746595#c47).
* Wed Jul 18 2012 fcrozat@suse.com
- Move systemd-analyse to a subpackage, to remove any python
  dependencies from systemd main package (bnc#772039).
* Tue Jul 10 2012 fcrozat@suse.com
- Add fastboot-forcefsck.patch: ensure fastboot and forcefsck on
  kernel commandline are handled.
- Add fix-write-user-state-file.patch: write logind state file
  correctly.
- Disable logind-logout.patch: cause too many issues (bnc#769531).
* Mon Jul  9 2012 fcrozat@suse.com
- Add fix-tty-startup.patch: don't limit tty VT to 12 (bnc#770182).
* Tue Jul  3 2012 sbrabec@suse.cz
- Fix SUSE specific sysconfig numlock logic for 12.2 (bnc#746595).
* Tue Jul  3 2012 fcrozat@suse.com
- Add fix-dir-noatime-tmpfiles.patch: do not modify directory
  atime, which was preventing removing empty directories
  (bnc#751253, rh#810257).
- Add improve-restart-behaviour.patch: prevent deadlock during
  try-restart (bnc#743218).
- Add journal-bugfixes.patch: don't crash when rotating journal
  (bnc#768953) and prevent memleak at rotation time too.
- Add ulimit-support.patch: add support for system wide ulimit
  (bnc#744818).
- Add change-terminal.patch: use vt102 instead of vt100 as terminal
  for non-vc tty.
- Package various .wants directories, which were no longer packaged
  due to plymouth units being removed from systemd package.
- Fix buildrequires for manpages build.
* Mon Jul  2 2012 fcrozat@suse.com
- Do not ship plymouth units, they are shipped by plymouth package
  now (bnc#769397).
- Fix module loading (bnc#769462)
* Thu Jun  7 2012 fcrozat@suse.com
- Add fix-swap-priority: fix default swap priority (bnc#731601).
* Fri May 25 2012 fcrozat@suse.com
- Re-enable logind-logout.patch, fix in xdm-np PAM file is the real
  fix.
* Thu May 24 2012 fcrozat@suse.com
- Update new-lsb-headers.patch to handle entries written after
  description tag (bnc#727771, bnc#747931).
* Thu May  3 2012 fcrozat@suse.com
- Disable logind-logout.patch: it crashes sudo session (if called
  after su -l) (bnc#746704).
* Tue Apr 24 2012 fcrozat@suse.com
- Add fix-getty-isolate.patch: don't quit getty when changing
  runlevel (bnc#746594)
* Fri Apr 20 2012 sbrabec@suse.cz
- Implemented SUSE specific sysconfig numlock logic (bnc#746595).
* Thu Apr 19 2012 fcrozat@suse.com
- Add dbus-1 as BuildRequires to fix build.
* Tue Apr  3 2012 dvaleev@suse.com
- apply ppc patch to systemd-gtk too (fixes build)
* Thu Mar 22 2012 fcrozat@suse.com
- Update fixppc.patch with upstream patches
- Add comments from upstream in
  0001-util-never-follow-symlinks-in-rm_rf_children.patch.
- Add logind-logout.patch: it should fix sudo / su with pam_systemd
  (bnc#746704).
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-add-sparse-support-to-detect-endianness-bug.patch: fix
  endianness error, preventing journal to work properly on ppc.
- Add fixppc.patch: fix build and warnings on ppc.
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-util-never-follow-symlinks-in-rm_rf_children.patch: fix
  CVE-2012-1174 (bnc#752281).
* Fri Mar 16 2012 fcrozat@suse.com
- Update to version 43:
  + Support optional initialization of the machine ID from the KVM
    or container configured UUID.
  + Support immediate reboots with "systemctl reboot -ff"
  + Show /etc/os-release data in systemd-analyze output
  + Many bugfixes for the journal, including endianess fixes and
    ensuring that disk space enforcement works
  + non-UTF8 strings are refused if used in configuration and unit
    files.
  + Register Mimo USB Screens as suitable for automatic seat
    configuration
  + Reorder configuration file lookup order. /etc now always
    overrides /run.
  + manpages for journal utilities.
- Drop fix-c++-compat.patch, no-tmpfs-fsck.patch,
  systemd-journald-fix-endianess-bug.patch.
- Requires util-linux >= 2.21 (needed to fix fsck on tmpfs).
* Mon Mar 12 2012 fcrozat@suse.com
- Add fix-c++-compat.patch: fix C++ compatibility error in header.
* Wed Feb 29 2012 fcrozat@suse.com
- Add systemd-journald-fix-endianess-bug.patch: fix journald not
  starting on ppc architecture.
- Add correct_plymouth_paths_and_conflicts.patch: ensure plymouth
  is correctly called and conflicts with bootsplash.
* Tue Feb 21 2012 fcrozat@suse.com
- Remove rsyslog listen.conf, handled directly by rsyslog now
  (bnc#747871).
* Mon Feb 20 2012 fcrozat@suse.com
- Update to version 43:
  + requires /etc/os-release, support for /etc/SuSE-release is no
    longer present.
  + Track class of PAM logins to distinguish greeters from normal
    user logins.
  + Various bug fixes.
* Sun Feb 19 2012 jengelh@medozas.de
- Use pkgconfig symbols for BuildRequires and specify version
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Enable Plymouth integration.
  * Bootsplash related files will be moved to the bootsplash
    package
* Mon Feb 13 2012 fcrozat@suse.com
- Update to version 42:
  + Various bug fixes
  + Watchdog support for supervising services is now usable
  + Service start rate limiting is now configurable and can be
    turned off per service.
  + New CanReboot(), CanPowerOff() bus calls in systemd-logind
- Dropped fix-kmod-build.patch, fix-message-after-chkconfig.patch,
  is-enabled-non-existing-service.patch (merged upstream)
- Add libxslt1 / docbook-xsl-stylesheets as BuildRequires for
  manpage generation
* Thu Feb  9 2012 fcrozat@suse.com
- Update to version 41:
  + systemd binary is now installed in /lib/systemd (symlink for
  /bin/systemd is available now)
  + kernel modules are now loaded through libkmod
  + Watchdog support is now useful (not complete)
  + new kernel command line available to set system wide
    environment variable: systemd.setenv
  + journald capabilities set is now limited
  + SIGPIPE is ignored by default. This can be disabled with
    IgnoreSIGPIPE=no in unit files.
- Add fix-kmod-build.patch: fix build with libkmod
- Drop remote-fs-after-network.patch (merged upstream)
- Add dm-lvm-after-local-fs-pre-target.patch: ensure md / lvm
  /dmraid is started before mounting partitions, if fsck was
  disabled for them (bnc#733283).
- Update lsb-header patch to correctly disable heuristic if
  X-Systemd-RemainAfterExit is specified (whatever its value)
- Add fix-message-after-chkconfig.patch: don't complain if only
  sysv services are called in systemctl.
- Add is-enabled-non-existing-service.patch: fix error message when
  running is-enabled on non-existing service.
* Tue Feb  7 2012 fcrozat@suse.com
- Update to version 40:
  + reason why a service failed is now exposed in the"Result" D-Bus
    property.
  + Rudimentary service watchdog support (not complete)
  + Improve bootcharts, by immediatly changing argv[0] after
    forking to to reflect which process will be executed.
  + Various bug fixes.
- Add remote-fs-after-network.patch and update insserv patch:
  ensure remote-fs-pre.target is enabled and started before network
  mount points (bnc#744293).
- Ensure journald doesn't prevent syslogs to read from /proc/kmsg.
* Tue Jan 31 2012 fcrozat@suse.com
- Ensure systemd show service status when started behind bootsplash
  (bnc#736225).
- Disable core dump redirection to journal, not stable atm.
* Thu Jan 26 2012 fcrozat@suse.com
- Update modules_on_boot.patch to not cause failed state for
  systemd-modules-load.service (bnc#741481).
* Wed Jan 25 2012 fcrozat@suse.com
- Update to version 39:
  + New systemd-cgtop tool to show control groups by their resource
    usage.
  + Linking against libacl for ACLs is optional again.
  + If a group "adm" exists, journal files are automatically owned
    by them, thus allow members of this group full access to the
    system journal as well as all user journals.
  + The journal now stores the SELinux context of the logging
    client for all entries.
  + Add C++ inclusion guards to all public headers.
  + New output mode "cat" in the journal to print only text
    messages, without any meta data like date or time.
  + Include tiny X server wrapper as a temporary stop-gap to teach
    XOrg udev display enumeration (until XOrg supports udev
    hotplugging for display devices).
  + Add new systemd-cat tool for executing arbitrary programs with
    STDERR/STDOUT connected to the journal. Can also act as BSD
    logger replacement, and does so by default.
  + Optionally store all locally generated coredumps in the journal
    along with meta data.
  + systemd-tmpfiles learnt four new commands: n, L, c, b, for
    writing short strings to files (for usage for /sys), and for
    creating symlinks, character and block device nodes.
  + New unit file option ControlGroupPersistent= to make cgroups
    persistent.
  + Support multiple local RTCs in a sane way.
  + No longer monopolize IO when replaying readahead data on
    rotating disks.
  + Don't show kernel threads in systemd-cgls anymore, unless
    requested with new -k switch.
- Drop systemd-syslog_away_early_on_shutdown.patch: fixed upstream.
- Add fdupes to BuildRequires and use it at build time.
* Thu Jan 19 2012 tittiatcoke@gmail.com
- Make the systemd journal persistent by creating the
  /var/log/journal directory
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 38 :
  - Bugfixes
  - Implementation of a Journal Utility Library
  - Implementation of a 128 Bit ID Utility Library
- 11 Patches integrated upstream
- Add systemd-syslog_away_early_on_shutdown.patch: make sure
  syslog socket goes away early during shutdown.
- Add listen.conf for rsyslog. This will ensure that it will still
  work fine with rsyslog and the new journal.
* Mon Jan  9 2012 fcrozat@suse.com
- Add fix-is-enabled.patch: ensure systemctl is-enabled work
  properly when systemd isn't running.
- Add logind-console.patch: do not bail logind if /dev/tty0 doesn't
  exist (bnc#733022, bnc#735047).
- Add sysctl-modules.patch: ensure sysctl is started after modules
  are loaded (bnc#725412).
- Fix warning in insserv patch.
- Update avoid-random-seed-cycle.patch with better upstream
  approach.
- Update storage-after-cryptsetup.patch to restart lvm before
  local-fs.target, not after it (bnc#740106).
- Increase pam-config dependency (bnc#713319).
* Wed Dec  7 2011 fcrozat@suse.com
- Remove storage-after-cryptsetup.service, add
  storage-after-cryptsetup.patch instead to prevent dependency
  cycle (bnc#722539).
- Add delay-fsck-cryptsetup-after-md-lvm-dmraid.patch: ensure
  fsck/cryptsetup is run after lvm/md/dmraid have landed
  (bnc#724912).
- Add cron-tty-pam.patch: Fix cron filling logs (bnc#731358).
- Add do_not_warn_pidfile.patch: Fix PID warning in logs
  (bnc#732912).
- Add mount-swap-log.patch: Ensure swap and mount output is
  redirected to default log target (rhb#750032).
- Add color-on-boot.patch: ensure colored status are displayed at
  boot time.
- Update modules_on_boot.patch to fix bnc#732041.
- Replace private_tmp_crash.patch with log_on_close.patch, better
  upstream fix for bnc#699829 and fix bnc#731719.
- Update vconsole patch to fix memleaks and crash (bnc#734527).
- Add handle-racy-daemon.patch: fix warnings with sendmail
  (bnc#732912).
- Add new-lsb-headers.patch: support PIDFile: and
  X-Systemd-RemainAfterExit: header in initscript (bnc#727771).
- Update bootsplash services to not start if vga= is missing from
  cmdline (bnc#727771)
- Add lock-opensuse.patch: disable /var/lock/{subsys,lockdev} and
  change default permissions on /var/lock (bnc#733523).
- Add garbage_collect_units: ensure error units are correctly
  garbage collected (rhb#680122).
- Add crypt-loop-file.patch: add support for crypt file loop
  (bnc#730496).
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 fcrozat@suse.com
- Fix rpm macros to only call presets on initial install
  (bnc#728104).
* Thu Oct 27 2011 fcrozat@suse.com
- Add no-tmpfs-fsck.patch: don't try to fsck tmpfs mountpoint
  (bnc#726791).
* Wed Oct 19 2011 fcrozat@suse.com
- Add avoid-random-seed-cycle.patch: fix dependency cycle between
  cryptsetup and random-seed-load (bnc#721666).
- Add crash-isolating.patch: fix crash when isolating a service.
- Fix bootsplash being killed too early.
- Fix some manpages not being redirected properly.
- Add storage-after-cryptsetup.service to restart lvm after
  cryptsetup. Fixes lvm on top of LUKS (bnc#724238).
* Fri Oct 14 2011 fcrozat@suse.com
- Recommends dbus-1-python, do not requires python (bnc#716939)
- Add private_tmp_crash.patch: prevent crash in debug mode
  (bnc#699829).
- Add systemctl-completion-fix.patch: fix incorrect bash completion
  with some commands (git).
* Wed Oct 12 2011 fcrozat@suse.com
- Shadow single sysv service, it was breaking runlevel 1.
- Add modules_on_boot.patch to handle /etc/sysconfig/kernel
  MODULES_ON_BOOT variable (bnc#721662).
* Wed Oct 12 2011 fcrozat@suse.com
- Update to release 37:
  - many bugfixes
  - ConditionCapability added, useful for containers.
  - locale mechanism got extend to kbd configuration for
    both X and the console
  - don't try to guess PID for SysV services anymore (bnc#723194)
- Drop detect-non-running.patch, logind-warning.patch.
- Rewrite systemd-sysv-convert in bash (bnc#716939)
* Tue Oct 11 2011 coolo@suse.com
- make sure updaters get in the /sbin/init from here - the sub package
  of the split package will decide which init wins in update case
* Tue Oct 11 2011 coolo@suse.com
- under openSUSE if it's not systemd, chances are good it's
  sysvinit
* Tue Oct 11 2011 coolo@suse.com
- do not list specific sbin_init providers
* Wed Oct  5 2011 fcrozat@suse.com
- Add logind-warning.patch: fix pam warning (bnc#716384)
* Fri Sep 30 2011 fcrozat@suse.com
- Update to version 36 :
  - many bugfixes
  - systemd now requires socket-activated syslog implementations
  - After=syslog.target is no longer needed in .service files
  - X-Interactive is ignored in LSB headers (was not working)
- Enable back insserv.conf parsing in systemd core and fix added
  dependencies (bnc#721428).
- Fix detection of LSB services status when running daemon
  (bnc#721426).
- Drop 0001-execute-fix-bus-serialization-for-commands.patch,
  fix-reload.patch
* Thu Sep 29 2011 fcrozat@suse.com
- Add services to stop bootsplash at end of startup and start it at
  beginning of shutdown.
- Fix bootsplash call and ensure dependencies are set right.
* Thu Sep 29 2011 fcrozat@suse.com
- Add detect-non-running.patch: fix assertion when running
  systemctl under non systemd system (git).
- Requires presets branding package.
- Improve macros a little bit.
* Mon Sep 26 2011 fcrozat@suse.com
- Merge migration rpm macros into service_add/service_del macros.
- Use systemd presets in rpm macros
- Add fix-reload.patch: handle daemon-reload and start condition
  properly (bnc#719221).
* Fri Sep 23 2011 fcrozat@suse.com
- Add systemd-splash / bootsplash-startup.service: enable
  bootsplash at startup.
* Fri Sep 16 2011 fcrozat@suse.com
- Create -32bit package (bnc#713319)
* Mon Sep 12 2011 fcrozat@suse.com
- Do not mask localnet service, it is not yet handled by systemd.
  (bnc#716746)
* Fri Sep  9 2011 fcrozat@suse.com
- Add revert_insserv_conf_parsing.patch and systemd-insserv_conf:
  remove insserv.conf parsing from systemd and use generator
  instead.
- put back default.target creation at package install and remove
  inittab generator, Yast2 is now able to create it.
* Thu Sep  1 2011 fcrozat@novell.com
- Update to version 34:
  * Bugfixes
  * optionaly apply cgroup attributes to cgroups systemd creates
  * honour sticky bit when trimming cgroup trees
  * improve readahead
- Add libacl-devel as BuildRequires (needed for systemd-uaccess)
- Add some %%{nil} to systemd.macros to fix some build issues.
- Fix dbus assertion
- move gtk part to its own package, to reduce bootstrapping
  (bnc#713981).
* Fri Aug 26 2011 fcrozat@suse.com
- Update compose_table patch to use two separate loadkeys call,
  compose table overflows otherwise (spotted by Werner Fink).
* Wed Aug 24 2011 fcrozat@novell.com
- Add tty1.patch: ensure passphrase are handled before starting
  gettty on tty1.
- Add inittab generator, creating default.target at startup based
  on /etc/inittab value.
- No longer try to create /etc/systemd/system/default.target at
  initial package install (bnc#707418)
- Fix configuration path used for systemd user manager.
- Ensure pam-config output is no display in install script.
- Remove buildrequires on vala, no longer needed.
* Fri Aug 19 2011 fcrozat@suse.com
- Handle disable_capslock, compose table and kbd_rate
- Add rpm macros.systemd file.
- Do not disable klogd, it has its own service now.
- Handle kexec correctly (bnc#671673).
- Disable preload services, they are conflicting with systemd.
* Fri Aug 19 2011 fcrozat@suse.com
- enable pam_systemd module, using pam-config.
* Thu Aug 18 2011 aj@suse.de
- Fix crash with systemctl enable.
* Tue Aug 16 2011 fcrozat@suse.com
- Fix localfs.service to no cause cycle and starts it after
  local-fs.target.
* Thu Aug  4 2011 fcrozat@suse.com
- Remove root-fsck.patch, mkinitrd will use the same path as
  dracut.
- Add systemd-cryptsetup.patch: don't complain on "none" option in
  crypttab.
- Add systemd-cryptsetup-query.patch: block boot until passphrase
  is typed.
* Wed Aug  3 2011 fcrozat@suse.com
- Add root-fsck.patch: do not run fsck on / if it is rw
- Ship a non null localfs.service, fixes static mount points not
  being mounted properly.
* Wed Aug  3 2011 aj@suse.de
- Update to version 33:
  * optimizations and bugfixes.
  * New PrivateNetwork= service setting which allows you to shut off
    networking for a specific service (i.e. all routable network
    interfaces will disappear for that service).
  * Merged insserv-parsing.patch and bash-completion-restart.patch
    patches.
* Tue Aug  2 2011 fcrozat@suse.com
- Add insserv-parsing.patch: read/parse insserv.conf.
- Add bash-completion-restart.patch: fix restart service list
  (bnc#704782).
* Mon Aug  1 2011 aj@suse.de
- Split up devel package.
- restart logind after upgrade.
- Adjust rpmlintrc for changes.
* Fri Jul 29 2011 aj@suse.de
- Update to version 32:
  * bugfixes
  * improve selinux setup
* Thu Jul 28 2011 aj@suse.de
- Update to version 31:
  * rewrite of enable/disable code: New features systemctl --runtime,
    systemctl mask, systemctl link and presets.
  * sd-daemon is now shared library.
* Tue Jul 19 2011 aj@suse.de
- Update to version 30:
  + Logic from pam_systemd has been moved to new systemd-login.
  + VT gettys are autospawn only when needed
  + Handle boot.local/halt.local on SUSE distribution
  + add support for systemctl --root
* Wed Jun 29 2011 fcrozat@suse.com
- Make sure to not start kbd initscript, it is handled by systemd
  natively.
* Fri Jun 17 2011 fcrozat@novell.com
- version 29:
  + enable chkconfig support in systemctl for openSUSE.
  + systemctl: plug a leak upon create_symlink mismatch
  + mount /run without MS_NOEXEC
  + dbus: fix name of capability property
  + systemctl: fix double unref of a dbus message
  + cryptsetup-generator: fix /etc/cryptsetup options
  + selinux: selinuxfs can be mounted on /sys/fs/selinux
  + readahead-common: fix total memory size detection
  + systemctl: fix 'is-enabled' for native units under /lib
  + systemctl: fix a FILE* leak
  + pam-module: add debug= parameter
  + remote-fs.target: do not order after network.target
- update tarball url.
* Wed Jun 15 2011 saschpe@suse.de
- Use RPM macros instead of $RPM_FOO variables
- Don't require %%{version}-%%{release} of the base package,
  %%{version} is sufficient
* Tue Jun 14 2011 kay.sievers@novell.com
- new snapshot
  - mount /run without MS_NOEXEC
  - readahead-common: fix total memory size detection
  - enable chkconfig support in systemctl for openSUSE
  - selinux: selinuxfs can be mounted on /sys/fs/selinux
  - cryptsetup-generator: fix /etc/cryptsetup options
  - systemctl: fix double unref of a dbus message
- drop merged chkconfig patch
* Tue Jun 14 2011 fcrozat@novell.com
- Add sysv chkconfig patch to be able to enable / disable sysv
  initscripts with systemctl.
- Ensure plymouth support is buildable conditionnally.
* Thu May 26 2011 kay.sievers@novell.com
- version 28
  - drop hwclock-save.service
  - fix segfault when a DBus message has no interface
  - man: update the list of unit search locations
  - readahead-collect: ignore EACCES for fanotify
  - rtc in localtime: use settimeofday(NULL, tz)
    instead of hwclock(8)
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - fix crash in D-Bus code
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - socket: always use SO_{RCV,SND}BUFFORCE to allow larger values
  - util: use new VT ESC sequence to clear scrollback buffer
  - sd-daemon: move _sd_hidden_ from .h to .c file
  - missing: add IP_TRANSPARENT
* Sat May 21 2011 kay.sievers@novell.com
- version 27
  - util: use open_terminal() in chvt() too
  - socket: expose SO_BROADCAST
  - git: add .mailmap
  - exec: expose tty reset options in dbus introspection data
  - socket: expose IP_TRANSPARENT
  - exec: hangup/reset/deallocate VTs in gettys
  - socket: use 666 socket mode by default since neither fifos,
    nor sockets, nor mqueues need to be executable
  - socket: add POSIX mqueue support
  - README: document relation to nss-myhostname
  - hostnamed: check that nss-myhostname is installed
* Tue May 17 2011 kay.sievers@novell.com
- new snapshot
  - sysctl: apply /etc/sysctl.conf last
  - systemd-analyze: print hostname, kernelversion and arch at
    the top of the plot
  - pam: downgrade a few log msgs
  - hostnamed: SetPrettyHostname() should check PK action
    org.freedesktop.hostname1.set-static-hostname
  - user-sessions: ignore EROFS when unlinking /etc/nologin if
    the file doesn't exist anyway
  - unit: make ignoring in snapshots a per unit property,
    instead of a per unit type property
  - vconsole: use open_terminal() instead of open()
  - units: enable automount units only if the kernel supports them
* Thu May  5 2011 coolo@opensuse.org
- remove policy filter
* Thu May  5 2011 meissner@suse.de
- add missing buildrequires dbus-1-devel, vala, libxslt-devel
- touch vala files for rebuilding to unbreak Factory
* Mon May  2 2011 kay.sievers@novell.com
- also delete plymouth files
* Mon May  2 2011 kay.sievers@novell.com
- disable plymouth sub-package until plymouth gets into Factory
* Sun May  1 2011 kay.sievers@novell.com
- new snapshot
  - binfmt, modules-load, sysctl, tmpfiles: add missing
    ConditionDirectoryNotEmpty=
  - binfmt, modules-load, sysctl, tmpfiles: read /usr/local/lib
    and where appropriate /lib directories
* Sat Apr 30 2011 kay.sievers@novell.com
- version 26
  - plymouth: introduce plymouth.enable=0 kernel command line
  - util: don't AND cx with cx
  - man: typo in sd_daemon reference
  - util: conf_files_list() return list as parameter
  - dbus: make daemon reexecution synchronous
* Thu Apr 28 2011 kay.sievers@novell.com
- new snapshot
  - service: properly notice when services with a main process
    that isn't a child of init die
  - unit: fix assert when trying to load unit instances for
    uninstanciable types
  - def: lower default timeout to 90s
  - manager: fix serialization counter
* Wed Apr 27 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't hit assert when dumping properties
  - cryptsetup: fix keyfile size option processing
  - socket: improve warning message when we get POLLHUP
  - mount: failure to mount cgroup hierarchies should not be fatal
  - configure: add AC_SYS_LARGEFILE
* Mon Apr 25 2011 kay.sievers@novell.com
- new snapshot
  - tmpfiles.d: switch to stacked config dirs in /lib, /etc, /run
  - sysctl.d, binfmt.d, modules-load.d: switch to stacked config
    dirs in /lib, /etc, /run
  - manager: mkdir /run/systemd/system when starting up
  - man: Spelling fixes
* Thu Apr 21 2011 kay.sievers@novell.com
- version 25
  - mount: Allow creating mount units for /var/lib/nfs/rpc_pipefs
    and /proc/fs/nfsd.
  - socket: support ListeSpecial= sockets
  - vconsole: don't set console font/keymap if settings are empty
  - nspawn: don't fail when we receive SIGCHLD
  - cgroup: don't accidentaly trim on reload
  - units: set capability bounding set for syslog services
  - socket: log more information about invalid poll events
  - man: fix specification of default timeouts
  - mount,crypto: rework meaning of noauto/nofail
  - fsck: don't fsck against basic.target in order to properly
    allow automount /home
  - manager: when running in test mode, do not write generated
    unit files to /run/systemd/generator
  - mount: properly parse timeouts options in the middle of
    the string
  - hostnamed: drop all caps but CAP_SYS_ADMIN
  - execute: when we run as PID 1 the kernel doesn't give us
    CAP_SETPCAP by default. Get that temporarily when dropping
    capabilities for good
  - mount: make device timeout configurable
  - cryptsetup: do not order crypto DM devices against the
    cryptsetup service
  - socket: reuse existing FIFOs
  - socket: guarantee order in which sockets are passed to be
    the one of the configuration file
  - systemctl: always consider unit files with no
    [Install] section but stored in /lib enabled
  - job: also print status messages when we successfully started
    a unit
  - hostnamed: add reference to SMBIOS specs
  - man: runlevel 5 is usually more comprehensive, so use it
    instead of 3 to detect whether a sysv service is enabled
  - polkit: follow the usual syntax for polkit actions
  - hostnamed: introduce systemd-hostnamed
  - units: order quotacheck after remount-rootfs
  - hostname: split out hostname validation into util.c
  - dbus: split out object management code into dbus-common,
    and simplify it
  - strv: properly override settings in env_append()
  - strv: detect non-assignments in env blocks properly in
    env_append()
  - strv: handle empty lists in strv_copy() properly
  - util: truncate newline inside of read_one_line_file()
  - util: modernize get_parent_of_pid() a bit
  - crypto: let the cryptsetup binary handles its own
    configurable timeouts
  - logger,initctl: use global exit timeout
  - ask-password: use default timeout
  - manager: drop all pending jobs when isolating
  - manager: introduce IgnoreOnIsolate flag so that we can keep
    systemd-logger around when isolating
  - units: never pull in sysinit from utmp, so that we can
    shutdown from emergency mode without pulling in sysinit
  - manager: downgrade a few log messages
  - units: require syslog.socket from the logger because we
    simply fail if we don't have it
  - logger: adjust socket description to match service
  - units: set stdout of kmsg syslogd to /dev/null
  - units: add --no-block when starting normal service after
    shell exited
  - ask-password: use kill(PID, 0) before querying a password
  - ask-password: support passwords without timeouts
  - ask-password: always send final NUL char
  - ask-password: properly accept empty passwords from agent
  - unit: skip default cgroup setup if we have no hierarchy
  - units: isolate emergency.target instead of emergency.service
    when we fail to mount all file systems
  - mount: don't pull in stdio logger for root mount unit
  - cgroup: be nice to Ingo Molnar
  - pam: use /proc/self/sessionid only with CAP_AUDIT_CONTROL
  - pam: use /proc/self/loginuid only with CAP_AUDIT_CONTROL
  - socket: try creating a socket under our own identity if we
    have no perms to consult the selinux database
  - socket: fix check for SEQPACKET
  - execute: don't fail if we cannot fix OOM in a container
  - unit: fix dump output
  - socket: be a bit more verbose when refusing to start a
    socket unit
  - socket: support netlink sockets
  - local-fs: invoke emergency.service mounting at boot fails
  - path: optionally, create watched directories in .path units
  - tmpfiles: don't warn if two identical lines are configured
  - man: add man page for ask-password
  - dbus: expose monotonic timestamps on the bus
  - manager: no need to use randomized generator dir when running
    as system manager
  - don't make up buffer sizes, use standard LINE_MAX instead
  - unit: disallow configuration of more than one on_failure
    dependencies if OnFailureIsolate= is on
  - unit: pull in logger unit only when running in system mode
  - manager: serialize/deserialize max job id and /usr taint flag
  - manager: don't garbage collect jobs when isolating, to change
    global state
  - unit: introduce OnFailureIsolate=
  - mount: relabel both before and after a mount, just in case
  - cmdline: we actually want to parse the kernel cmdline in VMs,
    just not in containers
  - units: rename rtc-set.target to time-sync.target and pull it
    in by hwclock-load.service
  - job: fix deserialization of jobs: do not ignore ordering
  - systemctl: properly parse JobNew signals
  - service: fix units with more than one socket
  - systemctl: make most operations NOPs in a chroot
  - manager: don't show PID for incoming signals if it is 0
  - man: fix description of systemctl reload-or-try-restart
  - mount: block creation of mount units for API file systems
  - units: call the logger a bridge too
  - build-sys: always place user units in /usr/lib/systemd
  - pkgconfig: update .pc file accordingly
  - lookup: always also look into /usr/lib for units
  - exec: support unlimited resources
  - selinux: relabel /run the same way as /dev after loading
    the policy since they both come pre-filled and unlabelled
  - manager: fd must be int, not char
  - change remaining /var/run to /run
  - units: move user units from /usr/share to /usr/lib since
    they might be arch-dependent
  - man: document /etc/sysctl.d/
  - binfmt: add binfmt tool to set up binfmt_misc at boot
  - tmpfiles: create leading directories for d/D instructions
  - condition: add ConditionSecurity
  - load-fragment: unify config_parse_condition_{kernel, virt}
  - condition: fix dumping of conditions
  - initctl: /dev/initctl is a named pipe, not a socket
  - kmsg-syslogd: pass facility value into kmsg
  - move /var/lock to HAVE_SYSV_COMPAT
  - tmpfiles: split off rules for legacy systems into legacy.conf
  - general: replace a few uses of /var/run by /run
  - tmpfiles: enforce new /var/lock semantics
  - man: document ConditionPathIsDirectory=
  - mount: also relabel pre-mounted API dirs
  - log: don't strip facility when writing to kmsg
  - build-sys: create a number of drop-in config dirs
  - random: do not print warning if random seed doesn't exist
  - plymouth: use PID file to detect whether ply is running
  - build-sys: install systemd-analyze by default
  - analyze: improve output
  - analyze: add plotter
  - unit: when deserializing do reconnect to dbus/syslog when
    they show up
  - analyze: beautify output a bit
  - add systemd-analyze tool
  - unit: don't override timestamps due to state changes when
    deserializing
  - plymouth: don't explicitly enable status message when
    plymouth is up
  - status: show status messages unconditionally if plymouth
    is around
  - taint: add missing cgroups taint flag
  - locale: don't access misinitialized variable
  - quota: do not pull in quota tools for mounts that do not
    originate in neither /etc/fstab nor fragment files
  - manager: fix taint check for /usr
  - unit: never apply /etc/rcN.d/ priority to native services
  - unit: fix parsing of condition-result
  - unit: don't complain about failed units when deserializing
  - exec: drop process group kill mode since it has little use
    and confuses the user
  - cgroup: explain when we cannot initialize the cgroup stuff
  - systemctl: don't truncate description when using pager
  - ask-password: also accept Backspace as first keypress as
    silent mode switch
  - unit: when deserializing jobs, don't pull in dependencies
  - locale: fix LC_MESSAGES variable name
  - plymouth: Remove the calls to plymouth message
  - udev: systemd-tag all ttys
  - tmpfiles fix /run/lock permissions
  - ask-password: use TAB to disable asterisk password echo
  - execute: socket isn't abstract anymore
  - use /run instead of /dev/.run
  - man: explain a couple of default dependencies
  - mount: pull in quota services from local mountpoints with
    usr/grpquota options
  - service: pull in sysv facility targets from the sysv units,
    not the other way round
  - units: pull in syslog.target from syslog.socket
  - units: don't ever pull in SysV targets from other SysV
    targets
  - units: document that some targets exists only for compat
    with SysV
  - man: document pidns containers
  - units: deemphesize Names= settings, and explain why nobody
    whould use them
  - units: on mandriva/fedora create single.service alias via
    symlink, not Names=
  - units: get rid of runlevel Names=, the symlinks in
    /lib/systemd/system are much more useful
  - rework syslog detection so that we need no compile-time
    option what the name of the syslog implementation is
  - man: document .requires/ directories
  - special: get rid of dbus.target
  - exec: properly apply capability bounding set, add inverted
    bounding sets
  - dbus: add service D-Bus property "Sockets"
  - dbus: consolidate service SysV conditionals
  - unit: serialize condition test results
  - def: centralize definition of default timeout in one place
  - chkconfig: check against runlevel 5 instead of 3, since it is
    a superset of the latter
  - systemctl: accept condstop as alias for stop
  - dbus: allow LoadUnit to unprivileged users
  - umount: make sure skip_ro is always correctly initialized
- create /run (link it to /var/run)
- refresh splash password patch
- conflict with old mkinitrd version (we need /run)
- conflict with old udev (we need /run)
* Wed Mar 16 2011 kay.sievers@novell.com
- new snapshot
  - man: fix systemctl try-restart description
  - Add Frugalware display-manager service
  - main: revert recognition of "b" argument
  - main: interpret all argv[] arguments unconditionally when
    run in a container
  - loopback: downgrade an error to warning
  - nspawn: bind mount /etc/localtime
  - nspawn: make tty code more robust against closed/reopened
    /dev/console
  - util: make touched files non-writable by default
  - nspawn: allocate a new pty instead of passing ours through
    to avoid terminal settings chaos
  - main: parse the whole arv[] as kernel command line
  - main: check if we have a valid PID before getting the name
  - ask-password: reset signal mask after we are done
  - cgroup: don't recheck all the time whether the systemd
    hierarchy is mounted, to make strace outputs nicer and save
    a few stat()s
  - man: document systemd-nspawn
  - cgls: don't strip user processes and kernel threads from
    default output
  - umount: don't try to remount bind mounts ro during shutdown
  - getty: move automatic serial getty logic into generator
  - container: skip a few things when we are run in a container
    such as accessing /proc/cmdline
  - cgls: by default start with group of PID 1
  - pam: determine user cgroup tree from cgroup of PID 1
  - nspawn: move container into its own name=systemd cgroup
  - manager: don't show kernel boot-up time for containers
  - manager: show who killed us
  - units: add console-shell.service which can be used insted of
    the gettys to get a shell on /dev/console
* Mon Mar 14 2011 kay.sievers@novell.com
- new snapshot
  - build-sys: move remaining tools from sbin/ to bin/ since they
    might eventually be useful for user execution
  - hostname: don't override the hostname with localhost if it
    is already set and /etc/hostname unset
  - audit: give up sending auditing messages when it failed due
    to EPERM
  - nspawn: don't require selinux on if it is compiled in
  - main: remove AF_UNIX sockets before binding
  - shutdown: print a nice message when terminating a container
  - nspawn: mount /selinux if needed
  - shutdown: just call exit() if we are in a container
  - umount: assume that a non-existing /dev/loop device means it
    is already detached
  - socket: use 777 as default mode for sockets
  - main: log to the console in a container
  - main: don't parse /proc/cmdline in containers
  - util: add detect_container()
  - nspawn: reset environment and load login shell
  - core: move abstract namespace sockets to /dev/.run
  - nspawn: add simple chroot(1) like tool to execute commands
    in a namespace container
  - util: return exit status in wait_for_terminate_and_warn()
  - util: properly identify pty devices by their major
* Sat Mar 12 2011 kay.sievers@novell.com
- new snapshot
  - polkit: autogenerate polkit policy with correct paths
  - systemctl: support remote and privileged systemctl access
    via SSH and pkexec
  - gnome-ask-password-agent: fix path to watch
* Fri Mar 11 2011 kay.sievers@novell.com
- fix broken sysctl.service linking
* Fri Mar 11 2011 kay.sievers@novell.com
- new snapshot
  - units: move the last flag files to /dev/.run
  - util: close all fds before freezing execution
  - dbus: timeout connection setup
  - main: properly handle -b boot option
  - pam: do not leak file descriptor if flock fails
- disable sysv services natively provided by systemd
* Thu Mar 10 2011 kay.sievers@novell.com
- new snapshot
  - main: refuse system to be started in a chroot
  - main: don't check if /usr really is a mount point, since it is
    fine if it is passed pre-mounted to us from the initrd
  - condition: take a timestamp and store last result of conditions
  - dev: use /dev/.run/systemd as runtime directory, instead of
    /dev/.systemd
  - machine-id: move machine-id-setup to /sbin
  - pkconfig: export full search path as .pc variable
  - selinux: bump up error level when in non-enforcing mode
  - dbus: fix dbus assert due to uninitialized error
  - dbus: properly generate UnknownInterface, UnknownProperty
    and PropertyReadOnly errors
  - mount: use /dev/.run as an early boot alias for /var/run
* Tue Mar  8 2011 kay.sievers@novell.com
- version 20
  - service: prefix description with LSB only if script has LSB header,
    use 'SysV:' otherwise
  - unit: don't accidently create ordering links to targets when
    default deps are off for either target and unit
  - mount: support less cumbersome x-systemd-xxx mount options
  - unit: distuingish mandatory from triggering conditions
  - dbus: return DBUS_ERROR_UNKNOWN_OBJECT when an object
    is unknown
  - systemctl: when forwarding is-enabled to chkconfig
    hardcode runlevel 3
  - job: introduce new job result code 'skipped' to use when pre
    conditions of job did not apply
  - job: convert job type as early as we can, to simplify things
  - Keep emacs configuration in one configuration file.
  - syslog: make sure the kmsg bridge is always pulled in and
    never terminated automatically
  - mount: make /media a tmpfs
* Mon Mar  7 2011 kay.sievers@novell.com
- new snapshot
  - add org.freedesktop.DBus.Properies.Set method
  - main: introduce /etc/machine-id
  - systemctl: fix exit code when directing is-enabled
    to chkconfig
  - dbus: add 'Tainted' property to Manager object
  - dbus: expose distribution name and features on manager
    object as properties
  - man: document changed EnvironmentFile= behaviour
  - main: add link to wiki page with longer explanation of the
    /usr madness
  - execute: load environment files at time of execution, not
    when we load the service configuration
  - path: after installing inotify watches, recheck file again
    to fix race
  - path: don't use IN_ATTRIB on parent dirs when watching a
    file, since those cannot be removed without emptying the dir
    first anyway and we need IN_ATTRIB only to detect the link
    count dropping to 0
  - kill: always send SIGCONT after SIGTERM
  - readahead: disable collector automatically on read-only media
  - sysctl: use scandir() instead of nftw() to guarantee
    systematic ordering
  - support DT_UNKNOWN where necessary for compat with reiserfs
  - systemctl: always null-terminate the password
- call systemd-machine-id-setup at installation
* Tue Mar  1 2011 kay.sievers@novell.com
- version 19
  - udev: don't ignore non-encrypted block devices with no
    superblock
  - udev: expose ttyUSB devices too
  - udev: mark hvc devices for exposure in systemd
  - cryptsetup: add a terse help
  - agent: don't print warnings if a password was removed or
    timed out
  - systemctl: shutdown agent explicitly so that it can reset
    the tty properly
  - never clean up a service that still has a process in it
  - label: udev might be making changes in /dev while we
    iterate through it
  - systemctl: properly handle job results
  - job: also trigger on-failure dependencies when jobs faile
    due to dependencies, timeout
  - job: when cancelling jobs, make sure to propagate this
    properly to depending jobs
  - job: start job timeout on enqueuing not when we start to
    process a job
  - unit: increase default timeout to 3min
  - logger: leave the logger longer around and allow it do
    handle more connections
  - dbus: pass along information why a job failed when it
    failed (dbus api change!)
  - general: unify error code we generate on timeout
  - units: synchronize gettys to plymouth even if plymouth is
    killed by gdm
  - job: start job timer when we begin running the job, not
    already when we add it to the queue of jobs
  - cryptsetup: try to show the mount point for a crypto disk
    if we can
  - rescue: terminate plymouth entirely when going into
    rescue mode
  - ask-password: fix handling of timeouts when waiting
    for password
  - ask-password: supported plymouth cached passwords
  - main: print warning if /usr is on a seperate partition
  - ensure we start not a single getty before plymouth is
    gone because we never know which ttys plymouth still controls
  - unit: introduce ConditionVirtualization=
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't rely that timer/path units have an initialized
    unit field (bnc#671561)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - order network mounts after network.target (bnc#672855)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - kmsg-syslogd: increase terminate timeout to 5min to generte
    less debug spew
  - shutdown(8) - call kexec if kexec kernel is loaded (bnc#671673)
  - unit: don't timeout fsck
  - man: fixed typo in SyslogIdentifier=
  - tmpfiles: never clean up block devices
  - main: refuse --test as root
* Fri Feb 18 2011 kay.sievers@novell.com
- new snapshot
  - units: order fsck@.service before basic.target
    instead of local-fs.target to relax things a little
  - readahead: remove misleading error messages
  - man: don't do more reloads than necessary in spec files
  - util: retry opening a TTY on EIO
  - util: beef up logic to find ctty name
  - tmpfiles: kill double slashes in unix socket names
- drop vhangup patch, it is fixed in login(3) by forwarding the
  SIGHUP to the child process
* Fri Feb 18 2011 coolo@novell.com
- revert back to conflicts: sysvinit
* Thu Feb 17 2011 werner@suse.de
- Add temporary workaround for bnc#652633, that is do a vhangup
  to all processes on a tty line used for a getty
* Wed Feb 16 2011 kay.sievers@novell.com
- version 18
  - systemctl: introduce --ignore-dependencies
  - systemctl: introduce --failed to show only failed services
  - systemctl: introduce --failed to show only failed services
  - rescue: make 'systemctl default' fail if there is already
    something running when the shell exited
  - util: seperate welcome line from other output by empty lines
  - manager: don't consider transaction jobs conflicting with
    queued jobs redundant
  - udev: ignore block devices which no known contents, to avoid
    trying of mounts/swapons when devices aren't set up full yet
  - swap: handle "nofail" from fstab
  - mount,swap: properly add dependencies to logger if needed
  - service: change default std output to inherit
  - exec: introduce global defaults for the standard output
    of services
  - udev: use SYSTEMD_READY to mask uninitialized DM devices
  - fsck: output to /dev/console by default in addition to syslog
  - execute: optionally forward program output to /dev/console in
    addition to syslog/kmsg
  - socket: refuse socket activation for SysV services
  - fsck: do not fail boot if fsck returns with an error code that
    hasn't 2 or 6 set
  - shutdown: execute all binaries in /lib/systemd/system-shutdown
    as last step before invoking reboot()
  - job: make status message printing more verbose
  - cryptsetup: fix unit file description
  - tmpfiles: never delete AF_UNIX sockets that are alive
  - getty: don't parse console= anymore, use
    /sys/class/tty/console/active instead
  - properly resolve /dev/console if more than once console=
    argument was passed on the kernel command line
  - getty: do not auto-spawn getty's on VC ttys if console=ttyN
  - fsck: skip root fsck if dracut already did it
  - util: when determining the right TERM for /dev/console
    consult /sys/class/tty/console/active
  - pam: introduce whitelist and blacklist user list feature
  - systemctl: minor optimizations
  - systemctl: don't unnecessarily close stdin/stdout/stderr for
    tty agent so that locking by tty works
  - readahead: disable readahead in virtual machines
  - tmpfiles: move binary to /bin to make it publicly available
  - tmpfiles: take names of tmpfiles configuration files on the
    command line
  - tmpfiles: log to stderr if possible
  - tmpfiles: support globs
  - units: introduce and hook up sound.target
  - dbus: allow all clients access to org.freedesktop.DBus.Peer
  - consider udev devices with SYSTEMD_READY=0 as unplugged
  - systemctl: don't start agent for --user
  - systemctl: make sure the tty agent does not retain a copy
    of stdio
* Tue Feb  8 2011 kay.sievers@novell.com
- new snapshot
  - plymouth: move plymouth out of TARGET_FEDORA
  - build-sys: fix AC_COMPILE_IFELSE tests
  - build-sys: ensure selinux configure check follows logic of
    other optional features
  - build-sys: autodetect and use pkg-config for libselinux
  - dbus: use ControlGroup as property name to match config option
  - pam: optionally reset cgroup memberships for login sessions
  - load-fragment: properly parse Nice= value
  - automount: use unit_pending_inactive() where appropriate
* Tue Feb  8 2011 jeffm@suse.de
- Removed unecessary workaround for plymouth startup.
* Fri Feb  4 2011 jeffm@suse.de
- Split plymouth support into systemd-plymouth package.
* Sat Jan 22 2011 kay.sievers@novell.com
- new snapshot
  - clang: fix some issues found with clang-analyzer
  - gcc: make gcc shut up
* Sat Jan 22 2011 kay.sievers@novell.com
- version 17
  - vala 0.10 seem to work fine
  - cryptsetup: fix ordering loop when dealing with encrypted
    swap devices
  - main: don't warn if /etc/mtab is a symlink to /proc/mounts
  - socket: don't crash if the .service unit for a .socket unit
    is not found
  - mount: ignore if an fsck is requested for a bind mount,
    so that we don't wait for the bind 'device' to show up
  - automount: fix segfault when shutting down
  - man: give an example for vconsole.conf
  - dbus: don't try to connect to the system bus before it is
    actually up
  - service: make chain of main commands and control commands
    independent of each other, so that both can be executed
    simultaneously and independently
  - service: don't allow reload operations for oneshot services
  - vala: convert from dbus-glib to gdbus
  - systemctl: highlight failed processes in systemctl status
  - systemctl: show process type along process exit codes
  - service: when reloading a service fails don't fail the entire
    service but just the reload job
* Wed Jan 19 2011 kay.sievers@novell.com
- new snapshot
  - shutdown: use correct kexec options
  - serial-getty: do not invoke /sbin/securetty; recent
    pam_securetty looks for console= in /proc/cmdline
  - systemctl: before spawning pager cache number of columns
  - pam: optionally keep processes of root user around
  - service: if a reload operation fails, don't shut down
    the service
  - execute: make sending of SIGKILL on shutdown optional
  - mount: do not translate uuids to lowercase
  - man: document missing KillSignal= and swap options
- require recent util-linux
- drop mtab symlink creation which is done in util-linux
* Sat Jan  8 2011 kay.sievers@novell.com
- version 16
  - device: don't warn if we cannot bump the udev socket buffer
  - logger: when passing on PID info, fall back to our own if
    originating process is already gone
  - service: don't hit an assert if information in LSB headers is
    incorrectly formatted
  - execute,util: fix two small memory leaks
  - getty: unset locale before execution
  - execute: drop empty assignments from env blocks on execution
    but keep them around otherwise to make them visible
  - umount: don't try to detach the dm device the root dir is on,
    to minimize warning messages
  - locale: fix variable names
  - fragment: allow prefixing of the EnvironmentFile=
    path with - to ignore errors
  - util: don't pass invalid fd to fdopendir() on error to avoid
    corruption of errno
  - tmpfiles: nicer message when two or more conflicting lines
    are configured for the same file
  - fragment: properly handle quotes in assignments in
    EnvironmentFile= files
  - sysctl: don't warn if sysctls are gone
  - readahead: ignore if files are removed during collection or
    before replay
  - serial: use TERM=vt100 instead of TERM=vt100-nav
  - cryptsetup: call mkswap on dm device, not on source device
  - mount-setup: mount /dev/pts with mode=620,gid=5 by default
    and make GID overridable via configure switch
  - systemctl: implement auto-pager a la git
  - shutdown: drop redundant sync() invocation
  - util: invoke sync() implicitly on freeze()
  - tmpfiles: do no follow symlinks when cleaning up dirs
* Tue Dec 28 2010 jeffm@suse.de
- Add support for building plymouth support with openSUSE
* Mon Dec 27 2010 kay.sievers@novell.com
- new snapshot
  - pam: do not sort user sessions into their own cgroups in
    the 'cpu' hierarchy
  - mount-setup: drop noexec flag from default mount options
    for /dev/shm
  - systemd.pc: change 'session' to 'user'
* Thu Dec 16 2010 kay.sievers@novell.com
- new snapshot
  - ifdef suse-only sysv script lookup code
* Thu Dec 16 2010 seife@opensuse.org
- add bootsplash handling patch to be able to enter e.g.
  crypto passphrases (bnc#659885)
* Thu Dec  9 2010 kay.sievers@novell.com
- new snapshot
  - add LSB 'smtp' alias for mail-transport-agent.target
* Wed Dec  8 2010 kay.sievers@novell.com
- new snapshot
  - path: fix watching the root directory
  - update README
* Fri Nov 26 2010 kay.sievers@novell.com
- new snapshot
  - gnome-ask-password-agent: also support libnotify < 0.7 for now
  - udev: increase event buffer size
- require fsck -l
* Thu Nov 25 2010 kay.sievers@novell.com
- version 15
  - dbus: use the right data slot allocator
  - manager: bump up max number of units to 128K
  - build-sys: allow cross-compilation
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Tue Nov 23 2010 kay.sievers@novell.com
- new snapshot
  - units: simplify shutdown scripts
  - logger: fix error handling
  - swap: order file-based swap devices after remount-rootfs
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Mon Nov 22 2010 kay.sievers@novell.com
- new snapshot
  - systemctl: don't return LSB status error codes for 'show'
  - mount: do not try to mount disabled cgroup controllers
  - man: document /etc/modules-load.d/, /etc/os-release,
    locale.conf, /etc/vconsole.conf, /etc/hostname
  - units: move a couple of units from base.target to
    sysinit.target
  - man: reorder things to follow the same order everywhere
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Sat Nov 20 2010 kay.sievers@novell.com
- version 13
  - cryptsetup: actually show disk name
  - cryptsetup: show udev device name when asking for password
  - sysctl: implement native tool and support /etc/sysctl.d
  - units: enable console ask-password agent by default
  - introduce /etc/os-release distro description
  - job: make sure we don't fail umount.target if a mount unit
    failed to stop
  - cgroup: after killing cgroup processes, ensure the group is
    really dead gone. wait for 3s at max
  - cgroup: if we couldn't remove a cgroup after killing
    evertyhing in it then it's fine
  - cryptsetup: automatically order crypt partitions before
    cryptsetup.target
  - man: trivial BindTo description fix
  - manager: make list of default controllers configurable
  - build: expose libcryptsetup dependency in build string
  - pam: document controllers= switch
  - cgroup: by default, duplicate service cgroup in the cpu hierarchy
  - pam: duplicate cgroup tree in the cpu hierarchy by default,
    optionally more
- enable native crypto handling instead of boot.crypto
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Wed Nov 17 2010 kay.sievers@novell.com
- version 12
  - ask-password: add --console mode to ask /dev/console
- revert too new libnotify code/requirement
* Tue Nov 16 2010 kay.sievers@novell.com
- new snapshot
  - cryptsetup: reword questions a little
  - units: order hwclock after readahead
  - path: don't mention too many inotify msgs
  - cryptsetup: include device name in password question
  - cryptsetup: lock ourselves into memory as long as we deal
    with passwords
  - plymouth: use updated socket name
  - units: set TERM for gettys again, since they acquire a TTY
  - units: allow start-up of plymouth ask-password agent very early
  - units: enable ask-paswword .path units early enough to be useful
    for early mounts
  - units: delay getty until logins are allowed
  - pam: always rely on loginuid instead of uid to determine cgroup
    and XDG_RUNTIME_DIR name
  - cgroup: call root cgroup system instead of systemd-1
  - exec: determine right TERM= setting based on tty name
  - pam: rename master user cgroup to 'master'
  - drop support for MANAGER_SESSION, introduce MANAGER_USER
  - units: use ConditionDirectoryNotEmpty= where applicable
  - unit: introduce ConditionDirectoryNotEmpty=
  - delete tmp.mount which may conflict with an unrelated fstab
    entry
- revert too new libnotify code/requirement
- disable native crypto handling
* Mon Nov 15 2010 kay.sievers@novell.com
- new snapshot
  - load-dropin: add support for .requires directories
  - manager: consider jobs already installed as redundant when
    reducing new transactions
  - manager: always pull 'following' units into transaction
  - util: always highlight distro name
  - units: make use of agetty mandatory
  - manager: don't fail transaction if adding CONFLICTED_BY job fails
  - job: make it possible to wait for devices to be unplugged
  - tmpfiles: ignore files marked with the sticky bit
  - cryptsetup: handle password=none properly
  - cryptsetup: properly parse cipher= switch
  - cryptsetup: support non-LUKS crypto partitions
  - ask-password: enable password agent
  - automatically start cryptsetup when looking for mount source
  - log: add automatic log target
  - cryptsetup: hook up tool with ask-password
  - manager: hookup generators
  - split mount_point_is_api() and mount_point_ignore()
- replace boot.crypto job with systemd native crypto handling
- enable readahead (requires 2.6.37+ kernel's fanotify to work)
* Thu Nov 11 2010 kay.sievers@novell.com
- new snapshot
  - tmpfiles: include reference to man page in tmpfiles files
  - vconsole: support additional keymap for toggling layouts
  - main: warn if /etc/mtab is not a symlink
  - add bash completion for systemctl --system
  - man: minor tmpfiles(5) updates and reindenting
  - main: rename process on startup to 'systemd' to avoid confusion
  - unit: add ConditionNull= condition
  - ac-power: make ac-power a proper binary that scripts can call
  - manager: parse RD_TIMESTAMP passed from initrd
  - modules-load: fix minor race
  - label: use internal utility functions wher epossible
  - cryptsetup: minimal cryptsetup unit generator
  - selinux: relabel /dev after loading policy
  - log: downgrade syslog connection failure message
  - service: delay automatic restart if job is pending
  - manager: when isolating undo all pending jobs, too
  - manager: only minimize impact if we are in fail mode
- replace /etc/mtab with link to /proc/self/mounts
* Thu Nov  4 2010 kay.sievers@novell.com
- new snapshot
  - man/tmpfiles.d.xml: add a manpage for tmpfiles
  - do not overwrite other udev tags
  - readahead: shortcut replay if /.readahead doesn't exist
* Fri Oct 29 2010 kay.sievers@novell.com
- new snapshot
  - fsck: return SUCCESS when we skip the check
  - fsck: skip checking / if it is writable
  - units: fix variable expansion
  - mount: don't pull in nofail mounts by default, but use them
    if they are around
  - job: recursively fail BoundBy dependencies
  - fsck: fix target name to check for
  - units: rename fedora/single.service to rescue.service
  - units: introduce plymouth-start and plymouth-kexec
  - unit: get rid of IgnoreDependencyFailure=
  - use util-linux:agetty instead of mingetty
  - unit: replace StopRetroactively= by BindTo= dependencies
  - automount: show who's triggering an automount
  - units: run sysctl only if /etc/sysctl.conf exists
  - systemctl: always show what and where for mount units
  - shutdown: reword a few messages a little
  - manager: show which jobs are actually installed after a transaction
  - timer: when deserializing timer state stay elapsed
  - device: set recursive_stop=true by default
  - unit: suppress incorrect deserialization errors
  - swap: there's no reason not order swap after sysinit
  - socket: fix IPv6 availability detection
* Wed Oct 27 2010 kay.sievers@novell.com
- new snapshot
  - create /dev/stderr and friends early on boot
  - run sysv related scripts with TERM=linux
  - add only swaps listed in /etc/fstab automatically to swap.target
  - errors: refer to systemctl status when useful
  - swap: add default cgroup to swap exec env
  - readahead: bump a device's request_nr when enabling readahead
  - shutdown: properly handle sigtimedwait() timing out
  - main: fix typo in kernel cmdline parameters help
  - ord-tty: properly handle SIGINT/SIGTERM
  - systemctl: automatically spawn temporary password agent
  - ask-password: properly handle multiple pending passwords
  - ask-password: enable plymouth agent by default
  - ask-password: add minimal plymouth password agent
* Tue Oct 26 2010 kay.sievers@novell.com
- new snapshot
  - make sure to pass TERM=linux to all sysv scripts
  - don't unset HOME/TERM when run in session mode
  - mount: add nosuid,nodev,noexec switches to /var/lock and /var/run
  - tmpfiles: Don't clean /var/lock/subsys
  - tmpfiles: Make wtmp match utmp perms, and add btmp
  - umount: Make sure / is remounted ro on shutdown
  - unset HOME and TERM set from the kernel
  - activate wall agent automatically
  - ask-password: add basic tty agent
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - rename ask-password-agent to gnome-ask-password-agent
  - fsck: suppress error message if we cannot change into single
    user mode since
  - dbus: epose FsckPassNo property for service objects
  - man: document systemctl --force
  - introduce 'systemctl kill'
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - syslog: enable kmsg bridge by default
  - fsck: add initial version of fsck and quotacheck wrappers
  - tmpfiles: remove forcefsck/fastboot flag files after boot
  - swap: listen for POLLPRI events on /proc/swaps if availabled
  - tmpfiles: integrate native tmpwatch
  - shutdown: loop only as long as we manage to unmount/detach devices
  - umount: disable dm devices by devnode, not by path name
  - introduce final.target
  - replace distro-specific shutdown scripts with native services
  - try to get rid of DM devices
  - log to console by default
  - introduce kexec.service, kexec.target and exit.target
  - hook in fsck@.service instance for all mount points with passno > 0
  - systemctl: warn if user enables unit with no installation instructions
  - dbus: add introspection to midlevel paths
  - look for dynamic throw-away units in /dev/.systemd/system
  - major rework, use /sbin/swapon for setting up swaps
  - introduce Restart=on-failure and Restart=on-abort
  - units: enable utmp for serial gettys too
  - rename 'banned' load state to 'masked'
  - optionally, create INIT_PROCESS/DEAD_PROCESS entries for a service
- use systemd-native fsck/mount
- use systemd-native tmpfiles.d/ instead of tmpwatch
* Fri Oct  8 2010 kay.sievers@novell.com
  new snapshot
  - fix 'systemctl enable getty@.service'
  - properly support 'banning' of services
  - handle nologin
  - add native reboot/shutdown implementation
* Thu Oct  7 2010 kay.sievers@novell.com
- version 11
* Wed Oct  6 2010 kay.sievers@novell.com
- new snapshot
  - readahead fixes
* Sun Oct  3 2010 aj@suse.de
- /etc/modules.d was renamed to modules-load.d
- only include tmpfiles.d/*conf files
* Wed Sep 29 2010 kay.sievers@novell.com
- don't create sysv order deps on merged units
- fix Provides: handling in LSB headers (network.target)
- native (optional) readahead
* Sun Sep 26 2010 aj@suse.de
- Do not package man pages twice.
* Wed Sep 22 2010 kay.sievers@novell.com
- new snapshot
  - basic services are enabled by default now
* Tue Sep 21 2010 kay.sievers@novell.com
- new snapshot
  - vconsole and locale setup
  - hook up tmpwatch
* Fri Sep 17 2010 kay.sievers@novell.com
- new snapshot
  - add new utility to initialize the virtual console
  - initialize locale from /etc/locale by default
  - ask-password: allow services query SSL/harddisk passphrases
* Fri Sep 17 2010 kay.sievers@novell.com
- version 10
  - logger: support SOCK_STREAM /dev/log sockets
  - make sure the file system is writable before we write utmp data
  - systemctl: use isolate when called as telinit for a runlevel
  - initctl: properly use isolate when activating runlevels
  - set HOME=/root when running shells
  - make sure we don't crash if there's an automount unit without
    mount unit
  - start logger only after syslog is up
* Fri Sep  3 2010 kay.sievers@novell.com
- version 9
  - units: don't add shutdown conflicts dep to umount.target
  - dbus: don't send cgroup agent messages directly to system bus
  - dbus: don't accept activation requests anymore if we are going
    down anyway
  - systemctl: fix return value of systemctl start and friends
  - service: wait for process exit only if we actually killed
    somebody
* Thu Aug 26 2010 kay.sievers@novell.com
- version 8
  - KERNEL 2.6.36+ REQUIRED!
  - mount cgroup file systems to /sys/fs/cgroup instead of /cgroup
  - invoke sulogin instead of /bin/sh
  - systemctl: show timestamps for state changes
  - add global configuration options for handling of auto mounts
* Fri Aug 20 2010 kay.sievers@novell.com
- apply /etc/fstab mount options to all api mounts
- properly handle LABEL="" in fstab
- do not consider LSB exit codes 5 and 6 as failure
* Tue Aug 17 2010 kay.sievers@novell.com
- prefix sysv job descriptions with LSB:
- add native sysctl + hwclock + random seed service files
- properly fallback to rescue.target if default.target is hosed
- rename ValidNoProcess= to RemainAfterExit=
- add systemd-modules-load tool to handle /etc/modules.d/
* Tue Aug 17 2010 kay.sievers@novell.com
- add support for delayed shutdown, similar to sysv in style
- rename Type=finish to Type=oneshot and allow multiple ExecStart=
- don't show ENOENT for non exitent configuration files
- log build time features on startup
- rearrange structs to make them smaller
- move runlevel[2-5] links to /lib
- create default.target link to /lib not /etc
- handle random-seed
- write utmp record before we kill all processes
- create /var/lock/subsys, /var/run/utmp
* Wed Aug 11 2010 kay.sievers@novell.com
- add audit messages for service changes
- update utmp with external program
- all to refuse manual service starting/stopping
* Tue Aug 10 2010 kay.sievers@novell.com
- version 7
  - hide output if quiet is passed on the kernel cmdline
  - fix auto restarting of units after a configuration reload
  - don't call bus_path_escape() with NULL unit name
* Fri Aug  6 2010 kay.sievers@novell.com
- version 6
  - man page update
* Fri Aug  6 2010 kay.sievers@novell.com
- new snapshot
  - downgrade a few log messages
  - properly handle devices which are referenced before they exist
* Thu Aug  5 2010 kay.sievers@novell.com
- new snapshot
  - fix dependency cycle of boot.* by splitting fsck.target
  - sort boot.* before other sysv services
    from sysinint.target
  - start getty for serial console
* Thu Aug  5 2010 kay.sievers@novell.com
- add licence to subpackages
* Wed Aug  4 2010 kay.sievers@novell.com
- version 5
  - selinux fixes
- fix hanging 'reboot' started from vc
* Mon Aug  2 2010 kay.sievers@novell.com
- enable getty.target by default
* Sat Jul 24 2010 kay.sievers@novell.com
- at install, read old inittab for the defaul target/runlevel
- disable services on package uninstall
* Sat Jul 24 2010 kay.sievers@novell.com
- version 4
  - merge systemd-install into systemctl
* Fri Jul 23 2010 kay.sievers@novell.com
- create config files in /etc in %%post
- mark files in /etc as config
- remove nodev from /dev/pts
- add selinux support
* Thu Jul 22 2010 kay.sievers@novell.com
- version 4 (pre)
  - require newer vala
  - add [Install] section to getty.target and remote-fs.target
- re-enable post-build check
* Wed Jul 21 2010 kay.sievers@novell.com
- do not add sysv services that are not enabled in /etc/rcN.d/
- allow symlinking unit files to /dev/null
- remove only pam sessions we ourselves created
- unit files in /etc/ always take precedence, even over link targets
* Tue Jul 20 2010 kay.sievers@novell.com
- fix access mode verification of FIFOs
* Sun Jul 18 2010 kay.sievers@novell.com
- fix default mode of /var/run and /var/lock
- force /var/run and /var/lock to be on tmpfs
* Wed Jul 14 2010 kay.sievers@novell.com
- always enable udev and dbus until we can require systemd from
  packages providing systemd service files
* Tue Jul 13 2010 kay.sievers@novell.com
- drop systemd-units.rpm
* Tue Jul 13 2010 kay.sievers@novell.com
- version 3
  - treat non-existing cgroups like empty ones, to deal with races
  - replace --running-as= by --session and --system
  - always allow stopping of units that failed to load
* Tue Jul 13 2010 kay.sievers@novell.com
- update
* Mon Jul 12 2010 kay.sievers@novell.com
- drop libcgroup
* Mon Jul 12 2010 kay.sievers@novell.com
- trim cgroups for services that are "active" but "exited"
- drop /bin/init hack and require now fixed mkinitrd
* Sun Jul 11 2010 kay.sievers@novell.com
- fix reboot issue
- fix abstract namespace name handling (needs udev update)
- prefer private D-Bus socket wherever possible
* Sat Jul 10 2010 kay.sievers@novell.com
- D-Bus 1.3.2 support
- use COLD_BOOT=1 on reboot to skip sysv boot.d/ handling
* Fri Jul  9 2010 kay.sievers@novell.com
- fix typo in spec file
* Fri Jul  9 2010 kay.sievers@novell.com
- provide /bin/init to be found by 'too simple' mkinitrd, and work
  around mindless relinking of relative links in the buildsystem
- add rpmlintrc to silent warnings about intentional behavior
* Fri Jul  9 2010 kay.sievers@novell.com
- version 2
* Thu Jul  8 2010 kay.sievers@novell.com
- fix 'reboot -w' to skip the actual reboot
- fix segfault in D-Bus code
- use unique instead of multiple keys in config file
- support continuation lines in config files
- support multiple commands in a single key in config files
- adapt log level of some messages
* Wed Jul  7 2010 kay.sievers@novell.com
- version 1
  - default log level to INFO
  - show welcome message
* Tue Jul  6 2010 kay.sievers@novell.com
- add systemd-install --start option
- add more documentation
* Mon Jul  5 2010 kay.sievers@novell.com
- new snapshot with extended D-Bus support
* Sun Jul  4 2010 kay.sievers@novell.com
- new snapshot with default unit dependency handling
* Sat Jul  3 2010 kay.sievers@novell.com
- new snapshot
* Fri Jul  2 2010 kay.sievers@novell.com
- add more documentation
* Thu Jul  1 2010 kay.sievers@novell.com
- new snapshot
* Thu Jun 24 2010 kay.sievers@novell.com
- split off systemd-units.rpm which can be pulled-in by other
  packages without further dependencies
* Thu Jun 24 2010 kay.sievers@novell.com
- add more documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- more man pages and documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- conflict with upstart
- include all installed doc files
* Tue Jun 22 2010 kay.sievers@novell.com
- provide pam module
* Mon Jun 21 2010 kay.sievers@novell.com
- use private D-Bus connection
- properly handle replacing a running upstart
* Fri Jun 18 2010 kay.sievers@novell.com
- implement wall message in halt/reboot/...
- speak /dev/initctl to old /sbin/init after installing
* Thu Jun 17 2010 kay.sievers@novell.com
- drop no longer needed -fno-strict-aliasing
- add README and examples
* Thu Jun 17 2010 kay.sievers@novell.com
- enable pam and libwrap
* Thu Jun 17 2010 kay.sievers@novell.com
- provide systemd-sysvinit.rpm with /sbin/init and friends
* Thu Jun 17 2010 kay.sievers@novell.com
- libwrap / pam support
* Wed Jun 16 2010 kay.sievers@novell.com
- initial packaging of experimental version 0
